""" Cisco_IOS_XR_ip_rsvp_oper 

This module contains a collection of YANG definitions
for Cisco IOS\-XR ip\-rsvp package operational data.

This module contains definitions
for the following management objects\:
  rsvp\-standby\: RSVP operational data for standby role
  rsvp\: rsvp

Copyright (c) 2013\-2016 by Cisco Systems, Inc.
All rights reserved.

"""
from ydk.entity_utils import get_relative_entity_path as _get_relative_entity_path
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YPYError, YPYModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error


class IgpteLibBwModel(Enum):
    """
    IgpteLibBwModel

    Bandwidth model

    .. data:: rdm = 0

    	Russian Dolls Model

    .. data:: mam = 1

    	Maximum Allocation Model

    .. data:: not_set = 2

    	No model set

    """

    rdm = Enum.YLeaf(0, "rdm")

    mam = Enum.YLeaf(1, "mam")

    not_set = Enum.YLeaf(2, "not-set")


class RsvpMgmtAssociation(Enum):
    """
    RsvpMgmtAssociation

    RSVP ASSOCIATION Types

    .. data:: none = 0

    	No ASSOCIATION Object present

    .. data:: ipv4 = 1

    	IPv4 ASSOCIATION Type

    .. data:: ipv6 = 2

    	IPv6 ASSOCIATION Type

    .. data:: extended_ipv4 = 3

    	EXTENDED IPv4 ASSOCIATION Type

    .. data:: extended_ipv6 = 4

    	EXTENDED IPv6 ASSOCIATION Type

    """

    none = Enum.YLeaf(0, "none")

    ipv4 = Enum.YLeaf(1, "ipv4")

    ipv6 = Enum.YLeaf(2, "ipv6")

    extended_ipv4 = Enum.YLeaf(3, "extended-ipv4")

    extended_ipv6 = Enum.YLeaf(4, "extended-ipv6")


class RsvpMgmtAuthChallengeStatus(Enum):
    """
    RsvpMgmtAuthChallengeStatus

    RSVP Authentication Challenge Status

    .. data:: rsvp_mgmt_auth_cs_not_cfg = 0

    	Not configured

    .. data:: rsvp_mgmt_auth_cs_completed = 1

    	Complete

    .. data:: rsvp_mgmt_auth_cs_in_progress = 2

    	In Progress

    .. data:: rsvp_mgmt_auth_cs_failure = 3

    	Failed

    .. data:: rsvp_mgmt_auth_cs_not_supported = 4

    	Not supported

    """

    rsvp_mgmt_auth_cs_not_cfg = Enum.YLeaf(0, "rsvp-mgmt-auth-cs-not-cfg")

    rsvp_mgmt_auth_cs_completed = Enum.YLeaf(1, "rsvp-mgmt-auth-cs-completed")

    rsvp_mgmt_auth_cs_in_progress = Enum.YLeaf(2, "rsvp-mgmt-auth-cs-in-progress")

    rsvp_mgmt_auth_cs_failure = Enum.YLeaf(3, "rsvp-mgmt-auth-cs-failure")

    rsvp_mgmt_auth_cs_not_supported = Enum.YLeaf(4, "rsvp-mgmt-auth-cs-not-supported")


class RsvpMgmtAuthDirection(Enum):
    """
    RsvpMgmtAuthDirection

    RSVP Authentication Direction Types

    .. data:: rsvp_mgmt_auth_direction_send = 0

    	Send

    .. data:: rsvp_mgmt_auth_direction_recv = 1

    	Receive

    """

    rsvp_mgmt_auth_direction_send = Enum.YLeaf(0, "rsvp-mgmt-auth-direction-send")

    rsvp_mgmt_auth_direction_recv = Enum.YLeaf(1, "rsvp-mgmt-auth-direction-recv")


class RsvpMgmtAuthKi(Enum):
    """
    RsvpMgmtAuthKi

    RSVP Authentication KeyInfo Type

    .. data:: rsvp_mgmt_auth_ki_type_none = 0

    	None

    .. data:: rsvp_mgmt_auth_ki_type_global = 1

    	Global

    .. data:: rsvp_mgmt_auth_ki_type_interface = 2

    	Interface

    .. data:: rsvp_mgmt_auth_ki_type_neighbor = 3

    	Neighbor

    """

    rsvp_mgmt_auth_ki_type_none = Enum.YLeaf(0, "rsvp-mgmt-auth-ki-type-none")

    rsvp_mgmt_auth_ki_type_global = Enum.YLeaf(1, "rsvp-mgmt-auth-ki-type-global")

    rsvp_mgmt_auth_ki_type_interface = Enum.YLeaf(2, "rsvp-mgmt-auth-ki-type-interface")

    rsvp_mgmt_auth_ki_type_neighbor = Enum.YLeaf(3, "rsvp-mgmt-auth-ki-type-neighbor")


class RsvpMgmtDsteModes(Enum):
    """
    RsvpMgmtDsteModes

    RSVP DSTE modes

    .. data:: pre_standard = 1

    	pre standard

    .. data:: standard = 3

    	standard

    """

    pre_standard = Enum.YLeaf(1, "pre-standard")

    standard = Enum.YLeaf(3, "standard")


class RsvpMgmtEroSubobj(Enum):
    """
    RsvpMgmtEroSubobj

    RSVP ERO Types

    .. data:: rsvp_mgmt_ero_type_ipv4 = 1

    	IPv4 ERO Type

    .. data:: rsvp_mgmt_ero_type_un_num = 4

    	Unnumbered ERO Type

    """

    rsvp_mgmt_ero_type_ipv4 = Enum.YLeaf(1, "rsvp-mgmt-ero-type-ipv4")

    rsvp_mgmt_ero_type_un_num = Enum.YLeaf(4, "rsvp-mgmt-ero-type-un-num")


class RsvpMgmtEroSubobjStatus(Enum):
    """
    RsvpMgmtEroSubobjStatus

    RSVP ERO Status

    .. data:: rsvp_mgmt_ero_status_not_available = 0

    	ERO is not available in topology

    .. data:: rsvp_mgmt_ero_status_available = 1

    	ERO is available in topology

    .. data:: rsvp_mgmt_ero_status_bw_not_available = 2

    	ERO doesn't have bw available in topology

    """

    rsvp_mgmt_ero_status_not_available = Enum.YLeaf(0, "rsvp-mgmt-ero-status-not-available")

    rsvp_mgmt_ero_status_available = Enum.YLeaf(1, "rsvp-mgmt-ero-status-available")

    rsvp_mgmt_ero_status_bw_not_available = Enum.YLeaf(2, "rsvp-mgmt-ero-status-bw-not-available")


class RsvpMgmtFilter(Enum):
    """
    RsvpMgmtFilter

    RSVP Filter Types

    .. data:: rsvp_mgmt_filter_type_ipv4 = 1

    	IPv4 FilterSpec Type

    .. data:: rsvp_mgmt_filter_type_p2mp_lsp_ipv4 = 12

    	P2MP LSP IPv4 FilterSpec Type

    """

    rsvp_mgmt_filter_type_ipv4 = Enum.YLeaf(1, "rsvp-mgmt-filter-type-ipv4")

    rsvp_mgmt_filter_type_p2mp_lsp_ipv4 = Enum.YLeaf(12, "rsvp-mgmt-filter-type-p2mp-lsp-ipv4")


class RsvpMgmtFlowSpec(Enum):
    """
    RsvpMgmtFlowSpec

    RSVP Generic FlowSpec Types

    .. data:: g709otn = 5

    	G709 OTN FlowSpec Type

    """

    g709otn = Enum.YLeaf(5, "g709otn")


class RsvpMgmtFrrStateEnum(Enum):
    """
    RsvpMgmtFrrStateEnum

    RSVP FRR States

    .. data:: ready_state = 0

    	Ready State

    .. data:: pending_state = 1

    	Pending

    .. data:: active_state = 2

    	Active State

    """

    ready_state = Enum.YLeaf(0, "ready-state")

    pending_state = Enum.YLeaf(1, "pending-state")

    active_state = Enum.YLeaf(2, "active-state")


class RsvpMgmtGenericLabel(Enum):
    """
    RsvpMgmtGenericLabel

    RSVP Generic Label Types

    .. data:: rsvp_mgmt_label_type_gmpls = 2

    	Generalized Label Type

    """

    rsvp_mgmt_label_type_gmpls = Enum.YLeaf(2, "rsvp-mgmt-label-type-gmpls")


class RsvpMgmtGrApp(Enum):
    """
    RsvpMgmtGrApp

    RSVP Graceful Restart application type

    .. data:: ouni = 0

    	Application is OUNI

    .. data:: gmpls = 1

    	Application is GMPLS

    """

    ouni = Enum.YLeaf(0, "ouni")

    gmpls = Enum.YLeaf(1, "gmpls")


class RsvpMgmtHelloDownReason(Enum):
    """
    RsvpMgmtHelloDownReason

    Reasons why RSVP Hellos went down

    .. data:: not_applicable = 0

    	Not applicable. This means RSVP Hellos are up

    .. data:: wrong_destination_instance = 1

    	Incorrect destination instance in received

    	Hellos

    .. data:: wrong_source_instance = 2

    	Incorrect source instance in received Hellos

    .. data:: hello_missed = 3

    	Hellos not being received

    .. data:: interface_down = 4

    	Interface went down

    .. data:: neighbor_disabled_hello = 5

    	Neighbor disabled Hellos

    .. data:: control_channel_down = 6

    	Control channel went down

    """

    not_applicable = Enum.YLeaf(0, "not-applicable")

    wrong_destination_instance = Enum.YLeaf(1, "wrong-destination-instance")

    wrong_source_instance = Enum.YLeaf(2, "wrong-source-instance")

    hello_missed = Enum.YLeaf(3, "hello-missed")

    interface_down = Enum.YLeaf(4, "interface-down")

    neighbor_disabled_hello = Enum.YLeaf(5, "neighbor-disabled-hello")

    control_channel_down = Enum.YLeaf(6, "control-channel-down")


class RsvpMgmtHelloInstance(Enum):
    """
    RsvpMgmtHelloInstance

    RSVP Hello instance types

    .. data:: active = 0

    	Hello requests and ACKs are sent

    .. data:: passive = 1

    	Hello ACKs only are sent

    """

    active = Enum.YLeaf(0, "active")

    passive = Enum.YLeaf(1, "passive")


class RsvpMgmtHelloInstanceOwner(Enum):
    """
    RsvpMgmtHelloInstanceOwner

    RSVP Hello instance owner

    .. data:: mpls_graceful_restart = 0

    	MPLS Graceful Restart

    .. data:: mpls_ouni = 1

    	MPLS OUNI

    """

    mpls_graceful_restart = Enum.YLeaf(0, "mpls-graceful-restart")

    mpls_ouni = Enum.YLeaf(1, "mpls-ouni")


class RsvpMgmtHelloState(Enum):
    """
    RsvpMgmtHelloState

    RSVP Hello instance states

    .. data:: hello_state_init = 0

    	No Hello messages ever received from neighbor

    .. data:: hello_state_up = 1

    	Receiving expected Hello messages from neighbor

    .. data:: hello_state_down = 2

    	Stopped receiving expected Hello messages from

    	neighbor

    """

    hello_state_init = Enum.YLeaf(0, "hello-state-init")

    hello_state_up = Enum.YLeaf(1, "hello-state-up")

    hello_state_down = Enum.YLeaf(2, "hello-state-down")


class RsvpMgmtQosServiceEnum(Enum):
    """
    RsvpMgmtQosServiceEnum

    QOS Types

    .. data:: rsvp_mgmt_qos_unknown = 0

    	QOS Unknown

    .. data:: rsvp_mgmt_qos_guaranteed = 3

    	QOS Guaranteed

    .. data:: rsvp_mgmt_qos_controlled_load = 5

    	QOS Controlled Load

    .. data:: rsvp_mgmt_qos_qualitative = 6

    	QOS Qualitative

    """

    rsvp_mgmt_qos_unknown = Enum.YLeaf(0, "rsvp-mgmt-qos-unknown")

    rsvp_mgmt_qos_guaranteed = Enum.YLeaf(3, "rsvp-mgmt-qos-guaranteed")

    rsvp_mgmt_qos_controlled_load = Enum.YLeaf(5, "rsvp-mgmt-qos-controlled-load")

    rsvp_mgmt_qos_qualitative = Enum.YLeaf(6, "rsvp-mgmt-qos-qualitative")


class RsvpMgmtReservationTypeEnum(Enum):
    """
    RsvpMgmtReservationTypeEnum

    RSVP Reservation Types

    .. data:: rsvp_mgmt_ff_option = 10

    	Single Reservation

    .. data:: rsvp_mgmt_wf_option = 17

    	Shared Reservation, Unlimited Scope

    .. data:: rsvp_mgmt_se_option = 18

    	Shared Reservation, Limited Scope

    """

    rsvp_mgmt_ff_option = Enum.YLeaf(10, "rsvp-mgmt-ff-option")

    rsvp_mgmt_wf_option = Enum.YLeaf(17, "rsvp-mgmt-wf-option")

    rsvp_mgmt_se_option = Enum.YLeaf(18, "rsvp-mgmt-se-option")


class RsvpMgmtRestartState(Enum):
    """
    RsvpMgmtRestartState

    RSVP GR (Graceful Restart) Restart states

    .. data:: done = 0

    	Restart is done

    .. data:: recovery = 1

    	Neighbor is in recovery

    .. data:: abort = 2

    	Neighbor recovery aborted

    """

    done = Enum.YLeaf(0, "done")

    recovery = Enum.YLeaf(1, "recovery")

    abort = Enum.YLeaf(2, "abort")


class RsvpMgmtRroSubobj(Enum):
    """
    RsvpMgmtRroSubobj

    RSVP RRO Types

    .. data:: ipv4rro_type = 1

    	IPv4 RRO Type

    .. data:: label_rro_type = 3

    	Label RRO Type

    .. data:: unnumbered_rro_type = 4

    	Unnumbered RRO Type

    .. data:: srlg_rro_type = 34

    	SRLG RRO Type

    """

    ipv4rro_type = Enum.YLeaf(1, "ipv4rro-type")

    label_rro_type = Enum.YLeaf(3, "label-rro-type")

    unnumbered_rro_type = Enum.YLeaf(4, "unnumbered-rro-type")

    srlg_rro_type = Enum.YLeaf(34, "srlg-rro-type")


class RsvpMgmtSession(Enum):
    """
    RsvpMgmtSession

    RSVP Session Types

    .. data:: rsvp_mgmt_session_type_udp_ipv4 = 1

    	UDP IPv4 Session Type

    .. data:: rsvp_mgmt_session_type_lsp_ipv4 = 7

    	LSP IPv4 Session Type

    .. data:: rsvp_mgmt_session_type_uni_ipv4 = 9

    	UNI IPv4 Session Type

    .. data:: rsvp_mgmt_session_type_p2mp_lsp_ipv4 = 13

    	P2MP LSP IPv4 Session Type

    """

    rsvp_mgmt_session_type_udp_ipv4 = Enum.YLeaf(1, "rsvp-mgmt-session-type-udp-ipv4")

    rsvp_mgmt_session_type_lsp_ipv4 = Enum.YLeaf(7, "rsvp-mgmt-session-type-lsp-ipv4")

    rsvp_mgmt_session_type_uni_ipv4 = Enum.YLeaf(9, "rsvp-mgmt-session-type-uni-ipv4")

    rsvp_mgmt_session_type_p2mp_lsp_ipv4 = Enum.YLeaf(13, "rsvp-mgmt-session-type-p2mp-lsp-ipv4")


class RsvpMgmtTspec(Enum):
    """
    RsvpMgmtTspec

    RSVP Generic Sender Tspec Types

    .. data:: g709otn = 5

    	G709 OTN Sender Tspec Type

    .. data:: intsrv = 12

    	Int-Serv Sender Tspec Type

    """

    g709otn = Enum.YLeaf(5, "g709otn")

    intsrv = Enum.YLeaf(12, "intsrv")


class RsvpMode(Enum):
    """
    RsvpMode

    Rsvp mode

    .. data:: send = 0

    	Send

    .. data:: receive = 1

    	Receive

    """

    send = Enum.YLeaf(0, "send")

    receive = Enum.YLeaf(1, "receive")


class RsvpProcNsrNotReadyReason(Enum):
    """
    RsvpProcNsrNotReadyReason

    Rsvp proc nsr not ready reason

    .. data:: collab_time_out = 0

    	Collab connection time out

    .. data:: collab_conntection_idt = 1

    	Collab connection down or IDT not done

    .. data:: nsr_peer_not_connected = 2

    	NSR peer not connected

    .. data:: nsr_peer_not_in_sync = 3

    	NSR peer not in sync

    """

    collab_time_out = Enum.YLeaf(0, "collab-time-out")

    collab_conntection_idt = Enum.YLeaf(1, "collab-conntection-idt")

    nsr_peer_not_connected = Enum.YLeaf(2, "nsr-peer-not-connected")

    nsr_peer_not_in_sync = Enum.YLeaf(3, "nsr-peer-not-in-sync")


class RsvpProcRole(Enum):
    """
    RsvpProcRole

    RSVP Process Role

    .. data:: unknown = 0

    	Unknown

    .. data:: v1_active = 1

    	V1 Active

    .. data:: v1_standby = 2

    	V1 Standby

    .. data:: v2_active = 3

    	V2 Active

    .. data:: v2_standby = 4

    	V2 Standby

    .. data:: v1_active_post_big_bang = 5

    	V1 Active post big-bang

    .. data:: v1_standby_post_big_bang = 6

    	V1 Standbyi post big-bang

    .. data:: count = 7

    	Count

    """

    unknown = Enum.YLeaf(0, "unknown")

    v1_active = Enum.YLeaf(1, "v1-active")

    v1_standby = Enum.YLeaf(2, "v1-standby")

    v2_active = Enum.YLeaf(3, "v2-active")

    v2_standby = Enum.YLeaf(4, "v2-standby")

    v1_active_post_big_bang = Enum.YLeaf(5, "v1-active-post-big-bang")

    v1_standby_post_big_bang = Enum.YLeaf(6, "v1-standby-post-big-bang")

    count = Enum.YLeaf(7, "count")


class RsvpSession(Enum):
    """
    RsvpSession

    Rsvp session

    .. data:: ipv4 = 1

    	Show IPv4 sessions only

    .. data:: p2p_lsp_ipv4 = 7

    	Show IPv4 P2P LSP sessions only

    .. data:: ouni_ipv4 = 9

    	Show IPv4 OUNI sessions only

    .. data:: p2mp_lsp_ipv4 = 13

    	Show IPv4 P2MP LSP sessions only

    """

    ipv4 = Enum.YLeaf(1, "ipv4")

    p2p_lsp_ipv4 = Enum.YLeaf(7, "p2p-lsp-ipv4")

    ouni_ipv4 = Enum.YLeaf(9, "ouni-ipv4")

    p2mp_lsp_ipv4 = Enum.YLeaf(13, "p2mp-lsp-ipv4")


class RsvpSyncStatus(Enum):
    """
    RsvpSyncStatus

    Rsvp sync status

    .. data:: not_ready = 0

    	Not Ready

    .. data:: ready = 1

    	Ready

    """

    not_ready = Enum.YLeaf(0, "not-ready")

    ready = Enum.YLeaf(1, "ready")


class RsvpTimerState(Enum):
    """
    RsvpTimerState

    RSVP Timer States

    .. data:: rsvp_timer_running_and_sleeping = 1

    	RSVP timer running and sleeping

    .. data:: rsvp_timer_running = 2

    	RSVP timer running

    .. data:: rsvp_timer_not_running = 3

    	RSVP timer not running

    """

    rsvp_timer_running_and_sleeping = Enum.YLeaf(1, "rsvp-timer-running-and-sleeping")

    rsvp_timer_running = Enum.YLeaf(2, "rsvp-timer-running")

    rsvp_timer_not_running = Enum.YLeaf(3, "rsvp-timer-not-running")



class RsvpStandby(Entity):
    """
    RSVP operational data for standby role
    
    .. attribute:: authentication_briefs
    
    	Table for Authentication related information
    	**type**\:   :py:class:`AuthenticationBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.AuthenticationBriefs>`
    
    .. attribute:: authentication_details
    
    	Table for detailed authentication related information
    	**type**\:   :py:class:`AuthenticationDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.AuthenticationDetails>`
    
    .. attribute:: controller_briefs
    
    	Table of brief info about RSVP\-enabled controller
    	**type**\:   :py:class:`ControllerBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.ControllerBriefs>`
    
    .. attribute:: controller_detaileds
    
    	Table of detailed info about RSVP\-enabled controllers
    	**type**\:   :py:class:`ControllerDetaileds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.ControllerDetaileds>`
    
    .. attribute:: controller_summaries
    
    	Table of summary info about RSVP\-enabled controllers
    	**type**\:   :py:class:`ControllerSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.ControllerSummaries>`
    
    .. attribute:: counters
    
    	Counters
    	**type**\:   :py:class:`Counters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Counters>`
    
    .. attribute:: frr_summary
    
    	Fast Re\-Route Summary State Information
    	**type**\:   :py:class:`FrrSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.FrrSummary>`
    
    .. attribute:: frrs
    
    	Table of detailed info about Fast Re\-route states
    	**type**\:   :py:class:`Frrs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Frrs>`
    
    .. attribute:: global_neighbor_briefs
    
    	Table of brief info about global neighbors
    	**type**\:   :py:class:`GlobalNeighborBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.GlobalNeighborBriefs>`
    
    .. attribute:: global_neighbor_details
    
    	Table of detailed info about global neighbors
    	**type**\:   :py:class:`GlobalNeighborDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.GlobalNeighborDetails>`
    
    .. attribute:: graceful_restart
    
    	Info about graceful\-restart
    	**type**\:   :py:class:`GracefulRestart <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.GracefulRestart>`
    
    .. attribute:: hello_instance_briefs
    
    	Table of brief info about hello instances
    	**type**\:   :py:class:`HelloInstanceBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.HelloInstanceBriefs>`
    
    .. attribute:: hello_instance_details
    
    	Table of detailed info about hello instances
    	**type**\:   :py:class:`HelloInstanceDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.HelloInstanceDetails>`
    
    .. attribute:: hello_interface_instance_briefs
    
    	Table of brief info about i/f\-based hello instances
    	**type**\:   :py:class:`HelloInterfaceInstanceBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.HelloInterfaceInstanceBriefs>`
    
    .. attribute:: hello_interface_instance_details
    
    	Table of detailed info about i/f\-based hello instances
    	**type**\:   :py:class:`HelloInterfaceInstanceDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.HelloInterfaceInstanceDetails>`
    
    .. attribute:: interface_briefs
    
    	Table of brief info about RSVP\-enabled interfaces
    	**type**\:   :py:class:`InterfaceBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.InterfaceBriefs>`
    
    .. attribute:: interface_detaileds
    
    	Table of detailed info about RSVP\-enabled interfaces
    	**type**\:   :py:class:`InterfaceDetaileds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.InterfaceDetaileds>`
    
    .. attribute:: interface_neighbor_briefs
    
    	Table of brief info about I/F neighbors
    	**type**\:   :py:class:`InterfaceNeighborBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.InterfaceNeighborBriefs>`
    
    .. attribute:: interface_neighbor_details
    
    	Table of detailed info about I/F neighbors
    	**type**\:   :py:class:`InterfaceNeighborDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.InterfaceNeighborDetails>`
    
    .. attribute:: interface_summaries
    
    	Table of summary info about RSVP\-enabled interfaces
    	**type**\:   :py:class:`InterfaceSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.InterfaceSummaries>`
    
    .. attribute:: nsr
    
    	RSVP NSR information
    	**type**\:   :py:class:`Nsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Nsr>`
    
    .. attribute:: open_config
    
    	OpenConfig info
    	**type**\:   :py:class:`OpenConfig <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.OpenConfig>`
    
    .. attribute:: psb_briefs
    
    	Table of brief info about path state blocks
    	**type**\:   :py:class:`PsbBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbBriefs>`
    
    .. attribute:: psb_detaileds
    
    	Table of detailed info about path state blocks
    	**type**\:   :py:class:`PsbDetaileds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbDetaileds>`
    
    .. attribute:: request_briefs
    
    	Table of brief info about requests
    	**type**\:   :py:class:`RequestBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RequestBriefs>`
    
    .. attribute:: request_details
    
    	Table of detail info about requests
    	**type**\:   :py:class:`RequestDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RequestDetails>`
    
    .. attribute:: rsb_briefs
    
    	Table of brief info about reservation state blocks
    	**type**\:   :py:class:`RsbBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RsbBriefs>`
    
    .. attribute:: rsb_detaileds
    
    	Table of detailed info about reservation state blocks
    	**type**\:   :py:class:`RsbDetaileds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RsbDetaileds>`
    
    .. attribute:: session_briefs
    
    	Table of brief info about sessions
    	**type**\:   :py:class:`SessionBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionBriefs>`
    
    .. attribute:: session_detaileds
    
    	Table of detailed info about sessions
    	**type**\:   :py:class:`SessionDetaileds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds>`
    
    .. attribute:: summary
    
    	RSVP summary information
    	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Summary>`
    
    

    """

    _prefix = 'ip-rsvp-oper'
    _revision = '2015-11-09'

    def __init__(self):
        super(RsvpStandby, self).__init__()
        self._top_entity = None

        self.yang_name = "rsvp-standby"
        self.yang_parent_name = "Cisco-IOS-XR-ip-rsvp-oper"

        self.authentication_briefs = RsvpStandby.AuthenticationBriefs()
        self.authentication_briefs.parent = self
        self._children_name_map["authentication_briefs"] = "authentication-briefs"
        self._children_yang_names.add("authentication-briefs")

        self.authentication_details = RsvpStandby.AuthenticationDetails()
        self.authentication_details.parent = self
        self._children_name_map["authentication_details"] = "authentication-details"
        self._children_yang_names.add("authentication-details")

        self.controller_briefs = RsvpStandby.ControllerBriefs()
        self.controller_briefs.parent = self
        self._children_name_map["controller_briefs"] = "controller-briefs"
        self._children_yang_names.add("controller-briefs")

        self.controller_detaileds = RsvpStandby.ControllerDetaileds()
        self.controller_detaileds.parent = self
        self._children_name_map["controller_detaileds"] = "controller-detaileds"
        self._children_yang_names.add("controller-detaileds")

        self.controller_summaries = RsvpStandby.ControllerSummaries()
        self.controller_summaries.parent = self
        self._children_name_map["controller_summaries"] = "controller-summaries"
        self._children_yang_names.add("controller-summaries")

        self.counters = RsvpStandby.Counters()
        self.counters.parent = self
        self._children_name_map["counters"] = "counters"
        self._children_yang_names.add("counters")

        self.frr_summary = RsvpStandby.FrrSummary()
        self.frr_summary.parent = self
        self._children_name_map["frr_summary"] = "frr-summary"
        self._children_yang_names.add("frr-summary")

        self.frrs = RsvpStandby.Frrs()
        self.frrs.parent = self
        self._children_name_map["frrs"] = "frrs"
        self._children_yang_names.add("frrs")

        self.global_neighbor_briefs = RsvpStandby.GlobalNeighborBriefs()
        self.global_neighbor_briefs.parent = self
        self._children_name_map["global_neighbor_briefs"] = "global-neighbor-briefs"
        self._children_yang_names.add("global-neighbor-briefs")

        self.global_neighbor_details = RsvpStandby.GlobalNeighborDetails()
        self.global_neighbor_details.parent = self
        self._children_name_map["global_neighbor_details"] = "global-neighbor-details"
        self._children_yang_names.add("global-neighbor-details")

        self.graceful_restart = RsvpStandby.GracefulRestart()
        self.graceful_restart.parent = self
        self._children_name_map["graceful_restart"] = "graceful-restart"
        self._children_yang_names.add("graceful-restart")

        self.hello_instance_briefs = RsvpStandby.HelloInstanceBriefs()
        self.hello_instance_briefs.parent = self
        self._children_name_map["hello_instance_briefs"] = "hello-instance-briefs"
        self._children_yang_names.add("hello-instance-briefs")

        self.hello_instance_details = RsvpStandby.HelloInstanceDetails()
        self.hello_instance_details.parent = self
        self._children_name_map["hello_instance_details"] = "hello-instance-details"
        self._children_yang_names.add("hello-instance-details")

        self.hello_interface_instance_briefs = RsvpStandby.HelloInterfaceInstanceBriefs()
        self.hello_interface_instance_briefs.parent = self
        self._children_name_map["hello_interface_instance_briefs"] = "hello-interface-instance-briefs"
        self._children_yang_names.add("hello-interface-instance-briefs")

        self.hello_interface_instance_details = RsvpStandby.HelloInterfaceInstanceDetails()
        self.hello_interface_instance_details.parent = self
        self._children_name_map["hello_interface_instance_details"] = "hello-interface-instance-details"
        self._children_yang_names.add("hello-interface-instance-details")

        self.interface_briefs = RsvpStandby.InterfaceBriefs()
        self.interface_briefs.parent = self
        self._children_name_map["interface_briefs"] = "interface-briefs"
        self._children_yang_names.add("interface-briefs")

        self.interface_detaileds = RsvpStandby.InterfaceDetaileds()
        self.interface_detaileds.parent = self
        self._children_name_map["interface_detaileds"] = "interface-detaileds"
        self._children_yang_names.add("interface-detaileds")

        self.interface_neighbor_briefs = RsvpStandby.InterfaceNeighborBriefs()
        self.interface_neighbor_briefs.parent = self
        self._children_name_map["interface_neighbor_briefs"] = "interface-neighbor-briefs"
        self._children_yang_names.add("interface-neighbor-briefs")

        self.interface_neighbor_details = RsvpStandby.InterfaceNeighborDetails()
        self.interface_neighbor_details.parent = self
        self._children_name_map["interface_neighbor_details"] = "interface-neighbor-details"
        self._children_yang_names.add("interface-neighbor-details")

        self.interface_summaries = RsvpStandby.InterfaceSummaries()
        self.interface_summaries.parent = self
        self._children_name_map["interface_summaries"] = "interface-summaries"
        self._children_yang_names.add("interface-summaries")

        self.nsr = RsvpStandby.Nsr()
        self.nsr.parent = self
        self._children_name_map["nsr"] = "nsr"
        self._children_yang_names.add("nsr")

        self.open_config = RsvpStandby.OpenConfig()
        self.open_config.parent = self
        self._children_name_map["open_config"] = "open-config"
        self._children_yang_names.add("open-config")

        self.psb_briefs = RsvpStandby.PsbBriefs()
        self.psb_briefs.parent = self
        self._children_name_map["psb_briefs"] = "psb-briefs"
        self._children_yang_names.add("psb-briefs")

        self.psb_detaileds = RsvpStandby.PsbDetaileds()
        self.psb_detaileds.parent = self
        self._children_name_map["psb_detaileds"] = "psb-detaileds"
        self._children_yang_names.add("psb-detaileds")

        self.request_briefs = RsvpStandby.RequestBriefs()
        self.request_briefs.parent = self
        self._children_name_map["request_briefs"] = "request-briefs"
        self._children_yang_names.add("request-briefs")

        self.request_details = RsvpStandby.RequestDetails()
        self.request_details.parent = self
        self._children_name_map["request_details"] = "request-details"
        self._children_yang_names.add("request-details")

        self.rsb_briefs = RsvpStandby.RsbBriefs()
        self.rsb_briefs.parent = self
        self._children_name_map["rsb_briefs"] = "rsb-briefs"
        self._children_yang_names.add("rsb-briefs")

        self.rsb_detaileds = RsvpStandby.RsbDetaileds()
        self.rsb_detaileds.parent = self
        self._children_name_map["rsb_detaileds"] = "rsb-detaileds"
        self._children_yang_names.add("rsb-detaileds")

        self.session_briefs = RsvpStandby.SessionBriefs()
        self.session_briefs.parent = self
        self._children_name_map["session_briefs"] = "session-briefs"
        self._children_yang_names.add("session-briefs")

        self.session_detaileds = RsvpStandby.SessionDetaileds()
        self.session_detaileds.parent = self
        self._children_name_map["session_detaileds"] = "session-detaileds"
        self._children_yang_names.add("session-detaileds")

        self.summary = RsvpStandby.Summary()
        self.summary.parent = self
        self._children_name_map["summary"] = "summary"
        self._children_yang_names.add("summary")


    class InterfaceNeighborBriefs(Entity):
        """
        Table of brief info about I/F neighbors
        
        .. attribute:: interface_neighbor_brief
        
        	Brief info for a single interface neighbor
        	**type**\: list of    :py:class:`InterfaceNeighborBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.InterfaceNeighborBriefs.InterfaceNeighborBrief>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(RsvpStandby.InterfaceNeighborBriefs, self).__init__()

            self.yang_name = "interface-neighbor-briefs"
            self.yang_parent_name = "rsvp-standby"

            self.interface_neighbor_brief = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(RsvpStandby.InterfaceNeighborBriefs, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(RsvpStandby.InterfaceNeighborBriefs, self).__setattr__(name, value)


        class InterfaceNeighborBrief(Entity):
            """
            Brief info for a single interface neighbor
            
            .. attribute:: neighbor_address  <key>
            
            	Address of global neighbor
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: interface_neighbor_list_compact
            
            	Compact list of I/F Neighbors
            	**type**\: list of    :py:class:`InterfaceNeighborListCompact <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.InterfaceNeighborBriefs.InterfaceNeighborBrief.InterfaceNeighborListCompact>`
            
            .. attribute:: node_address
            
            	Neighbor node address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(RsvpStandby.InterfaceNeighborBriefs.InterfaceNeighborBrief, self).__init__()

                self.yang_name = "interface-neighbor-brief"
                self.yang_parent_name = "interface-neighbor-briefs"

                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                self.node_address = YLeaf(YType.str, "node-address")

                self.interface_neighbor_list_compact = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("neighbor_address",
                                "node_address") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(RsvpStandby.InterfaceNeighborBriefs.InterfaceNeighborBrief, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(RsvpStandby.InterfaceNeighborBriefs.InterfaceNeighborBrief, self).__setattr__(name, value)


            class InterfaceNeighborListCompact(Entity):
                """
                Compact list of I/F Neighbors
                
                .. attribute:: interface_neighbor_address
                
                	Interface Neighbor address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: neighbor_interface_name
                
                	Neighbor's Interface handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.InterfaceNeighborBriefs.InterfaceNeighborBrief.InterfaceNeighborListCompact, self).__init__()

                    self.yang_name = "interface-neighbor-list-compact"
                    self.yang_parent_name = "interface-neighbor-brief"

                    self.interface_neighbor_address = YLeaf(YType.str, "interface-neighbor-address")

                    self.neighbor_interface_name = YLeaf(YType.str, "neighbor-interface-name")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("interface_neighbor_address",
                                    "neighbor_interface_name") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.InterfaceNeighborBriefs.InterfaceNeighborBrief.InterfaceNeighborListCompact, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.InterfaceNeighborBriefs.InterfaceNeighborBrief.InterfaceNeighborListCompact, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.interface_neighbor_address.is_set or
                        self.neighbor_interface_name.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.interface_neighbor_address.yfilter != YFilter.not_set or
                        self.neighbor_interface_name.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "interface-neighbor-list-compact" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.interface_neighbor_address.is_set or self.interface_neighbor_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface_neighbor_address.get_name_leafdata())
                    if (self.neighbor_interface_name.is_set or self.neighbor_interface_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.neighbor_interface_name.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface-neighbor-address" or name == "neighbor-interface-name"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "interface-neighbor-address"):
                        self.interface_neighbor_address = value
                        self.interface_neighbor_address.value_namespace = name_space
                        self.interface_neighbor_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "neighbor-interface-name"):
                        self.neighbor_interface_name = value
                        self.neighbor_interface_name.value_namespace = name_space
                        self.neighbor_interface_name.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.interface_neighbor_list_compact:
                    if (c.has_data()):
                        return True
                return (
                    self.neighbor_address.is_set or
                    self.node_address.is_set)

            def has_operation(self):
                for c in self.interface_neighbor_list_compact:
                    if (c.has_operation()):
                        return True
                return (
                    self.yfilter != YFilter.not_set or
                    self.neighbor_address.yfilter != YFilter.not_set or
                    self.node_address.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "interface-neighbor-brief" + "[neighbor-address='" + self.neighbor_address.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/interface-neighbor-briefs/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                if (self.node_address.is_set or self.node_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.node_address.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "interface-neighbor-list-compact"):
                    for c in self.interface_neighbor_list_compact:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = RsvpStandby.InterfaceNeighborBriefs.InterfaceNeighborBrief.InterfaceNeighborListCompact()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.interface_neighbor_list_compact.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "interface-neighbor-list-compact" or name == "neighbor-address" or name == "node-address"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "neighbor-address"):
                    self.neighbor_address = value
                    self.neighbor_address.value_namespace = name_space
                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                if(value_path == "node-address"):
                    self.node_address = value
                    self.node_address.value_namespace = name_space
                    self.node_address.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.interface_neighbor_brief:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.interface_neighbor_brief:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "interface-neighbor-briefs" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "interface-neighbor-brief"):
                for c in self.interface_neighbor_brief:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = RsvpStandby.InterfaceNeighborBriefs.InterfaceNeighborBrief()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.interface_neighbor_brief.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "interface-neighbor-brief"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class ControllerSummaries(Entity):
        """
        Table of summary info about RSVP\-enabled
        controllers
        
        .. attribute:: controller_summary
        
        	Summary info about an RSVP\-enabled controller
        	**type**\: list of    :py:class:`ControllerSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.ControllerSummaries.ControllerSummary>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(RsvpStandby.ControllerSummaries, self).__init__()

            self.yang_name = "controller-summaries"
            self.yang_parent_name = "rsvp-standby"

            self.controller_summary = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(RsvpStandby.ControllerSummaries, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(RsvpStandby.ControllerSummaries, self).__setattr__(name, value)


        class ControllerSummary(Entity):
            """
            Summary info about an RSVP\-enabled controller
            
            .. attribute:: controller_name  <key>
            
            	Controller Name
            	**type**\:  str
            
            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
            
            .. attribute:: bandwidth_information
            
            	Interface bandwidth information
            	**type**\:   :py:class:`BandwidthInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.ControllerSummaries.ControllerSummary.BandwidthInformation>`
            
            .. attribute:: interface_name_xr
            
            	Interface Name
            	**type**\:  str
            
            .. attribute:: paths_in
            
            	Number of locally created and incoming path states
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: paths_out
            
            	Number of outgoing path states
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: reservations_in
            
            	Number of locally created and incoming reservation states
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: reservations_out
            
            	Number of outgoing reservation states
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(RsvpStandby.ControllerSummaries.ControllerSummary, self).__init__()

                self.yang_name = "controller-summary"
                self.yang_parent_name = "controller-summaries"

                self.controller_name = YLeaf(YType.str, "controller-name")

                self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                self.paths_in = YLeaf(YType.uint32, "paths-in")

                self.paths_out = YLeaf(YType.uint32, "paths-out")

                self.reservations_in = YLeaf(YType.uint32, "reservations-in")

                self.reservations_out = YLeaf(YType.uint32, "reservations-out")

                self.bandwidth_information = RsvpStandby.ControllerSummaries.ControllerSummary.BandwidthInformation()
                self.bandwidth_information.parent = self
                self._children_name_map["bandwidth_information"] = "bandwidth-information"
                self._children_yang_names.add("bandwidth-information")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("controller_name",
                                "interface_name_xr",
                                "paths_in",
                                "paths_out",
                                "reservations_in",
                                "reservations_out") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(RsvpStandby.ControllerSummaries.ControllerSummary, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(RsvpStandby.ControllerSummaries.ControllerSummary, self).__setattr__(name, value)


            class BandwidthInformation(Entity):
                """
                Interface bandwidth information
                
                .. attribute:: dste_mode
                
                	DSTEMode
                	**type**\:   :py:class:`RsvpMgmtDsteModes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtDsteModes>`
                
                .. attribute:: pre_standard_dste_interface
                
                	Prestandard DSTE interface information
                	**type**\:   :py:class:`PreStandardDsteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.ControllerSummaries.ControllerSummary.BandwidthInformation.PreStandardDsteInterface>`
                
                .. attribute:: standard_dste_interface
                
                	Standard DSTE interface information
                	**type**\:   :py:class:`StandardDsteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.ControllerSummaries.ControllerSummary.BandwidthInformation.StandardDsteInterface>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.ControllerSummaries.ControllerSummary.BandwidthInformation, self).__init__()

                    self.yang_name = "bandwidth-information"
                    self.yang_parent_name = "controller-summary"

                    self.dste_mode = YLeaf(YType.enumeration, "dste-mode")

                    self.pre_standard_dste_interface = RsvpStandby.ControllerSummaries.ControllerSummary.BandwidthInformation.PreStandardDsteInterface()
                    self.pre_standard_dste_interface.parent = self
                    self._children_name_map["pre_standard_dste_interface"] = "pre-standard-dste-interface"
                    self._children_yang_names.add("pre-standard-dste-interface")

                    self.standard_dste_interface = RsvpStandby.ControllerSummaries.ControllerSummary.BandwidthInformation.StandardDsteInterface()
                    self.standard_dste_interface.parent = self
                    self._children_name_map["standard_dste_interface"] = "standard-dste-interface"
                    self._children_yang_names.add("standard-dste-interface")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("dste_mode") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.ControllerSummaries.ControllerSummary.BandwidthInformation, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.ControllerSummaries.ControllerSummary.BandwidthInformation, self).__setattr__(name, value)


                class PreStandardDsteInterface(Entity):
                    """
                    Prestandard DSTE interface information
                    
                    .. attribute:: allocated_bit_rate
                    
                    	Bandwidth (bits per second) now allocated
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: is_max_bandwidth_absolute
                    
                    	True if the Max B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: is_max_subpool_bandwidth_absolute
                    
                    	True if the Max sub\-pool B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: max_bandwidth
                    
                    	Max bandwidth (bits per second) allowed
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_flow_bandwidth
                    
                    	Max bandwidth (bits per second) allowed per flow
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_subpool_bandwidth
                    
                    	Max bandwidth (bits per second) allowed in subpool
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.ControllerSummaries.ControllerSummary.BandwidthInformation.PreStandardDsteInterface, self).__init__()

                        self.yang_name = "pre-standard-dste-interface"
                        self.yang_parent_name = "bandwidth-information"

                        self.allocated_bit_rate = YLeaf(YType.uint64, "allocated-bit-rate")

                        self.is_max_bandwidth_absolute = YLeaf(YType.boolean, "is-max-bandwidth-absolute")

                        self.is_max_subpool_bandwidth_absolute = YLeaf(YType.boolean, "is-max-subpool-bandwidth-absolute")

                        self.max_bandwidth = YLeaf(YType.uint64, "max-bandwidth")

                        self.max_flow_bandwidth = YLeaf(YType.uint64, "max-flow-bandwidth")

                        self.max_subpool_bandwidth = YLeaf(YType.uint64, "max-subpool-bandwidth")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("allocated_bit_rate",
                                        "is_max_bandwidth_absolute",
                                        "is_max_subpool_bandwidth_absolute",
                                        "max_bandwidth",
                                        "max_flow_bandwidth",
                                        "max_subpool_bandwidth") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.ControllerSummaries.ControllerSummary.BandwidthInformation.PreStandardDsteInterface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.ControllerSummaries.ControllerSummary.BandwidthInformation.PreStandardDsteInterface, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.allocated_bit_rate.is_set or
                            self.is_max_bandwidth_absolute.is_set or
                            self.is_max_subpool_bandwidth_absolute.is_set or
                            self.max_bandwidth.is_set or
                            self.max_flow_bandwidth.is_set or
                            self.max_subpool_bandwidth.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.allocated_bit_rate.yfilter != YFilter.not_set or
                            self.is_max_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.is_max_subpool_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.max_bandwidth.yfilter != YFilter.not_set or
                            self.max_flow_bandwidth.yfilter != YFilter.not_set or
                            self.max_subpool_bandwidth.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "pre-standard-dste-interface" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.allocated_bit_rate.is_set or self.allocated_bit_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.allocated_bit_rate.get_name_leafdata())
                        if (self.is_max_bandwidth_absolute.is_set or self.is_max_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_bandwidth_absolute.get_name_leafdata())
                        if (self.is_max_subpool_bandwidth_absolute.is_set or self.is_max_subpool_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_subpool_bandwidth_absolute.get_name_leafdata())
                        if (self.max_bandwidth.is_set or self.max_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_bandwidth.get_name_leafdata())
                        if (self.max_flow_bandwidth.is_set or self.max_flow_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_flow_bandwidth.get_name_leafdata())
                        if (self.max_subpool_bandwidth.is_set or self.max_subpool_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_subpool_bandwidth.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "allocated-bit-rate" or name == "is-max-bandwidth-absolute" or name == "is-max-subpool-bandwidth-absolute" or name == "max-bandwidth" or name == "max-flow-bandwidth" or name == "max-subpool-bandwidth"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "allocated-bit-rate"):
                            self.allocated_bit_rate = value
                            self.allocated_bit_rate.value_namespace = name_space
                            self.allocated_bit_rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-bandwidth-absolute"):
                            self.is_max_bandwidth_absolute = value
                            self.is_max_bandwidth_absolute.value_namespace = name_space
                            self.is_max_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-subpool-bandwidth-absolute"):
                            self.is_max_subpool_bandwidth_absolute = value
                            self.is_max_subpool_bandwidth_absolute.value_namespace = name_space
                            self.is_max_subpool_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-bandwidth"):
                            self.max_bandwidth = value
                            self.max_bandwidth.value_namespace = name_space
                            self.max_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-flow-bandwidth"):
                            self.max_flow_bandwidth = value
                            self.max_flow_bandwidth.value_namespace = name_space
                            self.max_flow_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-subpool-bandwidth"):
                            self.max_subpool_bandwidth = value
                            self.max_subpool_bandwidth.value_namespace = name_space
                            self.max_subpool_bandwidth.value_namespace_prefix = name_space_prefix


                class StandardDsteInterface(Entity):
                    """
                    Standard DSTE interface information
                    
                    .. attribute:: allocated_bit_rate
                    
                    	Bandwidth (bits per second) now allocated
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: is_max_bandwidth_absolute
                    
                    	True if the Max B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: is_max_bc0_bandwidth_absolute
                    
                    	True if the Max BC0 B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: is_max_bc1_bandwidth_absolute
                    
                    	True if the Max BC1 sub\-pool B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: max_bandwidth
                    
                    	Max bandwidth (bits per second) allowed
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_flow_bandwidth
                    
                    	Max bandwidth (bits per second) allowed per flow
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_pool0_bandwidth
                    
                    	Max bandwidth (bits per second) allowed in BC0 pool
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_pool1_bandwidth
                    
                    	Max bandwidth (bits per second) allowed in BC1 pool
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.ControllerSummaries.ControllerSummary.BandwidthInformation.StandardDsteInterface, self).__init__()

                        self.yang_name = "standard-dste-interface"
                        self.yang_parent_name = "bandwidth-information"

                        self.allocated_bit_rate = YLeaf(YType.uint64, "allocated-bit-rate")

                        self.is_max_bandwidth_absolute = YLeaf(YType.boolean, "is-max-bandwidth-absolute")

                        self.is_max_bc0_bandwidth_absolute = YLeaf(YType.boolean, "is-max-bc0-bandwidth-absolute")

                        self.is_max_bc1_bandwidth_absolute = YLeaf(YType.boolean, "is-max-bc1-bandwidth-absolute")

                        self.max_bandwidth = YLeaf(YType.uint64, "max-bandwidth")

                        self.max_flow_bandwidth = YLeaf(YType.uint64, "max-flow-bandwidth")

                        self.max_pool0_bandwidth = YLeaf(YType.uint64, "max-pool0-bandwidth")

                        self.max_pool1_bandwidth = YLeaf(YType.uint64, "max-pool1-bandwidth")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("allocated_bit_rate",
                                        "is_max_bandwidth_absolute",
                                        "is_max_bc0_bandwidth_absolute",
                                        "is_max_bc1_bandwidth_absolute",
                                        "max_bandwidth",
                                        "max_flow_bandwidth",
                                        "max_pool0_bandwidth",
                                        "max_pool1_bandwidth") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.ControllerSummaries.ControllerSummary.BandwidthInformation.StandardDsteInterface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.ControllerSummaries.ControllerSummary.BandwidthInformation.StandardDsteInterface, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.allocated_bit_rate.is_set or
                            self.is_max_bandwidth_absolute.is_set or
                            self.is_max_bc0_bandwidth_absolute.is_set or
                            self.is_max_bc1_bandwidth_absolute.is_set or
                            self.max_bandwidth.is_set or
                            self.max_flow_bandwidth.is_set or
                            self.max_pool0_bandwidth.is_set or
                            self.max_pool1_bandwidth.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.allocated_bit_rate.yfilter != YFilter.not_set or
                            self.is_max_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.is_max_bc0_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.is_max_bc1_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.max_bandwidth.yfilter != YFilter.not_set or
                            self.max_flow_bandwidth.yfilter != YFilter.not_set or
                            self.max_pool0_bandwidth.yfilter != YFilter.not_set or
                            self.max_pool1_bandwidth.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "standard-dste-interface" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.allocated_bit_rate.is_set or self.allocated_bit_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.allocated_bit_rate.get_name_leafdata())
                        if (self.is_max_bandwidth_absolute.is_set or self.is_max_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_bandwidth_absolute.get_name_leafdata())
                        if (self.is_max_bc0_bandwidth_absolute.is_set or self.is_max_bc0_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_bc0_bandwidth_absolute.get_name_leafdata())
                        if (self.is_max_bc1_bandwidth_absolute.is_set or self.is_max_bc1_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_bc1_bandwidth_absolute.get_name_leafdata())
                        if (self.max_bandwidth.is_set or self.max_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_bandwidth.get_name_leafdata())
                        if (self.max_flow_bandwidth.is_set or self.max_flow_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_flow_bandwidth.get_name_leafdata())
                        if (self.max_pool0_bandwidth.is_set or self.max_pool0_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_pool0_bandwidth.get_name_leafdata())
                        if (self.max_pool1_bandwidth.is_set or self.max_pool1_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_pool1_bandwidth.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "allocated-bit-rate" or name == "is-max-bandwidth-absolute" or name == "is-max-bc0-bandwidth-absolute" or name == "is-max-bc1-bandwidth-absolute" or name == "max-bandwidth" or name == "max-flow-bandwidth" or name == "max-pool0-bandwidth" or name == "max-pool1-bandwidth"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "allocated-bit-rate"):
                            self.allocated_bit_rate = value
                            self.allocated_bit_rate.value_namespace = name_space
                            self.allocated_bit_rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-bandwidth-absolute"):
                            self.is_max_bandwidth_absolute = value
                            self.is_max_bandwidth_absolute.value_namespace = name_space
                            self.is_max_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-bc0-bandwidth-absolute"):
                            self.is_max_bc0_bandwidth_absolute = value
                            self.is_max_bc0_bandwidth_absolute.value_namespace = name_space
                            self.is_max_bc0_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-bc1-bandwidth-absolute"):
                            self.is_max_bc1_bandwidth_absolute = value
                            self.is_max_bc1_bandwidth_absolute.value_namespace = name_space
                            self.is_max_bc1_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-bandwidth"):
                            self.max_bandwidth = value
                            self.max_bandwidth.value_namespace = name_space
                            self.max_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-flow-bandwidth"):
                            self.max_flow_bandwidth = value
                            self.max_flow_bandwidth.value_namespace = name_space
                            self.max_flow_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-pool0-bandwidth"):
                            self.max_pool0_bandwidth = value
                            self.max_pool0_bandwidth.value_namespace = name_space
                            self.max_pool0_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-pool1-bandwidth"):
                            self.max_pool1_bandwidth = value
                            self.max_pool1_bandwidth.value_namespace = name_space
                            self.max_pool1_bandwidth.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.dste_mode.is_set or
                        (self.pre_standard_dste_interface is not None and self.pre_standard_dste_interface.has_data()) or
                        (self.standard_dste_interface is not None and self.standard_dste_interface.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.dste_mode.yfilter != YFilter.not_set or
                        (self.pre_standard_dste_interface is not None and self.pre_standard_dste_interface.has_operation()) or
                        (self.standard_dste_interface is not None and self.standard_dste_interface.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bandwidth-information" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.dste_mode.is_set or self.dste_mode.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.dste_mode.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "pre-standard-dste-interface"):
                        if (self.pre_standard_dste_interface is None):
                            self.pre_standard_dste_interface = RsvpStandby.ControllerSummaries.ControllerSummary.BandwidthInformation.PreStandardDsteInterface()
                            self.pre_standard_dste_interface.parent = self
                            self._children_name_map["pre_standard_dste_interface"] = "pre-standard-dste-interface"
                        return self.pre_standard_dste_interface

                    if (child_yang_name == "standard-dste-interface"):
                        if (self.standard_dste_interface is None):
                            self.standard_dste_interface = RsvpStandby.ControllerSummaries.ControllerSummary.BandwidthInformation.StandardDsteInterface()
                            self.standard_dste_interface.parent = self
                            self._children_name_map["standard_dste_interface"] = "standard-dste-interface"
                        return self.standard_dste_interface

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "pre-standard-dste-interface" or name == "standard-dste-interface" or name == "dste-mode"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "dste-mode"):
                        self.dste_mode = value
                        self.dste_mode.value_namespace = name_space
                        self.dste_mode.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.controller_name.is_set or
                    self.interface_name_xr.is_set or
                    self.paths_in.is_set or
                    self.paths_out.is_set or
                    self.reservations_in.is_set or
                    self.reservations_out.is_set or
                    (self.bandwidth_information is not None and self.bandwidth_information.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.controller_name.yfilter != YFilter.not_set or
                    self.interface_name_xr.yfilter != YFilter.not_set or
                    self.paths_in.yfilter != YFilter.not_set or
                    self.paths_out.yfilter != YFilter.not_set or
                    self.reservations_in.yfilter != YFilter.not_set or
                    self.reservations_out.yfilter != YFilter.not_set or
                    (self.bandwidth_information is not None and self.bandwidth_information.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "controller-summary" + "[controller-name='" + self.controller_name.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/controller-summaries/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.controller_name.is_set or self.controller_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.controller_name.get_name_leafdata())
                if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                if (self.paths_in.is_set or self.paths_in.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.paths_in.get_name_leafdata())
                if (self.paths_out.is_set or self.paths_out.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.paths_out.get_name_leafdata())
                if (self.reservations_in.is_set or self.reservations_in.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.reservations_in.get_name_leafdata())
                if (self.reservations_out.is_set or self.reservations_out.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.reservations_out.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "bandwidth-information"):
                    if (self.bandwidth_information is None):
                        self.bandwidth_information = RsvpStandby.ControllerSummaries.ControllerSummary.BandwidthInformation()
                        self.bandwidth_information.parent = self
                        self._children_name_map["bandwidth_information"] = "bandwidth-information"
                    return self.bandwidth_information

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "bandwidth-information" or name == "controller-name" or name == "interface-name-xr" or name == "paths-in" or name == "paths-out" or name == "reservations-in" or name == "reservations-out"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "controller-name"):
                    self.controller_name = value
                    self.controller_name.value_namespace = name_space
                    self.controller_name.value_namespace_prefix = name_space_prefix
                if(value_path == "interface-name-xr"):
                    self.interface_name_xr = value
                    self.interface_name_xr.value_namespace = name_space
                    self.interface_name_xr.value_namespace_prefix = name_space_prefix
                if(value_path == "paths-in"):
                    self.paths_in = value
                    self.paths_in.value_namespace = name_space
                    self.paths_in.value_namespace_prefix = name_space_prefix
                if(value_path == "paths-out"):
                    self.paths_out = value
                    self.paths_out.value_namespace = name_space
                    self.paths_out.value_namespace_prefix = name_space_prefix
                if(value_path == "reservations-in"):
                    self.reservations_in = value
                    self.reservations_in.value_namespace = name_space
                    self.reservations_in.value_namespace_prefix = name_space_prefix
                if(value_path == "reservations-out"):
                    self.reservations_out = value
                    self.reservations_out.value_namespace = name_space
                    self.reservations_out.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.controller_summary:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.controller_summary:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "controller-summaries" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "controller-summary"):
                for c in self.controller_summary:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = RsvpStandby.ControllerSummaries.ControllerSummary()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.controller_summary.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "controller-summary"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class AuthenticationBriefs(Entity):
        """
        Table for Authentication related information
        
        .. attribute:: authentication_brief
        
        	Brief Authentication information
        	**type**\: list of    :py:class:`AuthenticationBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.AuthenticationBriefs.AuthenticationBrief>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(RsvpStandby.AuthenticationBriefs, self).__init__()

            self.yang_name = "authentication-briefs"
            self.yang_parent_name = "rsvp-standby"

            self.authentication_brief = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(RsvpStandby.AuthenticationBriefs, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(RsvpStandby.AuthenticationBriefs, self).__setattr__(name, value)


        class AuthenticationBrief(Entity):
            """
            Brief Authentication information
            
            .. attribute:: source_address  <key>
            
            	Source Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: destination_address  <key>
            
            	Destination Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: mode_id  <key>
            
            	Mode (Tx or Rx)
            	**type**\:   :py:class:`RsvpMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMode>`
            
            .. attribute:: interface_name  <key>
            
            	InterfaceName
            	**type**\:  str
            
            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
            
            .. attribute:: destination_address_xr
            
            	Destination address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: direction
            
            	Direction
            	**type**\:   :py:class:`RsvpMgmtAuthDirection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtAuthDirection>`
            
            .. attribute:: key_id
            
            	Key ID
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: key_id_valid
            
            	Key validity
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: key_source
            
            	Key source
            	**type**\:  str
            
            .. attribute:: key_type
            
            	Key type
            	**type**\:   :py:class:`RsvpMgmtAuthKi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtAuthKi>`
            
            .. attribute:: neighbor_address
            
            	Neighbor address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: source_address_xr
            
            	Source address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(RsvpStandby.AuthenticationBriefs.AuthenticationBrief, self).__init__()

                self.yang_name = "authentication-brief"
                self.yang_parent_name = "authentication-briefs"

                self.source_address = YLeaf(YType.str, "source-address")

                self.destination_address = YLeaf(YType.str, "destination-address")

                self.mode_id = YLeaf(YType.enumeration, "mode-id")

                self.interface_name = YLeaf(YType.str, "interface-name")

                self.destination_address_xr = YLeaf(YType.str, "destination-address-xr")

                self.direction = YLeaf(YType.enumeration, "direction")

                self.key_id = YLeaf(YType.uint64, "key-id")

                self.key_id_valid = YLeaf(YType.uint32, "key-id-valid")

                self.key_source = YLeaf(YType.str, "key-source")

                self.key_type = YLeaf(YType.enumeration, "key-type")

                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                self.source_address_xr = YLeaf(YType.str, "source-address-xr")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("source_address",
                                "destination_address",
                                "mode_id",
                                "interface_name",
                                "destination_address_xr",
                                "direction",
                                "key_id",
                                "key_id_valid",
                                "key_source",
                                "key_type",
                                "neighbor_address",
                                "source_address_xr") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(RsvpStandby.AuthenticationBriefs.AuthenticationBrief, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(RsvpStandby.AuthenticationBriefs.AuthenticationBrief, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.source_address.is_set or
                    self.destination_address.is_set or
                    self.mode_id.is_set or
                    self.interface_name.is_set or
                    self.destination_address_xr.is_set or
                    self.direction.is_set or
                    self.key_id.is_set or
                    self.key_id_valid.is_set or
                    self.key_source.is_set or
                    self.key_type.is_set or
                    self.neighbor_address.is_set or
                    self.source_address_xr.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.source_address.yfilter != YFilter.not_set or
                    self.destination_address.yfilter != YFilter.not_set or
                    self.mode_id.yfilter != YFilter.not_set or
                    self.interface_name.yfilter != YFilter.not_set or
                    self.destination_address_xr.yfilter != YFilter.not_set or
                    self.direction.yfilter != YFilter.not_set or
                    self.key_id.yfilter != YFilter.not_set or
                    self.key_id_valid.yfilter != YFilter.not_set or
                    self.key_source.yfilter != YFilter.not_set or
                    self.key_type.yfilter != YFilter.not_set or
                    self.neighbor_address.yfilter != YFilter.not_set or
                    self.source_address_xr.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "authentication-brief" + "[source-address='" + self.source_address.get() + "']" + "[destination-address='" + self.destination_address.get() + "']" + "[mode-id='" + self.mode_id.get() + "']" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/authentication-briefs/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_address.get_name_leafdata())
                if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_address.get_name_leafdata())
                if (self.mode_id.is_set or self.mode_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.mode_id.get_name_leafdata())
                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                if (self.destination_address_xr.is_set or self.destination_address_xr.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_address_xr.get_name_leafdata())
                if (self.direction.is_set or self.direction.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.direction.get_name_leafdata())
                if (self.key_id.is_set or self.key_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.key_id.get_name_leafdata())
                if (self.key_id_valid.is_set or self.key_id_valid.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.key_id_valid.get_name_leafdata())
                if (self.key_source.is_set or self.key_source.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.key_source.get_name_leafdata())
                if (self.key_type.is_set or self.key_type.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.key_type.get_name_leafdata())
                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                if (self.source_address_xr.is_set or self.source_address_xr.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_address_xr.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "source-address" or name == "destination-address" or name == "mode-id" or name == "interface-name" or name == "destination-address-xr" or name == "direction" or name == "key-id" or name == "key-id-valid" or name == "key-source" or name == "key-type" or name == "neighbor-address" or name == "source-address-xr"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "source-address"):
                    self.source_address = value
                    self.source_address.value_namespace = name_space
                    self.source_address.value_namespace_prefix = name_space_prefix
                if(value_path == "destination-address"):
                    self.destination_address = value
                    self.destination_address.value_namespace = name_space
                    self.destination_address.value_namespace_prefix = name_space_prefix
                if(value_path == "mode-id"):
                    self.mode_id = value
                    self.mode_id.value_namespace = name_space
                    self.mode_id.value_namespace_prefix = name_space_prefix
                if(value_path == "interface-name"):
                    self.interface_name = value
                    self.interface_name.value_namespace = name_space
                    self.interface_name.value_namespace_prefix = name_space_prefix
                if(value_path == "destination-address-xr"):
                    self.destination_address_xr = value
                    self.destination_address_xr.value_namespace = name_space
                    self.destination_address_xr.value_namespace_prefix = name_space_prefix
                if(value_path == "direction"):
                    self.direction = value
                    self.direction.value_namespace = name_space
                    self.direction.value_namespace_prefix = name_space_prefix
                if(value_path == "key-id"):
                    self.key_id = value
                    self.key_id.value_namespace = name_space
                    self.key_id.value_namespace_prefix = name_space_prefix
                if(value_path == "key-id-valid"):
                    self.key_id_valid = value
                    self.key_id_valid.value_namespace = name_space
                    self.key_id_valid.value_namespace_prefix = name_space_prefix
                if(value_path == "key-source"):
                    self.key_source = value
                    self.key_source.value_namespace = name_space
                    self.key_source.value_namespace_prefix = name_space_prefix
                if(value_path == "key-type"):
                    self.key_type = value
                    self.key_type.value_namespace = name_space
                    self.key_type.value_namespace_prefix = name_space_prefix
                if(value_path == "neighbor-address"):
                    self.neighbor_address = value
                    self.neighbor_address.value_namespace = name_space
                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                if(value_path == "source-address-xr"):
                    self.source_address_xr = value
                    self.source_address_xr.value_namespace = name_space
                    self.source_address_xr.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.authentication_brief:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.authentication_brief:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "authentication-briefs" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "authentication-brief"):
                for c in self.authentication_brief:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = RsvpStandby.AuthenticationBriefs.AuthenticationBrief()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.authentication_brief.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "authentication-brief"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class SessionBriefs(Entity):
        """
        Table of brief info about sessions
        
        .. attribute:: session_brief
        
        	Brief info about session
        	**type**\: list of    :py:class:`SessionBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionBriefs.SessionBrief>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(RsvpStandby.SessionBriefs, self).__init__()

            self.yang_name = "session-briefs"
            self.yang_parent_name = "rsvp-standby"

            self.session_brief = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(RsvpStandby.SessionBriefs, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(RsvpStandby.SessionBriefs, self).__setattr__(name, value)


        class SessionBrief(Entity):
            """
            Brief info about session
            
            .. attribute:: destination_address
            
            	Destination Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: destination_port
            
            	Destination Port
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: detail_list_size
            
            	Number of elements in detail list
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: extended_tunnel_id
            
            	Extended Tunnel ID
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: p2mp_id
            
            	P2MP ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: protocol
            
            	Protocol
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: ps_bs
            
            	Number of path state block states
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: requests
            
            	Number of request states
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: rs_bs
            
            	Number of reservation state block states
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: session
            
            	RSVP Session Information
            	**type**\:   :py:class:`Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionBriefs.SessionBrief.Session>`
            
            .. attribute:: session_type
            
            	Session Type
            	**type**\:   :py:class:`RsvpSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpSession>`
            
            .. attribute:: vrf_name
            
            	VRF Name
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(RsvpStandby.SessionBriefs.SessionBrief, self).__init__()

                self.yang_name = "session-brief"
                self.yang_parent_name = "session-briefs"

                self.destination_address = YLeaf(YType.str, "destination-address")

                self.destination_port = YLeaf(YType.int32, "destination-port")

                self.detail_list_size = YLeaf(YType.uint32, "detail-list-size")

                self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                self.p2mp_id = YLeaf(YType.int32, "p2mp-id")

                self.protocol = YLeaf(YType.int32, "protocol")

                self.ps_bs = YLeaf(YType.uint32, "ps-bs")

                self.requests = YLeaf(YType.uint32, "requests")

                self.rs_bs = YLeaf(YType.uint32, "rs-bs")

                self.session_type = YLeaf(YType.enumeration, "session-type")

                self.vrf_name = YLeaf(YType.str, "vrf-name")

                self.session = RsvpStandby.SessionBriefs.SessionBrief.Session()
                self.session.parent = self
                self._children_name_map["session"] = "session"
                self._children_yang_names.add("session")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("destination_address",
                                "destination_port",
                                "detail_list_size",
                                "extended_tunnel_id",
                                "p2mp_id",
                                "protocol",
                                "ps_bs",
                                "requests",
                                "rs_bs",
                                "session_type",
                                "vrf_name") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(RsvpStandby.SessionBriefs.SessionBrief, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(RsvpStandby.SessionBriefs.SessionBrief, self).__setattr__(name, value)


            class Session(Entity):
                """
                RSVP Session Information
                
                .. attribute:: rsvp_session
                
                	RSVP Session
                	**type**\:   :py:class:`RsvpSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionBriefs.SessionBrief.Session.RsvpSession>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.SessionBriefs.SessionBrief.Session, self).__init__()

                    self.yang_name = "session"
                    self.yang_parent_name = "session-brief"

                    self.rsvp_session = RsvpStandby.SessionBriefs.SessionBrief.Session.RsvpSession()
                    self.rsvp_session.parent = self
                    self._children_name_map["rsvp_session"] = "rsvp-session"
                    self._children_yang_names.add("rsvp-session")


                class RsvpSession(Entity):
                    """
                    RSVP Session
                    
                    .. attribute:: ipv4
                    
                    	UDP IPv4 session
                    	**type**\:   :py:class:`Ipv4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionBriefs.SessionBrief.Session.RsvpSession.Ipv4>`
                    
                    .. attribute:: ipv4_lsp_session
                    
                    	IPv4 LSP session
                    	**type**\:   :py:class:`Ipv4LspSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionBriefs.SessionBrief.Session.RsvpSession.Ipv4LspSession>`
                    
                    .. attribute:: ipv4_p2mp_lsp_session
                    
                    	IPv4 P2MP LSP session
                    	**type**\:   :py:class:`Ipv4P2MpLspSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionBriefs.SessionBrief.Session.RsvpSession.Ipv4P2MpLspSession>`
                    
                    .. attribute:: ipv4_uni_session
                    
                    	IPv4 UNI session
                    	**type**\:   :py:class:`Ipv4UniSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionBriefs.SessionBrief.Session.RsvpSession.Ipv4UniSession>`
                    
                    .. attribute:: session_type
                    
                    	SessionType
                    	**type**\:   :py:class:`RsvpMgmtSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtSession>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.SessionBriefs.SessionBrief.Session.RsvpSession, self).__init__()

                        self.yang_name = "rsvp-session"
                        self.yang_parent_name = "session"

                        self.session_type = YLeaf(YType.enumeration, "session-type")

                        self.ipv4 = RsvpStandby.SessionBriefs.SessionBrief.Session.RsvpSession.Ipv4()
                        self.ipv4.parent = self
                        self._children_name_map["ipv4"] = "ipv4"
                        self._children_yang_names.add("ipv4")

                        self.ipv4_lsp_session = RsvpStandby.SessionBriefs.SessionBrief.Session.RsvpSession.Ipv4LspSession()
                        self.ipv4_lsp_session.parent = self
                        self._children_name_map["ipv4_lsp_session"] = "ipv4-lsp-session"
                        self._children_yang_names.add("ipv4-lsp-session")

                        self.ipv4_p2mp_lsp_session = RsvpStandby.SessionBriefs.SessionBrief.Session.RsvpSession.Ipv4P2MpLspSession()
                        self.ipv4_p2mp_lsp_session.parent = self
                        self._children_name_map["ipv4_p2mp_lsp_session"] = "ipv4-p2mp-lsp-session"
                        self._children_yang_names.add("ipv4-p2mp-lsp-session")

                        self.ipv4_uni_session = RsvpStandby.SessionBriefs.SessionBrief.Session.RsvpSession.Ipv4UniSession()
                        self.ipv4_uni_session.parent = self
                        self._children_name_map["ipv4_uni_session"] = "ipv4-uni-session"
                        self._children_yang_names.add("ipv4-uni-session")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("session_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.SessionBriefs.SessionBrief.Session.RsvpSession, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.SessionBriefs.SessionBrief.Session.RsvpSession, self).__setattr__(name, value)


                    class Ipv4(Entity):
                        """
                        UDP IPv4 session
                        
                        .. attribute:: destination_address
                        
                        	Destination address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: destination_port
                        
                        	The Session Destination Port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: protocol
                        
                        	Protocol type (originally defined in RFC 790, further values in subsequent RFCs)
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.SessionBriefs.SessionBrief.Session.RsvpSession.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "rsvp-session"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.destination_port = YLeaf(YType.uint16, "destination-port")

                            self.protocol = YLeaf(YType.uint8, "protocol")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "destination_port",
                                            "protocol") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.SessionBriefs.SessionBrief.Session.RsvpSession.Ipv4, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.SessionBriefs.SessionBrief.Session.RsvpSession.Ipv4, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination_address.is_set or
                                self.destination_port.is_set or
                                self.protocol.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.destination_port.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-briefs/session-brief/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.destination_port.is_set or self.destination_port.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_port.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "destination-port" or name == "protocol"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "destination-port"):
                                self.destination_port = value
                                self.destination_port.value_namespace = name_space
                                self.destination_port.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix


                    class Ipv4LspSession(Entity):
                        """
                        IPv4 LSP session
                        
                        .. attribute:: destination_address
                        
                        	Destination address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: extended_tunnel_id
                        
                        	The Session Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: tunnel_id
                        
                        	The Session Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.SessionBriefs.SessionBrief.Session.RsvpSession.Ipv4LspSession, self).__init__()

                            self.yang_name = "ipv4-lsp-session"
                            self.yang_parent_name = "rsvp-session"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                            self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "extended_tunnel_id",
                                            "tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.SessionBriefs.SessionBrief.Session.RsvpSession.Ipv4LspSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.SessionBriefs.SessionBrief.Session.RsvpSession.Ipv4LspSession, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination_address.is_set or
                                self.extended_tunnel_id.is_set or
                                self.tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.extended_tunnel_id.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-lsp-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-briefs/session-brief/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "extended-tunnel-id" or name == "tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "extended-tunnel-id"):
                                self.extended_tunnel_id = value
                                self.extended_tunnel_id.value_namespace = name_space
                                self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix


                    class Ipv4UniSession(Entity):
                        """
                        IPv4 UNI session
                        
                        .. attribute:: destination_address
                        
                        	Destination address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: extended_address
                        
                        	The Session Extended Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: tunnel_id
                        
                        	The Session Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.SessionBriefs.SessionBrief.Session.RsvpSession.Ipv4UniSession, self).__init__()

                            self.yang_name = "ipv4-uni-session"
                            self.yang_parent_name = "rsvp-session"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.extended_address = YLeaf(YType.str, "extended-address")

                            self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "extended_address",
                                            "tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.SessionBriefs.SessionBrief.Session.RsvpSession.Ipv4UniSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.SessionBriefs.SessionBrief.Session.RsvpSession.Ipv4UniSession, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination_address.is_set or
                                self.extended_address.is_set or
                                self.tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.extended_address.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-uni-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-briefs/session-brief/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.extended_address.is_set or self.extended_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_address.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "extended-address" or name == "tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "extended-address"):
                                self.extended_address = value
                                self.extended_address.value_namespace = name_space
                                self.extended_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix


                    class Ipv4P2MpLspSession(Entity):
                        """
                        IPv4 P2MP LSP session
                        
                        .. attribute:: extended_tunnel_id
                        
                        	The Session Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: p2mp_id
                        
                        	The Point to Multipoint ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tunnel_id
                        
                        	The Session Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.SessionBriefs.SessionBrief.Session.RsvpSession.Ipv4P2MpLspSession, self).__init__()

                            self.yang_name = "ipv4-p2mp-lsp-session"
                            self.yang_parent_name = "rsvp-session"

                            self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                            self.p2mp_id = YLeaf(YType.uint32, "p2mp-id")

                            self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("extended_tunnel_id",
                                            "p2mp_id",
                                            "tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.SessionBriefs.SessionBrief.Session.RsvpSession.Ipv4P2MpLspSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.SessionBriefs.SessionBrief.Session.RsvpSession.Ipv4P2MpLspSession, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.extended_tunnel_id.is_set or
                                self.p2mp_id.is_set or
                                self.tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.extended_tunnel_id.yfilter != YFilter.not_set or
                                self.p2mp_id.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-p2mp-lsp-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-briefs/session-brief/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                            if (self.p2mp_id.is_set or self.p2mp_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.p2mp_id.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "extended-tunnel-id" or name == "p2mp-id" or name == "tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "extended-tunnel-id"):
                                self.extended_tunnel_id = value
                                self.extended_tunnel_id.value_namespace = name_space
                                self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "p2mp-id"):
                                self.p2mp_id = value
                                self.p2mp_id.value_namespace = name_space
                                self.p2mp_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.session_type.is_set or
                            (self.ipv4 is not None and self.ipv4.has_data()) or
                            (self.ipv4_lsp_session is not None and self.ipv4_lsp_session.has_data()) or
                            (self.ipv4_p2mp_lsp_session is not None and self.ipv4_p2mp_lsp_session.has_data()) or
                            (self.ipv4_uni_session is not None and self.ipv4_uni_session.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.session_type.yfilter != YFilter.not_set or
                            (self.ipv4 is not None and self.ipv4.has_operation()) or
                            (self.ipv4_lsp_session is not None and self.ipv4_lsp_session.has_operation()) or
                            (self.ipv4_p2mp_lsp_session is not None and self.ipv4_p2mp_lsp_session.has_operation()) or
                            (self.ipv4_uni_session is not None and self.ipv4_uni_session.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rsvp-session" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-briefs/session-brief/session/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.session_type.is_set or self.session_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.session_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "ipv4"):
                            if (self.ipv4 is None):
                                self.ipv4 = RsvpStandby.SessionBriefs.SessionBrief.Session.RsvpSession.Ipv4()
                                self.ipv4.parent = self
                                self._children_name_map["ipv4"] = "ipv4"
                            return self.ipv4

                        if (child_yang_name == "ipv4-lsp-session"):
                            if (self.ipv4_lsp_session is None):
                                self.ipv4_lsp_session = RsvpStandby.SessionBriefs.SessionBrief.Session.RsvpSession.Ipv4LspSession()
                                self.ipv4_lsp_session.parent = self
                                self._children_name_map["ipv4_lsp_session"] = "ipv4-lsp-session"
                            return self.ipv4_lsp_session

                        if (child_yang_name == "ipv4-p2mp-lsp-session"):
                            if (self.ipv4_p2mp_lsp_session is None):
                                self.ipv4_p2mp_lsp_session = RsvpStandby.SessionBriefs.SessionBrief.Session.RsvpSession.Ipv4P2MpLspSession()
                                self.ipv4_p2mp_lsp_session.parent = self
                                self._children_name_map["ipv4_p2mp_lsp_session"] = "ipv4-p2mp-lsp-session"
                            return self.ipv4_p2mp_lsp_session

                        if (child_yang_name == "ipv4-uni-session"):
                            if (self.ipv4_uni_session is None):
                                self.ipv4_uni_session = RsvpStandby.SessionBriefs.SessionBrief.Session.RsvpSession.Ipv4UniSession()
                                self.ipv4_uni_session.parent = self
                                self._children_name_map["ipv4_uni_session"] = "ipv4-uni-session"
                            return self.ipv4_uni_session

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ipv4" or name == "ipv4-lsp-session" or name == "ipv4-p2mp-lsp-session" or name == "ipv4-uni-session" or name == "session-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "session-type"):
                            self.session_type = value
                            self.session_type.value_namespace = name_space
                            self.session_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (self.rsvp_session is not None and self.rsvp_session.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.rsvp_session is not None and self.rsvp_session.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "session" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-briefs/session-brief/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "rsvp-session"):
                        if (self.rsvp_session is None):
                            self.rsvp_session = RsvpStandby.SessionBriefs.SessionBrief.Session.RsvpSession()
                            self.rsvp_session.parent = self
                            self._children_name_map["rsvp_session"] = "rsvp-session"
                        return self.rsvp_session

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "rsvp-session"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (
                    self.destination_address.is_set or
                    self.destination_port.is_set or
                    self.detail_list_size.is_set or
                    self.extended_tunnel_id.is_set or
                    self.p2mp_id.is_set or
                    self.protocol.is_set or
                    self.ps_bs.is_set or
                    self.requests.is_set or
                    self.rs_bs.is_set or
                    self.session_type.is_set or
                    self.vrf_name.is_set or
                    (self.session is not None and self.session.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.destination_address.yfilter != YFilter.not_set or
                    self.destination_port.yfilter != YFilter.not_set or
                    self.detail_list_size.yfilter != YFilter.not_set or
                    self.extended_tunnel_id.yfilter != YFilter.not_set or
                    self.p2mp_id.yfilter != YFilter.not_set or
                    self.protocol.yfilter != YFilter.not_set or
                    self.ps_bs.yfilter != YFilter.not_set or
                    self.requests.yfilter != YFilter.not_set or
                    self.rs_bs.yfilter != YFilter.not_set or
                    self.session_type.yfilter != YFilter.not_set or
                    self.vrf_name.yfilter != YFilter.not_set or
                    (self.session is not None and self.session.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "session-brief" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-briefs/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_address.get_name_leafdata())
                if (self.destination_port.is_set or self.destination_port.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_port.get_name_leafdata())
                if (self.detail_list_size.is_set or self.detail_list_size.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.detail_list_size.get_name_leafdata())
                if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                if (self.p2mp_id.is_set or self.p2mp_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.p2mp_id.get_name_leafdata())
                if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.protocol.get_name_leafdata())
                if (self.ps_bs.is_set or self.ps_bs.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.ps_bs.get_name_leafdata())
                if (self.requests.is_set or self.requests.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.requests.get_name_leafdata())
                if (self.rs_bs.is_set or self.rs_bs.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.rs_bs.get_name_leafdata())
                if (self.session_type.is_set or self.session_type.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.session_type.get_name_leafdata())
                if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.vrf_name.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "session"):
                    if (self.session is None):
                        self.session = RsvpStandby.SessionBriefs.SessionBrief.Session()
                        self.session.parent = self
                        self._children_name_map["session"] = "session"
                    return self.session

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "session" or name == "destination-address" or name == "destination-port" or name == "detail-list-size" or name == "extended-tunnel-id" or name == "p2mp-id" or name == "protocol" or name == "ps-bs" or name == "requests" or name == "rs-bs" or name == "session-type" or name == "vrf-name"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "destination-address"):
                    self.destination_address = value
                    self.destination_address.value_namespace = name_space
                    self.destination_address.value_namespace_prefix = name_space_prefix
                if(value_path == "destination-port"):
                    self.destination_port = value
                    self.destination_port.value_namespace = name_space
                    self.destination_port.value_namespace_prefix = name_space_prefix
                if(value_path == "detail-list-size"):
                    self.detail_list_size = value
                    self.detail_list_size.value_namespace = name_space
                    self.detail_list_size.value_namespace_prefix = name_space_prefix
                if(value_path == "extended-tunnel-id"):
                    self.extended_tunnel_id = value
                    self.extended_tunnel_id.value_namespace = name_space
                    self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                if(value_path == "p2mp-id"):
                    self.p2mp_id = value
                    self.p2mp_id.value_namespace = name_space
                    self.p2mp_id.value_namespace_prefix = name_space_prefix
                if(value_path == "protocol"):
                    self.protocol = value
                    self.protocol.value_namespace = name_space
                    self.protocol.value_namespace_prefix = name_space_prefix
                if(value_path == "ps-bs"):
                    self.ps_bs = value
                    self.ps_bs.value_namespace = name_space
                    self.ps_bs.value_namespace_prefix = name_space_prefix
                if(value_path == "requests"):
                    self.requests = value
                    self.requests.value_namespace = name_space
                    self.requests.value_namespace_prefix = name_space_prefix
                if(value_path == "rs-bs"):
                    self.rs_bs = value
                    self.rs_bs.value_namespace = name_space
                    self.rs_bs.value_namespace_prefix = name_space_prefix
                if(value_path == "session-type"):
                    self.session_type = value
                    self.session_type.value_namespace = name_space
                    self.session_type.value_namespace_prefix = name_space_prefix
                if(value_path == "vrf-name"):
                    self.vrf_name = value
                    self.vrf_name.value_namespace = name_space
                    self.vrf_name.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.session_brief:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.session_brief:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "session-briefs" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "session-brief"):
                for c in self.session_brief:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = RsvpStandby.SessionBriefs.SessionBrief()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.session_brief.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "session-brief"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class PsbDetaileds(Entity):
        """
        Table of detailed info about path state blocks
        
        .. attribute:: psb_detailed
        
        	Detailed info for a single path state block
        	**type**\: list of    :py:class:`PsbDetailed <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbDetaileds.PsbDetailed>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(RsvpStandby.PsbDetaileds, self).__init__()

            self.yang_name = "psb-detaileds"
            self.yang_parent_name = "rsvp-standby"

            self.psb_detailed = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(RsvpStandby.PsbDetaileds, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(RsvpStandby.PsbDetaileds, self).__setattr__(name, value)


        class PsbDetailed(Entity):
            """
            Detailed info for a single path state block
            
            .. attribute:: backup_tunnel_name
            
            	Path Backup Tunnel
            	**type**\:  str
            
            .. attribute:: class_type
            
            	DS\-TE Class\-Type
            	**type**\:   :py:class:`ClassType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbDetaileds.PsbDetailed.ClassType>`
            
            .. attribute:: destination_address
            
            	Destination Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: destination_port
            
            	Destination Port
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: expiry_time
            
            	Expiry Time
            	**type**\:   :py:class:`ExpiryTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbDetaileds.PsbDetailed.ExpiryTime>`
            
            .. attribute:: extended_tunnel_id
            
            	Extended Tunnel ID
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: generic_traffic_spec
            
            	RSVP Generic Traffic Spec Info
            	**type**\:   :py:class:`GenericTrafficSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbDetaileds.PsbDetailed.GenericTrafficSpec>`
            
            .. attribute:: header
            
            	RSVP Header Info
            	**type**\:   :py:class:`Header <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbDetaileds.PsbDetailed.Header>`
            
            .. attribute:: hop
            
            	Path Hop Info
            	**type**\:   :py:class:`Hop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbDetaileds.PsbDetailed.Hop>`
            
            .. attribute:: in_ero
            
            	Incoming Explicit Route Sub Objects
            	**type**\: list of    :py:class:`InEro <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbDetaileds.PsbDetailed.InEro>`
            
            .. attribute:: input_interface
            
            	Path Input Interface
            	**type**\:  str
            
            .. attribute:: is_in_ero_valid
            
            	Incoming ERO validity
            	**type**\:  bool
            
            .. attribute:: is_out_ero_valid
            
            	Outgoing ERO validity
            	**type**\:  bool
            
            .. attribute:: label_info
            
            	Label Information
            	**type**\:   :py:class:`LabelInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo>`
            
            .. attribute:: out_ero
            
            	Outgoing Explicit Route Sub Objects
            	**type**\: list of    :py:class:`OutEro <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbDetaileds.PsbDetailed.OutEro>`
            
            .. attribute:: p2mp_id
            
            	P2MP ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: path_flags
            
            	Path Flags
            	**type**\:   :py:class:`PathFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbDetaileds.PsbDetailed.PathFlags>`
            
            .. attribute:: pfc
            
            	Path Forwarding Contexts
            	**type**\: list of    :py:class:`Pfc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbDetaileds.PsbDetailed.Pfc>`
            
            .. attribute:: policy_flags
            
            	Policy Flags
            	**type**\:   :py:class:`PolicyFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbDetaileds.PsbDetailed.PolicyFlags>`
            
            .. attribute:: policy_query_flags
            
            	Policy Query Flags
            	**type**\:   :py:class:`PolicyQueryFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbDetaileds.PsbDetailed.PolicyQueryFlags>`
            
            .. attribute:: policy_source_info
            
            	Policy Sources Info
            	**type**\:   :py:class:`PolicySourceInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbDetaileds.PsbDetailed.PolicySourceInfo>`
            
            .. attribute:: protocol
            
            	Protocol
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: s2l_sub_lsp
            
            	RSVP S2L Sub\-LSP information
            	**type**\:   :py:class:`S2LSubLsp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbDetaileds.PsbDetailed.S2LSubLsp>`
            
            .. attribute:: session
            
            	RSVP Session Information
            	**type**\:   :py:class:`Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbDetaileds.PsbDetailed.Session>`
            
            .. attribute:: session_attribute
            
            	RSVP Session Attribute
            	**type**\:   :py:class:`SessionAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbDetaileds.PsbDetailed.SessionAttribute>`
            
            .. attribute:: session_type
            
            	Session Type
            	**type**\:   :py:class:`RsvpSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpSession>`
            
            .. attribute:: source_address
            
            	Source Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: source_port
            
            	Source Port 
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: sub_group_id
            
            	Subgroup ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: sub_group_origin
            
            	Subgroup Origin
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: template
            
            	RSVP Template
            	**type**\:   :py:class:`Template <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbDetaileds.PsbDetailed.Template>`
            
            .. attribute:: traffic_spec
            
            	RSVP Traffic Spec Info
            	**type**\:   :py:class:`TrafficSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbDetaileds.PsbDetailed.TrafficSpec>`
            
            .. attribute:: vrf_name
            
            	VRF Name
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(RsvpStandby.PsbDetaileds.PsbDetailed, self).__init__()

                self.yang_name = "psb-detailed"
                self.yang_parent_name = "psb-detaileds"

                self.backup_tunnel_name = YLeaf(YType.str, "backup-tunnel-name")

                self.destination_address = YLeaf(YType.str, "destination-address")

                self.destination_port = YLeaf(YType.int32, "destination-port")

                self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                self.input_interface = YLeaf(YType.str, "input-interface")

                self.is_in_ero_valid = YLeaf(YType.boolean, "is-in-ero-valid")

                self.is_out_ero_valid = YLeaf(YType.boolean, "is-out-ero-valid")

                self.p2mp_id = YLeaf(YType.int32, "p2mp-id")

                self.protocol = YLeaf(YType.int32, "protocol")

                self.session_type = YLeaf(YType.enumeration, "session-type")

                self.source_address = YLeaf(YType.str, "source-address")

                self.source_port = YLeaf(YType.int32, "source-port")

                self.sub_group_id = YLeaf(YType.int32, "sub-group-id")

                self.sub_group_origin = YLeaf(YType.str, "sub-group-origin")

                self.vrf_name = YLeaf(YType.str, "vrf-name")

                self.class_type = RsvpStandby.PsbDetaileds.PsbDetailed.ClassType()
                self.class_type.parent = self
                self._children_name_map["class_type"] = "class-type"
                self._children_yang_names.add("class-type")

                self.expiry_time = RsvpStandby.PsbDetaileds.PsbDetailed.ExpiryTime()
                self.expiry_time.parent = self
                self._children_name_map["expiry_time"] = "expiry-time"
                self._children_yang_names.add("expiry-time")

                self.generic_traffic_spec = RsvpStandby.PsbDetaileds.PsbDetailed.GenericTrafficSpec()
                self.generic_traffic_spec.parent = self
                self._children_name_map["generic_traffic_spec"] = "generic-traffic-spec"
                self._children_yang_names.add("generic-traffic-spec")

                self.header = RsvpStandby.PsbDetaileds.PsbDetailed.Header()
                self.header.parent = self
                self._children_name_map["header"] = "header"
                self._children_yang_names.add("header")

                self.hop = RsvpStandby.PsbDetaileds.PsbDetailed.Hop()
                self.hop.parent = self
                self._children_name_map["hop"] = "hop"
                self._children_yang_names.add("hop")

                self.label_info = RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo()
                self.label_info.parent = self
                self._children_name_map["label_info"] = "label-info"
                self._children_yang_names.add("label-info")

                self.path_flags = RsvpStandby.PsbDetaileds.PsbDetailed.PathFlags()
                self.path_flags.parent = self
                self._children_name_map["path_flags"] = "path-flags"
                self._children_yang_names.add("path-flags")

                self.policy_flags = RsvpStandby.PsbDetaileds.PsbDetailed.PolicyFlags()
                self.policy_flags.parent = self
                self._children_name_map["policy_flags"] = "policy-flags"
                self._children_yang_names.add("policy-flags")

                self.policy_query_flags = RsvpStandby.PsbDetaileds.PsbDetailed.PolicyQueryFlags()
                self.policy_query_flags.parent = self
                self._children_name_map["policy_query_flags"] = "policy-query-flags"
                self._children_yang_names.add("policy-query-flags")

                self.policy_source_info = RsvpStandby.PsbDetaileds.PsbDetailed.PolicySourceInfo()
                self.policy_source_info.parent = self
                self._children_name_map["policy_source_info"] = "policy-source-info"
                self._children_yang_names.add("policy-source-info")

                self.s2l_sub_lsp = RsvpStandby.PsbDetaileds.PsbDetailed.S2LSubLsp()
                self.s2l_sub_lsp.parent = self
                self._children_name_map["s2l_sub_lsp"] = "s2l-sub-lsp"
                self._children_yang_names.add("s2l-sub-lsp")

                self.session = RsvpStandby.PsbDetaileds.PsbDetailed.Session()
                self.session.parent = self
                self._children_name_map["session"] = "session"
                self._children_yang_names.add("session")

                self.session_attribute = RsvpStandby.PsbDetaileds.PsbDetailed.SessionAttribute()
                self.session_attribute.parent = self
                self._children_name_map["session_attribute"] = "session-attribute"
                self._children_yang_names.add("session-attribute")

                self.template = RsvpStandby.PsbDetaileds.PsbDetailed.Template()
                self.template.parent = self
                self._children_name_map["template"] = "template"
                self._children_yang_names.add("template")

                self.traffic_spec = RsvpStandby.PsbDetaileds.PsbDetailed.TrafficSpec()
                self.traffic_spec.parent = self
                self._children_name_map["traffic_spec"] = "traffic-spec"
                self._children_yang_names.add("traffic-spec")

                self.in_ero = YList(self)
                self.out_ero = YList(self)
                self.pfc = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("backup_tunnel_name",
                                "destination_address",
                                "destination_port",
                                "extended_tunnel_id",
                                "input_interface",
                                "is_in_ero_valid",
                                "is_out_ero_valid",
                                "p2mp_id",
                                "protocol",
                                "session_type",
                                "source_address",
                                "source_port",
                                "sub_group_id",
                                "sub_group_origin",
                                "vrf_name") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(RsvpStandby.PsbDetaileds.PsbDetailed, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(RsvpStandby.PsbDetaileds.PsbDetailed, self).__setattr__(name, value)


            class Session(Entity):
                """
                RSVP Session Information
                
                .. attribute:: rsvp_session
                
                	RSVP Session
                	**type**\:   :py:class:`RsvpSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbDetaileds.PsbDetailed.Session.RsvpSession>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.PsbDetaileds.PsbDetailed.Session, self).__init__()

                    self.yang_name = "session"
                    self.yang_parent_name = "psb-detailed"

                    self.rsvp_session = RsvpStandby.PsbDetaileds.PsbDetailed.Session.RsvpSession()
                    self.rsvp_session.parent = self
                    self._children_name_map["rsvp_session"] = "rsvp-session"
                    self._children_yang_names.add("rsvp-session")


                class RsvpSession(Entity):
                    """
                    RSVP Session
                    
                    .. attribute:: ipv4
                    
                    	UDP IPv4 session
                    	**type**\:   :py:class:`Ipv4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbDetaileds.PsbDetailed.Session.RsvpSession.Ipv4>`
                    
                    .. attribute:: ipv4_lsp_session
                    
                    	IPv4 LSP session
                    	**type**\:   :py:class:`Ipv4LspSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbDetaileds.PsbDetailed.Session.RsvpSession.Ipv4LspSession>`
                    
                    .. attribute:: ipv4_p2mp_lsp_session
                    
                    	IPv4 P2MP LSP session
                    	**type**\:   :py:class:`Ipv4P2MpLspSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbDetaileds.PsbDetailed.Session.RsvpSession.Ipv4P2MpLspSession>`
                    
                    .. attribute:: ipv4_uni_session
                    
                    	IPv4 UNI session
                    	**type**\:   :py:class:`Ipv4UniSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbDetaileds.PsbDetailed.Session.RsvpSession.Ipv4UniSession>`
                    
                    .. attribute:: session_type
                    
                    	SessionType
                    	**type**\:   :py:class:`RsvpMgmtSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtSession>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.PsbDetaileds.PsbDetailed.Session.RsvpSession, self).__init__()

                        self.yang_name = "rsvp-session"
                        self.yang_parent_name = "session"

                        self.session_type = YLeaf(YType.enumeration, "session-type")

                        self.ipv4 = RsvpStandby.PsbDetaileds.PsbDetailed.Session.RsvpSession.Ipv4()
                        self.ipv4.parent = self
                        self._children_name_map["ipv4"] = "ipv4"
                        self._children_yang_names.add("ipv4")

                        self.ipv4_lsp_session = RsvpStandby.PsbDetaileds.PsbDetailed.Session.RsvpSession.Ipv4LspSession()
                        self.ipv4_lsp_session.parent = self
                        self._children_name_map["ipv4_lsp_session"] = "ipv4-lsp-session"
                        self._children_yang_names.add("ipv4-lsp-session")

                        self.ipv4_p2mp_lsp_session = RsvpStandby.PsbDetaileds.PsbDetailed.Session.RsvpSession.Ipv4P2MpLspSession()
                        self.ipv4_p2mp_lsp_session.parent = self
                        self._children_name_map["ipv4_p2mp_lsp_session"] = "ipv4-p2mp-lsp-session"
                        self._children_yang_names.add("ipv4-p2mp-lsp-session")

                        self.ipv4_uni_session = RsvpStandby.PsbDetaileds.PsbDetailed.Session.RsvpSession.Ipv4UniSession()
                        self.ipv4_uni_session.parent = self
                        self._children_name_map["ipv4_uni_session"] = "ipv4-uni-session"
                        self._children_yang_names.add("ipv4-uni-session")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("session_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.PsbDetaileds.PsbDetailed.Session.RsvpSession, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.PsbDetaileds.PsbDetailed.Session.RsvpSession, self).__setattr__(name, value)


                    class Ipv4(Entity):
                        """
                        UDP IPv4 session
                        
                        .. attribute:: destination_address
                        
                        	Destination address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: destination_port
                        
                        	The Session Destination Port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: protocol
                        
                        	Protocol type (originally defined in RFC 790, further values in subsequent RFCs)
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.PsbDetaileds.PsbDetailed.Session.RsvpSession.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "rsvp-session"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.destination_port = YLeaf(YType.uint16, "destination-port")

                            self.protocol = YLeaf(YType.uint8, "protocol")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "destination_port",
                                            "protocol") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.PsbDetaileds.PsbDetailed.Session.RsvpSession.Ipv4, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.PsbDetaileds.PsbDetailed.Session.RsvpSession.Ipv4, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination_address.is_set or
                                self.destination_port.is_set or
                                self.protocol.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.destination_port.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-detaileds/psb-detailed/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.destination_port.is_set or self.destination_port.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_port.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "destination-port" or name == "protocol"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "destination-port"):
                                self.destination_port = value
                                self.destination_port.value_namespace = name_space
                                self.destination_port.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix


                    class Ipv4LspSession(Entity):
                        """
                        IPv4 LSP session
                        
                        .. attribute:: destination_address
                        
                        	Destination address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: extended_tunnel_id
                        
                        	The Session Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: tunnel_id
                        
                        	The Session Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.PsbDetaileds.PsbDetailed.Session.RsvpSession.Ipv4LspSession, self).__init__()

                            self.yang_name = "ipv4-lsp-session"
                            self.yang_parent_name = "rsvp-session"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                            self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "extended_tunnel_id",
                                            "tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.PsbDetaileds.PsbDetailed.Session.RsvpSession.Ipv4LspSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.PsbDetaileds.PsbDetailed.Session.RsvpSession.Ipv4LspSession, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination_address.is_set or
                                self.extended_tunnel_id.is_set or
                                self.tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.extended_tunnel_id.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-lsp-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-detaileds/psb-detailed/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "extended-tunnel-id" or name == "tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "extended-tunnel-id"):
                                self.extended_tunnel_id = value
                                self.extended_tunnel_id.value_namespace = name_space
                                self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix


                    class Ipv4UniSession(Entity):
                        """
                        IPv4 UNI session
                        
                        .. attribute:: destination_address
                        
                        	Destination address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: extended_address
                        
                        	The Session Extended Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: tunnel_id
                        
                        	The Session Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.PsbDetaileds.PsbDetailed.Session.RsvpSession.Ipv4UniSession, self).__init__()

                            self.yang_name = "ipv4-uni-session"
                            self.yang_parent_name = "rsvp-session"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.extended_address = YLeaf(YType.str, "extended-address")

                            self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "extended_address",
                                            "tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.PsbDetaileds.PsbDetailed.Session.RsvpSession.Ipv4UniSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.PsbDetaileds.PsbDetailed.Session.RsvpSession.Ipv4UniSession, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination_address.is_set or
                                self.extended_address.is_set or
                                self.tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.extended_address.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-uni-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-detaileds/psb-detailed/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.extended_address.is_set or self.extended_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_address.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "extended-address" or name == "tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "extended-address"):
                                self.extended_address = value
                                self.extended_address.value_namespace = name_space
                                self.extended_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix


                    class Ipv4P2MpLspSession(Entity):
                        """
                        IPv4 P2MP LSP session
                        
                        .. attribute:: extended_tunnel_id
                        
                        	The Session Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: p2mp_id
                        
                        	The Point to Multipoint ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tunnel_id
                        
                        	The Session Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.PsbDetaileds.PsbDetailed.Session.RsvpSession.Ipv4P2MpLspSession, self).__init__()

                            self.yang_name = "ipv4-p2mp-lsp-session"
                            self.yang_parent_name = "rsvp-session"

                            self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                            self.p2mp_id = YLeaf(YType.uint32, "p2mp-id")

                            self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("extended_tunnel_id",
                                            "p2mp_id",
                                            "tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.PsbDetaileds.PsbDetailed.Session.RsvpSession.Ipv4P2MpLspSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.PsbDetaileds.PsbDetailed.Session.RsvpSession.Ipv4P2MpLspSession, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.extended_tunnel_id.is_set or
                                self.p2mp_id.is_set or
                                self.tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.extended_tunnel_id.yfilter != YFilter.not_set or
                                self.p2mp_id.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-p2mp-lsp-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-detaileds/psb-detailed/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                            if (self.p2mp_id.is_set or self.p2mp_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.p2mp_id.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "extended-tunnel-id" or name == "p2mp-id" or name == "tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "extended-tunnel-id"):
                                self.extended_tunnel_id = value
                                self.extended_tunnel_id.value_namespace = name_space
                                self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "p2mp-id"):
                                self.p2mp_id = value
                                self.p2mp_id.value_namespace = name_space
                                self.p2mp_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.session_type.is_set or
                            (self.ipv4 is not None and self.ipv4.has_data()) or
                            (self.ipv4_lsp_session is not None and self.ipv4_lsp_session.has_data()) or
                            (self.ipv4_p2mp_lsp_session is not None and self.ipv4_p2mp_lsp_session.has_data()) or
                            (self.ipv4_uni_session is not None and self.ipv4_uni_session.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.session_type.yfilter != YFilter.not_set or
                            (self.ipv4 is not None and self.ipv4.has_operation()) or
                            (self.ipv4_lsp_session is not None and self.ipv4_lsp_session.has_operation()) or
                            (self.ipv4_p2mp_lsp_session is not None and self.ipv4_p2mp_lsp_session.has_operation()) or
                            (self.ipv4_uni_session is not None and self.ipv4_uni_session.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rsvp-session" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-detaileds/psb-detailed/session/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.session_type.is_set or self.session_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.session_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "ipv4"):
                            if (self.ipv4 is None):
                                self.ipv4 = RsvpStandby.PsbDetaileds.PsbDetailed.Session.RsvpSession.Ipv4()
                                self.ipv4.parent = self
                                self._children_name_map["ipv4"] = "ipv4"
                            return self.ipv4

                        if (child_yang_name == "ipv4-lsp-session"):
                            if (self.ipv4_lsp_session is None):
                                self.ipv4_lsp_session = RsvpStandby.PsbDetaileds.PsbDetailed.Session.RsvpSession.Ipv4LspSession()
                                self.ipv4_lsp_session.parent = self
                                self._children_name_map["ipv4_lsp_session"] = "ipv4-lsp-session"
                            return self.ipv4_lsp_session

                        if (child_yang_name == "ipv4-p2mp-lsp-session"):
                            if (self.ipv4_p2mp_lsp_session is None):
                                self.ipv4_p2mp_lsp_session = RsvpStandby.PsbDetaileds.PsbDetailed.Session.RsvpSession.Ipv4P2MpLspSession()
                                self.ipv4_p2mp_lsp_session.parent = self
                                self._children_name_map["ipv4_p2mp_lsp_session"] = "ipv4-p2mp-lsp-session"
                            return self.ipv4_p2mp_lsp_session

                        if (child_yang_name == "ipv4-uni-session"):
                            if (self.ipv4_uni_session is None):
                                self.ipv4_uni_session = RsvpStandby.PsbDetaileds.PsbDetailed.Session.RsvpSession.Ipv4UniSession()
                                self.ipv4_uni_session.parent = self
                                self._children_name_map["ipv4_uni_session"] = "ipv4-uni-session"
                            return self.ipv4_uni_session

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ipv4" or name == "ipv4-lsp-session" or name == "ipv4-p2mp-lsp-session" or name == "ipv4-uni-session" or name == "session-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "session-type"):
                            self.session_type = value
                            self.session_type.value_namespace = name_space
                            self.session_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (self.rsvp_session is not None and self.rsvp_session.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.rsvp_session is not None and self.rsvp_session.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "session" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-detaileds/psb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "rsvp-session"):
                        if (self.rsvp_session is None):
                            self.rsvp_session = RsvpStandby.PsbDetaileds.PsbDetailed.Session.RsvpSession()
                            self.rsvp_session.parent = self
                            self._children_name_map["rsvp_session"] = "rsvp-session"
                        return self.rsvp_session

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "rsvp-session"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class S2LSubLsp(Entity):
                """
                RSVP S2L Sub\-LSP information
                
                .. attribute:: s2l_destination_address
                
                	S2L Sub\-LSP Destination Address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.PsbDetaileds.PsbDetailed.S2LSubLsp, self).__init__()

                    self.yang_name = "s2l-sub-lsp"
                    self.yang_parent_name = "psb-detailed"

                    self.s2l_destination_address = YLeaf(YType.str, "s2l-destination-address")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("s2l_destination_address") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.PsbDetaileds.PsbDetailed.S2LSubLsp, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.PsbDetaileds.PsbDetailed.S2LSubLsp, self).__setattr__(name, value)

                def has_data(self):
                    return self.s2l_destination_address.is_set

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.s2l_destination_address.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "s2l-sub-lsp" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-detaileds/psb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.s2l_destination_address.is_set or self.s2l_destination_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.s2l_destination_address.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "s2l-destination-address"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "s2l-destination-address"):
                        self.s2l_destination_address = value
                        self.s2l_destination_address.value_namespace = name_space
                        self.s2l_destination_address.value_namespace_prefix = name_space_prefix


            class Template(Entity):
                """
                RSVP Template
                
                .. attribute:: rsvp_filter
                
                	RSVP Filter
                	**type**\:   :py:class:`RsvpFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbDetaileds.PsbDetailed.Template.RsvpFilter>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.PsbDetaileds.PsbDetailed.Template, self).__init__()

                    self.yang_name = "template"
                    self.yang_parent_name = "psb-detailed"

                    self.rsvp_filter = RsvpStandby.PsbDetaileds.PsbDetailed.Template.RsvpFilter()
                    self.rsvp_filter.parent = self
                    self._children_name_map["rsvp_filter"] = "rsvp-filter"
                    self._children_yang_names.add("rsvp-filter")


                class RsvpFilter(Entity):
                    """
                    RSVP Filter
                    
                    .. attribute:: filter_type
                    
                    	FilterType
                    	**type**\:   :py:class:`RsvpMgmtFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtFilter>`
                    
                    .. attribute:: p2mp_ipv4_session
                    
                    	IPv4 P2MP LSP FilterSpec
                    	**type**\:   :py:class:`P2MpIpv4Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbDetaileds.PsbDetailed.Template.RsvpFilter.P2MpIpv4Session>`
                    
                    .. attribute:: udp_ipv4_session
                    
                    	UDP IPV4 FilterSpec
                    	**type**\:   :py:class:`UdpIpv4Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbDetaileds.PsbDetailed.Template.RsvpFilter.UdpIpv4Session>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.PsbDetaileds.PsbDetailed.Template.RsvpFilter, self).__init__()

                        self.yang_name = "rsvp-filter"
                        self.yang_parent_name = "template"

                        self.filter_type = YLeaf(YType.enumeration, "filter-type")

                        self.p2mp_ipv4_session = RsvpStandby.PsbDetaileds.PsbDetailed.Template.RsvpFilter.P2MpIpv4Session()
                        self.p2mp_ipv4_session.parent = self
                        self._children_name_map["p2mp_ipv4_session"] = "p2mp-ipv4-session"
                        self._children_yang_names.add("p2mp-ipv4-session")

                        self.udp_ipv4_session = RsvpStandby.PsbDetaileds.PsbDetailed.Template.RsvpFilter.UdpIpv4Session()
                        self.udp_ipv4_session.parent = self
                        self._children_name_map["udp_ipv4_session"] = "udp-ipv4-session"
                        self._children_yang_names.add("udp-ipv4-session")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("filter_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.PsbDetaileds.PsbDetailed.Template.RsvpFilter, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.PsbDetaileds.PsbDetailed.Template.RsvpFilter, self).__setattr__(name, value)


                    class UdpIpv4Session(Entity):
                        """
                        UDP IPV4 FilterSpec
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source_port
                        
                        	Source Port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.PsbDetaileds.PsbDetailed.Template.RsvpFilter.UdpIpv4Session, self).__init__()

                            self.yang_name = "udp-ipv4-session"
                            self.yang_parent_name = "rsvp-filter"

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.source_port = YLeaf(YType.uint16, "source-port")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("source_address",
                                            "source_port") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.PsbDetaileds.PsbDetailed.Template.RsvpFilter.UdpIpv4Session, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.PsbDetaileds.PsbDetailed.Template.RsvpFilter.UdpIpv4Session, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.source_address.is_set or
                                self.source_port.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                self.source_port.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "udp-ipv4-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-detaileds/psb-detailed/template/rsvp-filter/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())
                            if (self.source_port.is_set or self.source_port.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_port.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "source-address" or name == "source-port"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-port"):
                                self.source_port = value
                                self.source_port.value_namespace = name_space
                                self.source_port.value_namespace_prefix = name_space_prefix


                    class P2MpIpv4Session(Entity):
                        """
                        IPv4 P2MP LSP FilterSpec
                        
                        .. attribute:: p2mp_sub_group_origin
                        
                        	Point to Multipoint SubGroup Origin
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source_port
                        
                        	Source Port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: sub_group_id
                        
                        	Point to Multipoint Subgroup ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.PsbDetaileds.PsbDetailed.Template.RsvpFilter.P2MpIpv4Session, self).__init__()

                            self.yang_name = "p2mp-ipv4-session"
                            self.yang_parent_name = "rsvp-filter"

                            self.p2mp_sub_group_origin = YLeaf(YType.str, "p2mp-sub-group-origin")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.source_port = YLeaf(YType.uint16, "source-port")

                            self.sub_group_id = YLeaf(YType.uint16, "sub-group-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("p2mp_sub_group_origin",
                                            "source_address",
                                            "source_port",
                                            "sub_group_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.PsbDetaileds.PsbDetailed.Template.RsvpFilter.P2MpIpv4Session, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.PsbDetaileds.PsbDetailed.Template.RsvpFilter.P2MpIpv4Session, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.p2mp_sub_group_origin.is_set or
                                self.source_address.is_set or
                                self.source_port.is_set or
                                self.sub_group_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.p2mp_sub_group_origin.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                self.source_port.yfilter != YFilter.not_set or
                                self.sub_group_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "p2mp-ipv4-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-detaileds/psb-detailed/template/rsvp-filter/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.p2mp_sub_group_origin.is_set or self.p2mp_sub_group_origin.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.p2mp_sub_group_origin.get_name_leafdata())
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())
                            if (self.source_port.is_set or self.source_port.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_port.get_name_leafdata())
                            if (self.sub_group_id.is_set or self.sub_group_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sub_group_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "p2mp-sub-group-origin" or name == "source-address" or name == "source-port" or name == "sub-group-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "p2mp-sub-group-origin"):
                                self.p2mp_sub_group_origin = value
                                self.p2mp_sub_group_origin.value_namespace = name_space
                                self.p2mp_sub_group_origin.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-port"):
                                self.source_port = value
                                self.source_port.value_namespace = name_space
                                self.source_port.value_namespace_prefix = name_space_prefix
                            if(value_path == "sub-group-id"):
                                self.sub_group_id = value
                                self.sub_group_id.value_namespace = name_space
                                self.sub_group_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.filter_type.is_set or
                            (self.p2mp_ipv4_session is not None and self.p2mp_ipv4_session.has_data()) or
                            (self.udp_ipv4_session is not None and self.udp_ipv4_session.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.filter_type.yfilter != YFilter.not_set or
                            (self.p2mp_ipv4_session is not None and self.p2mp_ipv4_session.has_operation()) or
                            (self.udp_ipv4_session is not None and self.udp_ipv4_session.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rsvp-filter" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-detaileds/psb-detailed/template/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.filter_type.is_set or self.filter_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.filter_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "p2mp-ipv4-session"):
                            if (self.p2mp_ipv4_session is None):
                                self.p2mp_ipv4_session = RsvpStandby.PsbDetaileds.PsbDetailed.Template.RsvpFilter.P2MpIpv4Session()
                                self.p2mp_ipv4_session.parent = self
                                self._children_name_map["p2mp_ipv4_session"] = "p2mp-ipv4-session"
                            return self.p2mp_ipv4_session

                        if (child_yang_name == "udp-ipv4-session"):
                            if (self.udp_ipv4_session is None):
                                self.udp_ipv4_session = RsvpStandby.PsbDetaileds.PsbDetailed.Template.RsvpFilter.UdpIpv4Session()
                                self.udp_ipv4_session.parent = self
                                self._children_name_map["udp_ipv4_session"] = "udp-ipv4-session"
                            return self.udp_ipv4_session

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "p2mp-ipv4-session" or name == "udp-ipv4-session" or name == "filter-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "filter-type"):
                            self.filter_type = value
                            self.filter_type.value_namespace = name_space
                            self.filter_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (self.rsvp_filter is not None and self.rsvp_filter.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.rsvp_filter is not None and self.rsvp_filter.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "template" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-detaileds/psb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "rsvp-filter"):
                        if (self.rsvp_filter is None):
                            self.rsvp_filter = RsvpStandby.PsbDetaileds.PsbDetailed.Template.RsvpFilter()
                            self.rsvp_filter.parent = self
                            self._children_name_map["rsvp_filter"] = "rsvp-filter"
                        return self.rsvp_filter

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "rsvp-filter"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class SessionAttribute(Entity):
                """
                RSVP Session Attribute
                
                .. attribute:: reservation_priority
                
                	Reservation Priority
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: sess_attribute_flags
                
                	Session Attributes
                	**type**\:   :py:class:`SessAttributeFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbDetaileds.PsbDetailed.SessionAttribute.SessAttributeFlags>`
                
                .. attribute:: setup_priority
                
                	Setup Priority
                	**type**\:  int
                
                	**range:** 0..255
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.PsbDetaileds.PsbDetailed.SessionAttribute, self).__init__()

                    self.yang_name = "session-attribute"
                    self.yang_parent_name = "psb-detailed"

                    self.reservation_priority = YLeaf(YType.uint8, "reservation-priority")

                    self.setup_priority = YLeaf(YType.uint8, "setup-priority")

                    self.sess_attribute_flags = RsvpStandby.PsbDetaileds.PsbDetailed.SessionAttribute.SessAttributeFlags()
                    self.sess_attribute_flags.parent = self
                    self._children_name_map["sess_attribute_flags"] = "sess-attribute-flags"
                    self._children_yang_names.add("sess-attribute-flags")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("reservation_priority",
                                    "setup_priority") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.PsbDetaileds.PsbDetailed.SessionAttribute, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.PsbDetaileds.PsbDetailed.SessionAttribute, self).__setattr__(name, value)


                class SessAttributeFlags(Entity):
                    """
                    Session Attributes
                    
                    .. attribute:: is_bandwidth_protect
                    
                    	Bandwidth Protection
                    	**type**\:  bool
                    
                    .. attribute:: is_local_protect
                    
                    	Local Protection
                    	**type**\:  bool
                    
                    .. attribute:: is_node_protect
                    
                    	Node Protection
                    	**type**\:  bool
                    
                    .. attribute:: is_record_labels
                    
                    	Records Labels
                    	**type**\:  bool
                    
                    .. attribute:: is_shared_explicit_requested
                    
                    	Shared Explicit Requested
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.PsbDetaileds.PsbDetailed.SessionAttribute.SessAttributeFlags, self).__init__()

                        self.yang_name = "sess-attribute-flags"
                        self.yang_parent_name = "session-attribute"

                        self.is_bandwidth_protect = YLeaf(YType.boolean, "is-bandwidth-protect")

                        self.is_local_protect = YLeaf(YType.boolean, "is-local-protect")

                        self.is_node_protect = YLeaf(YType.boolean, "is-node-protect")

                        self.is_record_labels = YLeaf(YType.boolean, "is-record-labels")

                        self.is_shared_explicit_requested = YLeaf(YType.boolean, "is-shared-explicit-requested")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("is_bandwidth_protect",
                                        "is_local_protect",
                                        "is_node_protect",
                                        "is_record_labels",
                                        "is_shared_explicit_requested") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.PsbDetaileds.PsbDetailed.SessionAttribute.SessAttributeFlags, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.PsbDetaileds.PsbDetailed.SessionAttribute.SessAttributeFlags, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.is_bandwidth_protect.is_set or
                            self.is_local_protect.is_set or
                            self.is_node_protect.is_set or
                            self.is_record_labels.is_set or
                            self.is_shared_explicit_requested.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.is_bandwidth_protect.yfilter != YFilter.not_set or
                            self.is_local_protect.yfilter != YFilter.not_set or
                            self.is_node_protect.yfilter != YFilter.not_set or
                            self.is_record_labels.yfilter != YFilter.not_set or
                            self.is_shared_explicit_requested.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "sess-attribute-flags" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-detaileds/psb-detailed/session-attribute/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.is_bandwidth_protect.is_set or self.is_bandwidth_protect.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_bandwidth_protect.get_name_leafdata())
                        if (self.is_local_protect.is_set or self.is_local_protect.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_local_protect.get_name_leafdata())
                        if (self.is_node_protect.is_set or self.is_node_protect.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_node_protect.get_name_leafdata())
                        if (self.is_record_labels.is_set or self.is_record_labels.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_record_labels.get_name_leafdata())
                        if (self.is_shared_explicit_requested.is_set or self.is_shared_explicit_requested.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_shared_explicit_requested.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "is-bandwidth-protect" or name == "is-local-protect" or name == "is-node-protect" or name == "is-record-labels" or name == "is-shared-explicit-requested"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "is-bandwidth-protect"):
                            self.is_bandwidth_protect = value
                            self.is_bandwidth_protect.value_namespace = name_space
                            self.is_bandwidth_protect.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-local-protect"):
                            self.is_local_protect = value
                            self.is_local_protect.value_namespace = name_space
                            self.is_local_protect.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-node-protect"):
                            self.is_node_protect = value
                            self.is_node_protect.value_namespace = name_space
                            self.is_node_protect.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-record-labels"):
                            self.is_record_labels = value
                            self.is_record_labels.value_namespace = name_space
                            self.is_record_labels.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-shared-explicit-requested"):
                            self.is_shared_explicit_requested = value
                            self.is_shared_explicit_requested.value_namespace = name_space
                            self.is_shared_explicit_requested.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.reservation_priority.is_set or
                        self.setup_priority.is_set or
                        (self.sess_attribute_flags is not None and self.sess_attribute_flags.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.reservation_priority.yfilter != YFilter.not_set or
                        self.setup_priority.yfilter != YFilter.not_set or
                        (self.sess_attribute_flags is not None and self.sess_attribute_flags.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "session-attribute" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-detaileds/psb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.reservation_priority.is_set or self.reservation_priority.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reservation_priority.get_name_leafdata())
                    if (self.setup_priority.is_set or self.setup_priority.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.setup_priority.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "sess-attribute-flags"):
                        if (self.sess_attribute_flags is None):
                            self.sess_attribute_flags = RsvpStandby.PsbDetaileds.PsbDetailed.SessionAttribute.SessAttributeFlags()
                            self.sess_attribute_flags.parent = self
                            self._children_name_map["sess_attribute_flags"] = "sess-attribute-flags"
                        return self.sess_attribute_flags

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "sess-attribute-flags" or name == "reservation-priority" or name == "setup-priority"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "reservation-priority"):
                        self.reservation_priority = value
                        self.reservation_priority.value_namespace = name_space
                        self.reservation_priority.value_namespace_prefix = name_space_prefix
                    if(value_path == "setup-priority"):
                        self.setup_priority = value
                        self.setup_priority.value_namespace = name_space
                        self.setup_priority.value_namespace_prefix = name_space_prefix


            class TrafficSpec(Entity):
                """
                RSVP Traffic Spec Info
                
                .. attribute:: traffic_average_rate
                
                	Traffic Average Rate in bytes per second
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: byte/s
                
                .. attribute:: traffic_max_burst
                
                	Traffic Maximum Burst
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: traffic_max_unit
                
                	Traffic Maximum Unit
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: traffic_min_unit
                
                	Traffic Minimum Unit
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: traffic_peak_rate
                
                	Traffic Peak Rate in bytes per second
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: byte/s
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.PsbDetaileds.PsbDetailed.TrafficSpec, self).__init__()

                    self.yang_name = "traffic-spec"
                    self.yang_parent_name = "psb-detailed"

                    self.traffic_average_rate = YLeaf(YType.uint64, "traffic-average-rate")

                    self.traffic_max_burst = YLeaf(YType.uint64, "traffic-max-burst")

                    self.traffic_max_unit = YLeaf(YType.uint32, "traffic-max-unit")

                    self.traffic_min_unit = YLeaf(YType.uint32, "traffic-min-unit")

                    self.traffic_peak_rate = YLeaf(YType.uint64, "traffic-peak-rate")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("traffic_average_rate",
                                    "traffic_max_burst",
                                    "traffic_max_unit",
                                    "traffic_min_unit",
                                    "traffic_peak_rate") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.PsbDetaileds.PsbDetailed.TrafficSpec, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.PsbDetaileds.PsbDetailed.TrafficSpec, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.traffic_average_rate.is_set or
                        self.traffic_max_burst.is_set or
                        self.traffic_max_unit.is_set or
                        self.traffic_min_unit.is_set or
                        self.traffic_peak_rate.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.traffic_average_rate.yfilter != YFilter.not_set or
                        self.traffic_max_burst.yfilter != YFilter.not_set or
                        self.traffic_max_unit.yfilter != YFilter.not_set or
                        self.traffic_min_unit.yfilter != YFilter.not_set or
                        self.traffic_peak_rate.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "traffic-spec" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-detaileds/psb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.traffic_average_rate.is_set or self.traffic_average_rate.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.traffic_average_rate.get_name_leafdata())
                    if (self.traffic_max_burst.is_set or self.traffic_max_burst.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.traffic_max_burst.get_name_leafdata())
                    if (self.traffic_max_unit.is_set or self.traffic_max_unit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.traffic_max_unit.get_name_leafdata())
                    if (self.traffic_min_unit.is_set or self.traffic_min_unit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.traffic_min_unit.get_name_leafdata())
                    if (self.traffic_peak_rate.is_set or self.traffic_peak_rate.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.traffic_peak_rate.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "traffic-average-rate" or name == "traffic-max-burst" or name == "traffic-max-unit" or name == "traffic-min-unit" or name == "traffic-peak-rate"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "traffic-average-rate"):
                        self.traffic_average_rate = value
                        self.traffic_average_rate.value_namespace = name_space
                        self.traffic_average_rate.value_namespace_prefix = name_space_prefix
                    if(value_path == "traffic-max-burst"):
                        self.traffic_max_burst = value
                        self.traffic_max_burst.value_namespace = name_space
                        self.traffic_max_burst.value_namespace_prefix = name_space_prefix
                    if(value_path == "traffic-max-unit"):
                        self.traffic_max_unit = value
                        self.traffic_max_unit.value_namespace = name_space
                        self.traffic_max_unit.value_namespace_prefix = name_space_prefix
                    if(value_path == "traffic-min-unit"):
                        self.traffic_min_unit = value
                        self.traffic_min_unit.value_namespace = name_space
                        self.traffic_min_unit.value_namespace_prefix = name_space_prefix
                    if(value_path == "traffic-peak-rate"):
                        self.traffic_peak_rate = value
                        self.traffic_peak_rate.value_namespace = name_space
                        self.traffic_peak_rate.value_namespace_prefix = name_space_prefix


            class GenericTrafficSpec(Entity):
                """
                RSVP Generic Traffic Spec Info
                
                .. attribute:: g709otn_tspec
                
                	G709 OTN Sender Tspec
                	**type**\:   :py:class:`G709OtnTspec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbDetaileds.PsbDetailed.GenericTrafficSpec.G709OtnTspec>`
                
                .. attribute:: intsrv_tspec
                
                	Integrated Services Sender Tspec
                	**type**\:   :py:class:`IntsrvTspec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbDetaileds.PsbDetailed.GenericTrafficSpec.IntsrvTspec>`
                
                .. attribute:: tspec_type
                
                	TspecType
                	**type**\:   :py:class:`RsvpMgmtTspec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtTspec>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.PsbDetaileds.PsbDetailed.GenericTrafficSpec, self).__init__()

                    self.yang_name = "generic-traffic-spec"
                    self.yang_parent_name = "psb-detailed"

                    self.tspec_type = YLeaf(YType.enumeration, "tspec-type")

                    self.g709otn_tspec = RsvpStandby.PsbDetaileds.PsbDetailed.GenericTrafficSpec.G709OtnTspec()
                    self.g709otn_tspec.parent = self
                    self._children_name_map["g709otn_tspec"] = "g709otn-tspec"
                    self._children_yang_names.add("g709otn-tspec")

                    self.intsrv_tspec = RsvpStandby.PsbDetaileds.PsbDetailed.GenericTrafficSpec.IntsrvTspec()
                    self.intsrv_tspec.parent = self
                    self._children_name_map["intsrv_tspec"] = "intsrv-tspec"
                    self._children_yang_names.add("intsrv-tspec")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("tspec_type") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.PsbDetaileds.PsbDetailed.GenericTrafficSpec, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.PsbDetaileds.PsbDetailed.GenericTrafficSpec, self).__setattr__(name, value)


                class G709OtnTspec(Entity):
                    """
                    G709 OTN Sender Tspec
                    
                    .. attribute:: traffic_bit_rate
                    
                    	G709 OTN Traffic Bit Rate
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: traffic_multiplier
                    
                    	G709 OTN Traffic Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: traffic_nvc
                    
                    	G709 OTN Traffic NVC
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: traffic_signal_type
                    
                    	G709 OTN Traffic Signal Type (Refer G709 v3)
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.PsbDetaileds.PsbDetailed.GenericTrafficSpec.G709OtnTspec, self).__init__()

                        self.yang_name = "g709otn-tspec"
                        self.yang_parent_name = "generic-traffic-spec"

                        self.traffic_bit_rate = YLeaf(YType.uint64, "traffic-bit-rate")

                        self.traffic_multiplier = YLeaf(YType.uint16, "traffic-multiplier")

                        self.traffic_nvc = YLeaf(YType.uint16, "traffic-nvc")

                        self.traffic_signal_type = YLeaf(YType.uint8, "traffic-signal-type")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("traffic_bit_rate",
                                        "traffic_multiplier",
                                        "traffic_nvc",
                                        "traffic_signal_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.PsbDetaileds.PsbDetailed.GenericTrafficSpec.G709OtnTspec, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.PsbDetaileds.PsbDetailed.GenericTrafficSpec.G709OtnTspec, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.traffic_bit_rate.is_set or
                            self.traffic_multiplier.is_set or
                            self.traffic_nvc.is_set or
                            self.traffic_signal_type.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.traffic_bit_rate.yfilter != YFilter.not_set or
                            self.traffic_multiplier.yfilter != YFilter.not_set or
                            self.traffic_nvc.yfilter != YFilter.not_set or
                            self.traffic_signal_type.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "g709otn-tspec" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-detaileds/psb-detailed/generic-traffic-spec/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.traffic_bit_rate.is_set or self.traffic_bit_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.traffic_bit_rate.get_name_leafdata())
                        if (self.traffic_multiplier.is_set or self.traffic_multiplier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.traffic_multiplier.get_name_leafdata())
                        if (self.traffic_nvc.is_set or self.traffic_nvc.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.traffic_nvc.get_name_leafdata())
                        if (self.traffic_signal_type.is_set or self.traffic_signal_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.traffic_signal_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "traffic-bit-rate" or name == "traffic-multiplier" or name == "traffic-nvc" or name == "traffic-signal-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "traffic-bit-rate"):
                            self.traffic_bit_rate = value
                            self.traffic_bit_rate.value_namespace = name_space
                            self.traffic_bit_rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "traffic-multiplier"):
                            self.traffic_multiplier = value
                            self.traffic_multiplier.value_namespace = name_space
                            self.traffic_multiplier.value_namespace_prefix = name_space_prefix
                        if(value_path == "traffic-nvc"):
                            self.traffic_nvc = value
                            self.traffic_nvc.value_namespace = name_space
                            self.traffic_nvc.value_namespace_prefix = name_space_prefix
                        if(value_path == "traffic-signal-type"):
                            self.traffic_signal_type = value
                            self.traffic_signal_type.value_namespace = name_space
                            self.traffic_signal_type.value_namespace_prefix = name_space_prefix


                class IntsrvTspec(Entity):
                    """
                    Integrated Services Sender Tspec
                    
                    .. attribute:: traffic_average_rate
                    
                    	Traffic Average Rate in bytes per second
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: byte/s
                    
                    .. attribute:: traffic_max_burst
                    
                    	Traffic Maximum Burst
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: traffic_max_unit
                    
                    	Traffic Maximum Unit
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: traffic_min_unit
                    
                    	Traffic Minimum Unit
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: traffic_peak_rate
                    
                    	Traffic Peak Rate in bytes per second
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: byte/s
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.PsbDetaileds.PsbDetailed.GenericTrafficSpec.IntsrvTspec, self).__init__()

                        self.yang_name = "intsrv-tspec"
                        self.yang_parent_name = "generic-traffic-spec"

                        self.traffic_average_rate = YLeaf(YType.uint64, "traffic-average-rate")

                        self.traffic_max_burst = YLeaf(YType.uint64, "traffic-max-burst")

                        self.traffic_max_unit = YLeaf(YType.uint32, "traffic-max-unit")

                        self.traffic_min_unit = YLeaf(YType.uint32, "traffic-min-unit")

                        self.traffic_peak_rate = YLeaf(YType.uint64, "traffic-peak-rate")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("traffic_average_rate",
                                        "traffic_max_burst",
                                        "traffic_max_unit",
                                        "traffic_min_unit",
                                        "traffic_peak_rate") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.PsbDetaileds.PsbDetailed.GenericTrafficSpec.IntsrvTspec, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.PsbDetaileds.PsbDetailed.GenericTrafficSpec.IntsrvTspec, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.traffic_average_rate.is_set or
                            self.traffic_max_burst.is_set or
                            self.traffic_max_unit.is_set or
                            self.traffic_min_unit.is_set or
                            self.traffic_peak_rate.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.traffic_average_rate.yfilter != YFilter.not_set or
                            self.traffic_max_burst.yfilter != YFilter.not_set or
                            self.traffic_max_unit.yfilter != YFilter.not_set or
                            self.traffic_min_unit.yfilter != YFilter.not_set or
                            self.traffic_peak_rate.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "intsrv-tspec" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-detaileds/psb-detailed/generic-traffic-spec/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.traffic_average_rate.is_set or self.traffic_average_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.traffic_average_rate.get_name_leafdata())
                        if (self.traffic_max_burst.is_set or self.traffic_max_burst.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.traffic_max_burst.get_name_leafdata())
                        if (self.traffic_max_unit.is_set or self.traffic_max_unit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.traffic_max_unit.get_name_leafdata())
                        if (self.traffic_min_unit.is_set or self.traffic_min_unit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.traffic_min_unit.get_name_leafdata())
                        if (self.traffic_peak_rate.is_set or self.traffic_peak_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.traffic_peak_rate.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "traffic-average-rate" or name == "traffic-max-burst" or name == "traffic-max-unit" or name == "traffic-min-unit" or name == "traffic-peak-rate"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "traffic-average-rate"):
                            self.traffic_average_rate = value
                            self.traffic_average_rate.value_namespace = name_space
                            self.traffic_average_rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "traffic-max-burst"):
                            self.traffic_max_burst = value
                            self.traffic_max_burst.value_namespace = name_space
                            self.traffic_max_burst.value_namespace_prefix = name_space_prefix
                        if(value_path == "traffic-max-unit"):
                            self.traffic_max_unit = value
                            self.traffic_max_unit.value_namespace = name_space
                            self.traffic_max_unit.value_namespace_prefix = name_space_prefix
                        if(value_path == "traffic-min-unit"):
                            self.traffic_min_unit = value
                            self.traffic_min_unit.value_namespace = name_space
                            self.traffic_min_unit.value_namespace_prefix = name_space_prefix
                        if(value_path == "traffic-peak-rate"):
                            self.traffic_peak_rate = value
                            self.traffic_peak_rate.value_namespace = name_space
                            self.traffic_peak_rate.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.tspec_type.is_set or
                        (self.g709otn_tspec is not None and self.g709otn_tspec.has_data()) or
                        (self.intsrv_tspec is not None and self.intsrv_tspec.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.tspec_type.yfilter != YFilter.not_set or
                        (self.g709otn_tspec is not None and self.g709otn_tspec.has_operation()) or
                        (self.intsrv_tspec is not None and self.intsrv_tspec.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "generic-traffic-spec" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-detaileds/psb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.tspec_type.is_set or self.tspec_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tspec_type.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "g709otn-tspec"):
                        if (self.g709otn_tspec is None):
                            self.g709otn_tspec = RsvpStandby.PsbDetaileds.PsbDetailed.GenericTrafficSpec.G709OtnTspec()
                            self.g709otn_tspec.parent = self
                            self._children_name_map["g709otn_tspec"] = "g709otn-tspec"
                        return self.g709otn_tspec

                    if (child_yang_name == "intsrv-tspec"):
                        if (self.intsrv_tspec is None):
                            self.intsrv_tspec = RsvpStandby.PsbDetaileds.PsbDetailed.GenericTrafficSpec.IntsrvTspec()
                            self.intsrv_tspec.parent = self
                            self._children_name_map["intsrv_tspec"] = "intsrv-tspec"
                        return self.intsrv_tspec

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "g709otn-tspec" or name == "intsrv-tspec" or name == "tspec-type"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "tspec-type"):
                        self.tspec_type = value
                        self.tspec_type.value_namespace = name_space
                        self.tspec_type.value_namespace_prefix = name_space_prefix


            class PathFlags(Entity):
                """
                Path Flags
                
                .. attribute:: is_bidirectional
                
                	Bidirectional
                	**type**\:  bool
                
                .. attribute:: is_local_repair
                
                	Rerouted
                	**type**\:  bool
                
                .. attribute:: is_local_sender
                
                	Local Sender
                	**type**\:  bool
                
                .. attribute:: is_lockout
                
                	Locked Out
                	**type**\:  bool
                
                .. attribute:: is_message_id_valid
                
                	MessageID Valid
                	**type**\:  bool
                
                .. attribute:: is_non_rsvp_hop_upstream
                
                	Non\-RSVP Hop Upstream
                	**type**\:  bool
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.PsbDetaileds.PsbDetailed.PathFlags, self).__init__()

                    self.yang_name = "path-flags"
                    self.yang_parent_name = "psb-detailed"

                    self.is_bidirectional = YLeaf(YType.boolean, "is-bidirectional")

                    self.is_local_repair = YLeaf(YType.boolean, "is-local-repair")

                    self.is_local_sender = YLeaf(YType.boolean, "is-local-sender")

                    self.is_lockout = YLeaf(YType.boolean, "is-lockout")

                    self.is_message_id_valid = YLeaf(YType.boolean, "is-message-id-valid")

                    self.is_non_rsvp_hop_upstream = YLeaf(YType.boolean, "is-non-rsvp-hop-upstream")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("is_bidirectional",
                                    "is_local_repair",
                                    "is_local_sender",
                                    "is_lockout",
                                    "is_message_id_valid",
                                    "is_non_rsvp_hop_upstream") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.PsbDetaileds.PsbDetailed.PathFlags, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.PsbDetaileds.PsbDetailed.PathFlags, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.is_bidirectional.is_set or
                        self.is_local_repair.is_set or
                        self.is_local_sender.is_set or
                        self.is_lockout.is_set or
                        self.is_message_id_valid.is_set or
                        self.is_non_rsvp_hop_upstream.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.is_bidirectional.yfilter != YFilter.not_set or
                        self.is_local_repair.yfilter != YFilter.not_set or
                        self.is_local_sender.yfilter != YFilter.not_set or
                        self.is_lockout.yfilter != YFilter.not_set or
                        self.is_message_id_valid.yfilter != YFilter.not_set or
                        self.is_non_rsvp_hop_upstream.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "path-flags" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-detaileds/psb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.is_bidirectional.is_set or self.is_bidirectional.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_bidirectional.get_name_leafdata())
                    if (self.is_local_repair.is_set or self.is_local_repair.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_local_repair.get_name_leafdata())
                    if (self.is_local_sender.is_set or self.is_local_sender.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_local_sender.get_name_leafdata())
                    if (self.is_lockout.is_set or self.is_lockout.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_lockout.get_name_leafdata())
                    if (self.is_message_id_valid.is_set or self.is_message_id_valid.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_message_id_valid.get_name_leafdata())
                    if (self.is_non_rsvp_hop_upstream.is_set or self.is_non_rsvp_hop_upstream.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_non_rsvp_hop_upstream.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "is-bidirectional" or name == "is-local-repair" or name == "is-local-sender" or name == "is-lockout" or name == "is-message-id-valid" or name == "is-non-rsvp-hop-upstream"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "is-bidirectional"):
                        self.is_bidirectional = value
                        self.is_bidirectional.value_namespace = name_space
                        self.is_bidirectional.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-local-repair"):
                        self.is_local_repair = value
                        self.is_local_repair.value_namespace = name_space
                        self.is_local_repair.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-local-sender"):
                        self.is_local_sender = value
                        self.is_local_sender.value_namespace = name_space
                        self.is_local_sender.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-lockout"):
                        self.is_lockout = value
                        self.is_lockout.value_namespace = name_space
                        self.is_lockout.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-message-id-valid"):
                        self.is_message_id_valid = value
                        self.is_message_id_valid.value_namespace = name_space
                        self.is_message_id_valid.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-non-rsvp-hop-upstream"):
                        self.is_non_rsvp_hop_upstream = value
                        self.is_non_rsvp_hop_upstream.value_namespace = name_space
                        self.is_non_rsvp_hop_upstream.value_namespace_prefix = name_space_prefix


            class Hop(Entity):
                """
                Path Hop Info
                
                .. attribute:: neighbor_address
                
                	IP address of the neighbor
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: neighbor_logical_interface_name
                
                	Neighbor Logical Interface Name
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.PsbDetaileds.PsbDetailed.Hop, self).__init__()

                    self.yang_name = "hop"
                    self.yang_parent_name = "psb-detailed"

                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                    self.neighbor_logical_interface_name = YLeaf(YType.str, "neighbor-logical-interface-name")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("neighbor_address",
                                    "neighbor_logical_interface_name") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.PsbDetaileds.PsbDetailed.Hop, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.PsbDetaileds.PsbDetailed.Hop, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.neighbor_address.is_set or
                        self.neighbor_logical_interface_name.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.neighbor_address.yfilter != YFilter.not_set or
                        self.neighbor_logical_interface_name.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "hop" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-detaileds/psb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                    if (self.neighbor_logical_interface_name.is_set or self.neighbor_logical_interface_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.neighbor_logical_interface_name.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "neighbor-address" or name == "neighbor-logical-interface-name"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "neighbor-address"):
                        self.neighbor_address = value
                        self.neighbor_address.value_namespace = name_space
                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "neighbor-logical-interface-name"):
                        self.neighbor_logical_interface_name = value
                        self.neighbor_logical_interface_name.value_namespace = name_space
                        self.neighbor_logical_interface_name.value_namespace_prefix = name_space_prefix


            class PolicySourceInfo(Entity):
                """
                Policy Sources Info
                
                .. attribute:: is_cable
                
                	Policy Source is Cable
                	**type**\:  bool
                
                .. attribute:: is_cops
                
                	Policy Source is COPS
                	**type**\:  bool
                
                .. attribute:: is_default
                
                	Policy Source is Default
                	**type**\:  bool
                
                .. attribute:: is_local
                
                	Policy Source is Local
                	**type**\:  bool
                
                .. attribute:: is_te_link
                
                	Policy Source is TE Link
                	**type**\:  bool
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.PsbDetaileds.PsbDetailed.PolicySourceInfo, self).__init__()

                    self.yang_name = "policy-source-info"
                    self.yang_parent_name = "psb-detailed"

                    self.is_cable = YLeaf(YType.boolean, "is-cable")

                    self.is_cops = YLeaf(YType.boolean, "is-cops")

                    self.is_default = YLeaf(YType.boolean, "is-default")

                    self.is_local = YLeaf(YType.boolean, "is-local")

                    self.is_te_link = YLeaf(YType.boolean, "is-te-link")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("is_cable",
                                    "is_cops",
                                    "is_default",
                                    "is_local",
                                    "is_te_link") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.PsbDetaileds.PsbDetailed.PolicySourceInfo, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.PsbDetaileds.PsbDetailed.PolicySourceInfo, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.is_cable.is_set or
                        self.is_cops.is_set or
                        self.is_default.is_set or
                        self.is_local.is_set or
                        self.is_te_link.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.is_cable.yfilter != YFilter.not_set or
                        self.is_cops.yfilter != YFilter.not_set or
                        self.is_default.yfilter != YFilter.not_set or
                        self.is_local.yfilter != YFilter.not_set or
                        self.is_te_link.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "policy-source-info" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-detaileds/psb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.is_cable.is_set or self.is_cable.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_cable.get_name_leafdata())
                    if (self.is_cops.is_set or self.is_cops.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_cops.get_name_leafdata())
                    if (self.is_default.is_set or self.is_default.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_default.get_name_leafdata())
                    if (self.is_local.is_set or self.is_local.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_local.get_name_leafdata())
                    if (self.is_te_link.is_set or self.is_te_link.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_te_link.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "is-cable" or name == "is-cops" or name == "is-default" or name == "is-local" or name == "is-te-link"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "is-cable"):
                        self.is_cable = value
                        self.is_cable.value_namespace = name_space
                        self.is_cable.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-cops"):
                        self.is_cops = value
                        self.is_cops.value_namespace = name_space
                        self.is_cops.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-default"):
                        self.is_default = value
                        self.is_default.value_namespace = name_space
                        self.is_default.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-local"):
                        self.is_local = value
                        self.is_local.value_namespace = name_space
                        self.is_local.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-te-link"):
                        self.is_te_link = value
                        self.is_te_link.value_namespace = name_space
                        self.is_te_link.value_namespace_prefix = name_space_prefix


            class Header(Entity):
                """
                RSVP Header Info
                
                .. attribute:: ip_source_address
                
                	IP Source Address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: ip_tos
                
                	IP Type of Service
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: ip_ttl
                
                	IP TTL
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: rsvp_header_flags
                
                	RSVP Header Flags (defined in RFC2205 Section 3 .1.1)
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: rsvp_message_type
                
                	RSVP Message Type
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: rsvp_ttl
                
                	RSVP TTL
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: rsvp_version
                
                	RSVP Version
                	**type**\:  int
                
                	**range:** 0..255
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.PsbDetaileds.PsbDetailed.Header, self).__init__()

                    self.yang_name = "header"
                    self.yang_parent_name = "psb-detailed"

                    self.ip_source_address = YLeaf(YType.str, "ip-source-address")

                    self.ip_tos = YLeaf(YType.uint8, "ip-tos")

                    self.ip_ttl = YLeaf(YType.uint8, "ip-ttl")

                    self.rsvp_header_flags = YLeaf(YType.uint8, "rsvp-header-flags")

                    self.rsvp_message_type = YLeaf(YType.uint8, "rsvp-message-type")

                    self.rsvp_ttl = YLeaf(YType.uint8, "rsvp-ttl")

                    self.rsvp_version = YLeaf(YType.uint8, "rsvp-version")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("ip_source_address",
                                    "ip_tos",
                                    "ip_ttl",
                                    "rsvp_header_flags",
                                    "rsvp_message_type",
                                    "rsvp_ttl",
                                    "rsvp_version") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.PsbDetaileds.PsbDetailed.Header, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.PsbDetaileds.PsbDetailed.Header, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.ip_source_address.is_set or
                        self.ip_tos.is_set or
                        self.ip_ttl.is_set or
                        self.rsvp_header_flags.is_set or
                        self.rsvp_message_type.is_set or
                        self.rsvp_ttl.is_set or
                        self.rsvp_version.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.ip_source_address.yfilter != YFilter.not_set or
                        self.ip_tos.yfilter != YFilter.not_set or
                        self.ip_ttl.yfilter != YFilter.not_set or
                        self.rsvp_header_flags.yfilter != YFilter.not_set or
                        self.rsvp_message_type.yfilter != YFilter.not_set or
                        self.rsvp_ttl.yfilter != YFilter.not_set or
                        self.rsvp_version.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "header" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-detaileds/psb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.ip_source_address.is_set or self.ip_source_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ip_source_address.get_name_leafdata())
                    if (self.ip_tos.is_set or self.ip_tos.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ip_tos.get_name_leafdata())
                    if (self.ip_ttl.is_set or self.ip_ttl.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ip_ttl.get_name_leafdata())
                    if (self.rsvp_header_flags.is_set or self.rsvp_header_flags.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_header_flags.get_name_leafdata())
                    if (self.rsvp_message_type.is_set or self.rsvp_message_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_message_type.get_name_leafdata())
                    if (self.rsvp_ttl.is_set or self.rsvp_ttl.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_ttl.get_name_leafdata())
                    if (self.rsvp_version.is_set or self.rsvp_version.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_version.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ip-source-address" or name == "ip-tos" or name == "ip-ttl" or name == "rsvp-header-flags" or name == "rsvp-message-type" or name == "rsvp-ttl" or name == "rsvp-version"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "ip-source-address"):
                        self.ip_source_address = value
                        self.ip_source_address.value_namespace = name_space
                        self.ip_source_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "ip-tos"):
                        self.ip_tos = value
                        self.ip_tos.value_namespace = name_space
                        self.ip_tos.value_namespace_prefix = name_space_prefix
                    if(value_path == "ip-ttl"):
                        self.ip_ttl = value
                        self.ip_ttl.value_namespace = name_space
                        self.ip_ttl.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-header-flags"):
                        self.rsvp_header_flags = value
                        self.rsvp_header_flags.value_namespace = name_space
                        self.rsvp_header_flags.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-message-type"):
                        self.rsvp_message_type = value
                        self.rsvp_message_type.value_namespace = name_space
                        self.rsvp_message_type.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-ttl"):
                        self.rsvp_ttl = value
                        self.rsvp_ttl.value_namespace = name_space
                        self.rsvp_ttl.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-version"):
                        self.rsvp_version = value
                        self.rsvp_version.value_namespace = name_space
                        self.rsvp_version.value_namespace_prefix = name_space_prefix


            class ExpiryTime(Entity):
                """
                Expiry Time
                
                .. attribute:: nanoseconds
                
                	Time Value in Nano\-seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: nanosecond
                
                .. attribute:: seconds
                
                	Time Value in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.PsbDetaileds.PsbDetailed.ExpiryTime, self).__init__()

                    self.yang_name = "expiry-time"
                    self.yang_parent_name = "psb-detailed"

                    self.nanoseconds = YLeaf(YType.int32, "nanoseconds")

                    self.seconds = YLeaf(YType.int32, "seconds")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("nanoseconds",
                                    "seconds") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.PsbDetaileds.PsbDetailed.ExpiryTime, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.PsbDetaileds.PsbDetailed.ExpiryTime, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.nanoseconds.is_set or
                        self.seconds.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.nanoseconds.yfilter != YFilter.not_set or
                        self.seconds.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "expiry-time" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-detaileds/psb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.nanoseconds.is_set or self.nanoseconds.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.nanoseconds.get_name_leafdata())
                    if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.seconds.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "nanoseconds" or name == "seconds"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "nanoseconds"):
                        self.nanoseconds = value
                        self.nanoseconds.value_namespace = name_space
                        self.nanoseconds.value_namespace_prefix = name_space_prefix
                    if(value_path == "seconds"):
                        self.seconds = value
                        self.seconds.value_namespace = name_space
                        self.seconds.value_namespace_prefix = name_space_prefix


            class PolicyFlags(Entity):
                """
                Policy Flags
                
                .. attribute:: is_accepted
                
                	Accepted
                	**type**\:  bool
                
                .. attribute:: is_forwarding
                
                	Forwarding
                	**type**\:  bool
                
                .. attribute:: is_installed
                
                	Installed
                	**type**\:  bool
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.PsbDetaileds.PsbDetailed.PolicyFlags, self).__init__()

                    self.yang_name = "policy-flags"
                    self.yang_parent_name = "psb-detailed"

                    self.is_accepted = YLeaf(YType.boolean, "is-accepted")

                    self.is_forwarding = YLeaf(YType.boolean, "is-forwarding")

                    self.is_installed = YLeaf(YType.boolean, "is-installed")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("is_accepted",
                                    "is_forwarding",
                                    "is_installed") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.PsbDetaileds.PsbDetailed.PolicyFlags, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.PsbDetaileds.PsbDetailed.PolicyFlags, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.is_accepted.is_set or
                        self.is_forwarding.is_set or
                        self.is_installed.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.is_accepted.yfilter != YFilter.not_set or
                        self.is_forwarding.yfilter != YFilter.not_set or
                        self.is_installed.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "policy-flags" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-detaileds/psb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.is_accepted.is_set or self.is_accepted.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_accepted.get_name_leafdata())
                    if (self.is_forwarding.is_set or self.is_forwarding.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_forwarding.get_name_leafdata())
                    if (self.is_installed.is_set or self.is_installed.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_installed.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "is-accepted" or name == "is-forwarding" or name == "is-installed"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "is-accepted"):
                        self.is_accepted = value
                        self.is_accepted.value_namespace = name_space
                        self.is_accepted.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-forwarding"):
                        self.is_forwarding = value
                        self.is_forwarding.value_namespace = name_space
                        self.is_forwarding.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-installed"):
                        self.is_installed = value
                        self.is_installed.value_namespace = name_space
                        self.is_installed.value_namespace_prefix = name_space_prefix


            class PolicyQueryFlags(Entity):
                """
                Policy Query Flags
                
                .. attribute:: is_bypass
                
                	Bypass
                	**type**\:  bool
                
                .. attribute:: is_needed
                
                	Needed
                	**type**\:  bool
                
                .. attribute:: is_report_required
                
                	Report Required
                	**type**\:  bool
                
                .. attribute:: is_resync
                
                	Resynchronization
                	**type**\:  bool
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.PsbDetaileds.PsbDetailed.PolicyQueryFlags, self).__init__()

                    self.yang_name = "policy-query-flags"
                    self.yang_parent_name = "psb-detailed"

                    self.is_bypass = YLeaf(YType.boolean, "is-bypass")

                    self.is_needed = YLeaf(YType.boolean, "is-needed")

                    self.is_report_required = YLeaf(YType.boolean, "is-report-required")

                    self.is_resync = YLeaf(YType.boolean, "is-resync")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("is_bypass",
                                    "is_needed",
                                    "is_report_required",
                                    "is_resync") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.PsbDetaileds.PsbDetailed.PolicyQueryFlags, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.PsbDetaileds.PsbDetailed.PolicyQueryFlags, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.is_bypass.is_set or
                        self.is_needed.is_set or
                        self.is_report_required.is_set or
                        self.is_resync.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.is_bypass.yfilter != YFilter.not_set or
                        self.is_needed.yfilter != YFilter.not_set or
                        self.is_report_required.yfilter != YFilter.not_set or
                        self.is_resync.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "policy-query-flags" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-detaileds/psb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.is_bypass.is_set or self.is_bypass.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_bypass.get_name_leafdata())
                    if (self.is_needed.is_set or self.is_needed.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_needed.get_name_leafdata())
                    if (self.is_report_required.is_set or self.is_report_required.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_report_required.get_name_leafdata())
                    if (self.is_resync.is_set or self.is_resync.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_resync.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "is-bypass" or name == "is-needed" or name == "is-report-required" or name == "is-resync"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "is-bypass"):
                        self.is_bypass = value
                        self.is_bypass.value_namespace = name_space
                        self.is_bypass.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-needed"):
                        self.is_needed = value
                        self.is_needed.value_namespace = name_space
                        self.is_needed.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-report-required"):
                        self.is_report_required = value
                        self.is_report_required.value_namespace = name_space
                        self.is_report_required.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-resync"):
                        self.is_resync = value
                        self.is_resync.value_namespace = name_space
                        self.is_resync.value_namespace_prefix = name_space_prefix


            class LabelInfo(Entity):
                """
                Label Information
                
                .. attribute:: generic_local_downstream_label
                
                	Generic Local Downstream Label
                	**type**\:   :py:class:`GenericLocalDownstreamLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericLocalDownstreamLabel>`
                
                .. attribute:: generic_local_upstream_label
                
                	Generic Local Upstream Label
                	**type**\:   :py:class:`GenericLocalUpstreamLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericLocalUpstreamLabel>`
                
                .. attribute:: generic_merge_point_label
                
                	Generic MergePoint Label
                	**type**\:   :py:class:`GenericMergePointLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericMergePointLabel>`
                
                .. attribute:: generic_outgoing_downstream_label
                
                	Generic Outgoing Downstream Label
                	**type**\:   :py:class:`GenericOutgoingDownstreamLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericOutgoingDownstreamLabel>`
                
                .. attribute:: generic_outgoing_upstream_label
                
                	Generic Outgoing Upstream Label
                	**type**\:   :py:class:`GenericOutgoingUpstreamLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericOutgoingUpstreamLabel>`
                
                .. attribute:: generic_recovery_label
                
                	Generic Recovery Label
                	**type**\:   :py:class:`GenericRecoveryLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericRecoveryLabel>`
                
                .. attribute:: is_valid
                
                	Is the label information valid
                	**type**\:  bool
                
                .. attribute:: local_downstream_label
                
                	Local Downstream Label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: local_upstream_label
                
                	Local Upstream Label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: lsp_wrap_label
                
                	LSP Wrap Label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: merge_point_label
                
                	MergePoint Label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: outgoing_downstream_label
                
                	Outgoing Downstream Label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: outgoing_upstream_label
                
                	Outgoing Upstream Label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: recovery_label
                
                	Recovery Label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo, self).__init__()

                    self.yang_name = "label-info"
                    self.yang_parent_name = "psb-detailed"

                    self.is_valid = YLeaf(YType.boolean, "is-valid")

                    self.local_downstream_label = YLeaf(YType.uint32, "local-downstream-label")

                    self.local_upstream_label = YLeaf(YType.uint32, "local-upstream-label")

                    self.lsp_wrap_label = YLeaf(YType.uint32, "lsp-wrap-label")

                    self.merge_point_label = YLeaf(YType.uint32, "merge-point-label")

                    self.outgoing_downstream_label = YLeaf(YType.uint32, "outgoing-downstream-label")

                    self.outgoing_upstream_label = YLeaf(YType.uint32, "outgoing-upstream-label")

                    self.recovery_label = YLeaf(YType.uint32, "recovery-label")

                    self.generic_local_downstream_label = RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericLocalDownstreamLabel()
                    self.generic_local_downstream_label.parent = self
                    self._children_name_map["generic_local_downstream_label"] = "generic-local-downstream-label"
                    self._children_yang_names.add("generic-local-downstream-label")

                    self.generic_local_upstream_label = RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericLocalUpstreamLabel()
                    self.generic_local_upstream_label.parent = self
                    self._children_name_map["generic_local_upstream_label"] = "generic-local-upstream-label"
                    self._children_yang_names.add("generic-local-upstream-label")

                    self.generic_merge_point_label = RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericMergePointLabel()
                    self.generic_merge_point_label.parent = self
                    self._children_name_map["generic_merge_point_label"] = "generic-merge-point-label"
                    self._children_yang_names.add("generic-merge-point-label")

                    self.generic_outgoing_downstream_label = RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericOutgoingDownstreamLabel()
                    self.generic_outgoing_downstream_label.parent = self
                    self._children_name_map["generic_outgoing_downstream_label"] = "generic-outgoing-downstream-label"
                    self._children_yang_names.add("generic-outgoing-downstream-label")

                    self.generic_outgoing_upstream_label = RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericOutgoingUpstreamLabel()
                    self.generic_outgoing_upstream_label.parent = self
                    self._children_name_map["generic_outgoing_upstream_label"] = "generic-outgoing-upstream-label"
                    self._children_yang_names.add("generic-outgoing-upstream-label")

                    self.generic_recovery_label = RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericRecoveryLabel()
                    self.generic_recovery_label.parent = self
                    self._children_name_map["generic_recovery_label"] = "generic-recovery-label"
                    self._children_yang_names.add("generic-recovery-label")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("is_valid",
                                    "local_downstream_label",
                                    "local_upstream_label",
                                    "lsp_wrap_label",
                                    "merge_point_label",
                                    "outgoing_downstream_label",
                                    "outgoing_upstream_label",
                                    "recovery_label") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo, self).__setattr__(name, value)


                class GenericLocalDownstreamLabel(Entity):
                    """
                    Generic Local Downstream Label
                    
                    .. attribute:: generalized_label
                    
                    	Generalized Label
                    	**type**\:   :py:class:`GeneralizedLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericLocalDownstreamLabel.GeneralizedLabel>`
                    
                    .. attribute:: generic_label_type
                    
                    	GenericLabelType
                    	**type**\:   :py:class:`RsvpMgmtGenericLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtGenericLabel>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericLocalDownstreamLabel, self).__init__()

                        self.yang_name = "generic-local-downstream-label"
                        self.yang_parent_name = "label-info"

                        self.generic_label_type = YLeaf(YType.enumeration, "generic-label-type")

                        self.generalized_label = RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericLocalDownstreamLabel.GeneralizedLabel()
                        self.generalized_label.parent = self
                        self._children_name_map["generalized_label"] = "generalized-label"
                        self._children_yang_names.add("generalized-label")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("generic_label_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericLocalDownstreamLabel, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericLocalDownstreamLabel, self).__setattr__(name, value)


                    class GeneralizedLabel(Entity):
                        """
                        Generalized Label
                        
                        .. attribute:: value
                        
                        	Generalized Label Value
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericLocalDownstreamLabel.GeneralizedLabel, self).__init__()

                            self.yang_name = "generalized-label"
                            self.yang_parent_name = "generic-local-downstream-label"

                            self.value = YLeafList(YType.uint32, "value")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("value") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericLocalDownstreamLabel.GeneralizedLabel, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericLocalDownstreamLabel.GeneralizedLabel, self).__setattr__(name, value)

                        def has_data(self):
                            for leaf in self.value.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            return False

                        def has_operation(self):
                            for leaf in self.value.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.value.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "generalized-label" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-detaileds/psb-detailed/label-info/generic-local-downstream-label/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            leaf_name_data.extend(self.value.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "value"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "value"):
                                self.value.append(value)

                    def has_data(self):
                        return (
                            self.generic_label_type.is_set or
                            (self.generalized_label is not None and self.generalized_label.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.generic_label_type.yfilter != YFilter.not_set or
                            (self.generalized_label is not None and self.generalized_label.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "generic-local-downstream-label" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-detaileds/psb-detailed/label-info/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.generic_label_type.is_set or self.generic_label_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.generic_label_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "generalized-label"):
                            if (self.generalized_label is None):
                                self.generalized_label = RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericLocalDownstreamLabel.GeneralizedLabel()
                                self.generalized_label.parent = self
                                self._children_name_map["generalized_label"] = "generalized-label"
                            return self.generalized_label

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "generalized-label" or name == "generic-label-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "generic-label-type"):
                            self.generic_label_type = value
                            self.generic_label_type.value_namespace = name_space
                            self.generic_label_type.value_namespace_prefix = name_space_prefix


                class GenericOutgoingDownstreamLabel(Entity):
                    """
                    Generic Outgoing Downstream Label
                    
                    .. attribute:: generalized_label
                    
                    	Generalized Label
                    	**type**\:   :py:class:`GeneralizedLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericOutgoingDownstreamLabel.GeneralizedLabel>`
                    
                    .. attribute:: generic_label_type
                    
                    	GenericLabelType
                    	**type**\:   :py:class:`RsvpMgmtGenericLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtGenericLabel>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericOutgoingDownstreamLabel, self).__init__()

                        self.yang_name = "generic-outgoing-downstream-label"
                        self.yang_parent_name = "label-info"

                        self.generic_label_type = YLeaf(YType.enumeration, "generic-label-type")

                        self.generalized_label = RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericOutgoingDownstreamLabel.GeneralizedLabel()
                        self.generalized_label.parent = self
                        self._children_name_map["generalized_label"] = "generalized-label"
                        self._children_yang_names.add("generalized-label")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("generic_label_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericOutgoingDownstreamLabel, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericOutgoingDownstreamLabel, self).__setattr__(name, value)


                    class GeneralizedLabel(Entity):
                        """
                        Generalized Label
                        
                        .. attribute:: value
                        
                        	Generalized Label Value
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericOutgoingDownstreamLabel.GeneralizedLabel, self).__init__()

                            self.yang_name = "generalized-label"
                            self.yang_parent_name = "generic-outgoing-downstream-label"

                            self.value = YLeafList(YType.uint32, "value")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("value") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericOutgoingDownstreamLabel.GeneralizedLabel, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericOutgoingDownstreamLabel.GeneralizedLabel, self).__setattr__(name, value)

                        def has_data(self):
                            for leaf in self.value.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            return False

                        def has_operation(self):
                            for leaf in self.value.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.value.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "generalized-label" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-detaileds/psb-detailed/label-info/generic-outgoing-downstream-label/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            leaf_name_data.extend(self.value.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "value"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "value"):
                                self.value.append(value)

                    def has_data(self):
                        return (
                            self.generic_label_type.is_set or
                            (self.generalized_label is not None and self.generalized_label.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.generic_label_type.yfilter != YFilter.not_set or
                            (self.generalized_label is not None and self.generalized_label.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "generic-outgoing-downstream-label" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-detaileds/psb-detailed/label-info/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.generic_label_type.is_set or self.generic_label_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.generic_label_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "generalized-label"):
                            if (self.generalized_label is None):
                                self.generalized_label = RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericOutgoingDownstreamLabel.GeneralizedLabel()
                                self.generalized_label.parent = self
                                self._children_name_map["generalized_label"] = "generalized-label"
                            return self.generalized_label

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "generalized-label" or name == "generic-label-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "generic-label-type"):
                            self.generic_label_type = value
                            self.generic_label_type.value_namespace = name_space
                            self.generic_label_type.value_namespace_prefix = name_space_prefix


                class GenericMergePointLabel(Entity):
                    """
                    Generic MergePoint Label
                    
                    .. attribute:: generalized_label
                    
                    	Generalized Label
                    	**type**\:   :py:class:`GeneralizedLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericMergePointLabel.GeneralizedLabel>`
                    
                    .. attribute:: generic_label_type
                    
                    	GenericLabelType
                    	**type**\:   :py:class:`RsvpMgmtGenericLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtGenericLabel>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericMergePointLabel, self).__init__()

                        self.yang_name = "generic-merge-point-label"
                        self.yang_parent_name = "label-info"

                        self.generic_label_type = YLeaf(YType.enumeration, "generic-label-type")

                        self.generalized_label = RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericMergePointLabel.GeneralizedLabel()
                        self.generalized_label.parent = self
                        self._children_name_map["generalized_label"] = "generalized-label"
                        self._children_yang_names.add("generalized-label")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("generic_label_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericMergePointLabel, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericMergePointLabel, self).__setattr__(name, value)


                    class GeneralizedLabel(Entity):
                        """
                        Generalized Label
                        
                        .. attribute:: value
                        
                        	Generalized Label Value
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericMergePointLabel.GeneralizedLabel, self).__init__()

                            self.yang_name = "generalized-label"
                            self.yang_parent_name = "generic-merge-point-label"

                            self.value = YLeafList(YType.uint32, "value")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("value") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericMergePointLabel.GeneralizedLabel, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericMergePointLabel.GeneralizedLabel, self).__setattr__(name, value)

                        def has_data(self):
                            for leaf in self.value.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            return False

                        def has_operation(self):
                            for leaf in self.value.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.value.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "generalized-label" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-detaileds/psb-detailed/label-info/generic-merge-point-label/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            leaf_name_data.extend(self.value.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "value"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "value"):
                                self.value.append(value)

                    def has_data(self):
                        return (
                            self.generic_label_type.is_set or
                            (self.generalized_label is not None and self.generalized_label.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.generic_label_type.yfilter != YFilter.not_set or
                            (self.generalized_label is not None and self.generalized_label.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "generic-merge-point-label" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-detaileds/psb-detailed/label-info/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.generic_label_type.is_set or self.generic_label_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.generic_label_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "generalized-label"):
                            if (self.generalized_label is None):
                                self.generalized_label = RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericMergePointLabel.GeneralizedLabel()
                                self.generalized_label.parent = self
                                self._children_name_map["generalized_label"] = "generalized-label"
                            return self.generalized_label

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "generalized-label" or name == "generic-label-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "generic-label-type"):
                            self.generic_label_type = value
                            self.generic_label_type.value_namespace = name_space
                            self.generic_label_type.value_namespace_prefix = name_space_prefix


                class GenericOutgoingUpstreamLabel(Entity):
                    """
                    Generic Outgoing Upstream Label
                    
                    .. attribute:: generalized_label
                    
                    	Generalized Label
                    	**type**\:   :py:class:`GeneralizedLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericOutgoingUpstreamLabel.GeneralizedLabel>`
                    
                    .. attribute:: generic_label_type
                    
                    	GenericLabelType
                    	**type**\:   :py:class:`RsvpMgmtGenericLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtGenericLabel>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericOutgoingUpstreamLabel, self).__init__()

                        self.yang_name = "generic-outgoing-upstream-label"
                        self.yang_parent_name = "label-info"

                        self.generic_label_type = YLeaf(YType.enumeration, "generic-label-type")

                        self.generalized_label = RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericOutgoingUpstreamLabel.GeneralizedLabel()
                        self.generalized_label.parent = self
                        self._children_name_map["generalized_label"] = "generalized-label"
                        self._children_yang_names.add("generalized-label")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("generic_label_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericOutgoingUpstreamLabel, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericOutgoingUpstreamLabel, self).__setattr__(name, value)


                    class GeneralizedLabel(Entity):
                        """
                        Generalized Label
                        
                        .. attribute:: value
                        
                        	Generalized Label Value
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericOutgoingUpstreamLabel.GeneralizedLabel, self).__init__()

                            self.yang_name = "generalized-label"
                            self.yang_parent_name = "generic-outgoing-upstream-label"

                            self.value = YLeafList(YType.uint32, "value")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("value") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericOutgoingUpstreamLabel.GeneralizedLabel, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericOutgoingUpstreamLabel.GeneralizedLabel, self).__setattr__(name, value)

                        def has_data(self):
                            for leaf in self.value.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            return False

                        def has_operation(self):
                            for leaf in self.value.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.value.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "generalized-label" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-detaileds/psb-detailed/label-info/generic-outgoing-upstream-label/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            leaf_name_data.extend(self.value.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "value"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "value"):
                                self.value.append(value)

                    def has_data(self):
                        return (
                            self.generic_label_type.is_set or
                            (self.generalized_label is not None and self.generalized_label.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.generic_label_type.yfilter != YFilter.not_set or
                            (self.generalized_label is not None and self.generalized_label.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "generic-outgoing-upstream-label" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-detaileds/psb-detailed/label-info/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.generic_label_type.is_set or self.generic_label_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.generic_label_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "generalized-label"):
                            if (self.generalized_label is None):
                                self.generalized_label = RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericOutgoingUpstreamLabel.GeneralizedLabel()
                                self.generalized_label.parent = self
                                self._children_name_map["generalized_label"] = "generalized-label"
                            return self.generalized_label

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "generalized-label" or name == "generic-label-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "generic-label-type"):
                            self.generic_label_type = value
                            self.generic_label_type.value_namespace = name_space
                            self.generic_label_type.value_namespace_prefix = name_space_prefix


                class GenericLocalUpstreamLabel(Entity):
                    """
                    Generic Local Upstream Label
                    
                    .. attribute:: generalized_label
                    
                    	Generalized Label
                    	**type**\:   :py:class:`GeneralizedLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericLocalUpstreamLabel.GeneralizedLabel>`
                    
                    .. attribute:: generic_label_type
                    
                    	GenericLabelType
                    	**type**\:   :py:class:`RsvpMgmtGenericLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtGenericLabel>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericLocalUpstreamLabel, self).__init__()

                        self.yang_name = "generic-local-upstream-label"
                        self.yang_parent_name = "label-info"

                        self.generic_label_type = YLeaf(YType.enumeration, "generic-label-type")

                        self.generalized_label = RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericLocalUpstreamLabel.GeneralizedLabel()
                        self.generalized_label.parent = self
                        self._children_name_map["generalized_label"] = "generalized-label"
                        self._children_yang_names.add("generalized-label")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("generic_label_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericLocalUpstreamLabel, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericLocalUpstreamLabel, self).__setattr__(name, value)


                    class GeneralizedLabel(Entity):
                        """
                        Generalized Label
                        
                        .. attribute:: value
                        
                        	Generalized Label Value
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericLocalUpstreamLabel.GeneralizedLabel, self).__init__()

                            self.yang_name = "generalized-label"
                            self.yang_parent_name = "generic-local-upstream-label"

                            self.value = YLeafList(YType.uint32, "value")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("value") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericLocalUpstreamLabel.GeneralizedLabel, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericLocalUpstreamLabel.GeneralizedLabel, self).__setattr__(name, value)

                        def has_data(self):
                            for leaf in self.value.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            return False

                        def has_operation(self):
                            for leaf in self.value.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.value.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "generalized-label" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-detaileds/psb-detailed/label-info/generic-local-upstream-label/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            leaf_name_data.extend(self.value.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "value"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "value"):
                                self.value.append(value)

                    def has_data(self):
                        return (
                            self.generic_label_type.is_set or
                            (self.generalized_label is not None and self.generalized_label.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.generic_label_type.yfilter != YFilter.not_set or
                            (self.generalized_label is not None and self.generalized_label.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "generic-local-upstream-label" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-detaileds/psb-detailed/label-info/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.generic_label_type.is_set or self.generic_label_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.generic_label_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "generalized-label"):
                            if (self.generalized_label is None):
                                self.generalized_label = RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericLocalUpstreamLabel.GeneralizedLabel()
                                self.generalized_label.parent = self
                                self._children_name_map["generalized_label"] = "generalized-label"
                            return self.generalized_label

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "generalized-label" or name == "generic-label-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "generic-label-type"):
                            self.generic_label_type = value
                            self.generic_label_type.value_namespace = name_space
                            self.generic_label_type.value_namespace_prefix = name_space_prefix


                class GenericRecoveryLabel(Entity):
                    """
                    Generic Recovery Label
                    
                    .. attribute:: generalized_label
                    
                    	Generalized Label
                    	**type**\:   :py:class:`GeneralizedLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericRecoveryLabel.GeneralizedLabel>`
                    
                    .. attribute:: generic_label_type
                    
                    	GenericLabelType
                    	**type**\:   :py:class:`RsvpMgmtGenericLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtGenericLabel>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericRecoveryLabel, self).__init__()

                        self.yang_name = "generic-recovery-label"
                        self.yang_parent_name = "label-info"

                        self.generic_label_type = YLeaf(YType.enumeration, "generic-label-type")

                        self.generalized_label = RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericRecoveryLabel.GeneralizedLabel()
                        self.generalized_label.parent = self
                        self._children_name_map["generalized_label"] = "generalized-label"
                        self._children_yang_names.add("generalized-label")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("generic_label_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericRecoveryLabel, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericRecoveryLabel, self).__setattr__(name, value)


                    class GeneralizedLabel(Entity):
                        """
                        Generalized Label
                        
                        .. attribute:: value
                        
                        	Generalized Label Value
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericRecoveryLabel.GeneralizedLabel, self).__init__()

                            self.yang_name = "generalized-label"
                            self.yang_parent_name = "generic-recovery-label"

                            self.value = YLeafList(YType.uint32, "value")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("value") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericRecoveryLabel.GeneralizedLabel, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericRecoveryLabel.GeneralizedLabel, self).__setattr__(name, value)

                        def has_data(self):
                            for leaf in self.value.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            return False

                        def has_operation(self):
                            for leaf in self.value.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.value.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "generalized-label" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-detaileds/psb-detailed/label-info/generic-recovery-label/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            leaf_name_data.extend(self.value.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "value"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "value"):
                                self.value.append(value)

                    def has_data(self):
                        return (
                            self.generic_label_type.is_set or
                            (self.generalized_label is not None and self.generalized_label.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.generic_label_type.yfilter != YFilter.not_set or
                            (self.generalized_label is not None and self.generalized_label.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "generic-recovery-label" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-detaileds/psb-detailed/label-info/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.generic_label_type.is_set or self.generic_label_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.generic_label_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "generalized-label"):
                            if (self.generalized_label is None):
                                self.generalized_label = RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericRecoveryLabel.GeneralizedLabel()
                                self.generalized_label.parent = self
                                self._children_name_map["generalized_label"] = "generalized-label"
                            return self.generalized_label

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "generalized-label" or name == "generic-label-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "generic-label-type"):
                            self.generic_label_type = value
                            self.generic_label_type.value_namespace = name_space
                            self.generic_label_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.is_valid.is_set or
                        self.local_downstream_label.is_set or
                        self.local_upstream_label.is_set or
                        self.lsp_wrap_label.is_set or
                        self.merge_point_label.is_set or
                        self.outgoing_downstream_label.is_set or
                        self.outgoing_upstream_label.is_set or
                        self.recovery_label.is_set or
                        (self.generic_local_downstream_label is not None and self.generic_local_downstream_label.has_data()) or
                        (self.generic_local_upstream_label is not None and self.generic_local_upstream_label.has_data()) or
                        (self.generic_merge_point_label is not None and self.generic_merge_point_label.has_data()) or
                        (self.generic_outgoing_downstream_label is not None and self.generic_outgoing_downstream_label.has_data()) or
                        (self.generic_outgoing_upstream_label is not None and self.generic_outgoing_upstream_label.has_data()) or
                        (self.generic_recovery_label is not None and self.generic_recovery_label.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.is_valid.yfilter != YFilter.not_set or
                        self.local_downstream_label.yfilter != YFilter.not_set or
                        self.local_upstream_label.yfilter != YFilter.not_set or
                        self.lsp_wrap_label.yfilter != YFilter.not_set or
                        self.merge_point_label.yfilter != YFilter.not_set or
                        self.outgoing_downstream_label.yfilter != YFilter.not_set or
                        self.outgoing_upstream_label.yfilter != YFilter.not_set or
                        self.recovery_label.yfilter != YFilter.not_set or
                        (self.generic_local_downstream_label is not None and self.generic_local_downstream_label.has_operation()) or
                        (self.generic_local_upstream_label is not None and self.generic_local_upstream_label.has_operation()) or
                        (self.generic_merge_point_label is not None and self.generic_merge_point_label.has_operation()) or
                        (self.generic_outgoing_downstream_label is not None and self.generic_outgoing_downstream_label.has_operation()) or
                        (self.generic_outgoing_upstream_label is not None and self.generic_outgoing_upstream_label.has_operation()) or
                        (self.generic_recovery_label is not None and self.generic_recovery_label.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "label-info" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-detaileds/psb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_valid.get_name_leafdata())
                    if (self.local_downstream_label.is_set or self.local_downstream_label.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.local_downstream_label.get_name_leafdata())
                    if (self.local_upstream_label.is_set or self.local_upstream_label.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.local_upstream_label.get_name_leafdata())
                    if (self.lsp_wrap_label.is_set or self.lsp_wrap_label.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.lsp_wrap_label.get_name_leafdata())
                    if (self.merge_point_label.is_set or self.merge_point_label.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.merge_point_label.get_name_leafdata())
                    if (self.outgoing_downstream_label.is_set or self.outgoing_downstream_label.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.outgoing_downstream_label.get_name_leafdata())
                    if (self.outgoing_upstream_label.is_set or self.outgoing_upstream_label.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.outgoing_upstream_label.get_name_leafdata())
                    if (self.recovery_label.is_set or self.recovery_label.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.recovery_label.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "generic-local-downstream-label"):
                        if (self.generic_local_downstream_label is None):
                            self.generic_local_downstream_label = RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericLocalDownstreamLabel()
                            self.generic_local_downstream_label.parent = self
                            self._children_name_map["generic_local_downstream_label"] = "generic-local-downstream-label"
                        return self.generic_local_downstream_label

                    if (child_yang_name == "generic-local-upstream-label"):
                        if (self.generic_local_upstream_label is None):
                            self.generic_local_upstream_label = RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericLocalUpstreamLabel()
                            self.generic_local_upstream_label.parent = self
                            self._children_name_map["generic_local_upstream_label"] = "generic-local-upstream-label"
                        return self.generic_local_upstream_label

                    if (child_yang_name == "generic-merge-point-label"):
                        if (self.generic_merge_point_label is None):
                            self.generic_merge_point_label = RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericMergePointLabel()
                            self.generic_merge_point_label.parent = self
                            self._children_name_map["generic_merge_point_label"] = "generic-merge-point-label"
                        return self.generic_merge_point_label

                    if (child_yang_name == "generic-outgoing-downstream-label"):
                        if (self.generic_outgoing_downstream_label is None):
                            self.generic_outgoing_downstream_label = RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericOutgoingDownstreamLabel()
                            self.generic_outgoing_downstream_label.parent = self
                            self._children_name_map["generic_outgoing_downstream_label"] = "generic-outgoing-downstream-label"
                        return self.generic_outgoing_downstream_label

                    if (child_yang_name == "generic-outgoing-upstream-label"):
                        if (self.generic_outgoing_upstream_label is None):
                            self.generic_outgoing_upstream_label = RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericOutgoingUpstreamLabel()
                            self.generic_outgoing_upstream_label.parent = self
                            self._children_name_map["generic_outgoing_upstream_label"] = "generic-outgoing-upstream-label"
                        return self.generic_outgoing_upstream_label

                    if (child_yang_name == "generic-recovery-label"):
                        if (self.generic_recovery_label is None):
                            self.generic_recovery_label = RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo.GenericRecoveryLabel()
                            self.generic_recovery_label.parent = self
                            self._children_name_map["generic_recovery_label"] = "generic-recovery-label"
                        return self.generic_recovery_label

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "generic-local-downstream-label" or name == "generic-local-upstream-label" or name == "generic-merge-point-label" or name == "generic-outgoing-downstream-label" or name == "generic-outgoing-upstream-label" or name == "generic-recovery-label" or name == "is-valid" or name == "local-downstream-label" or name == "local-upstream-label" or name == "lsp-wrap-label" or name == "merge-point-label" or name == "outgoing-downstream-label" or name == "outgoing-upstream-label" or name == "recovery-label"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "is-valid"):
                        self.is_valid = value
                        self.is_valid.value_namespace = name_space
                        self.is_valid.value_namespace_prefix = name_space_prefix
                    if(value_path == "local-downstream-label"):
                        self.local_downstream_label = value
                        self.local_downstream_label.value_namespace = name_space
                        self.local_downstream_label.value_namespace_prefix = name_space_prefix
                    if(value_path == "local-upstream-label"):
                        self.local_upstream_label = value
                        self.local_upstream_label.value_namespace = name_space
                        self.local_upstream_label.value_namespace_prefix = name_space_prefix
                    if(value_path == "lsp-wrap-label"):
                        self.lsp_wrap_label = value
                        self.lsp_wrap_label.value_namespace = name_space
                        self.lsp_wrap_label.value_namespace_prefix = name_space_prefix
                    if(value_path == "merge-point-label"):
                        self.merge_point_label = value
                        self.merge_point_label.value_namespace = name_space
                        self.merge_point_label.value_namespace_prefix = name_space_prefix
                    if(value_path == "outgoing-downstream-label"):
                        self.outgoing_downstream_label = value
                        self.outgoing_downstream_label.value_namespace = name_space
                        self.outgoing_downstream_label.value_namespace_prefix = name_space_prefix
                    if(value_path == "outgoing-upstream-label"):
                        self.outgoing_upstream_label = value
                        self.outgoing_upstream_label.value_namespace = name_space
                        self.outgoing_upstream_label.value_namespace_prefix = name_space_prefix
                    if(value_path == "recovery-label"):
                        self.recovery_label = value
                        self.recovery_label.value_namespace = name_space
                        self.recovery_label.value_namespace_prefix = name_space_prefix


            class ClassType(Entity):
                """
                DS\-TE Class\-Type
                
                .. attribute:: class_type
                
                	DS\-TE Class\-Type
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: is_class_type_info_valid
                
                	Is the Class\-Type information valid
                	**type**\:  bool
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.PsbDetaileds.PsbDetailed.ClassType, self).__init__()

                    self.yang_name = "class-type"
                    self.yang_parent_name = "psb-detailed"

                    self.class_type = YLeaf(YType.uint8, "class-type")

                    self.is_class_type_info_valid = YLeaf(YType.boolean, "is-class-type-info-valid")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("class_type",
                                    "is_class_type_info_valid") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.PsbDetaileds.PsbDetailed.ClassType, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.PsbDetaileds.PsbDetailed.ClassType, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.class_type.is_set or
                        self.is_class_type_info_valid.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.class_type.yfilter != YFilter.not_set or
                        self.is_class_type_info_valid.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "class-type" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-detaileds/psb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.class_type.is_set or self.class_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.class_type.get_name_leafdata())
                    if (self.is_class_type_info_valid.is_set or self.is_class_type_info_valid.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_class_type_info_valid.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "class-type" or name == "is-class-type-info-valid"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "class-type"):
                        self.class_type = value
                        self.class_type.value_namespace = name_space
                        self.class_type.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-class-type-info-valid"):
                        self.is_class_type_info_valid = value
                        self.is_class_type_info_valid.value_namespace = name_space
                        self.is_class_type_info_valid.value_namespace_prefix = name_space_prefix


            class Pfc(Entity):
                """
                Path Forwarding Contexts
                
                .. attribute:: output_interface
                
                	Output interface
                	**type**\:  str
                
                .. attribute:: policy_flags
                
                	Policy Flags
                	**type**\:   :py:class:`PolicyFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbDetaileds.PsbDetailed.Pfc.PolicyFlags>`
                
                .. attribute:: policy_query_flags
                
                	Policy Query Flags
                	**type**\:   :py:class:`PolicyQueryFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbDetaileds.PsbDetailed.Pfc.PolicyQueryFlags>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.PsbDetaileds.PsbDetailed.Pfc, self).__init__()

                    self.yang_name = "pfc"
                    self.yang_parent_name = "psb-detailed"

                    self.output_interface = YLeaf(YType.str, "output-interface")

                    self.policy_flags = RsvpStandby.PsbDetaileds.PsbDetailed.Pfc.PolicyFlags()
                    self.policy_flags.parent = self
                    self._children_name_map["policy_flags"] = "policy-flags"
                    self._children_yang_names.add("policy-flags")

                    self.policy_query_flags = RsvpStandby.PsbDetaileds.PsbDetailed.Pfc.PolicyQueryFlags()
                    self.policy_query_flags.parent = self
                    self._children_name_map["policy_query_flags"] = "policy-query-flags"
                    self._children_yang_names.add("policy-query-flags")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("output_interface") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.PsbDetaileds.PsbDetailed.Pfc, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.PsbDetaileds.PsbDetailed.Pfc, self).__setattr__(name, value)


                class PolicyFlags(Entity):
                    """
                    Policy Flags
                    
                    .. attribute:: is_accepted
                    
                    	Accepted
                    	**type**\:  bool
                    
                    .. attribute:: is_forwarding
                    
                    	Forwarding
                    	**type**\:  bool
                    
                    .. attribute:: is_installed
                    
                    	Installed
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.PsbDetaileds.PsbDetailed.Pfc.PolicyFlags, self).__init__()

                        self.yang_name = "policy-flags"
                        self.yang_parent_name = "pfc"

                        self.is_accepted = YLeaf(YType.boolean, "is-accepted")

                        self.is_forwarding = YLeaf(YType.boolean, "is-forwarding")

                        self.is_installed = YLeaf(YType.boolean, "is-installed")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("is_accepted",
                                        "is_forwarding",
                                        "is_installed") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.PsbDetaileds.PsbDetailed.Pfc.PolicyFlags, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.PsbDetaileds.PsbDetailed.Pfc.PolicyFlags, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.is_accepted.is_set or
                            self.is_forwarding.is_set or
                            self.is_installed.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.is_accepted.yfilter != YFilter.not_set or
                            self.is_forwarding.yfilter != YFilter.not_set or
                            self.is_installed.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "policy-flags" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-detaileds/psb-detailed/pfc/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.is_accepted.is_set or self.is_accepted.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_accepted.get_name_leafdata())
                        if (self.is_forwarding.is_set or self.is_forwarding.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_forwarding.get_name_leafdata())
                        if (self.is_installed.is_set or self.is_installed.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_installed.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "is-accepted" or name == "is-forwarding" or name == "is-installed"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "is-accepted"):
                            self.is_accepted = value
                            self.is_accepted.value_namespace = name_space
                            self.is_accepted.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-forwarding"):
                            self.is_forwarding = value
                            self.is_forwarding.value_namespace = name_space
                            self.is_forwarding.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-installed"):
                            self.is_installed = value
                            self.is_installed.value_namespace = name_space
                            self.is_installed.value_namespace_prefix = name_space_prefix


                class PolicyQueryFlags(Entity):
                    """
                    Policy Query Flags
                    
                    .. attribute:: is_bypass
                    
                    	Bypass
                    	**type**\:  bool
                    
                    .. attribute:: is_needed
                    
                    	Needed
                    	**type**\:  bool
                    
                    .. attribute:: is_report_required
                    
                    	Report Required
                    	**type**\:  bool
                    
                    .. attribute:: is_resync
                    
                    	Resynchronization
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.PsbDetaileds.PsbDetailed.Pfc.PolicyQueryFlags, self).__init__()

                        self.yang_name = "policy-query-flags"
                        self.yang_parent_name = "pfc"

                        self.is_bypass = YLeaf(YType.boolean, "is-bypass")

                        self.is_needed = YLeaf(YType.boolean, "is-needed")

                        self.is_report_required = YLeaf(YType.boolean, "is-report-required")

                        self.is_resync = YLeaf(YType.boolean, "is-resync")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("is_bypass",
                                        "is_needed",
                                        "is_report_required",
                                        "is_resync") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.PsbDetaileds.PsbDetailed.Pfc.PolicyQueryFlags, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.PsbDetaileds.PsbDetailed.Pfc.PolicyQueryFlags, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.is_bypass.is_set or
                            self.is_needed.is_set or
                            self.is_report_required.is_set or
                            self.is_resync.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.is_bypass.yfilter != YFilter.not_set or
                            self.is_needed.yfilter != YFilter.not_set or
                            self.is_report_required.yfilter != YFilter.not_set or
                            self.is_resync.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "policy-query-flags" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-detaileds/psb-detailed/pfc/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.is_bypass.is_set or self.is_bypass.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_bypass.get_name_leafdata())
                        if (self.is_needed.is_set or self.is_needed.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_needed.get_name_leafdata())
                        if (self.is_report_required.is_set or self.is_report_required.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_report_required.get_name_leafdata())
                        if (self.is_resync.is_set or self.is_resync.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_resync.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "is-bypass" or name == "is-needed" or name == "is-report-required" or name == "is-resync"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "is-bypass"):
                            self.is_bypass = value
                            self.is_bypass.value_namespace = name_space
                            self.is_bypass.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-needed"):
                            self.is_needed = value
                            self.is_needed.value_namespace = name_space
                            self.is_needed.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-report-required"):
                            self.is_report_required = value
                            self.is_report_required.value_namespace = name_space
                            self.is_report_required.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-resync"):
                            self.is_resync = value
                            self.is_resync.value_namespace = name_space
                            self.is_resync.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.output_interface.is_set or
                        (self.policy_flags is not None and self.policy_flags.has_data()) or
                        (self.policy_query_flags is not None and self.policy_query_flags.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.output_interface.yfilter != YFilter.not_set or
                        (self.policy_flags is not None and self.policy_flags.has_operation()) or
                        (self.policy_query_flags is not None and self.policy_query_flags.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "pfc" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-detaileds/psb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.output_interface.is_set or self.output_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_interface.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "policy-flags"):
                        if (self.policy_flags is None):
                            self.policy_flags = RsvpStandby.PsbDetaileds.PsbDetailed.Pfc.PolicyFlags()
                            self.policy_flags.parent = self
                            self._children_name_map["policy_flags"] = "policy-flags"
                        return self.policy_flags

                    if (child_yang_name == "policy-query-flags"):
                        if (self.policy_query_flags is None):
                            self.policy_query_flags = RsvpStandby.PsbDetaileds.PsbDetailed.Pfc.PolicyQueryFlags()
                            self.policy_query_flags.parent = self
                            self._children_name_map["policy_query_flags"] = "policy-query-flags"
                        return self.policy_query_flags

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "policy-flags" or name == "policy-query-flags" or name == "output-interface"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "output-interface"):
                        self.output_interface = value
                        self.output_interface.value_namespace = name_space
                        self.output_interface.value_namespace_prefix = name_space_prefix


            class InEro(Entity):
                """
                Incoming Explicit Route Sub Objects
                
                .. attribute:: ero_type
                
                	EROType
                	**type**\:   :py:class:`RsvpMgmtEroSubobj <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtEroSubobj>`
                
                .. attribute:: ipv4ero_sub_object
                
                	IPV4 ERO Sub Object
                	**type**\:   :py:class:`Ipv4EroSubObject <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbDetaileds.PsbDetailed.InEro.Ipv4EroSubObject>`
                
                .. attribute:: unnumbered_ero_sub_object
                
                	Unnumbered ERO Sub Object
                	**type**\:   :py:class:`UnnumberedEroSubObject <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbDetaileds.PsbDetailed.InEro.UnnumberedEroSubObject>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.PsbDetaileds.PsbDetailed.InEro, self).__init__()

                    self.yang_name = "in-ero"
                    self.yang_parent_name = "psb-detailed"

                    self.ero_type = YLeaf(YType.enumeration, "ero-type")

                    self.ipv4ero_sub_object = RsvpStandby.PsbDetaileds.PsbDetailed.InEro.Ipv4EroSubObject()
                    self.ipv4ero_sub_object.parent = self
                    self._children_name_map["ipv4ero_sub_object"] = "ipv4ero-sub-object"
                    self._children_yang_names.add("ipv4ero-sub-object")

                    self.unnumbered_ero_sub_object = RsvpStandby.PsbDetaileds.PsbDetailed.InEro.UnnumberedEroSubObject()
                    self.unnumbered_ero_sub_object.parent = self
                    self._children_name_map["unnumbered_ero_sub_object"] = "unnumbered-ero-sub-object"
                    self._children_yang_names.add("unnumbered-ero-sub-object")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("ero_type") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.PsbDetaileds.PsbDetailed.InEro, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.PsbDetaileds.PsbDetailed.InEro, self).__setattr__(name, value)


                class Ipv4EroSubObject(Entity):
                    """
                    IPV4 ERO Sub Object
                    
                    .. attribute:: ero_address
                    
                    	The ERO IPV4 Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: is_strict_route
                    
                    	ERO Entry Is Strict
                    	**type**\:  bool
                    
                    .. attribute:: prefix_length
                    
                    	ERO Prefix Length
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.PsbDetaileds.PsbDetailed.InEro.Ipv4EroSubObject, self).__init__()

                        self.yang_name = "ipv4ero-sub-object"
                        self.yang_parent_name = "in-ero"

                        self.ero_address = YLeaf(YType.str, "ero-address")

                        self.is_strict_route = YLeaf(YType.boolean, "is-strict-route")

                        self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("ero_address",
                                        "is_strict_route",
                                        "prefix_length") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.PsbDetaileds.PsbDetailed.InEro.Ipv4EroSubObject, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.PsbDetaileds.PsbDetailed.InEro.Ipv4EroSubObject, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.ero_address.is_set or
                            self.is_strict_route.is_set or
                            self.prefix_length.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.ero_address.yfilter != YFilter.not_set or
                            self.is_strict_route.yfilter != YFilter.not_set or
                            self.prefix_length.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ipv4ero-sub-object" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-detaileds/psb-detailed/in-ero/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.ero_address.is_set or self.ero_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ero_address.get_name_leafdata())
                        if (self.is_strict_route.is_set or self.is_strict_route.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_strict_route.get_name_leafdata())
                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix_length.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ero-address" or name == "is-strict-route" or name == "prefix-length"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "ero-address"):
                            self.ero_address = value
                            self.ero_address.value_namespace = name_space
                            self.ero_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-strict-route"):
                            self.is_strict_route = value
                            self.is_strict_route.value_namespace = name_space
                            self.is_strict_route.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix-length"):
                            self.prefix_length = value
                            self.prefix_length.value_namespace = name_space
                            self.prefix_length.value_namespace_prefix = name_space_prefix


                class UnnumberedEroSubObject(Entity):
                    """
                    Unnumbered ERO Sub Object
                    
                    .. attribute:: ero_interface_id
                    
                    	The Interface ID in ERO
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ero_router_id
                    
                    	The Router ID in ERO
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: is_strict_route
                    
                    	ERO Entry Is Strict
                    	**type**\:  bool
                    
                    .. attribute:: status
                    
                    	Status of ERO
                    	**type**\:   :py:class:`RsvpMgmtEroSubobjStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtEroSubobjStatus>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.PsbDetaileds.PsbDetailed.InEro.UnnumberedEroSubObject, self).__init__()

                        self.yang_name = "unnumbered-ero-sub-object"
                        self.yang_parent_name = "in-ero"

                        self.ero_interface_id = YLeaf(YType.uint32, "ero-interface-id")

                        self.ero_router_id = YLeaf(YType.str, "ero-router-id")

                        self.is_strict_route = YLeaf(YType.boolean, "is-strict-route")

                        self.status = YLeaf(YType.enumeration, "status")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("ero_interface_id",
                                        "ero_router_id",
                                        "is_strict_route",
                                        "status") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.PsbDetaileds.PsbDetailed.InEro.UnnumberedEroSubObject, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.PsbDetaileds.PsbDetailed.InEro.UnnumberedEroSubObject, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.ero_interface_id.is_set or
                            self.ero_router_id.is_set or
                            self.is_strict_route.is_set or
                            self.status.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.ero_interface_id.yfilter != YFilter.not_set or
                            self.ero_router_id.yfilter != YFilter.not_set or
                            self.is_strict_route.yfilter != YFilter.not_set or
                            self.status.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "unnumbered-ero-sub-object" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-detaileds/psb-detailed/in-ero/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.ero_interface_id.is_set or self.ero_interface_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ero_interface_id.get_name_leafdata())
                        if (self.ero_router_id.is_set or self.ero_router_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ero_router_id.get_name_leafdata())
                        if (self.is_strict_route.is_set or self.is_strict_route.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_strict_route.get_name_leafdata())
                        if (self.status.is_set or self.status.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.status.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ero-interface-id" or name == "ero-router-id" or name == "is-strict-route" or name == "status"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "ero-interface-id"):
                            self.ero_interface_id = value
                            self.ero_interface_id.value_namespace = name_space
                            self.ero_interface_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "ero-router-id"):
                            self.ero_router_id = value
                            self.ero_router_id.value_namespace = name_space
                            self.ero_router_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-strict-route"):
                            self.is_strict_route = value
                            self.is_strict_route.value_namespace = name_space
                            self.is_strict_route.value_namespace_prefix = name_space_prefix
                        if(value_path == "status"):
                            self.status = value
                            self.status.value_namespace = name_space
                            self.status.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.ero_type.is_set or
                        (self.ipv4ero_sub_object is not None and self.ipv4ero_sub_object.has_data()) or
                        (self.unnumbered_ero_sub_object is not None and self.unnumbered_ero_sub_object.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.ero_type.yfilter != YFilter.not_set or
                        (self.ipv4ero_sub_object is not None and self.ipv4ero_sub_object.has_operation()) or
                        (self.unnumbered_ero_sub_object is not None and self.unnumbered_ero_sub_object.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "in-ero" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-detaileds/psb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.ero_type.is_set or self.ero_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ero_type.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "ipv4ero-sub-object"):
                        if (self.ipv4ero_sub_object is None):
                            self.ipv4ero_sub_object = RsvpStandby.PsbDetaileds.PsbDetailed.InEro.Ipv4EroSubObject()
                            self.ipv4ero_sub_object.parent = self
                            self._children_name_map["ipv4ero_sub_object"] = "ipv4ero-sub-object"
                        return self.ipv4ero_sub_object

                    if (child_yang_name == "unnumbered-ero-sub-object"):
                        if (self.unnumbered_ero_sub_object is None):
                            self.unnumbered_ero_sub_object = RsvpStandby.PsbDetaileds.PsbDetailed.InEro.UnnumberedEroSubObject()
                            self.unnumbered_ero_sub_object.parent = self
                            self._children_name_map["unnumbered_ero_sub_object"] = "unnumbered-ero-sub-object"
                        return self.unnumbered_ero_sub_object

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ipv4ero-sub-object" or name == "unnumbered-ero-sub-object" or name == "ero-type"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "ero-type"):
                        self.ero_type = value
                        self.ero_type.value_namespace = name_space
                        self.ero_type.value_namespace_prefix = name_space_prefix


            class OutEro(Entity):
                """
                Outgoing Explicit Route Sub Objects
                
                .. attribute:: ero_type
                
                	EROType
                	**type**\:   :py:class:`RsvpMgmtEroSubobj <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtEroSubobj>`
                
                .. attribute:: ipv4ero_sub_object
                
                	IPV4 ERO Sub Object
                	**type**\:   :py:class:`Ipv4EroSubObject <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbDetaileds.PsbDetailed.OutEro.Ipv4EroSubObject>`
                
                .. attribute:: unnumbered_ero_sub_object
                
                	Unnumbered ERO Sub Object
                	**type**\:   :py:class:`UnnumberedEroSubObject <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbDetaileds.PsbDetailed.OutEro.UnnumberedEroSubObject>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.PsbDetaileds.PsbDetailed.OutEro, self).__init__()

                    self.yang_name = "out-ero"
                    self.yang_parent_name = "psb-detailed"

                    self.ero_type = YLeaf(YType.enumeration, "ero-type")

                    self.ipv4ero_sub_object = RsvpStandby.PsbDetaileds.PsbDetailed.OutEro.Ipv4EroSubObject()
                    self.ipv4ero_sub_object.parent = self
                    self._children_name_map["ipv4ero_sub_object"] = "ipv4ero-sub-object"
                    self._children_yang_names.add("ipv4ero-sub-object")

                    self.unnumbered_ero_sub_object = RsvpStandby.PsbDetaileds.PsbDetailed.OutEro.UnnumberedEroSubObject()
                    self.unnumbered_ero_sub_object.parent = self
                    self._children_name_map["unnumbered_ero_sub_object"] = "unnumbered-ero-sub-object"
                    self._children_yang_names.add("unnumbered-ero-sub-object")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("ero_type") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.PsbDetaileds.PsbDetailed.OutEro, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.PsbDetaileds.PsbDetailed.OutEro, self).__setattr__(name, value)


                class Ipv4EroSubObject(Entity):
                    """
                    IPV4 ERO Sub Object
                    
                    .. attribute:: ero_address
                    
                    	The ERO IPV4 Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: is_strict_route
                    
                    	ERO Entry Is Strict
                    	**type**\:  bool
                    
                    .. attribute:: prefix_length
                    
                    	ERO Prefix Length
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.PsbDetaileds.PsbDetailed.OutEro.Ipv4EroSubObject, self).__init__()

                        self.yang_name = "ipv4ero-sub-object"
                        self.yang_parent_name = "out-ero"

                        self.ero_address = YLeaf(YType.str, "ero-address")

                        self.is_strict_route = YLeaf(YType.boolean, "is-strict-route")

                        self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("ero_address",
                                        "is_strict_route",
                                        "prefix_length") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.PsbDetaileds.PsbDetailed.OutEro.Ipv4EroSubObject, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.PsbDetaileds.PsbDetailed.OutEro.Ipv4EroSubObject, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.ero_address.is_set or
                            self.is_strict_route.is_set or
                            self.prefix_length.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.ero_address.yfilter != YFilter.not_set or
                            self.is_strict_route.yfilter != YFilter.not_set or
                            self.prefix_length.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ipv4ero-sub-object" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-detaileds/psb-detailed/out-ero/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.ero_address.is_set or self.ero_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ero_address.get_name_leafdata())
                        if (self.is_strict_route.is_set or self.is_strict_route.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_strict_route.get_name_leafdata())
                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix_length.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ero-address" or name == "is-strict-route" or name == "prefix-length"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "ero-address"):
                            self.ero_address = value
                            self.ero_address.value_namespace = name_space
                            self.ero_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-strict-route"):
                            self.is_strict_route = value
                            self.is_strict_route.value_namespace = name_space
                            self.is_strict_route.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix-length"):
                            self.prefix_length = value
                            self.prefix_length.value_namespace = name_space
                            self.prefix_length.value_namespace_prefix = name_space_prefix


                class UnnumberedEroSubObject(Entity):
                    """
                    Unnumbered ERO Sub Object
                    
                    .. attribute:: ero_interface_id
                    
                    	The Interface ID in ERO
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ero_router_id
                    
                    	The Router ID in ERO
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: is_strict_route
                    
                    	ERO Entry Is Strict
                    	**type**\:  bool
                    
                    .. attribute:: status
                    
                    	Status of ERO
                    	**type**\:   :py:class:`RsvpMgmtEroSubobjStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtEroSubobjStatus>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.PsbDetaileds.PsbDetailed.OutEro.UnnumberedEroSubObject, self).__init__()

                        self.yang_name = "unnumbered-ero-sub-object"
                        self.yang_parent_name = "out-ero"

                        self.ero_interface_id = YLeaf(YType.uint32, "ero-interface-id")

                        self.ero_router_id = YLeaf(YType.str, "ero-router-id")

                        self.is_strict_route = YLeaf(YType.boolean, "is-strict-route")

                        self.status = YLeaf(YType.enumeration, "status")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("ero_interface_id",
                                        "ero_router_id",
                                        "is_strict_route",
                                        "status") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.PsbDetaileds.PsbDetailed.OutEro.UnnumberedEroSubObject, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.PsbDetaileds.PsbDetailed.OutEro.UnnumberedEroSubObject, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.ero_interface_id.is_set or
                            self.ero_router_id.is_set or
                            self.is_strict_route.is_set or
                            self.status.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.ero_interface_id.yfilter != YFilter.not_set or
                            self.ero_router_id.yfilter != YFilter.not_set or
                            self.is_strict_route.yfilter != YFilter.not_set or
                            self.status.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "unnumbered-ero-sub-object" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-detaileds/psb-detailed/out-ero/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.ero_interface_id.is_set or self.ero_interface_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ero_interface_id.get_name_leafdata())
                        if (self.ero_router_id.is_set or self.ero_router_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ero_router_id.get_name_leafdata())
                        if (self.is_strict_route.is_set or self.is_strict_route.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_strict_route.get_name_leafdata())
                        if (self.status.is_set or self.status.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.status.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ero-interface-id" or name == "ero-router-id" or name == "is-strict-route" or name == "status"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "ero-interface-id"):
                            self.ero_interface_id = value
                            self.ero_interface_id.value_namespace = name_space
                            self.ero_interface_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "ero-router-id"):
                            self.ero_router_id = value
                            self.ero_router_id.value_namespace = name_space
                            self.ero_router_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-strict-route"):
                            self.is_strict_route = value
                            self.is_strict_route.value_namespace = name_space
                            self.is_strict_route.value_namespace_prefix = name_space_prefix
                        if(value_path == "status"):
                            self.status = value
                            self.status.value_namespace = name_space
                            self.status.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.ero_type.is_set or
                        (self.ipv4ero_sub_object is not None and self.ipv4ero_sub_object.has_data()) or
                        (self.unnumbered_ero_sub_object is not None and self.unnumbered_ero_sub_object.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.ero_type.yfilter != YFilter.not_set or
                        (self.ipv4ero_sub_object is not None and self.ipv4ero_sub_object.has_operation()) or
                        (self.unnumbered_ero_sub_object is not None and self.unnumbered_ero_sub_object.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "out-ero" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-detaileds/psb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.ero_type.is_set or self.ero_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ero_type.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "ipv4ero-sub-object"):
                        if (self.ipv4ero_sub_object is None):
                            self.ipv4ero_sub_object = RsvpStandby.PsbDetaileds.PsbDetailed.OutEro.Ipv4EroSubObject()
                            self.ipv4ero_sub_object.parent = self
                            self._children_name_map["ipv4ero_sub_object"] = "ipv4ero-sub-object"
                        return self.ipv4ero_sub_object

                    if (child_yang_name == "unnumbered-ero-sub-object"):
                        if (self.unnumbered_ero_sub_object is None):
                            self.unnumbered_ero_sub_object = RsvpStandby.PsbDetaileds.PsbDetailed.OutEro.UnnumberedEroSubObject()
                            self.unnumbered_ero_sub_object.parent = self
                            self._children_name_map["unnumbered_ero_sub_object"] = "unnumbered-ero-sub-object"
                        return self.unnumbered_ero_sub_object

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ipv4ero-sub-object" or name == "unnumbered-ero-sub-object" or name == "ero-type"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "ero-type"):
                        self.ero_type = value
                        self.ero_type.value_namespace = name_space
                        self.ero_type.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.in_ero:
                    if (c.has_data()):
                        return True
                for c in self.out_ero:
                    if (c.has_data()):
                        return True
                for c in self.pfc:
                    if (c.has_data()):
                        return True
                return (
                    self.backup_tunnel_name.is_set or
                    self.destination_address.is_set or
                    self.destination_port.is_set or
                    self.extended_tunnel_id.is_set or
                    self.input_interface.is_set or
                    self.is_in_ero_valid.is_set or
                    self.is_out_ero_valid.is_set or
                    self.p2mp_id.is_set or
                    self.protocol.is_set or
                    self.session_type.is_set or
                    self.source_address.is_set or
                    self.source_port.is_set or
                    self.sub_group_id.is_set or
                    self.sub_group_origin.is_set or
                    self.vrf_name.is_set or
                    (self.class_type is not None and self.class_type.has_data()) or
                    (self.expiry_time is not None and self.expiry_time.has_data()) or
                    (self.generic_traffic_spec is not None and self.generic_traffic_spec.has_data()) or
                    (self.header is not None and self.header.has_data()) or
                    (self.hop is not None and self.hop.has_data()) or
                    (self.label_info is not None and self.label_info.has_data()) or
                    (self.path_flags is not None and self.path_flags.has_data()) or
                    (self.policy_flags is not None and self.policy_flags.has_data()) or
                    (self.policy_query_flags is not None and self.policy_query_flags.has_data()) or
                    (self.policy_source_info is not None and self.policy_source_info.has_data()) or
                    (self.s2l_sub_lsp is not None and self.s2l_sub_lsp.has_data()) or
                    (self.session is not None and self.session.has_data()) or
                    (self.session_attribute is not None and self.session_attribute.has_data()) or
                    (self.template is not None and self.template.has_data()) or
                    (self.traffic_spec is not None and self.traffic_spec.has_data()))

            def has_operation(self):
                for c in self.in_ero:
                    if (c.has_operation()):
                        return True
                for c in self.out_ero:
                    if (c.has_operation()):
                        return True
                for c in self.pfc:
                    if (c.has_operation()):
                        return True
                return (
                    self.yfilter != YFilter.not_set or
                    self.backup_tunnel_name.yfilter != YFilter.not_set or
                    self.destination_address.yfilter != YFilter.not_set or
                    self.destination_port.yfilter != YFilter.not_set or
                    self.extended_tunnel_id.yfilter != YFilter.not_set or
                    self.input_interface.yfilter != YFilter.not_set or
                    self.is_in_ero_valid.yfilter != YFilter.not_set or
                    self.is_out_ero_valid.yfilter != YFilter.not_set or
                    self.p2mp_id.yfilter != YFilter.not_set or
                    self.protocol.yfilter != YFilter.not_set or
                    self.session_type.yfilter != YFilter.not_set or
                    self.source_address.yfilter != YFilter.not_set or
                    self.source_port.yfilter != YFilter.not_set or
                    self.sub_group_id.yfilter != YFilter.not_set or
                    self.sub_group_origin.yfilter != YFilter.not_set or
                    self.vrf_name.yfilter != YFilter.not_set or
                    (self.class_type is not None and self.class_type.has_operation()) or
                    (self.expiry_time is not None and self.expiry_time.has_operation()) or
                    (self.generic_traffic_spec is not None and self.generic_traffic_spec.has_operation()) or
                    (self.header is not None and self.header.has_operation()) or
                    (self.hop is not None and self.hop.has_operation()) or
                    (self.label_info is not None and self.label_info.has_operation()) or
                    (self.path_flags is not None and self.path_flags.has_operation()) or
                    (self.policy_flags is not None and self.policy_flags.has_operation()) or
                    (self.policy_query_flags is not None and self.policy_query_flags.has_operation()) or
                    (self.policy_source_info is not None and self.policy_source_info.has_operation()) or
                    (self.s2l_sub_lsp is not None and self.s2l_sub_lsp.has_operation()) or
                    (self.session is not None and self.session.has_operation()) or
                    (self.session_attribute is not None and self.session_attribute.has_operation()) or
                    (self.template is not None and self.template.has_operation()) or
                    (self.traffic_spec is not None and self.traffic_spec.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "psb-detailed" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-detaileds/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.backup_tunnel_name.is_set or self.backup_tunnel_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.backup_tunnel_name.get_name_leafdata())
                if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_address.get_name_leafdata())
                if (self.destination_port.is_set or self.destination_port.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_port.get_name_leafdata())
                if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                if (self.input_interface.is_set or self.input_interface.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.input_interface.get_name_leafdata())
                if (self.is_in_ero_valid.is_set or self.is_in_ero_valid.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.is_in_ero_valid.get_name_leafdata())
                if (self.is_out_ero_valid.is_set or self.is_out_ero_valid.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.is_out_ero_valid.get_name_leafdata())
                if (self.p2mp_id.is_set or self.p2mp_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.p2mp_id.get_name_leafdata())
                if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.protocol.get_name_leafdata())
                if (self.session_type.is_set or self.session_type.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.session_type.get_name_leafdata())
                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_address.get_name_leafdata())
                if (self.source_port.is_set or self.source_port.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_port.get_name_leafdata())
                if (self.sub_group_id.is_set or self.sub_group_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.sub_group_id.get_name_leafdata())
                if (self.sub_group_origin.is_set or self.sub_group_origin.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.sub_group_origin.get_name_leafdata())
                if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.vrf_name.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "class-type"):
                    if (self.class_type is None):
                        self.class_type = RsvpStandby.PsbDetaileds.PsbDetailed.ClassType()
                        self.class_type.parent = self
                        self._children_name_map["class_type"] = "class-type"
                    return self.class_type

                if (child_yang_name == "expiry-time"):
                    if (self.expiry_time is None):
                        self.expiry_time = RsvpStandby.PsbDetaileds.PsbDetailed.ExpiryTime()
                        self.expiry_time.parent = self
                        self._children_name_map["expiry_time"] = "expiry-time"
                    return self.expiry_time

                if (child_yang_name == "generic-traffic-spec"):
                    if (self.generic_traffic_spec is None):
                        self.generic_traffic_spec = RsvpStandby.PsbDetaileds.PsbDetailed.GenericTrafficSpec()
                        self.generic_traffic_spec.parent = self
                        self._children_name_map["generic_traffic_spec"] = "generic-traffic-spec"
                    return self.generic_traffic_spec

                if (child_yang_name == "header"):
                    if (self.header is None):
                        self.header = RsvpStandby.PsbDetaileds.PsbDetailed.Header()
                        self.header.parent = self
                        self._children_name_map["header"] = "header"
                    return self.header

                if (child_yang_name == "hop"):
                    if (self.hop is None):
                        self.hop = RsvpStandby.PsbDetaileds.PsbDetailed.Hop()
                        self.hop.parent = self
                        self._children_name_map["hop"] = "hop"
                    return self.hop

                if (child_yang_name == "in-ero"):
                    for c in self.in_ero:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = RsvpStandby.PsbDetaileds.PsbDetailed.InEro()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.in_ero.append(c)
                    return c

                if (child_yang_name == "label-info"):
                    if (self.label_info is None):
                        self.label_info = RsvpStandby.PsbDetaileds.PsbDetailed.LabelInfo()
                        self.label_info.parent = self
                        self._children_name_map["label_info"] = "label-info"
                    return self.label_info

                if (child_yang_name == "out-ero"):
                    for c in self.out_ero:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = RsvpStandby.PsbDetaileds.PsbDetailed.OutEro()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.out_ero.append(c)
                    return c

                if (child_yang_name == "path-flags"):
                    if (self.path_flags is None):
                        self.path_flags = RsvpStandby.PsbDetaileds.PsbDetailed.PathFlags()
                        self.path_flags.parent = self
                        self._children_name_map["path_flags"] = "path-flags"
                    return self.path_flags

                if (child_yang_name == "pfc"):
                    for c in self.pfc:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = RsvpStandby.PsbDetaileds.PsbDetailed.Pfc()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.pfc.append(c)
                    return c

                if (child_yang_name == "policy-flags"):
                    if (self.policy_flags is None):
                        self.policy_flags = RsvpStandby.PsbDetaileds.PsbDetailed.PolicyFlags()
                        self.policy_flags.parent = self
                        self._children_name_map["policy_flags"] = "policy-flags"
                    return self.policy_flags

                if (child_yang_name == "policy-query-flags"):
                    if (self.policy_query_flags is None):
                        self.policy_query_flags = RsvpStandby.PsbDetaileds.PsbDetailed.PolicyQueryFlags()
                        self.policy_query_flags.parent = self
                        self._children_name_map["policy_query_flags"] = "policy-query-flags"
                    return self.policy_query_flags

                if (child_yang_name == "policy-source-info"):
                    if (self.policy_source_info is None):
                        self.policy_source_info = RsvpStandby.PsbDetaileds.PsbDetailed.PolicySourceInfo()
                        self.policy_source_info.parent = self
                        self._children_name_map["policy_source_info"] = "policy-source-info"
                    return self.policy_source_info

                if (child_yang_name == "s2l-sub-lsp"):
                    if (self.s2l_sub_lsp is None):
                        self.s2l_sub_lsp = RsvpStandby.PsbDetaileds.PsbDetailed.S2LSubLsp()
                        self.s2l_sub_lsp.parent = self
                        self._children_name_map["s2l_sub_lsp"] = "s2l-sub-lsp"
                    return self.s2l_sub_lsp

                if (child_yang_name == "session"):
                    if (self.session is None):
                        self.session = RsvpStandby.PsbDetaileds.PsbDetailed.Session()
                        self.session.parent = self
                        self._children_name_map["session"] = "session"
                    return self.session

                if (child_yang_name == "session-attribute"):
                    if (self.session_attribute is None):
                        self.session_attribute = RsvpStandby.PsbDetaileds.PsbDetailed.SessionAttribute()
                        self.session_attribute.parent = self
                        self._children_name_map["session_attribute"] = "session-attribute"
                    return self.session_attribute

                if (child_yang_name == "template"):
                    if (self.template is None):
                        self.template = RsvpStandby.PsbDetaileds.PsbDetailed.Template()
                        self.template.parent = self
                        self._children_name_map["template"] = "template"
                    return self.template

                if (child_yang_name == "traffic-spec"):
                    if (self.traffic_spec is None):
                        self.traffic_spec = RsvpStandby.PsbDetaileds.PsbDetailed.TrafficSpec()
                        self.traffic_spec.parent = self
                        self._children_name_map["traffic_spec"] = "traffic-spec"
                    return self.traffic_spec

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "class-type" or name == "expiry-time" or name == "generic-traffic-spec" or name == "header" or name == "hop" or name == "in-ero" or name == "label-info" or name == "out-ero" or name == "path-flags" or name == "pfc" or name == "policy-flags" or name == "policy-query-flags" or name == "policy-source-info" or name == "s2l-sub-lsp" or name == "session" or name == "session-attribute" or name == "template" or name == "traffic-spec" or name == "backup-tunnel-name" or name == "destination-address" or name == "destination-port" or name == "extended-tunnel-id" or name == "input-interface" or name == "is-in-ero-valid" or name == "is-out-ero-valid" or name == "p2mp-id" or name == "protocol" or name == "session-type" or name == "source-address" or name == "source-port" or name == "sub-group-id" or name == "sub-group-origin" or name == "vrf-name"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "backup-tunnel-name"):
                    self.backup_tunnel_name = value
                    self.backup_tunnel_name.value_namespace = name_space
                    self.backup_tunnel_name.value_namespace_prefix = name_space_prefix
                if(value_path == "destination-address"):
                    self.destination_address = value
                    self.destination_address.value_namespace = name_space
                    self.destination_address.value_namespace_prefix = name_space_prefix
                if(value_path == "destination-port"):
                    self.destination_port = value
                    self.destination_port.value_namespace = name_space
                    self.destination_port.value_namespace_prefix = name_space_prefix
                if(value_path == "extended-tunnel-id"):
                    self.extended_tunnel_id = value
                    self.extended_tunnel_id.value_namespace = name_space
                    self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                if(value_path == "input-interface"):
                    self.input_interface = value
                    self.input_interface.value_namespace = name_space
                    self.input_interface.value_namespace_prefix = name_space_prefix
                if(value_path == "is-in-ero-valid"):
                    self.is_in_ero_valid = value
                    self.is_in_ero_valid.value_namespace = name_space
                    self.is_in_ero_valid.value_namespace_prefix = name_space_prefix
                if(value_path == "is-out-ero-valid"):
                    self.is_out_ero_valid = value
                    self.is_out_ero_valid.value_namespace = name_space
                    self.is_out_ero_valid.value_namespace_prefix = name_space_prefix
                if(value_path == "p2mp-id"):
                    self.p2mp_id = value
                    self.p2mp_id.value_namespace = name_space
                    self.p2mp_id.value_namespace_prefix = name_space_prefix
                if(value_path == "protocol"):
                    self.protocol = value
                    self.protocol.value_namespace = name_space
                    self.protocol.value_namespace_prefix = name_space_prefix
                if(value_path == "session-type"):
                    self.session_type = value
                    self.session_type.value_namespace = name_space
                    self.session_type.value_namespace_prefix = name_space_prefix
                if(value_path == "source-address"):
                    self.source_address = value
                    self.source_address.value_namespace = name_space
                    self.source_address.value_namespace_prefix = name_space_prefix
                if(value_path == "source-port"):
                    self.source_port = value
                    self.source_port.value_namespace = name_space
                    self.source_port.value_namespace_prefix = name_space_prefix
                if(value_path == "sub-group-id"):
                    self.sub_group_id = value
                    self.sub_group_id.value_namespace = name_space
                    self.sub_group_id.value_namespace_prefix = name_space_prefix
                if(value_path == "sub-group-origin"):
                    self.sub_group_origin = value
                    self.sub_group_origin.value_namespace = name_space
                    self.sub_group_origin.value_namespace_prefix = name_space_prefix
                if(value_path == "vrf-name"):
                    self.vrf_name = value
                    self.vrf_name.value_namespace = name_space
                    self.vrf_name.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.psb_detailed:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.psb_detailed:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "psb-detaileds" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "psb-detailed"):
                for c in self.psb_detailed:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = RsvpStandby.PsbDetaileds.PsbDetailed()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.psb_detailed.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "psb-detailed"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class ControllerDetaileds(Entity):
        """
        Table of detailed info about RSVP\-enabled
        controllers
        
        .. attribute:: controller_detailed
        
        	Detailed info about an RSVP\-enabled controller
        	**type**\: list of    :py:class:`ControllerDetailed <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.ControllerDetaileds.ControllerDetailed>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(RsvpStandby.ControllerDetaileds, self).__init__()

            self.yang_name = "controller-detaileds"
            self.yang_parent_name = "rsvp-standby"

            self.controller_detailed = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(RsvpStandby.ControllerDetaileds, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(RsvpStandby.ControllerDetaileds, self).__setattr__(name, value)


        class ControllerDetailed(Entity):
            """
            Detailed info about an RSVP\-enabled controller
            
            .. attribute:: controller_name  <key>
            
            	Controller Name
            	**type**\:  str
            
            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
            
            .. attribute:: ack_hold_time
            
            	ACK hold time in msec
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: ack_max_size
            
            	Max size for ACK message
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: bandwidth_information
            
            	Interface bandwidth information
            	**type**\:   :py:class:`BandwidthInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.ControllerDetaileds.ControllerDetailed.BandwidthInformation>`
            
            .. attribute:: bundle_message_max_size
            
            	Max size in bytes of a single Bundle message
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            	**units**\: byte
            
            .. attribute:: expiry_drops_tolerated
            
            	Number of missed messages tolerated
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: expiry_interval
            
            	Expiry interval in msecs
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            	**units**\: millisecond
            
            .. attribute:: expiry_states
            
            	Number of states for expiry check
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: expiry_timer_state
            
            	Expiry timer state
            	**type**\:   :py:class:`RsvpTimerState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpTimerState>`
            
            .. attribute:: flags
            
            	Interface flags
            	**type**\:   :py:class:`Flags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.ControllerDetaileds.ControllerDetailed.Flags>`
            
            .. attribute:: integrity_receive_password
            
            	Integrity receive password
            	**type**\:  str
            
            	**length:** 0..40
            
            .. attribute:: integrity_receive_password_optional
            
            	Integrity recv password optional
            	**type**\:  int
            
            	**range:** 0..255
            
            .. attribute:: integrity_send_password
            
            	Integrity send password
            	**type**\:  str
            
            	**length:** 0..40
            
            .. attribute:: interface_name_xr
            
            	Interface Name
            	**type**\:  str
            
            .. attribute:: neighbor_array
            
            	Neighbor array
            	**type**\: list of    :py:class:`NeighborArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.ControllerDetaileds.ControllerDetailed.NeighborArray>`
            
            .. attribute:: out_of_band_expiry_drops_tolerated
            
            	Number of out\-of\-band missed messages tolerated
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: out_of_band_refresh_interval
            
            	Out\-of\-band Refresh interval in msecs
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            	**units**\: millisecond
            
            .. attribute:: pacing_interval
            
            	Pacing interval in msecs
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            	**units**\: millisecond
            
            .. attribute:: pacing_message_rate
            
            	No. of messages per interval
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: pacing_messages
            
            	Number of messages deferred for pacing
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: pacing_timer_state
            
            	State of pacing timer
            	**type**\:   :py:class:`RsvpTimerState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpTimerState>`
            
            .. attribute:: refresh_interval
            
            	Refresh interval in msecs
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            	**units**\: millisecond
            
            .. attribute:: refresh_timer_state
            
            	Refresh timer state
            	**type**\:   :py:class:`RsvpTimerState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpTimerState>`
            
            .. attribute:: retransmit_time
            
            	Retransmit time in msec
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: signalling_ip_tos
            
            	IP TOS (precedence/DSCP) to use in signalling messages
            	**type**\:  int
            
            	**range:** 0..255
            
            .. attribute:: summary_refresh_max_size
            
            	Max size in bytes of a single SRefresh
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            	**units**\: byte
            
            .. attribute:: summary_refresh_timer_state
            
            	Summary refresh timer state
            	**type**\:   :py:class:`RsvpTimerState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpTimerState>`
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(RsvpStandby.ControllerDetaileds.ControllerDetailed, self).__init__()

                self.yang_name = "controller-detailed"
                self.yang_parent_name = "controller-detaileds"

                self.controller_name = YLeaf(YType.str, "controller-name")

                self.ack_hold_time = YLeaf(YType.uint32, "ack-hold-time")

                self.ack_max_size = YLeaf(YType.uint32, "ack-max-size")

                self.bundle_message_max_size = YLeaf(YType.uint32, "bundle-message-max-size")

                self.expiry_drops_tolerated = YLeaf(YType.int32, "expiry-drops-tolerated")

                self.expiry_interval = YLeaf(YType.int32, "expiry-interval")

                self.expiry_states = YLeaf(YType.int32, "expiry-states")

                self.expiry_timer_state = YLeaf(YType.enumeration, "expiry-timer-state")

                self.integrity_receive_password = YLeaf(YType.str, "integrity-receive-password")

                self.integrity_receive_password_optional = YLeaf(YType.uint8, "integrity-receive-password-optional")

                self.integrity_send_password = YLeaf(YType.str, "integrity-send-password")

                self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                self.out_of_band_expiry_drops_tolerated = YLeaf(YType.uint32, "out-of-band-expiry-drops-tolerated")

                self.out_of_band_refresh_interval = YLeaf(YType.uint32, "out-of-band-refresh-interval")

                self.pacing_interval = YLeaf(YType.uint32, "pacing-interval")

                self.pacing_message_rate = YLeaf(YType.uint32, "pacing-message-rate")

                self.pacing_messages = YLeaf(YType.int32, "pacing-messages")

                self.pacing_timer_state = YLeaf(YType.enumeration, "pacing-timer-state")

                self.refresh_interval = YLeaf(YType.int32, "refresh-interval")

                self.refresh_timer_state = YLeaf(YType.enumeration, "refresh-timer-state")

                self.retransmit_time = YLeaf(YType.uint32, "retransmit-time")

                self.signalling_ip_tos = YLeaf(YType.uint8, "signalling-ip-tos")

                self.summary_refresh_max_size = YLeaf(YType.uint32, "summary-refresh-max-size")

                self.summary_refresh_timer_state = YLeaf(YType.enumeration, "summary-refresh-timer-state")

                self.bandwidth_information = RsvpStandby.ControllerDetaileds.ControllerDetailed.BandwidthInformation()
                self.bandwidth_information.parent = self
                self._children_name_map["bandwidth_information"] = "bandwidth-information"
                self._children_yang_names.add("bandwidth-information")

                self.flags = RsvpStandby.ControllerDetaileds.ControllerDetailed.Flags()
                self.flags.parent = self
                self._children_name_map["flags"] = "flags"
                self._children_yang_names.add("flags")

                self.neighbor_array = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("controller_name",
                                "ack_hold_time",
                                "ack_max_size",
                                "bundle_message_max_size",
                                "expiry_drops_tolerated",
                                "expiry_interval",
                                "expiry_states",
                                "expiry_timer_state",
                                "integrity_receive_password",
                                "integrity_receive_password_optional",
                                "integrity_send_password",
                                "interface_name_xr",
                                "out_of_band_expiry_drops_tolerated",
                                "out_of_band_refresh_interval",
                                "pacing_interval",
                                "pacing_message_rate",
                                "pacing_messages",
                                "pacing_timer_state",
                                "refresh_interval",
                                "refresh_timer_state",
                                "retransmit_time",
                                "signalling_ip_tos",
                                "summary_refresh_max_size",
                                "summary_refresh_timer_state") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(RsvpStandby.ControllerDetaileds.ControllerDetailed, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(RsvpStandby.ControllerDetaileds.ControllerDetailed, self).__setattr__(name, value)


            class BandwidthInformation(Entity):
                """
                Interface bandwidth information
                
                .. attribute:: dste_mode
                
                	DSTEMode
                	**type**\:   :py:class:`RsvpMgmtDsteModes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtDsteModes>`
                
                .. attribute:: pre_standard_dste_interface
                
                	Prestandard DSTE interface information
                	**type**\:   :py:class:`PreStandardDsteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.ControllerDetaileds.ControllerDetailed.BandwidthInformation.PreStandardDsteInterface>`
                
                .. attribute:: standard_dste_interface
                
                	Standard DSTE interface information
                	**type**\:   :py:class:`StandardDsteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.ControllerDetaileds.ControllerDetailed.BandwidthInformation.StandardDsteInterface>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.ControllerDetaileds.ControllerDetailed.BandwidthInformation, self).__init__()

                    self.yang_name = "bandwidth-information"
                    self.yang_parent_name = "controller-detailed"

                    self.dste_mode = YLeaf(YType.enumeration, "dste-mode")

                    self.pre_standard_dste_interface = RsvpStandby.ControllerDetaileds.ControllerDetailed.BandwidthInformation.PreStandardDsteInterface()
                    self.pre_standard_dste_interface.parent = self
                    self._children_name_map["pre_standard_dste_interface"] = "pre-standard-dste-interface"
                    self._children_yang_names.add("pre-standard-dste-interface")

                    self.standard_dste_interface = RsvpStandby.ControllerDetaileds.ControllerDetailed.BandwidthInformation.StandardDsteInterface()
                    self.standard_dste_interface.parent = self
                    self._children_name_map["standard_dste_interface"] = "standard-dste-interface"
                    self._children_yang_names.add("standard-dste-interface")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("dste_mode") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.ControllerDetaileds.ControllerDetailed.BandwidthInformation, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.ControllerDetaileds.ControllerDetailed.BandwidthInformation, self).__setattr__(name, value)


                class PreStandardDsteInterface(Entity):
                    """
                    Prestandard DSTE interface information
                    
                    .. attribute:: allocated_bit_rate
                    
                    	Bandwidth (bits per second) now allocated
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: is_max_bandwidth_absolute
                    
                    	True if the Max B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: is_max_subpool_bandwidth_absolute
                    
                    	True if the Max sub\-pool B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: max_bandwidth
                    
                    	Max bandwidth (bits per second) allowed
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_flow_bandwidth
                    
                    	Max bandwidth (bits per second) allowed per flow
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_subpool_bandwidth
                    
                    	Max bandwidth (bits per second) allowed in subpool
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.ControllerDetaileds.ControllerDetailed.BandwidthInformation.PreStandardDsteInterface, self).__init__()

                        self.yang_name = "pre-standard-dste-interface"
                        self.yang_parent_name = "bandwidth-information"

                        self.allocated_bit_rate = YLeaf(YType.uint64, "allocated-bit-rate")

                        self.is_max_bandwidth_absolute = YLeaf(YType.boolean, "is-max-bandwidth-absolute")

                        self.is_max_subpool_bandwidth_absolute = YLeaf(YType.boolean, "is-max-subpool-bandwidth-absolute")

                        self.max_bandwidth = YLeaf(YType.uint64, "max-bandwidth")

                        self.max_flow_bandwidth = YLeaf(YType.uint64, "max-flow-bandwidth")

                        self.max_subpool_bandwidth = YLeaf(YType.uint64, "max-subpool-bandwidth")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("allocated_bit_rate",
                                        "is_max_bandwidth_absolute",
                                        "is_max_subpool_bandwidth_absolute",
                                        "max_bandwidth",
                                        "max_flow_bandwidth",
                                        "max_subpool_bandwidth") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.ControllerDetaileds.ControllerDetailed.BandwidthInformation.PreStandardDsteInterface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.ControllerDetaileds.ControllerDetailed.BandwidthInformation.PreStandardDsteInterface, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.allocated_bit_rate.is_set or
                            self.is_max_bandwidth_absolute.is_set or
                            self.is_max_subpool_bandwidth_absolute.is_set or
                            self.max_bandwidth.is_set or
                            self.max_flow_bandwidth.is_set or
                            self.max_subpool_bandwidth.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.allocated_bit_rate.yfilter != YFilter.not_set or
                            self.is_max_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.is_max_subpool_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.max_bandwidth.yfilter != YFilter.not_set or
                            self.max_flow_bandwidth.yfilter != YFilter.not_set or
                            self.max_subpool_bandwidth.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "pre-standard-dste-interface" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.allocated_bit_rate.is_set or self.allocated_bit_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.allocated_bit_rate.get_name_leafdata())
                        if (self.is_max_bandwidth_absolute.is_set or self.is_max_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_bandwidth_absolute.get_name_leafdata())
                        if (self.is_max_subpool_bandwidth_absolute.is_set or self.is_max_subpool_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_subpool_bandwidth_absolute.get_name_leafdata())
                        if (self.max_bandwidth.is_set or self.max_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_bandwidth.get_name_leafdata())
                        if (self.max_flow_bandwidth.is_set or self.max_flow_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_flow_bandwidth.get_name_leafdata())
                        if (self.max_subpool_bandwidth.is_set or self.max_subpool_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_subpool_bandwidth.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "allocated-bit-rate" or name == "is-max-bandwidth-absolute" or name == "is-max-subpool-bandwidth-absolute" or name == "max-bandwidth" or name == "max-flow-bandwidth" or name == "max-subpool-bandwidth"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "allocated-bit-rate"):
                            self.allocated_bit_rate = value
                            self.allocated_bit_rate.value_namespace = name_space
                            self.allocated_bit_rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-bandwidth-absolute"):
                            self.is_max_bandwidth_absolute = value
                            self.is_max_bandwidth_absolute.value_namespace = name_space
                            self.is_max_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-subpool-bandwidth-absolute"):
                            self.is_max_subpool_bandwidth_absolute = value
                            self.is_max_subpool_bandwidth_absolute.value_namespace = name_space
                            self.is_max_subpool_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-bandwidth"):
                            self.max_bandwidth = value
                            self.max_bandwidth.value_namespace = name_space
                            self.max_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-flow-bandwidth"):
                            self.max_flow_bandwidth = value
                            self.max_flow_bandwidth.value_namespace = name_space
                            self.max_flow_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-subpool-bandwidth"):
                            self.max_subpool_bandwidth = value
                            self.max_subpool_bandwidth.value_namespace = name_space
                            self.max_subpool_bandwidth.value_namespace_prefix = name_space_prefix


                class StandardDsteInterface(Entity):
                    """
                    Standard DSTE interface information
                    
                    .. attribute:: allocated_bit_rate
                    
                    	Bandwidth (bits per second) now allocated
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: is_max_bandwidth_absolute
                    
                    	True if the Max B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: is_max_bc0_bandwidth_absolute
                    
                    	True if the Max BC0 B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: is_max_bc1_bandwidth_absolute
                    
                    	True if the Max BC1 sub\-pool B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: max_bandwidth
                    
                    	Max bandwidth (bits per second) allowed
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_flow_bandwidth
                    
                    	Max bandwidth (bits per second) allowed per flow
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_pool0_bandwidth
                    
                    	Max bandwidth (bits per second) allowed in BC0 pool
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_pool1_bandwidth
                    
                    	Max bandwidth (bits per second) allowed in BC1 pool
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.ControllerDetaileds.ControllerDetailed.BandwidthInformation.StandardDsteInterface, self).__init__()

                        self.yang_name = "standard-dste-interface"
                        self.yang_parent_name = "bandwidth-information"

                        self.allocated_bit_rate = YLeaf(YType.uint64, "allocated-bit-rate")

                        self.is_max_bandwidth_absolute = YLeaf(YType.boolean, "is-max-bandwidth-absolute")

                        self.is_max_bc0_bandwidth_absolute = YLeaf(YType.boolean, "is-max-bc0-bandwidth-absolute")

                        self.is_max_bc1_bandwidth_absolute = YLeaf(YType.boolean, "is-max-bc1-bandwidth-absolute")

                        self.max_bandwidth = YLeaf(YType.uint64, "max-bandwidth")

                        self.max_flow_bandwidth = YLeaf(YType.uint64, "max-flow-bandwidth")

                        self.max_pool0_bandwidth = YLeaf(YType.uint64, "max-pool0-bandwidth")

                        self.max_pool1_bandwidth = YLeaf(YType.uint64, "max-pool1-bandwidth")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("allocated_bit_rate",
                                        "is_max_bandwidth_absolute",
                                        "is_max_bc0_bandwidth_absolute",
                                        "is_max_bc1_bandwidth_absolute",
                                        "max_bandwidth",
                                        "max_flow_bandwidth",
                                        "max_pool0_bandwidth",
                                        "max_pool1_bandwidth") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.ControllerDetaileds.ControllerDetailed.BandwidthInformation.StandardDsteInterface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.ControllerDetaileds.ControllerDetailed.BandwidthInformation.StandardDsteInterface, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.allocated_bit_rate.is_set or
                            self.is_max_bandwidth_absolute.is_set or
                            self.is_max_bc0_bandwidth_absolute.is_set or
                            self.is_max_bc1_bandwidth_absolute.is_set or
                            self.max_bandwidth.is_set or
                            self.max_flow_bandwidth.is_set or
                            self.max_pool0_bandwidth.is_set or
                            self.max_pool1_bandwidth.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.allocated_bit_rate.yfilter != YFilter.not_set or
                            self.is_max_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.is_max_bc0_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.is_max_bc1_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.max_bandwidth.yfilter != YFilter.not_set or
                            self.max_flow_bandwidth.yfilter != YFilter.not_set or
                            self.max_pool0_bandwidth.yfilter != YFilter.not_set or
                            self.max_pool1_bandwidth.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "standard-dste-interface" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.allocated_bit_rate.is_set or self.allocated_bit_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.allocated_bit_rate.get_name_leafdata())
                        if (self.is_max_bandwidth_absolute.is_set or self.is_max_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_bandwidth_absolute.get_name_leafdata())
                        if (self.is_max_bc0_bandwidth_absolute.is_set or self.is_max_bc0_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_bc0_bandwidth_absolute.get_name_leafdata())
                        if (self.is_max_bc1_bandwidth_absolute.is_set or self.is_max_bc1_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_bc1_bandwidth_absolute.get_name_leafdata())
                        if (self.max_bandwidth.is_set or self.max_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_bandwidth.get_name_leafdata())
                        if (self.max_flow_bandwidth.is_set or self.max_flow_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_flow_bandwidth.get_name_leafdata())
                        if (self.max_pool0_bandwidth.is_set or self.max_pool0_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_pool0_bandwidth.get_name_leafdata())
                        if (self.max_pool1_bandwidth.is_set or self.max_pool1_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_pool1_bandwidth.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "allocated-bit-rate" or name == "is-max-bandwidth-absolute" or name == "is-max-bc0-bandwidth-absolute" or name == "is-max-bc1-bandwidth-absolute" or name == "max-bandwidth" or name == "max-flow-bandwidth" or name == "max-pool0-bandwidth" or name == "max-pool1-bandwidth"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "allocated-bit-rate"):
                            self.allocated_bit_rate = value
                            self.allocated_bit_rate.value_namespace = name_space
                            self.allocated_bit_rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-bandwidth-absolute"):
                            self.is_max_bandwidth_absolute = value
                            self.is_max_bandwidth_absolute.value_namespace = name_space
                            self.is_max_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-bc0-bandwidth-absolute"):
                            self.is_max_bc0_bandwidth_absolute = value
                            self.is_max_bc0_bandwidth_absolute.value_namespace = name_space
                            self.is_max_bc0_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-bc1-bandwidth-absolute"):
                            self.is_max_bc1_bandwidth_absolute = value
                            self.is_max_bc1_bandwidth_absolute.value_namespace = name_space
                            self.is_max_bc1_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-bandwidth"):
                            self.max_bandwidth = value
                            self.max_bandwidth.value_namespace = name_space
                            self.max_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-flow-bandwidth"):
                            self.max_flow_bandwidth = value
                            self.max_flow_bandwidth.value_namespace = name_space
                            self.max_flow_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-pool0-bandwidth"):
                            self.max_pool0_bandwidth = value
                            self.max_pool0_bandwidth.value_namespace = name_space
                            self.max_pool0_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-pool1-bandwidth"):
                            self.max_pool1_bandwidth = value
                            self.max_pool1_bandwidth.value_namespace = name_space
                            self.max_pool1_bandwidth.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.dste_mode.is_set or
                        (self.pre_standard_dste_interface is not None and self.pre_standard_dste_interface.has_data()) or
                        (self.standard_dste_interface is not None and self.standard_dste_interface.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.dste_mode.yfilter != YFilter.not_set or
                        (self.pre_standard_dste_interface is not None and self.pre_standard_dste_interface.has_operation()) or
                        (self.standard_dste_interface is not None and self.standard_dste_interface.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bandwidth-information" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.dste_mode.is_set or self.dste_mode.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.dste_mode.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "pre-standard-dste-interface"):
                        if (self.pre_standard_dste_interface is None):
                            self.pre_standard_dste_interface = RsvpStandby.ControllerDetaileds.ControllerDetailed.BandwidthInformation.PreStandardDsteInterface()
                            self.pre_standard_dste_interface.parent = self
                            self._children_name_map["pre_standard_dste_interface"] = "pre-standard-dste-interface"
                        return self.pre_standard_dste_interface

                    if (child_yang_name == "standard-dste-interface"):
                        if (self.standard_dste_interface is None):
                            self.standard_dste_interface = RsvpStandby.ControllerDetaileds.ControllerDetailed.BandwidthInformation.StandardDsteInterface()
                            self.standard_dste_interface.parent = self
                            self._children_name_map["standard_dste_interface"] = "standard-dste-interface"
                        return self.standard_dste_interface

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "pre-standard-dste-interface" or name == "standard-dste-interface" or name == "dste-mode"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "dste-mode"):
                        self.dste_mode = value
                        self.dste_mode.value_namespace = name_space
                        self.dste_mode.value_namespace_prefix = name_space_prefix


            class Flags(Entity):
                """
                Interface flags
                
                .. attribute:: is_backup_tunnel
                
                	This is backup tunnel
                	**type**\:  bool
                
                .. attribute:: is_interface_created
                
                	Interface is created
                	**type**\:  bool
                
                .. attribute:: is_interface_down
                
                	Interface is DOWN
                	**type**\:  bool
                
                .. attribute:: is_message_bundling_enabled
                
                	Use bundling for outgoing RSVP messages
                	**type**\:  bool
                
                .. attribute:: is_mpls_enabled
                
                	MPLS enabled on interface
                	**type**\:  bool
                
                .. attribute:: is_non_default_vrf
                
                	Interface is defined in non\-Default VRF
                	**type**\:  bool
                
                .. attribute:: is_pacing_enabled
                
                	Message pacing enabled
                	**type**\:  bool
                
                .. attribute:: is_refresh_enabled
                
                	Refresh enabled
                	**type**\:  bool
                
                .. attribute:: is_refresh_reduction_enabled
                
                	Refresh Reduction enabled
                	**type**\:  bool
                
                .. attribute:: is_rel_s_refresh_enabled
                
                	Use reliable xmt for SRefresh
                	**type**\:  bool
                
                .. attribute:: is_rsvp_configured
                
                	RSVP explicitly configured
                	**type**\:  bool
                
                .. attribute:: is_s_refresh_enabled
                
                	Summary Refresh enabled
                	**type**\:  bool
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.ControllerDetaileds.ControllerDetailed.Flags, self).__init__()

                    self.yang_name = "flags"
                    self.yang_parent_name = "controller-detailed"

                    self.is_backup_tunnel = YLeaf(YType.boolean, "is-backup-tunnel")

                    self.is_interface_created = YLeaf(YType.boolean, "is-interface-created")

                    self.is_interface_down = YLeaf(YType.boolean, "is-interface-down")

                    self.is_message_bundling_enabled = YLeaf(YType.boolean, "is-message-bundling-enabled")

                    self.is_mpls_enabled = YLeaf(YType.boolean, "is-mpls-enabled")

                    self.is_non_default_vrf = YLeaf(YType.boolean, "is-non-default-vrf")

                    self.is_pacing_enabled = YLeaf(YType.boolean, "is-pacing-enabled")

                    self.is_refresh_enabled = YLeaf(YType.boolean, "is-refresh-enabled")

                    self.is_refresh_reduction_enabled = YLeaf(YType.boolean, "is-refresh-reduction-enabled")

                    self.is_rel_s_refresh_enabled = YLeaf(YType.boolean, "is-rel-s-refresh-enabled")

                    self.is_rsvp_configured = YLeaf(YType.boolean, "is-rsvp-configured")

                    self.is_s_refresh_enabled = YLeaf(YType.boolean, "is-s-refresh-enabled")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("is_backup_tunnel",
                                    "is_interface_created",
                                    "is_interface_down",
                                    "is_message_bundling_enabled",
                                    "is_mpls_enabled",
                                    "is_non_default_vrf",
                                    "is_pacing_enabled",
                                    "is_refresh_enabled",
                                    "is_refresh_reduction_enabled",
                                    "is_rel_s_refresh_enabled",
                                    "is_rsvp_configured",
                                    "is_s_refresh_enabled") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.ControllerDetaileds.ControllerDetailed.Flags, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.ControllerDetaileds.ControllerDetailed.Flags, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.is_backup_tunnel.is_set or
                        self.is_interface_created.is_set or
                        self.is_interface_down.is_set or
                        self.is_message_bundling_enabled.is_set or
                        self.is_mpls_enabled.is_set or
                        self.is_non_default_vrf.is_set or
                        self.is_pacing_enabled.is_set or
                        self.is_refresh_enabled.is_set or
                        self.is_refresh_reduction_enabled.is_set or
                        self.is_rel_s_refresh_enabled.is_set or
                        self.is_rsvp_configured.is_set or
                        self.is_s_refresh_enabled.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.is_backup_tunnel.yfilter != YFilter.not_set or
                        self.is_interface_created.yfilter != YFilter.not_set or
                        self.is_interface_down.yfilter != YFilter.not_set or
                        self.is_message_bundling_enabled.yfilter != YFilter.not_set or
                        self.is_mpls_enabled.yfilter != YFilter.not_set or
                        self.is_non_default_vrf.yfilter != YFilter.not_set or
                        self.is_pacing_enabled.yfilter != YFilter.not_set or
                        self.is_refresh_enabled.yfilter != YFilter.not_set or
                        self.is_refresh_reduction_enabled.yfilter != YFilter.not_set or
                        self.is_rel_s_refresh_enabled.yfilter != YFilter.not_set or
                        self.is_rsvp_configured.yfilter != YFilter.not_set or
                        self.is_s_refresh_enabled.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "flags" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.is_backup_tunnel.is_set or self.is_backup_tunnel.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_backup_tunnel.get_name_leafdata())
                    if (self.is_interface_created.is_set or self.is_interface_created.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_interface_created.get_name_leafdata())
                    if (self.is_interface_down.is_set or self.is_interface_down.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_interface_down.get_name_leafdata())
                    if (self.is_message_bundling_enabled.is_set or self.is_message_bundling_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_message_bundling_enabled.get_name_leafdata())
                    if (self.is_mpls_enabled.is_set or self.is_mpls_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_mpls_enabled.get_name_leafdata())
                    if (self.is_non_default_vrf.is_set or self.is_non_default_vrf.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_non_default_vrf.get_name_leafdata())
                    if (self.is_pacing_enabled.is_set or self.is_pacing_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_pacing_enabled.get_name_leafdata())
                    if (self.is_refresh_enabled.is_set or self.is_refresh_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_refresh_enabled.get_name_leafdata())
                    if (self.is_refresh_reduction_enabled.is_set or self.is_refresh_reduction_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_refresh_reduction_enabled.get_name_leafdata())
                    if (self.is_rel_s_refresh_enabled.is_set or self.is_rel_s_refresh_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_rel_s_refresh_enabled.get_name_leafdata())
                    if (self.is_rsvp_configured.is_set or self.is_rsvp_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_rsvp_configured.get_name_leafdata())
                    if (self.is_s_refresh_enabled.is_set or self.is_s_refresh_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_s_refresh_enabled.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "is-backup-tunnel" or name == "is-interface-created" or name == "is-interface-down" or name == "is-message-bundling-enabled" or name == "is-mpls-enabled" or name == "is-non-default-vrf" or name == "is-pacing-enabled" or name == "is-refresh-enabled" or name == "is-refresh-reduction-enabled" or name == "is-rel-s-refresh-enabled" or name == "is-rsvp-configured" or name == "is-s-refresh-enabled"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "is-backup-tunnel"):
                        self.is_backup_tunnel = value
                        self.is_backup_tunnel.value_namespace = name_space
                        self.is_backup_tunnel.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-interface-created"):
                        self.is_interface_created = value
                        self.is_interface_created.value_namespace = name_space
                        self.is_interface_created.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-interface-down"):
                        self.is_interface_down = value
                        self.is_interface_down.value_namespace = name_space
                        self.is_interface_down.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-message-bundling-enabled"):
                        self.is_message_bundling_enabled = value
                        self.is_message_bundling_enabled.value_namespace = name_space
                        self.is_message_bundling_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-mpls-enabled"):
                        self.is_mpls_enabled = value
                        self.is_mpls_enabled.value_namespace = name_space
                        self.is_mpls_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-non-default-vrf"):
                        self.is_non_default_vrf = value
                        self.is_non_default_vrf.value_namespace = name_space
                        self.is_non_default_vrf.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-pacing-enabled"):
                        self.is_pacing_enabled = value
                        self.is_pacing_enabled.value_namespace = name_space
                        self.is_pacing_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-refresh-enabled"):
                        self.is_refresh_enabled = value
                        self.is_refresh_enabled.value_namespace = name_space
                        self.is_refresh_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-refresh-reduction-enabled"):
                        self.is_refresh_reduction_enabled = value
                        self.is_refresh_reduction_enabled.value_namespace = name_space
                        self.is_refresh_reduction_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-rel-s-refresh-enabled"):
                        self.is_rel_s_refresh_enabled = value
                        self.is_rel_s_refresh_enabled.value_namespace = name_space
                        self.is_rel_s_refresh_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-rsvp-configured"):
                        self.is_rsvp_configured = value
                        self.is_rsvp_configured.value_namespace = name_space
                        self.is_rsvp_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-s-refresh-enabled"):
                        self.is_s_refresh_enabled = value
                        self.is_s_refresh_enabled.value_namespace = name_space
                        self.is_s_refresh_enabled.value_namespace_prefix = name_space_prefix


            class NeighborArray(Entity):
                """
                Neighbor array
                
                .. attribute:: expiry_time
                
                	Expiry time
                	**type**\:   :py:class:`ExpiryTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.ControllerDetaileds.ControllerDetailed.NeighborArray.ExpiryTime>`
                
                .. attribute:: is_neighbor_refresh_reduction_capable
                
                	Is neighbor capable of Refresh Reduction
                	**type**\:  bool
                
                .. attribute:: message_ids
                
                	Number of MessageIDs
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: neighbor_address
                
                	IP address of the neighbor
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: neighbor_message_id
                
                	List of Neighbor MessageIDs
                	**type**\: list of    :py:class:`NeighborMessageId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.ControllerDetaileds.ControllerDetailed.NeighborArray.NeighborMessageId>`
                
                .. attribute:: outgoing_states
                
                	Number of outgoing states to the neighbour
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.ControllerDetaileds.ControllerDetailed.NeighborArray, self).__init__()

                    self.yang_name = "neighbor-array"
                    self.yang_parent_name = "controller-detailed"

                    self.is_neighbor_refresh_reduction_capable = YLeaf(YType.boolean, "is-neighbor-refresh-reduction-capable")

                    self.message_ids = YLeaf(YType.uint32, "message-ids")

                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                    self.outgoing_states = YLeaf(YType.int32, "outgoing-states")

                    self.expiry_time = RsvpStandby.ControllerDetaileds.ControllerDetailed.NeighborArray.ExpiryTime()
                    self.expiry_time.parent = self
                    self._children_name_map["expiry_time"] = "expiry-time"
                    self._children_yang_names.add("expiry-time")

                    self.neighbor_message_id = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("is_neighbor_refresh_reduction_capable",
                                    "message_ids",
                                    "neighbor_address",
                                    "outgoing_states") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.ControllerDetaileds.ControllerDetailed.NeighborArray, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.ControllerDetaileds.ControllerDetailed.NeighborArray, self).__setattr__(name, value)


                class ExpiryTime(Entity):
                    """
                    Expiry time
                    
                    .. attribute:: nanoseconds
                    
                    	Time Value in Nano\-seconds
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: nanosecond
                    
                    .. attribute:: seconds
                    
                    	Time Value in Seconds
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.ControllerDetaileds.ControllerDetailed.NeighborArray.ExpiryTime, self).__init__()

                        self.yang_name = "expiry-time"
                        self.yang_parent_name = "neighbor-array"

                        self.nanoseconds = YLeaf(YType.int32, "nanoseconds")

                        self.seconds = YLeaf(YType.int32, "seconds")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("nanoseconds",
                                        "seconds") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.ControllerDetaileds.ControllerDetailed.NeighborArray.ExpiryTime, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.ControllerDetaileds.ControllerDetailed.NeighborArray.ExpiryTime, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.nanoseconds.is_set or
                            self.seconds.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.nanoseconds.yfilter != YFilter.not_set or
                            self.seconds.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "expiry-time" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.nanoseconds.is_set or self.nanoseconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.nanoseconds.get_name_leafdata())
                        if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.seconds.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "nanoseconds" or name == "seconds"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "nanoseconds"):
                            self.nanoseconds = value
                            self.nanoseconds.value_namespace = name_space
                            self.nanoseconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "seconds"):
                            self.seconds = value
                            self.seconds.value_namespace = name_space
                            self.seconds.value_namespace_prefix = name_space_prefix


                class NeighborMessageId(Entity):
                    """
                    List of Neighbor MessageIDs
                    
                    .. attribute:: message_id
                    
                    	Message ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.ControllerDetaileds.ControllerDetailed.NeighborArray.NeighborMessageId, self).__init__()

                        self.yang_name = "neighbor-message-id"
                        self.yang_parent_name = "neighbor-array"

                        self.message_id = YLeaf(YType.uint32, "message-id")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("message_id") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.ControllerDetaileds.ControllerDetailed.NeighborArray.NeighborMessageId, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.ControllerDetaileds.ControllerDetailed.NeighborArray.NeighborMessageId, self).__setattr__(name, value)

                    def has_data(self):
                        return self.message_id.is_set

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.message_id.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "neighbor-message-id" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.message_id.is_set or self.message_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.message_id.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "message-id"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "message-id"):
                            self.message_id = value
                            self.message_id.value_namespace = name_space
                            self.message_id.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.neighbor_message_id:
                        if (c.has_data()):
                            return True
                    return (
                        self.is_neighbor_refresh_reduction_capable.is_set or
                        self.message_ids.is_set or
                        self.neighbor_address.is_set or
                        self.outgoing_states.is_set or
                        (self.expiry_time is not None and self.expiry_time.has_data()))

                def has_operation(self):
                    for c in self.neighbor_message_id:
                        if (c.has_operation()):
                            return True
                    return (
                        self.yfilter != YFilter.not_set or
                        self.is_neighbor_refresh_reduction_capable.yfilter != YFilter.not_set or
                        self.message_ids.yfilter != YFilter.not_set or
                        self.neighbor_address.yfilter != YFilter.not_set or
                        self.outgoing_states.yfilter != YFilter.not_set or
                        (self.expiry_time is not None and self.expiry_time.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "neighbor-array" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.is_neighbor_refresh_reduction_capable.is_set or self.is_neighbor_refresh_reduction_capable.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_neighbor_refresh_reduction_capable.get_name_leafdata())
                    if (self.message_ids.is_set or self.message_ids.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.message_ids.get_name_leafdata())
                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                    if (self.outgoing_states.is_set or self.outgoing_states.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.outgoing_states.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "expiry-time"):
                        if (self.expiry_time is None):
                            self.expiry_time = RsvpStandby.ControllerDetaileds.ControllerDetailed.NeighborArray.ExpiryTime()
                            self.expiry_time.parent = self
                            self._children_name_map["expiry_time"] = "expiry-time"
                        return self.expiry_time

                    if (child_yang_name == "neighbor-message-id"):
                        for c in self.neighbor_message_id:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = RsvpStandby.ControllerDetaileds.ControllerDetailed.NeighborArray.NeighborMessageId()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.neighbor_message_id.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "expiry-time" or name == "neighbor-message-id" or name == "is-neighbor-refresh-reduction-capable" or name == "message-ids" or name == "neighbor-address" or name == "outgoing-states"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "is-neighbor-refresh-reduction-capable"):
                        self.is_neighbor_refresh_reduction_capable = value
                        self.is_neighbor_refresh_reduction_capable.value_namespace = name_space
                        self.is_neighbor_refresh_reduction_capable.value_namespace_prefix = name_space_prefix
                    if(value_path == "message-ids"):
                        self.message_ids = value
                        self.message_ids.value_namespace = name_space
                        self.message_ids.value_namespace_prefix = name_space_prefix
                    if(value_path == "neighbor-address"):
                        self.neighbor_address = value
                        self.neighbor_address.value_namespace = name_space
                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "outgoing-states"):
                        self.outgoing_states = value
                        self.outgoing_states.value_namespace = name_space
                        self.outgoing_states.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.neighbor_array:
                    if (c.has_data()):
                        return True
                return (
                    self.controller_name.is_set or
                    self.ack_hold_time.is_set or
                    self.ack_max_size.is_set or
                    self.bundle_message_max_size.is_set or
                    self.expiry_drops_tolerated.is_set or
                    self.expiry_interval.is_set or
                    self.expiry_states.is_set or
                    self.expiry_timer_state.is_set or
                    self.integrity_receive_password.is_set or
                    self.integrity_receive_password_optional.is_set or
                    self.integrity_send_password.is_set or
                    self.interface_name_xr.is_set or
                    self.out_of_band_expiry_drops_tolerated.is_set or
                    self.out_of_band_refresh_interval.is_set or
                    self.pacing_interval.is_set or
                    self.pacing_message_rate.is_set or
                    self.pacing_messages.is_set or
                    self.pacing_timer_state.is_set or
                    self.refresh_interval.is_set or
                    self.refresh_timer_state.is_set or
                    self.retransmit_time.is_set or
                    self.signalling_ip_tos.is_set or
                    self.summary_refresh_max_size.is_set or
                    self.summary_refresh_timer_state.is_set or
                    (self.bandwidth_information is not None and self.bandwidth_information.has_data()) or
                    (self.flags is not None and self.flags.has_data()))

            def has_operation(self):
                for c in self.neighbor_array:
                    if (c.has_operation()):
                        return True
                return (
                    self.yfilter != YFilter.not_set or
                    self.controller_name.yfilter != YFilter.not_set or
                    self.ack_hold_time.yfilter != YFilter.not_set or
                    self.ack_max_size.yfilter != YFilter.not_set or
                    self.bundle_message_max_size.yfilter != YFilter.not_set or
                    self.expiry_drops_tolerated.yfilter != YFilter.not_set or
                    self.expiry_interval.yfilter != YFilter.not_set or
                    self.expiry_states.yfilter != YFilter.not_set or
                    self.expiry_timer_state.yfilter != YFilter.not_set or
                    self.integrity_receive_password.yfilter != YFilter.not_set or
                    self.integrity_receive_password_optional.yfilter != YFilter.not_set or
                    self.integrity_send_password.yfilter != YFilter.not_set or
                    self.interface_name_xr.yfilter != YFilter.not_set or
                    self.out_of_band_expiry_drops_tolerated.yfilter != YFilter.not_set or
                    self.out_of_band_refresh_interval.yfilter != YFilter.not_set or
                    self.pacing_interval.yfilter != YFilter.not_set or
                    self.pacing_message_rate.yfilter != YFilter.not_set or
                    self.pacing_messages.yfilter != YFilter.not_set or
                    self.pacing_timer_state.yfilter != YFilter.not_set or
                    self.refresh_interval.yfilter != YFilter.not_set or
                    self.refresh_timer_state.yfilter != YFilter.not_set or
                    self.retransmit_time.yfilter != YFilter.not_set or
                    self.signalling_ip_tos.yfilter != YFilter.not_set or
                    self.summary_refresh_max_size.yfilter != YFilter.not_set or
                    self.summary_refresh_timer_state.yfilter != YFilter.not_set or
                    (self.bandwidth_information is not None and self.bandwidth_information.has_operation()) or
                    (self.flags is not None and self.flags.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "controller-detailed" + "[controller-name='" + self.controller_name.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/controller-detaileds/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.controller_name.is_set or self.controller_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.controller_name.get_name_leafdata())
                if (self.ack_hold_time.is_set or self.ack_hold_time.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.ack_hold_time.get_name_leafdata())
                if (self.ack_max_size.is_set or self.ack_max_size.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.ack_max_size.get_name_leafdata())
                if (self.bundle_message_max_size.is_set or self.bundle_message_max_size.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.bundle_message_max_size.get_name_leafdata())
                if (self.expiry_drops_tolerated.is_set or self.expiry_drops_tolerated.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.expiry_drops_tolerated.get_name_leafdata())
                if (self.expiry_interval.is_set or self.expiry_interval.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.expiry_interval.get_name_leafdata())
                if (self.expiry_states.is_set or self.expiry_states.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.expiry_states.get_name_leafdata())
                if (self.expiry_timer_state.is_set or self.expiry_timer_state.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.expiry_timer_state.get_name_leafdata())
                if (self.integrity_receive_password.is_set or self.integrity_receive_password.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.integrity_receive_password.get_name_leafdata())
                if (self.integrity_receive_password_optional.is_set or self.integrity_receive_password_optional.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.integrity_receive_password_optional.get_name_leafdata())
                if (self.integrity_send_password.is_set or self.integrity_send_password.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.integrity_send_password.get_name_leafdata())
                if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                if (self.out_of_band_expiry_drops_tolerated.is_set or self.out_of_band_expiry_drops_tolerated.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.out_of_band_expiry_drops_tolerated.get_name_leafdata())
                if (self.out_of_band_refresh_interval.is_set or self.out_of_band_refresh_interval.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.out_of_band_refresh_interval.get_name_leafdata())
                if (self.pacing_interval.is_set or self.pacing_interval.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.pacing_interval.get_name_leafdata())
                if (self.pacing_message_rate.is_set or self.pacing_message_rate.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.pacing_message_rate.get_name_leafdata())
                if (self.pacing_messages.is_set or self.pacing_messages.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.pacing_messages.get_name_leafdata())
                if (self.pacing_timer_state.is_set or self.pacing_timer_state.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.pacing_timer_state.get_name_leafdata())
                if (self.refresh_interval.is_set or self.refresh_interval.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.refresh_interval.get_name_leafdata())
                if (self.refresh_timer_state.is_set or self.refresh_timer_state.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.refresh_timer_state.get_name_leafdata())
                if (self.retransmit_time.is_set or self.retransmit_time.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.retransmit_time.get_name_leafdata())
                if (self.signalling_ip_tos.is_set or self.signalling_ip_tos.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.signalling_ip_tos.get_name_leafdata())
                if (self.summary_refresh_max_size.is_set or self.summary_refresh_max_size.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.summary_refresh_max_size.get_name_leafdata())
                if (self.summary_refresh_timer_state.is_set or self.summary_refresh_timer_state.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.summary_refresh_timer_state.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "bandwidth-information"):
                    if (self.bandwidth_information is None):
                        self.bandwidth_information = RsvpStandby.ControllerDetaileds.ControllerDetailed.BandwidthInformation()
                        self.bandwidth_information.parent = self
                        self._children_name_map["bandwidth_information"] = "bandwidth-information"
                    return self.bandwidth_information

                if (child_yang_name == "flags"):
                    if (self.flags is None):
                        self.flags = RsvpStandby.ControllerDetaileds.ControllerDetailed.Flags()
                        self.flags.parent = self
                        self._children_name_map["flags"] = "flags"
                    return self.flags

                if (child_yang_name == "neighbor-array"):
                    for c in self.neighbor_array:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = RsvpStandby.ControllerDetaileds.ControllerDetailed.NeighborArray()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.neighbor_array.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "bandwidth-information" or name == "flags" or name == "neighbor-array" or name == "controller-name" or name == "ack-hold-time" or name == "ack-max-size" or name == "bundle-message-max-size" or name == "expiry-drops-tolerated" or name == "expiry-interval" or name == "expiry-states" or name == "expiry-timer-state" or name == "integrity-receive-password" or name == "integrity-receive-password-optional" or name == "integrity-send-password" or name == "interface-name-xr" or name == "out-of-band-expiry-drops-tolerated" or name == "out-of-band-refresh-interval" or name == "pacing-interval" or name == "pacing-message-rate" or name == "pacing-messages" or name == "pacing-timer-state" or name == "refresh-interval" or name == "refresh-timer-state" or name == "retransmit-time" or name == "signalling-ip-tos" or name == "summary-refresh-max-size" or name == "summary-refresh-timer-state"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "controller-name"):
                    self.controller_name = value
                    self.controller_name.value_namespace = name_space
                    self.controller_name.value_namespace_prefix = name_space_prefix
                if(value_path == "ack-hold-time"):
                    self.ack_hold_time = value
                    self.ack_hold_time.value_namespace = name_space
                    self.ack_hold_time.value_namespace_prefix = name_space_prefix
                if(value_path == "ack-max-size"):
                    self.ack_max_size = value
                    self.ack_max_size.value_namespace = name_space
                    self.ack_max_size.value_namespace_prefix = name_space_prefix
                if(value_path == "bundle-message-max-size"):
                    self.bundle_message_max_size = value
                    self.bundle_message_max_size.value_namespace = name_space
                    self.bundle_message_max_size.value_namespace_prefix = name_space_prefix
                if(value_path == "expiry-drops-tolerated"):
                    self.expiry_drops_tolerated = value
                    self.expiry_drops_tolerated.value_namespace = name_space
                    self.expiry_drops_tolerated.value_namespace_prefix = name_space_prefix
                if(value_path == "expiry-interval"):
                    self.expiry_interval = value
                    self.expiry_interval.value_namespace = name_space
                    self.expiry_interval.value_namespace_prefix = name_space_prefix
                if(value_path == "expiry-states"):
                    self.expiry_states = value
                    self.expiry_states.value_namespace = name_space
                    self.expiry_states.value_namespace_prefix = name_space_prefix
                if(value_path == "expiry-timer-state"):
                    self.expiry_timer_state = value
                    self.expiry_timer_state.value_namespace = name_space
                    self.expiry_timer_state.value_namespace_prefix = name_space_prefix
                if(value_path == "integrity-receive-password"):
                    self.integrity_receive_password = value
                    self.integrity_receive_password.value_namespace = name_space
                    self.integrity_receive_password.value_namespace_prefix = name_space_prefix
                if(value_path == "integrity-receive-password-optional"):
                    self.integrity_receive_password_optional = value
                    self.integrity_receive_password_optional.value_namespace = name_space
                    self.integrity_receive_password_optional.value_namespace_prefix = name_space_prefix
                if(value_path == "integrity-send-password"):
                    self.integrity_send_password = value
                    self.integrity_send_password.value_namespace = name_space
                    self.integrity_send_password.value_namespace_prefix = name_space_prefix
                if(value_path == "interface-name-xr"):
                    self.interface_name_xr = value
                    self.interface_name_xr.value_namespace = name_space
                    self.interface_name_xr.value_namespace_prefix = name_space_prefix
                if(value_path == "out-of-band-expiry-drops-tolerated"):
                    self.out_of_band_expiry_drops_tolerated = value
                    self.out_of_band_expiry_drops_tolerated.value_namespace = name_space
                    self.out_of_band_expiry_drops_tolerated.value_namespace_prefix = name_space_prefix
                if(value_path == "out-of-band-refresh-interval"):
                    self.out_of_band_refresh_interval = value
                    self.out_of_band_refresh_interval.value_namespace = name_space
                    self.out_of_band_refresh_interval.value_namespace_prefix = name_space_prefix
                if(value_path == "pacing-interval"):
                    self.pacing_interval = value
                    self.pacing_interval.value_namespace = name_space
                    self.pacing_interval.value_namespace_prefix = name_space_prefix
                if(value_path == "pacing-message-rate"):
                    self.pacing_message_rate = value
                    self.pacing_message_rate.value_namespace = name_space
                    self.pacing_message_rate.value_namespace_prefix = name_space_prefix
                if(value_path == "pacing-messages"):
                    self.pacing_messages = value
                    self.pacing_messages.value_namespace = name_space
                    self.pacing_messages.value_namespace_prefix = name_space_prefix
                if(value_path == "pacing-timer-state"):
                    self.pacing_timer_state = value
                    self.pacing_timer_state.value_namespace = name_space
                    self.pacing_timer_state.value_namespace_prefix = name_space_prefix
                if(value_path == "refresh-interval"):
                    self.refresh_interval = value
                    self.refresh_interval.value_namespace = name_space
                    self.refresh_interval.value_namespace_prefix = name_space_prefix
                if(value_path == "refresh-timer-state"):
                    self.refresh_timer_state = value
                    self.refresh_timer_state.value_namespace = name_space
                    self.refresh_timer_state.value_namespace_prefix = name_space_prefix
                if(value_path == "retransmit-time"):
                    self.retransmit_time = value
                    self.retransmit_time.value_namespace = name_space
                    self.retransmit_time.value_namespace_prefix = name_space_prefix
                if(value_path == "signalling-ip-tos"):
                    self.signalling_ip_tos = value
                    self.signalling_ip_tos.value_namespace = name_space
                    self.signalling_ip_tos.value_namespace_prefix = name_space_prefix
                if(value_path == "summary-refresh-max-size"):
                    self.summary_refresh_max_size = value
                    self.summary_refresh_max_size.value_namespace = name_space
                    self.summary_refresh_max_size.value_namespace_prefix = name_space_prefix
                if(value_path == "summary-refresh-timer-state"):
                    self.summary_refresh_timer_state = value
                    self.summary_refresh_timer_state.value_namespace = name_space
                    self.summary_refresh_timer_state.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.controller_detailed:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.controller_detailed:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "controller-detaileds" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "controller-detailed"):
                for c in self.controller_detailed:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = RsvpStandby.ControllerDetaileds.ControllerDetailed()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.controller_detailed.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "controller-detailed"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class FrrSummary(Entity):
        """
        Fast Re\-Route Summary State Information
        
        .. attribute:: path_states
        
        	Path state counters
        	**type**\:   :py:class:`PathStates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.FrrSummary.PathStates>`
        
        .. attribute:: reservation_states
        
        	Rerservation state counters
        	**type**\:   :py:class:`ReservationStates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.FrrSummary.ReservationStates>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(RsvpStandby.FrrSummary, self).__init__()

            self.yang_name = "frr-summary"
            self.yang_parent_name = "rsvp-standby"

            self.path_states = RsvpStandby.FrrSummary.PathStates()
            self.path_states.parent = self
            self._children_name_map["path_states"] = "path-states"
            self._children_yang_names.add("path-states")

            self.reservation_states = RsvpStandby.FrrSummary.ReservationStates()
            self.reservation_states.parent = self
            self._children_name_map["reservation_states"] = "reservation-states"
            self._children_yang_names.add("reservation-states")


        class PathStates(Entity):
            """
            Path state counters
            
            .. attribute:: active_instances
            
            	Number of active instances of this state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: active_wait_instances
            
            	Number of instances of this state awaiting Path messages to be sent out or Resv messages to be received
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: ready_instances
            
            	Number of ready instances of this state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: total
            
            	Total number of instances of this state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(RsvpStandby.FrrSummary.PathStates, self).__init__()

                self.yang_name = "path-states"
                self.yang_parent_name = "frr-summary"

                self.active_instances = YLeaf(YType.uint32, "active-instances")

                self.active_wait_instances = YLeaf(YType.uint32, "active-wait-instances")

                self.ready_instances = YLeaf(YType.uint32, "ready-instances")

                self.total = YLeaf(YType.uint32, "total")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("active_instances",
                                "active_wait_instances",
                                "ready_instances",
                                "total") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(RsvpStandby.FrrSummary.PathStates, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(RsvpStandby.FrrSummary.PathStates, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.active_instances.is_set or
                    self.active_wait_instances.is_set or
                    self.ready_instances.is_set or
                    self.total.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.active_instances.yfilter != YFilter.not_set or
                    self.active_wait_instances.yfilter != YFilter.not_set or
                    self.ready_instances.yfilter != YFilter.not_set or
                    self.total.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "path-states" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/frr-summary/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.active_instances.is_set or self.active_instances.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.active_instances.get_name_leafdata())
                if (self.active_wait_instances.is_set or self.active_wait_instances.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.active_wait_instances.get_name_leafdata())
                if (self.ready_instances.is_set or self.ready_instances.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.ready_instances.get_name_leafdata())
                if (self.total.is_set or self.total.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.total.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "active-instances" or name == "active-wait-instances" or name == "ready-instances" or name == "total"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "active-instances"):
                    self.active_instances = value
                    self.active_instances.value_namespace = name_space
                    self.active_instances.value_namespace_prefix = name_space_prefix
                if(value_path == "active-wait-instances"):
                    self.active_wait_instances = value
                    self.active_wait_instances.value_namespace = name_space
                    self.active_wait_instances.value_namespace_prefix = name_space_prefix
                if(value_path == "ready-instances"):
                    self.ready_instances = value
                    self.ready_instances.value_namespace = name_space
                    self.ready_instances.value_namespace_prefix = name_space_prefix
                if(value_path == "total"):
                    self.total = value
                    self.total.value_namespace = name_space
                    self.total.value_namespace_prefix = name_space_prefix


        class ReservationStates(Entity):
            """
            Rerservation state counters
            
            .. attribute:: active_instances
            
            	Number of active instances of this state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: active_wait_instances
            
            	Number of instances of this state awaiting Path messages to be sent out or Resv messages to be received
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: ready_instances
            
            	Number of ready instances of this state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: total
            
            	Total number of instances of this state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(RsvpStandby.FrrSummary.ReservationStates, self).__init__()

                self.yang_name = "reservation-states"
                self.yang_parent_name = "frr-summary"

                self.active_instances = YLeaf(YType.uint32, "active-instances")

                self.active_wait_instances = YLeaf(YType.uint32, "active-wait-instances")

                self.ready_instances = YLeaf(YType.uint32, "ready-instances")

                self.total = YLeaf(YType.uint32, "total")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("active_instances",
                                "active_wait_instances",
                                "ready_instances",
                                "total") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(RsvpStandby.FrrSummary.ReservationStates, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(RsvpStandby.FrrSummary.ReservationStates, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.active_instances.is_set or
                    self.active_wait_instances.is_set or
                    self.ready_instances.is_set or
                    self.total.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.active_instances.yfilter != YFilter.not_set or
                    self.active_wait_instances.yfilter != YFilter.not_set or
                    self.ready_instances.yfilter != YFilter.not_set or
                    self.total.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "reservation-states" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/frr-summary/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.active_instances.is_set or self.active_instances.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.active_instances.get_name_leafdata())
                if (self.active_wait_instances.is_set or self.active_wait_instances.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.active_wait_instances.get_name_leafdata())
                if (self.ready_instances.is_set or self.ready_instances.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.ready_instances.get_name_leafdata())
                if (self.total.is_set or self.total.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.total.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "active-instances" or name == "active-wait-instances" or name == "ready-instances" or name == "total"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "active-instances"):
                    self.active_instances = value
                    self.active_instances.value_namespace = name_space
                    self.active_instances.value_namespace_prefix = name_space_prefix
                if(value_path == "active-wait-instances"):
                    self.active_wait_instances = value
                    self.active_wait_instances.value_namespace = name_space
                    self.active_wait_instances.value_namespace_prefix = name_space_prefix
                if(value_path == "ready-instances"):
                    self.ready_instances = value
                    self.ready_instances.value_namespace = name_space
                    self.ready_instances.value_namespace_prefix = name_space_prefix
                if(value_path == "total"):
                    self.total = value
                    self.total.value_namespace = name_space
                    self.total.value_namespace_prefix = name_space_prefix

        def has_data(self):
            return (
                (self.path_states is not None and self.path_states.has_data()) or
                (self.reservation_states is not None and self.reservation_states.has_data()))

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.path_states is not None and self.path_states.has_operation()) or
                (self.reservation_states is not None and self.reservation_states.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "frr-summary" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "path-states"):
                if (self.path_states is None):
                    self.path_states = RsvpStandby.FrrSummary.PathStates()
                    self.path_states.parent = self
                    self._children_name_map["path_states"] = "path-states"
                return self.path_states

            if (child_yang_name == "reservation-states"):
                if (self.reservation_states is None):
                    self.reservation_states = RsvpStandby.FrrSummary.ReservationStates()
                    self.reservation_states.parent = self
                    self._children_name_map["reservation_states"] = "reservation-states"
                return self.reservation_states

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "path-states" or name == "reservation-states"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class RsbDetaileds(Entity):
        """
        Table of detailed info about reservation state
        blocks
        
        .. attribute:: rsb_detailed
        
        	Detailed info for a single reservation state block
        	**type**\: list of    :py:class:`RsbDetailed <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RsbDetaileds.RsbDetailed>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(RsvpStandby.RsbDetaileds, self).__init__()

            self.yang_name = "rsb-detaileds"
            self.yang_parent_name = "rsvp-standby"

            self.rsb_detailed = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(RsvpStandby.RsbDetaileds, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(RsvpStandby.RsbDetaileds, self).__setattr__(name, value)


        class RsbDetailed(Entity):
            """
            Detailed info for a single reservation state
            block
            
            .. attribute:: destination_address
            
            	Destination Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: destination_port
            
            	Destination Port
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: expiry_time
            
            	Expiry Time
            	**type**\:   :py:class:`ExpiryTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RsbDetaileds.RsbDetailed.ExpiryTime>`
            
            .. attribute:: extended_tunnel_id
            
            	Extended Tunnel ID
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: filter
            
            	RSVP Filter
            	**type**\:   :py:class:`Filter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RsbDetaileds.RsbDetailed.Filter>`
            
            .. attribute:: flow_spec
            
            	Flow Spec Information
            	**type**\:   :py:class:`FlowSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RsbDetaileds.RsbDetailed.FlowSpec>`
            
            .. attribute:: generic_flow_spec
            
            	Generic Flow Spec Information
            	**type**\:   :py:class:`GenericFlowSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RsbDetaileds.RsbDetailed.GenericFlowSpec>`
            
            .. attribute:: header
            
            	RSVP Header Information
            	**type**\:   :py:class:`Header <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RsbDetaileds.RsbDetailed.Header>`
            
            .. attribute:: hop
            
            	Hop Infomation
            	**type**\:   :py:class:`Hop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RsbDetaileds.RsbDetailed.Hop>`
            
            .. attribute:: input_adjusted_interface
            
            	Input Adjusted Interface
            	**type**\:  str
            
            .. attribute:: input_physical_interface
            
            	Input Physical Interface
            	**type**\:  str
            
            .. attribute:: label_info
            
            	Label Information
            	**type**\:   :py:class:`LabelInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo>`
            
            .. attribute:: p2mp_id
            
            	P2MP ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: policy_flags
            
            	RSVP Policy Flags
            	**type**\:   :py:class:`PolicyFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RsbDetaileds.RsbDetailed.PolicyFlags>`
            
            .. attribute:: policy_query_flags
            
            	RSVP Query Flags
            	**type**\:   :py:class:`PolicyQueryFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RsbDetaileds.RsbDetailed.PolicyQueryFlags>`
            
            .. attribute:: policy_sources
            
            	RSVP Policy Sources
            	**type**\:   :py:class:`PolicySources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RsbDetaileds.RsbDetailed.PolicySources>`
            
            .. attribute:: protocol
            
            	Protocol
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: rsb_flags
            
            	Reservation State Block Flags
            	**type**\:   :py:class:`RsbFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RsbDetaileds.RsbDetailed.RsbFlags>`
            
            .. attribute:: s2l_sub_lsp
            
            	RSVP S2L Sub\-LSP information
            	**type**\:   :py:class:`S2LSubLsp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RsbDetaileds.RsbDetailed.S2LSubLsp>`
            
            .. attribute:: session
            
            	RSVP Session Information
            	**type**\:   :py:class:`Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RsbDetaileds.RsbDetailed.Session>`
            
            .. attribute:: session_type
            
            	Session Type
            	**type**\:   :py:class:`RsvpSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpSession>`
            
            .. attribute:: source_address
            
            	Source Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: source_port
            
            	Source Port 
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: style
            
            	RSVP Style
            	**type**\:   :py:class:`Style <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RsbDetaileds.RsbDetailed.Style>`
            
            .. attribute:: sub_group_id
            
            	Subgroup ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: sub_group_origin
            
            	Subgroup Origin
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: vrf_name
            
            	VRF Name
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(RsvpStandby.RsbDetaileds.RsbDetailed, self).__init__()

                self.yang_name = "rsb-detailed"
                self.yang_parent_name = "rsb-detaileds"

                self.destination_address = YLeaf(YType.str, "destination-address")

                self.destination_port = YLeaf(YType.int32, "destination-port")

                self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                self.input_adjusted_interface = YLeaf(YType.str, "input-adjusted-interface")

                self.input_physical_interface = YLeaf(YType.str, "input-physical-interface")

                self.p2mp_id = YLeaf(YType.int32, "p2mp-id")

                self.protocol = YLeaf(YType.int32, "protocol")

                self.session_type = YLeaf(YType.enumeration, "session-type")

                self.source_address = YLeaf(YType.str, "source-address")

                self.source_port = YLeaf(YType.int32, "source-port")

                self.sub_group_id = YLeaf(YType.int32, "sub-group-id")

                self.sub_group_origin = YLeaf(YType.str, "sub-group-origin")

                self.vrf_name = YLeaf(YType.str, "vrf-name")

                self.expiry_time = RsvpStandby.RsbDetaileds.RsbDetailed.ExpiryTime()
                self.expiry_time.parent = self
                self._children_name_map["expiry_time"] = "expiry-time"
                self._children_yang_names.add("expiry-time")

                self.filter = RsvpStandby.RsbDetaileds.RsbDetailed.Filter()
                self.filter.parent = self
                self._children_name_map["filter"] = "filter"
                self._children_yang_names.add("filter")

                self.flow_spec = RsvpStandby.RsbDetaileds.RsbDetailed.FlowSpec()
                self.flow_spec.parent = self
                self._children_name_map["flow_spec"] = "flow-spec"
                self._children_yang_names.add("flow-spec")

                self.generic_flow_spec = RsvpStandby.RsbDetaileds.RsbDetailed.GenericFlowSpec()
                self.generic_flow_spec.parent = self
                self._children_name_map["generic_flow_spec"] = "generic-flow-spec"
                self._children_yang_names.add("generic-flow-spec")

                self.header = RsvpStandby.RsbDetaileds.RsbDetailed.Header()
                self.header.parent = self
                self._children_name_map["header"] = "header"
                self._children_yang_names.add("header")

                self.hop = RsvpStandby.RsbDetaileds.RsbDetailed.Hop()
                self.hop.parent = self
                self._children_name_map["hop"] = "hop"
                self._children_yang_names.add("hop")

                self.label_info = RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo()
                self.label_info.parent = self
                self._children_name_map["label_info"] = "label-info"
                self._children_yang_names.add("label-info")

                self.policy_flags = RsvpStandby.RsbDetaileds.RsbDetailed.PolicyFlags()
                self.policy_flags.parent = self
                self._children_name_map["policy_flags"] = "policy-flags"
                self._children_yang_names.add("policy-flags")

                self.policy_query_flags = RsvpStandby.RsbDetaileds.RsbDetailed.PolicyQueryFlags()
                self.policy_query_flags.parent = self
                self._children_name_map["policy_query_flags"] = "policy-query-flags"
                self._children_yang_names.add("policy-query-flags")

                self.policy_sources = RsvpStandby.RsbDetaileds.RsbDetailed.PolicySources()
                self.policy_sources.parent = self
                self._children_name_map["policy_sources"] = "policy-sources"
                self._children_yang_names.add("policy-sources")

                self.rsb_flags = RsvpStandby.RsbDetaileds.RsbDetailed.RsbFlags()
                self.rsb_flags.parent = self
                self._children_name_map["rsb_flags"] = "rsb-flags"
                self._children_yang_names.add("rsb-flags")

                self.s2l_sub_lsp = RsvpStandby.RsbDetaileds.RsbDetailed.S2LSubLsp()
                self.s2l_sub_lsp.parent = self
                self._children_name_map["s2l_sub_lsp"] = "s2l-sub-lsp"
                self._children_yang_names.add("s2l-sub-lsp")

                self.session = RsvpStandby.RsbDetaileds.RsbDetailed.Session()
                self.session.parent = self
                self._children_name_map["session"] = "session"
                self._children_yang_names.add("session")

                self.style = RsvpStandby.RsbDetaileds.RsbDetailed.Style()
                self.style.parent = self
                self._children_name_map["style"] = "style"
                self._children_yang_names.add("style")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("destination_address",
                                "destination_port",
                                "extended_tunnel_id",
                                "input_adjusted_interface",
                                "input_physical_interface",
                                "p2mp_id",
                                "protocol",
                                "session_type",
                                "source_address",
                                "source_port",
                                "sub_group_id",
                                "sub_group_origin",
                                "vrf_name") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(RsvpStandby.RsbDetaileds.RsbDetailed, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(RsvpStandby.RsbDetaileds.RsbDetailed, self).__setattr__(name, value)


            class FlowSpec(Entity):
                """
                Flow Spec Information
                
                .. attribute:: flow_average_rate
                
                	The Flow Average Rate in bytes per second
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: byte/s
                
                .. attribute:: flow_max_burst
                
                	The Flow Maximum Burst
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: flow_max_unit
                
                	The Flow Maximum Unit
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: flow_min_unit
                
                	The Flow Minimum Unit
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: flow_peak_rate
                
                	The Flow Peak Rate in bytes per second
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: byte/s
                
                .. attribute:: flow_qos
                
                	The Flow Quality of Service
                	**type**\:   :py:class:`RsvpMgmtQosServiceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtQosServiceEnum>`
                
                .. attribute:: flow_requested_rate
                
                	The Flow Requested Rate in bytes per second
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: byte/s
                
                .. attribute:: flow_slack
                
                	The Flow Slack
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.RsbDetaileds.RsbDetailed.FlowSpec, self).__init__()

                    self.yang_name = "flow-spec"
                    self.yang_parent_name = "rsb-detailed"

                    self.flow_average_rate = YLeaf(YType.uint64, "flow-average-rate")

                    self.flow_max_burst = YLeaf(YType.uint64, "flow-max-burst")

                    self.flow_max_unit = YLeaf(YType.uint32, "flow-max-unit")

                    self.flow_min_unit = YLeaf(YType.uint32, "flow-min-unit")

                    self.flow_peak_rate = YLeaf(YType.uint64, "flow-peak-rate")

                    self.flow_qos = YLeaf(YType.enumeration, "flow-qos")

                    self.flow_requested_rate = YLeaf(YType.uint64, "flow-requested-rate")

                    self.flow_slack = YLeaf(YType.uint32, "flow-slack")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("flow_average_rate",
                                    "flow_max_burst",
                                    "flow_max_unit",
                                    "flow_min_unit",
                                    "flow_peak_rate",
                                    "flow_qos",
                                    "flow_requested_rate",
                                    "flow_slack") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.RsbDetaileds.RsbDetailed.FlowSpec, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.RsbDetaileds.RsbDetailed.FlowSpec, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.flow_average_rate.is_set or
                        self.flow_max_burst.is_set or
                        self.flow_max_unit.is_set or
                        self.flow_min_unit.is_set or
                        self.flow_peak_rate.is_set or
                        self.flow_qos.is_set or
                        self.flow_requested_rate.is_set or
                        self.flow_slack.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.flow_average_rate.yfilter != YFilter.not_set or
                        self.flow_max_burst.yfilter != YFilter.not_set or
                        self.flow_max_unit.yfilter != YFilter.not_set or
                        self.flow_min_unit.yfilter != YFilter.not_set or
                        self.flow_peak_rate.yfilter != YFilter.not_set or
                        self.flow_qos.yfilter != YFilter.not_set or
                        self.flow_requested_rate.yfilter != YFilter.not_set or
                        self.flow_slack.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "flow-spec" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/rsb-detaileds/rsb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.flow_average_rate.is_set or self.flow_average_rate.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_average_rate.get_name_leafdata())
                    if (self.flow_max_burst.is_set or self.flow_max_burst.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_max_burst.get_name_leafdata())
                    if (self.flow_max_unit.is_set or self.flow_max_unit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_max_unit.get_name_leafdata())
                    if (self.flow_min_unit.is_set or self.flow_min_unit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_min_unit.get_name_leafdata())
                    if (self.flow_peak_rate.is_set or self.flow_peak_rate.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_peak_rate.get_name_leafdata())
                    if (self.flow_qos.is_set or self.flow_qos.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_qos.get_name_leafdata())
                    if (self.flow_requested_rate.is_set or self.flow_requested_rate.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_requested_rate.get_name_leafdata())
                    if (self.flow_slack.is_set or self.flow_slack.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_slack.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "flow-average-rate" or name == "flow-max-burst" or name == "flow-max-unit" or name == "flow-min-unit" or name == "flow-peak-rate" or name == "flow-qos" or name == "flow-requested-rate" or name == "flow-slack"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "flow-average-rate"):
                        self.flow_average_rate = value
                        self.flow_average_rate.value_namespace = name_space
                        self.flow_average_rate.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-max-burst"):
                        self.flow_max_burst = value
                        self.flow_max_burst.value_namespace = name_space
                        self.flow_max_burst.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-max-unit"):
                        self.flow_max_unit = value
                        self.flow_max_unit.value_namespace = name_space
                        self.flow_max_unit.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-min-unit"):
                        self.flow_min_unit = value
                        self.flow_min_unit.value_namespace = name_space
                        self.flow_min_unit.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-peak-rate"):
                        self.flow_peak_rate = value
                        self.flow_peak_rate.value_namespace = name_space
                        self.flow_peak_rate.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-qos"):
                        self.flow_qos = value
                        self.flow_qos.value_namespace = name_space
                        self.flow_qos.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-requested-rate"):
                        self.flow_requested_rate = value
                        self.flow_requested_rate.value_namespace = name_space
                        self.flow_requested_rate.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-slack"):
                        self.flow_slack = value
                        self.flow_slack.value_namespace = name_space
                        self.flow_slack.value_namespace_prefix = name_space_prefix


            class GenericFlowSpec(Entity):
                """
                Generic Flow Spec Information
                
                .. attribute:: flow_spec_type
                
                	FlowSpecType
                	**type**\:   :py:class:`RsvpMgmtFlowSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtFlowSpec>`
                
                .. attribute:: g709otn_flow_spec
                
                	G709 OTN FlowSpec
                	**type**\:   :py:class:`G709OtnFlowSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RsbDetaileds.RsbDetailed.GenericFlowSpec.G709OtnFlowSpec>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.RsbDetaileds.RsbDetailed.GenericFlowSpec, self).__init__()

                    self.yang_name = "generic-flow-spec"
                    self.yang_parent_name = "rsb-detailed"

                    self.flow_spec_type = YLeaf(YType.enumeration, "flow-spec-type")

                    self.g709otn_flow_spec = RsvpStandby.RsbDetaileds.RsbDetailed.GenericFlowSpec.G709OtnFlowSpec()
                    self.g709otn_flow_spec.parent = self
                    self._children_name_map["g709otn_flow_spec"] = "g709otn-flow-spec"
                    self._children_yang_names.add("g709otn-flow-spec")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("flow_spec_type") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.RsbDetaileds.RsbDetailed.GenericFlowSpec, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.RsbDetaileds.RsbDetailed.GenericFlowSpec, self).__setattr__(name, value)


                class G709OtnFlowSpec(Entity):
                    """
                    G709 OTN FlowSpec
                    
                    .. attribute:: flow_bit_rate
                    
                    	G709 OTN Flow Bit Rate
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: flow_multiplier
                    
                    	G709 OTN Flow Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: flow_nvc
                    
                    	G709 OTN Flow NVC
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: flow_signal_type
                    
                    	G709 OTN Flow Signal Type (Refer G709 v3)
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.RsbDetaileds.RsbDetailed.GenericFlowSpec.G709OtnFlowSpec, self).__init__()

                        self.yang_name = "g709otn-flow-spec"
                        self.yang_parent_name = "generic-flow-spec"

                        self.flow_bit_rate = YLeaf(YType.uint64, "flow-bit-rate")

                        self.flow_multiplier = YLeaf(YType.uint16, "flow-multiplier")

                        self.flow_nvc = YLeaf(YType.uint16, "flow-nvc")

                        self.flow_signal_type = YLeaf(YType.uint8, "flow-signal-type")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("flow_bit_rate",
                                        "flow_multiplier",
                                        "flow_nvc",
                                        "flow_signal_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.RsbDetaileds.RsbDetailed.GenericFlowSpec.G709OtnFlowSpec, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.RsbDetaileds.RsbDetailed.GenericFlowSpec.G709OtnFlowSpec, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.flow_bit_rate.is_set or
                            self.flow_multiplier.is_set or
                            self.flow_nvc.is_set or
                            self.flow_signal_type.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.flow_bit_rate.yfilter != YFilter.not_set or
                            self.flow_multiplier.yfilter != YFilter.not_set or
                            self.flow_nvc.yfilter != YFilter.not_set or
                            self.flow_signal_type.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "g709otn-flow-spec" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/rsb-detaileds/rsb-detailed/generic-flow-spec/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.flow_bit_rate.is_set or self.flow_bit_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.flow_bit_rate.get_name_leafdata())
                        if (self.flow_multiplier.is_set or self.flow_multiplier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.flow_multiplier.get_name_leafdata())
                        if (self.flow_nvc.is_set or self.flow_nvc.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.flow_nvc.get_name_leafdata())
                        if (self.flow_signal_type.is_set or self.flow_signal_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.flow_signal_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "flow-bit-rate" or name == "flow-multiplier" or name == "flow-nvc" or name == "flow-signal-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "flow-bit-rate"):
                            self.flow_bit_rate = value
                            self.flow_bit_rate.value_namespace = name_space
                            self.flow_bit_rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "flow-multiplier"):
                            self.flow_multiplier = value
                            self.flow_multiplier.value_namespace = name_space
                            self.flow_multiplier.value_namespace_prefix = name_space_prefix
                        if(value_path == "flow-nvc"):
                            self.flow_nvc = value
                            self.flow_nvc.value_namespace = name_space
                            self.flow_nvc.value_namespace_prefix = name_space_prefix
                        if(value_path == "flow-signal-type"):
                            self.flow_signal_type = value
                            self.flow_signal_type.value_namespace = name_space
                            self.flow_signal_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.flow_spec_type.is_set or
                        (self.g709otn_flow_spec is not None and self.g709otn_flow_spec.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.flow_spec_type.yfilter != YFilter.not_set or
                        (self.g709otn_flow_spec is not None and self.g709otn_flow_spec.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "generic-flow-spec" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/rsb-detaileds/rsb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.flow_spec_type.is_set or self.flow_spec_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_spec_type.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "g709otn-flow-spec"):
                        if (self.g709otn_flow_spec is None):
                            self.g709otn_flow_spec = RsvpStandby.RsbDetaileds.RsbDetailed.GenericFlowSpec.G709OtnFlowSpec()
                            self.g709otn_flow_spec.parent = self
                            self._children_name_map["g709otn_flow_spec"] = "g709otn-flow-spec"
                        return self.g709otn_flow_spec

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "g709otn-flow-spec" or name == "flow-spec-type"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "flow-spec-type"):
                        self.flow_spec_type = value
                        self.flow_spec_type.value_namespace = name_space
                        self.flow_spec_type.value_namespace_prefix = name_space_prefix


            class Session(Entity):
                """
                RSVP Session Information
                
                .. attribute:: rsvp_session
                
                	RSVP Session
                	**type**\:   :py:class:`RsvpSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RsbDetaileds.RsbDetailed.Session.RsvpSession>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.RsbDetaileds.RsbDetailed.Session, self).__init__()

                    self.yang_name = "session"
                    self.yang_parent_name = "rsb-detailed"

                    self.rsvp_session = RsvpStandby.RsbDetaileds.RsbDetailed.Session.RsvpSession()
                    self.rsvp_session.parent = self
                    self._children_name_map["rsvp_session"] = "rsvp-session"
                    self._children_yang_names.add("rsvp-session")


                class RsvpSession(Entity):
                    """
                    RSVP Session
                    
                    .. attribute:: ipv4
                    
                    	UDP IPv4 session
                    	**type**\:   :py:class:`Ipv4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RsbDetaileds.RsbDetailed.Session.RsvpSession.Ipv4>`
                    
                    .. attribute:: ipv4_lsp_session
                    
                    	IPv4 LSP session
                    	**type**\:   :py:class:`Ipv4LspSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RsbDetaileds.RsbDetailed.Session.RsvpSession.Ipv4LspSession>`
                    
                    .. attribute:: ipv4_p2mp_lsp_session
                    
                    	IPv4 P2MP LSP session
                    	**type**\:   :py:class:`Ipv4P2MpLspSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RsbDetaileds.RsbDetailed.Session.RsvpSession.Ipv4P2MpLspSession>`
                    
                    .. attribute:: ipv4_uni_session
                    
                    	IPv4 UNI session
                    	**type**\:   :py:class:`Ipv4UniSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RsbDetaileds.RsbDetailed.Session.RsvpSession.Ipv4UniSession>`
                    
                    .. attribute:: session_type
                    
                    	SessionType
                    	**type**\:   :py:class:`RsvpMgmtSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtSession>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.RsbDetaileds.RsbDetailed.Session.RsvpSession, self).__init__()

                        self.yang_name = "rsvp-session"
                        self.yang_parent_name = "session"

                        self.session_type = YLeaf(YType.enumeration, "session-type")

                        self.ipv4 = RsvpStandby.RsbDetaileds.RsbDetailed.Session.RsvpSession.Ipv4()
                        self.ipv4.parent = self
                        self._children_name_map["ipv4"] = "ipv4"
                        self._children_yang_names.add("ipv4")

                        self.ipv4_lsp_session = RsvpStandby.RsbDetaileds.RsbDetailed.Session.RsvpSession.Ipv4LspSession()
                        self.ipv4_lsp_session.parent = self
                        self._children_name_map["ipv4_lsp_session"] = "ipv4-lsp-session"
                        self._children_yang_names.add("ipv4-lsp-session")

                        self.ipv4_p2mp_lsp_session = RsvpStandby.RsbDetaileds.RsbDetailed.Session.RsvpSession.Ipv4P2MpLspSession()
                        self.ipv4_p2mp_lsp_session.parent = self
                        self._children_name_map["ipv4_p2mp_lsp_session"] = "ipv4-p2mp-lsp-session"
                        self._children_yang_names.add("ipv4-p2mp-lsp-session")

                        self.ipv4_uni_session = RsvpStandby.RsbDetaileds.RsbDetailed.Session.RsvpSession.Ipv4UniSession()
                        self.ipv4_uni_session.parent = self
                        self._children_name_map["ipv4_uni_session"] = "ipv4-uni-session"
                        self._children_yang_names.add("ipv4-uni-session")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("session_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.RsbDetaileds.RsbDetailed.Session.RsvpSession, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.RsbDetaileds.RsbDetailed.Session.RsvpSession, self).__setattr__(name, value)


                    class Ipv4(Entity):
                        """
                        UDP IPv4 session
                        
                        .. attribute:: destination_address
                        
                        	Destination address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: destination_port
                        
                        	The Session Destination Port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: protocol
                        
                        	Protocol type (originally defined in RFC 790, further values in subsequent RFCs)
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.RsbDetaileds.RsbDetailed.Session.RsvpSession.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "rsvp-session"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.destination_port = YLeaf(YType.uint16, "destination-port")

                            self.protocol = YLeaf(YType.uint8, "protocol")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "destination_port",
                                            "protocol") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.RsbDetaileds.RsbDetailed.Session.RsvpSession.Ipv4, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.RsbDetaileds.RsbDetailed.Session.RsvpSession.Ipv4, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination_address.is_set or
                                self.destination_port.is_set or
                                self.protocol.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.destination_port.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/rsb-detaileds/rsb-detailed/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.destination_port.is_set or self.destination_port.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_port.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "destination-port" or name == "protocol"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "destination-port"):
                                self.destination_port = value
                                self.destination_port.value_namespace = name_space
                                self.destination_port.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix


                    class Ipv4LspSession(Entity):
                        """
                        IPv4 LSP session
                        
                        .. attribute:: destination_address
                        
                        	Destination address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: extended_tunnel_id
                        
                        	The Session Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: tunnel_id
                        
                        	The Session Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.RsbDetaileds.RsbDetailed.Session.RsvpSession.Ipv4LspSession, self).__init__()

                            self.yang_name = "ipv4-lsp-session"
                            self.yang_parent_name = "rsvp-session"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                            self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "extended_tunnel_id",
                                            "tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.RsbDetaileds.RsbDetailed.Session.RsvpSession.Ipv4LspSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.RsbDetaileds.RsbDetailed.Session.RsvpSession.Ipv4LspSession, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination_address.is_set or
                                self.extended_tunnel_id.is_set or
                                self.tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.extended_tunnel_id.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-lsp-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/rsb-detaileds/rsb-detailed/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "extended-tunnel-id" or name == "tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "extended-tunnel-id"):
                                self.extended_tunnel_id = value
                                self.extended_tunnel_id.value_namespace = name_space
                                self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix


                    class Ipv4UniSession(Entity):
                        """
                        IPv4 UNI session
                        
                        .. attribute:: destination_address
                        
                        	Destination address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: extended_address
                        
                        	The Session Extended Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: tunnel_id
                        
                        	The Session Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.RsbDetaileds.RsbDetailed.Session.RsvpSession.Ipv4UniSession, self).__init__()

                            self.yang_name = "ipv4-uni-session"
                            self.yang_parent_name = "rsvp-session"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.extended_address = YLeaf(YType.str, "extended-address")

                            self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "extended_address",
                                            "tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.RsbDetaileds.RsbDetailed.Session.RsvpSession.Ipv4UniSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.RsbDetaileds.RsbDetailed.Session.RsvpSession.Ipv4UniSession, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination_address.is_set or
                                self.extended_address.is_set or
                                self.tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.extended_address.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-uni-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/rsb-detaileds/rsb-detailed/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.extended_address.is_set or self.extended_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_address.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "extended-address" or name == "tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "extended-address"):
                                self.extended_address = value
                                self.extended_address.value_namespace = name_space
                                self.extended_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix


                    class Ipv4P2MpLspSession(Entity):
                        """
                        IPv4 P2MP LSP session
                        
                        .. attribute:: extended_tunnel_id
                        
                        	The Session Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: p2mp_id
                        
                        	The Point to Multipoint ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tunnel_id
                        
                        	The Session Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.RsbDetaileds.RsbDetailed.Session.RsvpSession.Ipv4P2MpLspSession, self).__init__()

                            self.yang_name = "ipv4-p2mp-lsp-session"
                            self.yang_parent_name = "rsvp-session"

                            self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                            self.p2mp_id = YLeaf(YType.uint32, "p2mp-id")

                            self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("extended_tunnel_id",
                                            "p2mp_id",
                                            "tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.RsbDetaileds.RsbDetailed.Session.RsvpSession.Ipv4P2MpLspSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.RsbDetaileds.RsbDetailed.Session.RsvpSession.Ipv4P2MpLspSession, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.extended_tunnel_id.is_set or
                                self.p2mp_id.is_set or
                                self.tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.extended_tunnel_id.yfilter != YFilter.not_set or
                                self.p2mp_id.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-p2mp-lsp-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/rsb-detaileds/rsb-detailed/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                            if (self.p2mp_id.is_set or self.p2mp_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.p2mp_id.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "extended-tunnel-id" or name == "p2mp-id" or name == "tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "extended-tunnel-id"):
                                self.extended_tunnel_id = value
                                self.extended_tunnel_id.value_namespace = name_space
                                self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "p2mp-id"):
                                self.p2mp_id = value
                                self.p2mp_id.value_namespace = name_space
                                self.p2mp_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.session_type.is_set or
                            (self.ipv4 is not None and self.ipv4.has_data()) or
                            (self.ipv4_lsp_session is not None and self.ipv4_lsp_session.has_data()) or
                            (self.ipv4_p2mp_lsp_session is not None and self.ipv4_p2mp_lsp_session.has_data()) or
                            (self.ipv4_uni_session is not None and self.ipv4_uni_session.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.session_type.yfilter != YFilter.not_set or
                            (self.ipv4 is not None and self.ipv4.has_operation()) or
                            (self.ipv4_lsp_session is not None and self.ipv4_lsp_session.has_operation()) or
                            (self.ipv4_p2mp_lsp_session is not None and self.ipv4_p2mp_lsp_session.has_operation()) or
                            (self.ipv4_uni_session is not None and self.ipv4_uni_session.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rsvp-session" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/rsb-detaileds/rsb-detailed/session/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.session_type.is_set or self.session_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.session_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "ipv4"):
                            if (self.ipv4 is None):
                                self.ipv4 = RsvpStandby.RsbDetaileds.RsbDetailed.Session.RsvpSession.Ipv4()
                                self.ipv4.parent = self
                                self._children_name_map["ipv4"] = "ipv4"
                            return self.ipv4

                        if (child_yang_name == "ipv4-lsp-session"):
                            if (self.ipv4_lsp_session is None):
                                self.ipv4_lsp_session = RsvpStandby.RsbDetaileds.RsbDetailed.Session.RsvpSession.Ipv4LspSession()
                                self.ipv4_lsp_session.parent = self
                                self._children_name_map["ipv4_lsp_session"] = "ipv4-lsp-session"
                            return self.ipv4_lsp_session

                        if (child_yang_name == "ipv4-p2mp-lsp-session"):
                            if (self.ipv4_p2mp_lsp_session is None):
                                self.ipv4_p2mp_lsp_session = RsvpStandby.RsbDetaileds.RsbDetailed.Session.RsvpSession.Ipv4P2MpLspSession()
                                self.ipv4_p2mp_lsp_session.parent = self
                                self._children_name_map["ipv4_p2mp_lsp_session"] = "ipv4-p2mp-lsp-session"
                            return self.ipv4_p2mp_lsp_session

                        if (child_yang_name == "ipv4-uni-session"):
                            if (self.ipv4_uni_session is None):
                                self.ipv4_uni_session = RsvpStandby.RsbDetaileds.RsbDetailed.Session.RsvpSession.Ipv4UniSession()
                                self.ipv4_uni_session.parent = self
                                self._children_name_map["ipv4_uni_session"] = "ipv4-uni-session"
                            return self.ipv4_uni_session

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ipv4" or name == "ipv4-lsp-session" or name == "ipv4-p2mp-lsp-session" or name == "ipv4-uni-session" or name == "session-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "session-type"):
                            self.session_type = value
                            self.session_type.value_namespace = name_space
                            self.session_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (self.rsvp_session is not None and self.rsvp_session.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.rsvp_session is not None and self.rsvp_session.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "session" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/rsb-detaileds/rsb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "rsvp-session"):
                        if (self.rsvp_session is None):
                            self.rsvp_session = RsvpStandby.RsbDetaileds.RsbDetailed.Session.RsvpSession()
                            self.rsvp_session.parent = self
                            self._children_name_map["rsvp_session"] = "rsvp-session"
                        return self.rsvp_session

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "rsvp-session"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class S2LSubLsp(Entity):
                """
                RSVP S2L Sub\-LSP information
                
                .. attribute:: s2l_destination_address
                
                	S2L Sub\-LSP Destination Address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.RsbDetaileds.RsbDetailed.S2LSubLsp, self).__init__()

                    self.yang_name = "s2l-sub-lsp"
                    self.yang_parent_name = "rsb-detailed"

                    self.s2l_destination_address = YLeaf(YType.str, "s2l-destination-address")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("s2l_destination_address") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.RsbDetaileds.RsbDetailed.S2LSubLsp, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.RsbDetaileds.RsbDetailed.S2LSubLsp, self).__setattr__(name, value)

                def has_data(self):
                    return self.s2l_destination_address.is_set

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.s2l_destination_address.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "s2l-sub-lsp" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/rsb-detaileds/rsb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.s2l_destination_address.is_set or self.s2l_destination_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.s2l_destination_address.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "s2l-destination-address"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "s2l-destination-address"):
                        self.s2l_destination_address = value
                        self.s2l_destination_address.value_namespace = name_space
                        self.s2l_destination_address.value_namespace_prefix = name_space_prefix


            class Style(Entity):
                """
                RSVP Style
                
                .. attribute:: reservation_type
                
                	The Reservation Type\: WF, SE or FF
                	**type**\:   :py:class:`RsvpMgmtReservationTypeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtReservationTypeEnum>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.RsbDetaileds.RsbDetailed.Style, self).__init__()

                    self.yang_name = "style"
                    self.yang_parent_name = "rsb-detailed"

                    self.reservation_type = YLeaf(YType.enumeration, "reservation-type")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("reservation_type") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.RsbDetaileds.RsbDetailed.Style, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.RsbDetaileds.RsbDetailed.Style, self).__setattr__(name, value)

                def has_data(self):
                    return self.reservation_type.is_set

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.reservation_type.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "style" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/rsb-detaileds/rsb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.reservation_type.is_set or self.reservation_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reservation_type.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "reservation-type"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "reservation-type"):
                        self.reservation_type = value
                        self.reservation_type.value_namespace = name_space
                        self.reservation_type.value_namespace_prefix = name_space_prefix


            class Filter(Entity):
                """
                RSVP Filter
                
                .. attribute:: rsvp_filter
                
                	RSVP Filter
                	**type**\:   :py:class:`RsvpFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RsbDetaileds.RsbDetailed.Filter.RsvpFilter>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.RsbDetaileds.RsbDetailed.Filter, self).__init__()

                    self.yang_name = "filter"
                    self.yang_parent_name = "rsb-detailed"

                    self.rsvp_filter = RsvpStandby.RsbDetaileds.RsbDetailed.Filter.RsvpFilter()
                    self.rsvp_filter.parent = self
                    self._children_name_map["rsvp_filter"] = "rsvp-filter"
                    self._children_yang_names.add("rsvp-filter")


                class RsvpFilter(Entity):
                    """
                    RSVP Filter
                    
                    .. attribute:: filter_type
                    
                    	FilterType
                    	**type**\:   :py:class:`RsvpMgmtFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtFilter>`
                    
                    .. attribute:: p2mp_ipv4_session
                    
                    	IPv4 P2MP LSP FilterSpec
                    	**type**\:   :py:class:`P2MpIpv4Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RsbDetaileds.RsbDetailed.Filter.RsvpFilter.P2MpIpv4Session>`
                    
                    .. attribute:: udp_ipv4_session
                    
                    	UDP IPV4 FilterSpec
                    	**type**\:   :py:class:`UdpIpv4Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RsbDetaileds.RsbDetailed.Filter.RsvpFilter.UdpIpv4Session>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.RsbDetaileds.RsbDetailed.Filter.RsvpFilter, self).__init__()

                        self.yang_name = "rsvp-filter"
                        self.yang_parent_name = "filter"

                        self.filter_type = YLeaf(YType.enumeration, "filter-type")

                        self.p2mp_ipv4_session = RsvpStandby.RsbDetaileds.RsbDetailed.Filter.RsvpFilter.P2MpIpv4Session()
                        self.p2mp_ipv4_session.parent = self
                        self._children_name_map["p2mp_ipv4_session"] = "p2mp-ipv4-session"
                        self._children_yang_names.add("p2mp-ipv4-session")

                        self.udp_ipv4_session = RsvpStandby.RsbDetaileds.RsbDetailed.Filter.RsvpFilter.UdpIpv4Session()
                        self.udp_ipv4_session.parent = self
                        self._children_name_map["udp_ipv4_session"] = "udp-ipv4-session"
                        self._children_yang_names.add("udp-ipv4-session")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("filter_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.RsbDetaileds.RsbDetailed.Filter.RsvpFilter, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.RsbDetaileds.RsbDetailed.Filter.RsvpFilter, self).__setattr__(name, value)


                    class UdpIpv4Session(Entity):
                        """
                        UDP IPV4 FilterSpec
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source_port
                        
                        	Source Port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.RsbDetaileds.RsbDetailed.Filter.RsvpFilter.UdpIpv4Session, self).__init__()

                            self.yang_name = "udp-ipv4-session"
                            self.yang_parent_name = "rsvp-filter"

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.source_port = YLeaf(YType.uint16, "source-port")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("source_address",
                                            "source_port") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.RsbDetaileds.RsbDetailed.Filter.RsvpFilter.UdpIpv4Session, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.RsbDetaileds.RsbDetailed.Filter.RsvpFilter.UdpIpv4Session, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.source_address.is_set or
                                self.source_port.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                self.source_port.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "udp-ipv4-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/rsb-detaileds/rsb-detailed/filter/rsvp-filter/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())
                            if (self.source_port.is_set or self.source_port.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_port.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "source-address" or name == "source-port"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-port"):
                                self.source_port = value
                                self.source_port.value_namespace = name_space
                                self.source_port.value_namespace_prefix = name_space_prefix


                    class P2MpIpv4Session(Entity):
                        """
                        IPv4 P2MP LSP FilterSpec
                        
                        .. attribute:: p2mp_sub_group_origin
                        
                        	Point to Multipoint SubGroup Origin
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source_port
                        
                        	Source Port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: sub_group_id
                        
                        	Point to Multipoint Subgroup ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.RsbDetaileds.RsbDetailed.Filter.RsvpFilter.P2MpIpv4Session, self).__init__()

                            self.yang_name = "p2mp-ipv4-session"
                            self.yang_parent_name = "rsvp-filter"

                            self.p2mp_sub_group_origin = YLeaf(YType.str, "p2mp-sub-group-origin")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.source_port = YLeaf(YType.uint16, "source-port")

                            self.sub_group_id = YLeaf(YType.uint16, "sub-group-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("p2mp_sub_group_origin",
                                            "source_address",
                                            "source_port",
                                            "sub_group_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.RsbDetaileds.RsbDetailed.Filter.RsvpFilter.P2MpIpv4Session, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.RsbDetaileds.RsbDetailed.Filter.RsvpFilter.P2MpIpv4Session, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.p2mp_sub_group_origin.is_set or
                                self.source_address.is_set or
                                self.source_port.is_set or
                                self.sub_group_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.p2mp_sub_group_origin.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                self.source_port.yfilter != YFilter.not_set or
                                self.sub_group_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "p2mp-ipv4-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/rsb-detaileds/rsb-detailed/filter/rsvp-filter/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.p2mp_sub_group_origin.is_set or self.p2mp_sub_group_origin.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.p2mp_sub_group_origin.get_name_leafdata())
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())
                            if (self.source_port.is_set or self.source_port.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_port.get_name_leafdata())
                            if (self.sub_group_id.is_set or self.sub_group_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sub_group_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "p2mp-sub-group-origin" or name == "source-address" or name == "source-port" or name == "sub-group-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "p2mp-sub-group-origin"):
                                self.p2mp_sub_group_origin = value
                                self.p2mp_sub_group_origin.value_namespace = name_space
                                self.p2mp_sub_group_origin.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-port"):
                                self.source_port = value
                                self.source_port.value_namespace = name_space
                                self.source_port.value_namespace_prefix = name_space_prefix
                            if(value_path == "sub-group-id"):
                                self.sub_group_id = value
                                self.sub_group_id.value_namespace = name_space
                                self.sub_group_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.filter_type.is_set or
                            (self.p2mp_ipv4_session is not None and self.p2mp_ipv4_session.has_data()) or
                            (self.udp_ipv4_session is not None and self.udp_ipv4_session.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.filter_type.yfilter != YFilter.not_set or
                            (self.p2mp_ipv4_session is not None and self.p2mp_ipv4_session.has_operation()) or
                            (self.udp_ipv4_session is not None and self.udp_ipv4_session.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rsvp-filter" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/rsb-detaileds/rsb-detailed/filter/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.filter_type.is_set or self.filter_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.filter_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "p2mp-ipv4-session"):
                            if (self.p2mp_ipv4_session is None):
                                self.p2mp_ipv4_session = RsvpStandby.RsbDetaileds.RsbDetailed.Filter.RsvpFilter.P2MpIpv4Session()
                                self.p2mp_ipv4_session.parent = self
                                self._children_name_map["p2mp_ipv4_session"] = "p2mp-ipv4-session"
                            return self.p2mp_ipv4_session

                        if (child_yang_name == "udp-ipv4-session"):
                            if (self.udp_ipv4_session is None):
                                self.udp_ipv4_session = RsvpStandby.RsbDetaileds.RsbDetailed.Filter.RsvpFilter.UdpIpv4Session()
                                self.udp_ipv4_session.parent = self
                                self._children_name_map["udp_ipv4_session"] = "udp-ipv4-session"
                            return self.udp_ipv4_session

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "p2mp-ipv4-session" or name == "udp-ipv4-session" or name == "filter-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "filter-type"):
                            self.filter_type = value
                            self.filter_type.value_namespace = name_space
                            self.filter_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (self.rsvp_filter is not None and self.rsvp_filter.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.rsvp_filter is not None and self.rsvp_filter.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "filter" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/rsb-detaileds/rsb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "rsvp-filter"):
                        if (self.rsvp_filter is None):
                            self.rsvp_filter = RsvpStandby.RsbDetaileds.RsbDetailed.Filter.RsvpFilter()
                            self.rsvp_filter.parent = self
                            self._children_name_map["rsvp_filter"] = "rsvp-filter"
                        return self.rsvp_filter

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "rsvp-filter"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class RsbFlags(Entity):
                """
                Reservation State Block Flags
                
                .. attribute:: is_local_receiver
                
                	Local Receiver
                	**type**\:  bool
                
                .. attribute:: is_local_repair
                
                	Rerouted
                	**type**\:  bool
                
                .. attribute:: is_lockout
                
                	Locked Out
                	**type**\:  bool
                
                .. attribute:: is_merge_point
                
                	Is node a Merge Point
                	**type**\:  bool
                
                .. attribute:: is_message_id_valid
                
                	MessageID Valid
                	**type**\:  bool
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.RsbDetaileds.RsbDetailed.RsbFlags, self).__init__()

                    self.yang_name = "rsb-flags"
                    self.yang_parent_name = "rsb-detailed"

                    self.is_local_receiver = YLeaf(YType.boolean, "is-local-receiver")

                    self.is_local_repair = YLeaf(YType.boolean, "is-local-repair")

                    self.is_lockout = YLeaf(YType.boolean, "is-lockout")

                    self.is_merge_point = YLeaf(YType.boolean, "is-merge-point")

                    self.is_message_id_valid = YLeaf(YType.boolean, "is-message-id-valid")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("is_local_receiver",
                                    "is_local_repair",
                                    "is_lockout",
                                    "is_merge_point",
                                    "is_message_id_valid") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.RsbDetaileds.RsbDetailed.RsbFlags, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.RsbDetaileds.RsbDetailed.RsbFlags, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.is_local_receiver.is_set or
                        self.is_local_repair.is_set or
                        self.is_lockout.is_set or
                        self.is_merge_point.is_set or
                        self.is_message_id_valid.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.is_local_receiver.yfilter != YFilter.not_set or
                        self.is_local_repair.yfilter != YFilter.not_set or
                        self.is_lockout.yfilter != YFilter.not_set or
                        self.is_merge_point.yfilter != YFilter.not_set or
                        self.is_message_id_valid.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "rsb-flags" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/rsb-detaileds/rsb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.is_local_receiver.is_set or self.is_local_receiver.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_local_receiver.get_name_leafdata())
                    if (self.is_local_repair.is_set or self.is_local_repair.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_local_repair.get_name_leafdata())
                    if (self.is_lockout.is_set or self.is_lockout.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_lockout.get_name_leafdata())
                    if (self.is_merge_point.is_set or self.is_merge_point.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_merge_point.get_name_leafdata())
                    if (self.is_message_id_valid.is_set or self.is_message_id_valid.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_message_id_valid.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "is-local-receiver" or name == "is-local-repair" or name == "is-lockout" or name == "is-merge-point" or name == "is-message-id-valid"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "is-local-receiver"):
                        self.is_local_receiver = value
                        self.is_local_receiver.value_namespace = name_space
                        self.is_local_receiver.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-local-repair"):
                        self.is_local_repair = value
                        self.is_local_repair.value_namespace = name_space
                        self.is_local_repair.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-lockout"):
                        self.is_lockout = value
                        self.is_lockout.value_namespace = name_space
                        self.is_lockout.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-merge-point"):
                        self.is_merge_point = value
                        self.is_merge_point.value_namespace = name_space
                        self.is_merge_point.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-message-id-valid"):
                        self.is_message_id_valid = value
                        self.is_message_id_valid.value_namespace = name_space
                        self.is_message_id_valid.value_namespace_prefix = name_space_prefix


            class Hop(Entity):
                """
                Hop Infomation
                
                .. attribute:: neighbor_address
                
                	IP address of the neighbor
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: neighbor_logical_interface_name
                
                	Neighbor Logical Interface Name
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.RsbDetaileds.RsbDetailed.Hop, self).__init__()

                    self.yang_name = "hop"
                    self.yang_parent_name = "rsb-detailed"

                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                    self.neighbor_logical_interface_name = YLeaf(YType.str, "neighbor-logical-interface-name")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("neighbor_address",
                                    "neighbor_logical_interface_name") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.RsbDetaileds.RsbDetailed.Hop, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.RsbDetaileds.RsbDetailed.Hop, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.neighbor_address.is_set or
                        self.neighbor_logical_interface_name.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.neighbor_address.yfilter != YFilter.not_set or
                        self.neighbor_logical_interface_name.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "hop" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/rsb-detaileds/rsb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                    if (self.neighbor_logical_interface_name.is_set or self.neighbor_logical_interface_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.neighbor_logical_interface_name.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "neighbor-address" or name == "neighbor-logical-interface-name"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "neighbor-address"):
                        self.neighbor_address = value
                        self.neighbor_address.value_namespace = name_space
                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "neighbor-logical-interface-name"):
                        self.neighbor_logical_interface_name = value
                        self.neighbor_logical_interface_name.value_namespace = name_space
                        self.neighbor_logical_interface_name.value_namespace_prefix = name_space_prefix


            class PolicySources(Entity):
                """
                RSVP Policy Sources
                
                .. attribute:: is_cable
                
                	Policy Source is Cable
                	**type**\:  bool
                
                .. attribute:: is_cops
                
                	Policy Source is COPS
                	**type**\:  bool
                
                .. attribute:: is_default
                
                	Policy Source is Default
                	**type**\:  bool
                
                .. attribute:: is_local
                
                	Policy Source is Local
                	**type**\:  bool
                
                .. attribute:: is_te_link
                
                	Policy Source is TE Link
                	**type**\:  bool
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.RsbDetaileds.RsbDetailed.PolicySources, self).__init__()

                    self.yang_name = "policy-sources"
                    self.yang_parent_name = "rsb-detailed"

                    self.is_cable = YLeaf(YType.boolean, "is-cable")

                    self.is_cops = YLeaf(YType.boolean, "is-cops")

                    self.is_default = YLeaf(YType.boolean, "is-default")

                    self.is_local = YLeaf(YType.boolean, "is-local")

                    self.is_te_link = YLeaf(YType.boolean, "is-te-link")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("is_cable",
                                    "is_cops",
                                    "is_default",
                                    "is_local",
                                    "is_te_link") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.RsbDetaileds.RsbDetailed.PolicySources, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.RsbDetaileds.RsbDetailed.PolicySources, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.is_cable.is_set or
                        self.is_cops.is_set or
                        self.is_default.is_set or
                        self.is_local.is_set or
                        self.is_te_link.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.is_cable.yfilter != YFilter.not_set or
                        self.is_cops.yfilter != YFilter.not_set or
                        self.is_default.yfilter != YFilter.not_set or
                        self.is_local.yfilter != YFilter.not_set or
                        self.is_te_link.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "policy-sources" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/rsb-detaileds/rsb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.is_cable.is_set or self.is_cable.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_cable.get_name_leafdata())
                    if (self.is_cops.is_set or self.is_cops.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_cops.get_name_leafdata())
                    if (self.is_default.is_set or self.is_default.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_default.get_name_leafdata())
                    if (self.is_local.is_set or self.is_local.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_local.get_name_leafdata())
                    if (self.is_te_link.is_set or self.is_te_link.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_te_link.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "is-cable" or name == "is-cops" or name == "is-default" or name == "is-local" or name == "is-te-link"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "is-cable"):
                        self.is_cable = value
                        self.is_cable.value_namespace = name_space
                        self.is_cable.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-cops"):
                        self.is_cops = value
                        self.is_cops.value_namespace = name_space
                        self.is_cops.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-default"):
                        self.is_default = value
                        self.is_default.value_namespace = name_space
                        self.is_default.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-local"):
                        self.is_local = value
                        self.is_local.value_namespace = name_space
                        self.is_local.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-te-link"):
                        self.is_te_link = value
                        self.is_te_link.value_namespace = name_space
                        self.is_te_link.value_namespace_prefix = name_space_prefix


            class Header(Entity):
                """
                RSVP Header Information
                
                .. attribute:: ip_source_address
                
                	IP Source Address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: ip_tos
                
                	IP Type of Service
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: ip_ttl
                
                	IP TTL
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: rsvp_header_flags
                
                	RSVP Header Flags (defined in RFC2205 Section 3 .1.1)
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: rsvp_message_type
                
                	RSVP Message Type
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: rsvp_ttl
                
                	RSVP TTL
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: rsvp_version
                
                	RSVP Version
                	**type**\:  int
                
                	**range:** 0..255
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.RsbDetaileds.RsbDetailed.Header, self).__init__()

                    self.yang_name = "header"
                    self.yang_parent_name = "rsb-detailed"

                    self.ip_source_address = YLeaf(YType.str, "ip-source-address")

                    self.ip_tos = YLeaf(YType.uint8, "ip-tos")

                    self.ip_ttl = YLeaf(YType.uint8, "ip-ttl")

                    self.rsvp_header_flags = YLeaf(YType.uint8, "rsvp-header-flags")

                    self.rsvp_message_type = YLeaf(YType.uint8, "rsvp-message-type")

                    self.rsvp_ttl = YLeaf(YType.uint8, "rsvp-ttl")

                    self.rsvp_version = YLeaf(YType.uint8, "rsvp-version")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("ip_source_address",
                                    "ip_tos",
                                    "ip_ttl",
                                    "rsvp_header_flags",
                                    "rsvp_message_type",
                                    "rsvp_ttl",
                                    "rsvp_version") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.RsbDetaileds.RsbDetailed.Header, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.RsbDetaileds.RsbDetailed.Header, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.ip_source_address.is_set or
                        self.ip_tos.is_set or
                        self.ip_ttl.is_set or
                        self.rsvp_header_flags.is_set or
                        self.rsvp_message_type.is_set or
                        self.rsvp_ttl.is_set or
                        self.rsvp_version.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.ip_source_address.yfilter != YFilter.not_set or
                        self.ip_tos.yfilter != YFilter.not_set or
                        self.ip_ttl.yfilter != YFilter.not_set or
                        self.rsvp_header_flags.yfilter != YFilter.not_set or
                        self.rsvp_message_type.yfilter != YFilter.not_set or
                        self.rsvp_ttl.yfilter != YFilter.not_set or
                        self.rsvp_version.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "header" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/rsb-detaileds/rsb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.ip_source_address.is_set or self.ip_source_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ip_source_address.get_name_leafdata())
                    if (self.ip_tos.is_set or self.ip_tos.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ip_tos.get_name_leafdata())
                    if (self.ip_ttl.is_set or self.ip_ttl.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ip_ttl.get_name_leafdata())
                    if (self.rsvp_header_flags.is_set or self.rsvp_header_flags.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_header_flags.get_name_leafdata())
                    if (self.rsvp_message_type.is_set or self.rsvp_message_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_message_type.get_name_leafdata())
                    if (self.rsvp_ttl.is_set or self.rsvp_ttl.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_ttl.get_name_leafdata())
                    if (self.rsvp_version.is_set or self.rsvp_version.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_version.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ip-source-address" or name == "ip-tos" or name == "ip-ttl" or name == "rsvp-header-flags" or name == "rsvp-message-type" or name == "rsvp-ttl" or name == "rsvp-version"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "ip-source-address"):
                        self.ip_source_address = value
                        self.ip_source_address.value_namespace = name_space
                        self.ip_source_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "ip-tos"):
                        self.ip_tos = value
                        self.ip_tos.value_namespace = name_space
                        self.ip_tos.value_namespace_prefix = name_space_prefix
                    if(value_path == "ip-ttl"):
                        self.ip_ttl = value
                        self.ip_ttl.value_namespace = name_space
                        self.ip_ttl.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-header-flags"):
                        self.rsvp_header_flags = value
                        self.rsvp_header_flags.value_namespace = name_space
                        self.rsvp_header_flags.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-message-type"):
                        self.rsvp_message_type = value
                        self.rsvp_message_type.value_namespace = name_space
                        self.rsvp_message_type.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-ttl"):
                        self.rsvp_ttl = value
                        self.rsvp_ttl.value_namespace = name_space
                        self.rsvp_ttl.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-version"):
                        self.rsvp_version = value
                        self.rsvp_version.value_namespace = name_space
                        self.rsvp_version.value_namespace_prefix = name_space_prefix


            class PolicyFlags(Entity):
                """
                RSVP Policy Flags
                
                .. attribute:: is_accepted
                
                	Accepted
                	**type**\:  bool
                
                .. attribute:: is_forwarding
                
                	Forwarding
                	**type**\:  bool
                
                .. attribute:: is_installed
                
                	Installed
                	**type**\:  bool
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.RsbDetaileds.RsbDetailed.PolicyFlags, self).__init__()

                    self.yang_name = "policy-flags"
                    self.yang_parent_name = "rsb-detailed"

                    self.is_accepted = YLeaf(YType.boolean, "is-accepted")

                    self.is_forwarding = YLeaf(YType.boolean, "is-forwarding")

                    self.is_installed = YLeaf(YType.boolean, "is-installed")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("is_accepted",
                                    "is_forwarding",
                                    "is_installed") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.RsbDetaileds.RsbDetailed.PolicyFlags, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.RsbDetaileds.RsbDetailed.PolicyFlags, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.is_accepted.is_set or
                        self.is_forwarding.is_set or
                        self.is_installed.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.is_accepted.yfilter != YFilter.not_set or
                        self.is_forwarding.yfilter != YFilter.not_set or
                        self.is_installed.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "policy-flags" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/rsb-detaileds/rsb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.is_accepted.is_set or self.is_accepted.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_accepted.get_name_leafdata())
                    if (self.is_forwarding.is_set or self.is_forwarding.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_forwarding.get_name_leafdata())
                    if (self.is_installed.is_set or self.is_installed.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_installed.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "is-accepted" or name == "is-forwarding" or name == "is-installed"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "is-accepted"):
                        self.is_accepted = value
                        self.is_accepted.value_namespace = name_space
                        self.is_accepted.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-forwarding"):
                        self.is_forwarding = value
                        self.is_forwarding.value_namespace = name_space
                        self.is_forwarding.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-installed"):
                        self.is_installed = value
                        self.is_installed.value_namespace = name_space
                        self.is_installed.value_namespace_prefix = name_space_prefix


            class ExpiryTime(Entity):
                """
                Expiry Time
                
                .. attribute:: nanoseconds
                
                	Time Value in Nano\-seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: nanosecond
                
                .. attribute:: seconds
                
                	Time Value in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.RsbDetaileds.RsbDetailed.ExpiryTime, self).__init__()

                    self.yang_name = "expiry-time"
                    self.yang_parent_name = "rsb-detailed"

                    self.nanoseconds = YLeaf(YType.int32, "nanoseconds")

                    self.seconds = YLeaf(YType.int32, "seconds")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("nanoseconds",
                                    "seconds") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.RsbDetaileds.RsbDetailed.ExpiryTime, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.RsbDetaileds.RsbDetailed.ExpiryTime, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.nanoseconds.is_set or
                        self.seconds.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.nanoseconds.yfilter != YFilter.not_set or
                        self.seconds.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "expiry-time" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/rsb-detaileds/rsb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.nanoseconds.is_set or self.nanoseconds.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.nanoseconds.get_name_leafdata())
                    if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.seconds.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "nanoseconds" or name == "seconds"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "nanoseconds"):
                        self.nanoseconds = value
                        self.nanoseconds.value_namespace = name_space
                        self.nanoseconds.value_namespace_prefix = name_space_prefix
                    if(value_path == "seconds"):
                        self.seconds = value
                        self.seconds.value_namespace = name_space
                        self.seconds.value_namespace_prefix = name_space_prefix


            class PolicyQueryFlags(Entity):
                """
                RSVP Query Flags
                
                .. attribute:: is_bypass
                
                	Bypass
                	**type**\:  bool
                
                .. attribute:: is_needed
                
                	Needed
                	**type**\:  bool
                
                .. attribute:: is_report_required
                
                	Report Required
                	**type**\:  bool
                
                .. attribute:: is_resync
                
                	Resynchronization
                	**type**\:  bool
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.RsbDetaileds.RsbDetailed.PolicyQueryFlags, self).__init__()

                    self.yang_name = "policy-query-flags"
                    self.yang_parent_name = "rsb-detailed"

                    self.is_bypass = YLeaf(YType.boolean, "is-bypass")

                    self.is_needed = YLeaf(YType.boolean, "is-needed")

                    self.is_report_required = YLeaf(YType.boolean, "is-report-required")

                    self.is_resync = YLeaf(YType.boolean, "is-resync")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("is_bypass",
                                    "is_needed",
                                    "is_report_required",
                                    "is_resync") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.RsbDetaileds.RsbDetailed.PolicyQueryFlags, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.RsbDetaileds.RsbDetailed.PolicyQueryFlags, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.is_bypass.is_set or
                        self.is_needed.is_set or
                        self.is_report_required.is_set or
                        self.is_resync.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.is_bypass.yfilter != YFilter.not_set or
                        self.is_needed.yfilter != YFilter.not_set or
                        self.is_report_required.yfilter != YFilter.not_set or
                        self.is_resync.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "policy-query-flags" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/rsb-detaileds/rsb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.is_bypass.is_set or self.is_bypass.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_bypass.get_name_leafdata())
                    if (self.is_needed.is_set or self.is_needed.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_needed.get_name_leafdata())
                    if (self.is_report_required.is_set or self.is_report_required.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_report_required.get_name_leafdata())
                    if (self.is_resync.is_set or self.is_resync.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_resync.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "is-bypass" or name == "is-needed" or name == "is-report-required" or name == "is-resync"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "is-bypass"):
                        self.is_bypass = value
                        self.is_bypass.value_namespace = name_space
                        self.is_bypass.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-needed"):
                        self.is_needed = value
                        self.is_needed.value_namespace = name_space
                        self.is_needed.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-report-required"):
                        self.is_report_required = value
                        self.is_report_required.value_namespace = name_space
                        self.is_report_required.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-resync"):
                        self.is_resync = value
                        self.is_resync.value_namespace = name_space
                        self.is_resync.value_namespace_prefix = name_space_prefix


            class LabelInfo(Entity):
                """
                Label Information
                
                .. attribute:: generic_local_downstream_label
                
                	Generic Local Downstream Label
                	**type**\:   :py:class:`GenericLocalDownstreamLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericLocalDownstreamLabel>`
                
                .. attribute:: generic_local_upstream_label
                
                	Generic Local Upstream Label
                	**type**\:   :py:class:`GenericLocalUpstreamLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericLocalUpstreamLabel>`
                
                .. attribute:: generic_merge_point_label
                
                	Generic MergePoint Label
                	**type**\:   :py:class:`GenericMergePointLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericMergePointLabel>`
                
                .. attribute:: generic_outgoing_downstream_label
                
                	Generic Outgoing Downstream Label
                	**type**\:   :py:class:`GenericOutgoingDownstreamLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericOutgoingDownstreamLabel>`
                
                .. attribute:: generic_outgoing_upstream_label
                
                	Generic Outgoing Upstream Label
                	**type**\:   :py:class:`GenericOutgoingUpstreamLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericOutgoingUpstreamLabel>`
                
                .. attribute:: generic_recovery_label
                
                	Generic Recovery Label
                	**type**\:   :py:class:`GenericRecoveryLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericRecoveryLabel>`
                
                .. attribute:: is_valid
                
                	Is the label information valid
                	**type**\:  bool
                
                .. attribute:: local_downstream_label
                
                	Local Downstream Label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: local_upstream_label
                
                	Local Upstream Label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: lsp_wrap_label
                
                	LSP Wrap Label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: merge_point_label
                
                	MergePoint Label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: outgoing_downstream_label
                
                	Outgoing Downstream Label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: outgoing_upstream_label
                
                	Outgoing Upstream Label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: recovery_label
                
                	Recovery Label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo, self).__init__()

                    self.yang_name = "label-info"
                    self.yang_parent_name = "rsb-detailed"

                    self.is_valid = YLeaf(YType.boolean, "is-valid")

                    self.local_downstream_label = YLeaf(YType.uint32, "local-downstream-label")

                    self.local_upstream_label = YLeaf(YType.uint32, "local-upstream-label")

                    self.lsp_wrap_label = YLeaf(YType.uint32, "lsp-wrap-label")

                    self.merge_point_label = YLeaf(YType.uint32, "merge-point-label")

                    self.outgoing_downstream_label = YLeaf(YType.uint32, "outgoing-downstream-label")

                    self.outgoing_upstream_label = YLeaf(YType.uint32, "outgoing-upstream-label")

                    self.recovery_label = YLeaf(YType.uint32, "recovery-label")

                    self.generic_local_downstream_label = RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericLocalDownstreamLabel()
                    self.generic_local_downstream_label.parent = self
                    self._children_name_map["generic_local_downstream_label"] = "generic-local-downstream-label"
                    self._children_yang_names.add("generic-local-downstream-label")

                    self.generic_local_upstream_label = RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericLocalUpstreamLabel()
                    self.generic_local_upstream_label.parent = self
                    self._children_name_map["generic_local_upstream_label"] = "generic-local-upstream-label"
                    self._children_yang_names.add("generic-local-upstream-label")

                    self.generic_merge_point_label = RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericMergePointLabel()
                    self.generic_merge_point_label.parent = self
                    self._children_name_map["generic_merge_point_label"] = "generic-merge-point-label"
                    self._children_yang_names.add("generic-merge-point-label")

                    self.generic_outgoing_downstream_label = RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericOutgoingDownstreamLabel()
                    self.generic_outgoing_downstream_label.parent = self
                    self._children_name_map["generic_outgoing_downstream_label"] = "generic-outgoing-downstream-label"
                    self._children_yang_names.add("generic-outgoing-downstream-label")

                    self.generic_outgoing_upstream_label = RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericOutgoingUpstreamLabel()
                    self.generic_outgoing_upstream_label.parent = self
                    self._children_name_map["generic_outgoing_upstream_label"] = "generic-outgoing-upstream-label"
                    self._children_yang_names.add("generic-outgoing-upstream-label")

                    self.generic_recovery_label = RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericRecoveryLabel()
                    self.generic_recovery_label.parent = self
                    self._children_name_map["generic_recovery_label"] = "generic-recovery-label"
                    self._children_yang_names.add("generic-recovery-label")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("is_valid",
                                    "local_downstream_label",
                                    "local_upstream_label",
                                    "lsp_wrap_label",
                                    "merge_point_label",
                                    "outgoing_downstream_label",
                                    "outgoing_upstream_label",
                                    "recovery_label") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo, self).__setattr__(name, value)


                class GenericLocalDownstreamLabel(Entity):
                    """
                    Generic Local Downstream Label
                    
                    .. attribute:: generalized_label
                    
                    	Generalized Label
                    	**type**\:   :py:class:`GeneralizedLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericLocalDownstreamLabel.GeneralizedLabel>`
                    
                    .. attribute:: generic_label_type
                    
                    	GenericLabelType
                    	**type**\:   :py:class:`RsvpMgmtGenericLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtGenericLabel>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericLocalDownstreamLabel, self).__init__()

                        self.yang_name = "generic-local-downstream-label"
                        self.yang_parent_name = "label-info"

                        self.generic_label_type = YLeaf(YType.enumeration, "generic-label-type")

                        self.generalized_label = RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericLocalDownstreamLabel.GeneralizedLabel()
                        self.generalized_label.parent = self
                        self._children_name_map["generalized_label"] = "generalized-label"
                        self._children_yang_names.add("generalized-label")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("generic_label_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericLocalDownstreamLabel, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericLocalDownstreamLabel, self).__setattr__(name, value)


                    class GeneralizedLabel(Entity):
                        """
                        Generalized Label
                        
                        .. attribute:: value
                        
                        	Generalized Label Value
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericLocalDownstreamLabel.GeneralizedLabel, self).__init__()

                            self.yang_name = "generalized-label"
                            self.yang_parent_name = "generic-local-downstream-label"

                            self.value = YLeafList(YType.uint32, "value")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("value") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericLocalDownstreamLabel.GeneralizedLabel, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericLocalDownstreamLabel.GeneralizedLabel, self).__setattr__(name, value)

                        def has_data(self):
                            for leaf in self.value.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            return False

                        def has_operation(self):
                            for leaf in self.value.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.value.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "generalized-label" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/rsb-detaileds/rsb-detailed/label-info/generic-local-downstream-label/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            leaf_name_data.extend(self.value.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "value"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "value"):
                                self.value.append(value)

                    def has_data(self):
                        return (
                            self.generic_label_type.is_set or
                            (self.generalized_label is not None and self.generalized_label.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.generic_label_type.yfilter != YFilter.not_set or
                            (self.generalized_label is not None and self.generalized_label.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "generic-local-downstream-label" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/rsb-detaileds/rsb-detailed/label-info/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.generic_label_type.is_set or self.generic_label_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.generic_label_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "generalized-label"):
                            if (self.generalized_label is None):
                                self.generalized_label = RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericLocalDownstreamLabel.GeneralizedLabel()
                                self.generalized_label.parent = self
                                self._children_name_map["generalized_label"] = "generalized-label"
                            return self.generalized_label

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "generalized-label" or name == "generic-label-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "generic-label-type"):
                            self.generic_label_type = value
                            self.generic_label_type.value_namespace = name_space
                            self.generic_label_type.value_namespace_prefix = name_space_prefix


                class GenericOutgoingDownstreamLabel(Entity):
                    """
                    Generic Outgoing Downstream Label
                    
                    .. attribute:: generalized_label
                    
                    	Generalized Label
                    	**type**\:   :py:class:`GeneralizedLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericOutgoingDownstreamLabel.GeneralizedLabel>`
                    
                    .. attribute:: generic_label_type
                    
                    	GenericLabelType
                    	**type**\:   :py:class:`RsvpMgmtGenericLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtGenericLabel>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericOutgoingDownstreamLabel, self).__init__()

                        self.yang_name = "generic-outgoing-downstream-label"
                        self.yang_parent_name = "label-info"

                        self.generic_label_type = YLeaf(YType.enumeration, "generic-label-type")

                        self.generalized_label = RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericOutgoingDownstreamLabel.GeneralizedLabel()
                        self.generalized_label.parent = self
                        self._children_name_map["generalized_label"] = "generalized-label"
                        self._children_yang_names.add("generalized-label")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("generic_label_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericOutgoingDownstreamLabel, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericOutgoingDownstreamLabel, self).__setattr__(name, value)


                    class GeneralizedLabel(Entity):
                        """
                        Generalized Label
                        
                        .. attribute:: value
                        
                        	Generalized Label Value
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericOutgoingDownstreamLabel.GeneralizedLabel, self).__init__()

                            self.yang_name = "generalized-label"
                            self.yang_parent_name = "generic-outgoing-downstream-label"

                            self.value = YLeafList(YType.uint32, "value")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("value") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericOutgoingDownstreamLabel.GeneralizedLabel, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericOutgoingDownstreamLabel.GeneralizedLabel, self).__setattr__(name, value)

                        def has_data(self):
                            for leaf in self.value.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            return False

                        def has_operation(self):
                            for leaf in self.value.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.value.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "generalized-label" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/rsb-detaileds/rsb-detailed/label-info/generic-outgoing-downstream-label/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            leaf_name_data.extend(self.value.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "value"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "value"):
                                self.value.append(value)

                    def has_data(self):
                        return (
                            self.generic_label_type.is_set or
                            (self.generalized_label is not None and self.generalized_label.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.generic_label_type.yfilter != YFilter.not_set or
                            (self.generalized_label is not None and self.generalized_label.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "generic-outgoing-downstream-label" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/rsb-detaileds/rsb-detailed/label-info/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.generic_label_type.is_set or self.generic_label_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.generic_label_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "generalized-label"):
                            if (self.generalized_label is None):
                                self.generalized_label = RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericOutgoingDownstreamLabel.GeneralizedLabel()
                                self.generalized_label.parent = self
                                self._children_name_map["generalized_label"] = "generalized-label"
                            return self.generalized_label

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "generalized-label" or name == "generic-label-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "generic-label-type"):
                            self.generic_label_type = value
                            self.generic_label_type.value_namespace = name_space
                            self.generic_label_type.value_namespace_prefix = name_space_prefix


                class GenericMergePointLabel(Entity):
                    """
                    Generic MergePoint Label
                    
                    .. attribute:: generalized_label
                    
                    	Generalized Label
                    	**type**\:   :py:class:`GeneralizedLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericMergePointLabel.GeneralizedLabel>`
                    
                    .. attribute:: generic_label_type
                    
                    	GenericLabelType
                    	**type**\:   :py:class:`RsvpMgmtGenericLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtGenericLabel>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericMergePointLabel, self).__init__()

                        self.yang_name = "generic-merge-point-label"
                        self.yang_parent_name = "label-info"

                        self.generic_label_type = YLeaf(YType.enumeration, "generic-label-type")

                        self.generalized_label = RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericMergePointLabel.GeneralizedLabel()
                        self.generalized_label.parent = self
                        self._children_name_map["generalized_label"] = "generalized-label"
                        self._children_yang_names.add("generalized-label")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("generic_label_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericMergePointLabel, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericMergePointLabel, self).__setattr__(name, value)


                    class GeneralizedLabel(Entity):
                        """
                        Generalized Label
                        
                        .. attribute:: value
                        
                        	Generalized Label Value
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericMergePointLabel.GeneralizedLabel, self).__init__()

                            self.yang_name = "generalized-label"
                            self.yang_parent_name = "generic-merge-point-label"

                            self.value = YLeafList(YType.uint32, "value")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("value") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericMergePointLabel.GeneralizedLabel, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericMergePointLabel.GeneralizedLabel, self).__setattr__(name, value)

                        def has_data(self):
                            for leaf in self.value.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            return False

                        def has_operation(self):
                            for leaf in self.value.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.value.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "generalized-label" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/rsb-detaileds/rsb-detailed/label-info/generic-merge-point-label/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            leaf_name_data.extend(self.value.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "value"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "value"):
                                self.value.append(value)

                    def has_data(self):
                        return (
                            self.generic_label_type.is_set or
                            (self.generalized_label is not None and self.generalized_label.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.generic_label_type.yfilter != YFilter.not_set or
                            (self.generalized_label is not None and self.generalized_label.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "generic-merge-point-label" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/rsb-detaileds/rsb-detailed/label-info/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.generic_label_type.is_set or self.generic_label_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.generic_label_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "generalized-label"):
                            if (self.generalized_label is None):
                                self.generalized_label = RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericMergePointLabel.GeneralizedLabel()
                                self.generalized_label.parent = self
                                self._children_name_map["generalized_label"] = "generalized-label"
                            return self.generalized_label

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "generalized-label" or name == "generic-label-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "generic-label-type"):
                            self.generic_label_type = value
                            self.generic_label_type.value_namespace = name_space
                            self.generic_label_type.value_namespace_prefix = name_space_prefix


                class GenericOutgoingUpstreamLabel(Entity):
                    """
                    Generic Outgoing Upstream Label
                    
                    .. attribute:: generalized_label
                    
                    	Generalized Label
                    	**type**\:   :py:class:`GeneralizedLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericOutgoingUpstreamLabel.GeneralizedLabel>`
                    
                    .. attribute:: generic_label_type
                    
                    	GenericLabelType
                    	**type**\:   :py:class:`RsvpMgmtGenericLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtGenericLabel>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericOutgoingUpstreamLabel, self).__init__()

                        self.yang_name = "generic-outgoing-upstream-label"
                        self.yang_parent_name = "label-info"

                        self.generic_label_type = YLeaf(YType.enumeration, "generic-label-type")

                        self.generalized_label = RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericOutgoingUpstreamLabel.GeneralizedLabel()
                        self.generalized_label.parent = self
                        self._children_name_map["generalized_label"] = "generalized-label"
                        self._children_yang_names.add("generalized-label")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("generic_label_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericOutgoingUpstreamLabel, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericOutgoingUpstreamLabel, self).__setattr__(name, value)


                    class GeneralizedLabel(Entity):
                        """
                        Generalized Label
                        
                        .. attribute:: value
                        
                        	Generalized Label Value
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericOutgoingUpstreamLabel.GeneralizedLabel, self).__init__()

                            self.yang_name = "generalized-label"
                            self.yang_parent_name = "generic-outgoing-upstream-label"

                            self.value = YLeafList(YType.uint32, "value")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("value") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericOutgoingUpstreamLabel.GeneralizedLabel, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericOutgoingUpstreamLabel.GeneralizedLabel, self).__setattr__(name, value)

                        def has_data(self):
                            for leaf in self.value.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            return False

                        def has_operation(self):
                            for leaf in self.value.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.value.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "generalized-label" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/rsb-detaileds/rsb-detailed/label-info/generic-outgoing-upstream-label/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            leaf_name_data.extend(self.value.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "value"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "value"):
                                self.value.append(value)

                    def has_data(self):
                        return (
                            self.generic_label_type.is_set or
                            (self.generalized_label is not None and self.generalized_label.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.generic_label_type.yfilter != YFilter.not_set or
                            (self.generalized_label is not None and self.generalized_label.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "generic-outgoing-upstream-label" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/rsb-detaileds/rsb-detailed/label-info/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.generic_label_type.is_set or self.generic_label_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.generic_label_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "generalized-label"):
                            if (self.generalized_label is None):
                                self.generalized_label = RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericOutgoingUpstreamLabel.GeneralizedLabel()
                                self.generalized_label.parent = self
                                self._children_name_map["generalized_label"] = "generalized-label"
                            return self.generalized_label

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "generalized-label" or name == "generic-label-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "generic-label-type"):
                            self.generic_label_type = value
                            self.generic_label_type.value_namespace = name_space
                            self.generic_label_type.value_namespace_prefix = name_space_prefix


                class GenericLocalUpstreamLabel(Entity):
                    """
                    Generic Local Upstream Label
                    
                    .. attribute:: generalized_label
                    
                    	Generalized Label
                    	**type**\:   :py:class:`GeneralizedLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericLocalUpstreamLabel.GeneralizedLabel>`
                    
                    .. attribute:: generic_label_type
                    
                    	GenericLabelType
                    	**type**\:   :py:class:`RsvpMgmtGenericLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtGenericLabel>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericLocalUpstreamLabel, self).__init__()

                        self.yang_name = "generic-local-upstream-label"
                        self.yang_parent_name = "label-info"

                        self.generic_label_type = YLeaf(YType.enumeration, "generic-label-type")

                        self.generalized_label = RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericLocalUpstreamLabel.GeneralizedLabel()
                        self.generalized_label.parent = self
                        self._children_name_map["generalized_label"] = "generalized-label"
                        self._children_yang_names.add("generalized-label")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("generic_label_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericLocalUpstreamLabel, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericLocalUpstreamLabel, self).__setattr__(name, value)


                    class GeneralizedLabel(Entity):
                        """
                        Generalized Label
                        
                        .. attribute:: value
                        
                        	Generalized Label Value
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericLocalUpstreamLabel.GeneralizedLabel, self).__init__()

                            self.yang_name = "generalized-label"
                            self.yang_parent_name = "generic-local-upstream-label"

                            self.value = YLeafList(YType.uint32, "value")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("value") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericLocalUpstreamLabel.GeneralizedLabel, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericLocalUpstreamLabel.GeneralizedLabel, self).__setattr__(name, value)

                        def has_data(self):
                            for leaf in self.value.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            return False

                        def has_operation(self):
                            for leaf in self.value.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.value.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "generalized-label" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/rsb-detaileds/rsb-detailed/label-info/generic-local-upstream-label/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            leaf_name_data.extend(self.value.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "value"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "value"):
                                self.value.append(value)

                    def has_data(self):
                        return (
                            self.generic_label_type.is_set or
                            (self.generalized_label is not None and self.generalized_label.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.generic_label_type.yfilter != YFilter.not_set or
                            (self.generalized_label is not None and self.generalized_label.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "generic-local-upstream-label" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/rsb-detaileds/rsb-detailed/label-info/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.generic_label_type.is_set or self.generic_label_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.generic_label_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "generalized-label"):
                            if (self.generalized_label is None):
                                self.generalized_label = RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericLocalUpstreamLabel.GeneralizedLabel()
                                self.generalized_label.parent = self
                                self._children_name_map["generalized_label"] = "generalized-label"
                            return self.generalized_label

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "generalized-label" or name == "generic-label-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "generic-label-type"):
                            self.generic_label_type = value
                            self.generic_label_type.value_namespace = name_space
                            self.generic_label_type.value_namespace_prefix = name_space_prefix


                class GenericRecoveryLabel(Entity):
                    """
                    Generic Recovery Label
                    
                    .. attribute:: generalized_label
                    
                    	Generalized Label
                    	**type**\:   :py:class:`GeneralizedLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericRecoveryLabel.GeneralizedLabel>`
                    
                    .. attribute:: generic_label_type
                    
                    	GenericLabelType
                    	**type**\:   :py:class:`RsvpMgmtGenericLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtGenericLabel>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericRecoveryLabel, self).__init__()

                        self.yang_name = "generic-recovery-label"
                        self.yang_parent_name = "label-info"

                        self.generic_label_type = YLeaf(YType.enumeration, "generic-label-type")

                        self.generalized_label = RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericRecoveryLabel.GeneralizedLabel()
                        self.generalized_label.parent = self
                        self._children_name_map["generalized_label"] = "generalized-label"
                        self._children_yang_names.add("generalized-label")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("generic_label_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericRecoveryLabel, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericRecoveryLabel, self).__setattr__(name, value)


                    class GeneralizedLabel(Entity):
                        """
                        Generalized Label
                        
                        .. attribute:: value
                        
                        	Generalized Label Value
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericRecoveryLabel.GeneralizedLabel, self).__init__()

                            self.yang_name = "generalized-label"
                            self.yang_parent_name = "generic-recovery-label"

                            self.value = YLeafList(YType.uint32, "value")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("value") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericRecoveryLabel.GeneralizedLabel, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericRecoveryLabel.GeneralizedLabel, self).__setattr__(name, value)

                        def has_data(self):
                            for leaf in self.value.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            return False

                        def has_operation(self):
                            for leaf in self.value.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.value.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "generalized-label" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/rsb-detaileds/rsb-detailed/label-info/generic-recovery-label/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            leaf_name_data.extend(self.value.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "value"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "value"):
                                self.value.append(value)

                    def has_data(self):
                        return (
                            self.generic_label_type.is_set or
                            (self.generalized_label is not None and self.generalized_label.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.generic_label_type.yfilter != YFilter.not_set or
                            (self.generalized_label is not None and self.generalized_label.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "generic-recovery-label" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/rsb-detaileds/rsb-detailed/label-info/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.generic_label_type.is_set or self.generic_label_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.generic_label_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "generalized-label"):
                            if (self.generalized_label is None):
                                self.generalized_label = RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericRecoveryLabel.GeneralizedLabel()
                                self.generalized_label.parent = self
                                self._children_name_map["generalized_label"] = "generalized-label"
                            return self.generalized_label

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "generalized-label" or name == "generic-label-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "generic-label-type"):
                            self.generic_label_type = value
                            self.generic_label_type.value_namespace = name_space
                            self.generic_label_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.is_valid.is_set or
                        self.local_downstream_label.is_set or
                        self.local_upstream_label.is_set or
                        self.lsp_wrap_label.is_set or
                        self.merge_point_label.is_set or
                        self.outgoing_downstream_label.is_set or
                        self.outgoing_upstream_label.is_set or
                        self.recovery_label.is_set or
                        (self.generic_local_downstream_label is not None and self.generic_local_downstream_label.has_data()) or
                        (self.generic_local_upstream_label is not None and self.generic_local_upstream_label.has_data()) or
                        (self.generic_merge_point_label is not None and self.generic_merge_point_label.has_data()) or
                        (self.generic_outgoing_downstream_label is not None and self.generic_outgoing_downstream_label.has_data()) or
                        (self.generic_outgoing_upstream_label is not None and self.generic_outgoing_upstream_label.has_data()) or
                        (self.generic_recovery_label is not None and self.generic_recovery_label.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.is_valid.yfilter != YFilter.not_set or
                        self.local_downstream_label.yfilter != YFilter.not_set or
                        self.local_upstream_label.yfilter != YFilter.not_set or
                        self.lsp_wrap_label.yfilter != YFilter.not_set or
                        self.merge_point_label.yfilter != YFilter.not_set or
                        self.outgoing_downstream_label.yfilter != YFilter.not_set or
                        self.outgoing_upstream_label.yfilter != YFilter.not_set or
                        self.recovery_label.yfilter != YFilter.not_set or
                        (self.generic_local_downstream_label is not None and self.generic_local_downstream_label.has_operation()) or
                        (self.generic_local_upstream_label is not None and self.generic_local_upstream_label.has_operation()) or
                        (self.generic_merge_point_label is not None and self.generic_merge_point_label.has_operation()) or
                        (self.generic_outgoing_downstream_label is not None and self.generic_outgoing_downstream_label.has_operation()) or
                        (self.generic_outgoing_upstream_label is not None and self.generic_outgoing_upstream_label.has_operation()) or
                        (self.generic_recovery_label is not None and self.generic_recovery_label.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "label-info" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/rsb-detaileds/rsb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_valid.get_name_leafdata())
                    if (self.local_downstream_label.is_set or self.local_downstream_label.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.local_downstream_label.get_name_leafdata())
                    if (self.local_upstream_label.is_set or self.local_upstream_label.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.local_upstream_label.get_name_leafdata())
                    if (self.lsp_wrap_label.is_set or self.lsp_wrap_label.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.lsp_wrap_label.get_name_leafdata())
                    if (self.merge_point_label.is_set or self.merge_point_label.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.merge_point_label.get_name_leafdata())
                    if (self.outgoing_downstream_label.is_set or self.outgoing_downstream_label.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.outgoing_downstream_label.get_name_leafdata())
                    if (self.outgoing_upstream_label.is_set or self.outgoing_upstream_label.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.outgoing_upstream_label.get_name_leafdata())
                    if (self.recovery_label.is_set or self.recovery_label.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.recovery_label.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "generic-local-downstream-label"):
                        if (self.generic_local_downstream_label is None):
                            self.generic_local_downstream_label = RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericLocalDownstreamLabel()
                            self.generic_local_downstream_label.parent = self
                            self._children_name_map["generic_local_downstream_label"] = "generic-local-downstream-label"
                        return self.generic_local_downstream_label

                    if (child_yang_name == "generic-local-upstream-label"):
                        if (self.generic_local_upstream_label is None):
                            self.generic_local_upstream_label = RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericLocalUpstreamLabel()
                            self.generic_local_upstream_label.parent = self
                            self._children_name_map["generic_local_upstream_label"] = "generic-local-upstream-label"
                        return self.generic_local_upstream_label

                    if (child_yang_name == "generic-merge-point-label"):
                        if (self.generic_merge_point_label is None):
                            self.generic_merge_point_label = RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericMergePointLabel()
                            self.generic_merge_point_label.parent = self
                            self._children_name_map["generic_merge_point_label"] = "generic-merge-point-label"
                        return self.generic_merge_point_label

                    if (child_yang_name == "generic-outgoing-downstream-label"):
                        if (self.generic_outgoing_downstream_label is None):
                            self.generic_outgoing_downstream_label = RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericOutgoingDownstreamLabel()
                            self.generic_outgoing_downstream_label.parent = self
                            self._children_name_map["generic_outgoing_downstream_label"] = "generic-outgoing-downstream-label"
                        return self.generic_outgoing_downstream_label

                    if (child_yang_name == "generic-outgoing-upstream-label"):
                        if (self.generic_outgoing_upstream_label is None):
                            self.generic_outgoing_upstream_label = RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericOutgoingUpstreamLabel()
                            self.generic_outgoing_upstream_label.parent = self
                            self._children_name_map["generic_outgoing_upstream_label"] = "generic-outgoing-upstream-label"
                        return self.generic_outgoing_upstream_label

                    if (child_yang_name == "generic-recovery-label"):
                        if (self.generic_recovery_label is None):
                            self.generic_recovery_label = RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo.GenericRecoveryLabel()
                            self.generic_recovery_label.parent = self
                            self._children_name_map["generic_recovery_label"] = "generic-recovery-label"
                        return self.generic_recovery_label

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "generic-local-downstream-label" or name == "generic-local-upstream-label" or name == "generic-merge-point-label" or name == "generic-outgoing-downstream-label" or name == "generic-outgoing-upstream-label" or name == "generic-recovery-label" or name == "is-valid" or name == "local-downstream-label" or name == "local-upstream-label" or name == "lsp-wrap-label" or name == "merge-point-label" or name == "outgoing-downstream-label" or name == "outgoing-upstream-label" or name == "recovery-label"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "is-valid"):
                        self.is_valid = value
                        self.is_valid.value_namespace = name_space
                        self.is_valid.value_namespace_prefix = name_space_prefix
                    if(value_path == "local-downstream-label"):
                        self.local_downstream_label = value
                        self.local_downstream_label.value_namespace = name_space
                        self.local_downstream_label.value_namespace_prefix = name_space_prefix
                    if(value_path == "local-upstream-label"):
                        self.local_upstream_label = value
                        self.local_upstream_label.value_namespace = name_space
                        self.local_upstream_label.value_namespace_prefix = name_space_prefix
                    if(value_path == "lsp-wrap-label"):
                        self.lsp_wrap_label = value
                        self.lsp_wrap_label.value_namespace = name_space
                        self.lsp_wrap_label.value_namespace_prefix = name_space_prefix
                    if(value_path == "merge-point-label"):
                        self.merge_point_label = value
                        self.merge_point_label.value_namespace = name_space
                        self.merge_point_label.value_namespace_prefix = name_space_prefix
                    if(value_path == "outgoing-downstream-label"):
                        self.outgoing_downstream_label = value
                        self.outgoing_downstream_label.value_namespace = name_space
                        self.outgoing_downstream_label.value_namespace_prefix = name_space_prefix
                    if(value_path == "outgoing-upstream-label"):
                        self.outgoing_upstream_label = value
                        self.outgoing_upstream_label.value_namespace = name_space
                        self.outgoing_upstream_label.value_namespace_prefix = name_space_prefix
                    if(value_path == "recovery-label"):
                        self.recovery_label = value
                        self.recovery_label.value_namespace = name_space
                        self.recovery_label.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.destination_address.is_set or
                    self.destination_port.is_set or
                    self.extended_tunnel_id.is_set or
                    self.input_adjusted_interface.is_set or
                    self.input_physical_interface.is_set or
                    self.p2mp_id.is_set or
                    self.protocol.is_set or
                    self.session_type.is_set or
                    self.source_address.is_set or
                    self.source_port.is_set or
                    self.sub_group_id.is_set or
                    self.sub_group_origin.is_set or
                    self.vrf_name.is_set or
                    (self.expiry_time is not None and self.expiry_time.has_data()) or
                    (self.filter is not None and self.filter.has_data()) or
                    (self.flow_spec is not None and self.flow_spec.has_data()) or
                    (self.generic_flow_spec is not None and self.generic_flow_spec.has_data()) or
                    (self.header is not None and self.header.has_data()) or
                    (self.hop is not None and self.hop.has_data()) or
                    (self.label_info is not None and self.label_info.has_data()) or
                    (self.policy_flags is not None and self.policy_flags.has_data()) or
                    (self.policy_query_flags is not None and self.policy_query_flags.has_data()) or
                    (self.policy_sources is not None and self.policy_sources.has_data()) or
                    (self.rsb_flags is not None and self.rsb_flags.has_data()) or
                    (self.s2l_sub_lsp is not None and self.s2l_sub_lsp.has_data()) or
                    (self.session is not None and self.session.has_data()) or
                    (self.style is not None and self.style.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.destination_address.yfilter != YFilter.not_set or
                    self.destination_port.yfilter != YFilter.not_set or
                    self.extended_tunnel_id.yfilter != YFilter.not_set or
                    self.input_adjusted_interface.yfilter != YFilter.not_set or
                    self.input_physical_interface.yfilter != YFilter.not_set or
                    self.p2mp_id.yfilter != YFilter.not_set or
                    self.protocol.yfilter != YFilter.not_set or
                    self.session_type.yfilter != YFilter.not_set or
                    self.source_address.yfilter != YFilter.not_set or
                    self.source_port.yfilter != YFilter.not_set or
                    self.sub_group_id.yfilter != YFilter.not_set or
                    self.sub_group_origin.yfilter != YFilter.not_set or
                    self.vrf_name.yfilter != YFilter.not_set or
                    (self.expiry_time is not None and self.expiry_time.has_operation()) or
                    (self.filter is not None and self.filter.has_operation()) or
                    (self.flow_spec is not None and self.flow_spec.has_operation()) or
                    (self.generic_flow_spec is not None and self.generic_flow_spec.has_operation()) or
                    (self.header is not None and self.header.has_operation()) or
                    (self.hop is not None and self.hop.has_operation()) or
                    (self.label_info is not None and self.label_info.has_operation()) or
                    (self.policy_flags is not None and self.policy_flags.has_operation()) or
                    (self.policy_query_flags is not None and self.policy_query_flags.has_operation()) or
                    (self.policy_sources is not None and self.policy_sources.has_operation()) or
                    (self.rsb_flags is not None and self.rsb_flags.has_operation()) or
                    (self.s2l_sub_lsp is not None and self.s2l_sub_lsp.has_operation()) or
                    (self.session is not None and self.session.has_operation()) or
                    (self.style is not None and self.style.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "rsb-detailed" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/rsb-detaileds/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_address.get_name_leafdata())
                if (self.destination_port.is_set or self.destination_port.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_port.get_name_leafdata())
                if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                if (self.input_adjusted_interface.is_set or self.input_adjusted_interface.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.input_adjusted_interface.get_name_leafdata())
                if (self.input_physical_interface.is_set or self.input_physical_interface.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.input_physical_interface.get_name_leafdata())
                if (self.p2mp_id.is_set or self.p2mp_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.p2mp_id.get_name_leafdata())
                if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.protocol.get_name_leafdata())
                if (self.session_type.is_set or self.session_type.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.session_type.get_name_leafdata())
                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_address.get_name_leafdata())
                if (self.source_port.is_set or self.source_port.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_port.get_name_leafdata())
                if (self.sub_group_id.is_set or self.sub_group_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.sub_group_id.get_name_leafdata())
                if (self.sub_group_origin.is_set or self.sub_group_origin.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.sub_group_origin.get_name_leafdata())
                if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.vrf_name.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "expiry-time"):
                    if (self.expiry_time is None):
                        self.expiry_time = RsvpStandby.RsbDetaileds.RsbDetailed.ExpiryTime()
                        self.expiry_time.parent = self
                        self._children_name_map["expiry_time"] = "expiry-time"
                    return self.expiry_time

                if (child_yang_name == "filter"):
                    if (self.filter is None):
                        self.filter = RsvpStandby.RsbDetaileds.RsbDetailed.Filter()
                        self.filter.parent = self
                        self._children_name_map["filter"] = "filter"
                    return self.filter

                if (child_yang_name == "flow-spec"):
                    if (self.flow_spec is None):
                        self.flow_spec = RsvpStandby.RsbDetaileds.RsbDetailed.FlowSpec()
                        self.flow_spec.parent = self
                        self._children_name_map["flow_spec"] = "flow-spec"
                    return self.flow_spec

                if (child_yang_name == "generic-flow-spec"):
                    if (self.generic_flow_spec is None):
                        self.generic_flow_spec = RsvpStandby.RsbDetaileds.RsbDetailed.GenericFlowSpec()
                        self.generic_flow_spec.parent = self
                        self._children_name_map["generic_flow_spec"] = "generic-flow-spec"
                    return self.generic_flow_spec

                if (child_yang_name == "header"):
                    if (self.header is None):
                        self.header = RsvpStandby.RsbDetaileds.RsbDetailed.Header()
                        self.header.parent = self
                        self._children_name_map["header"] = "header"
                    return self.header

                if (child_yang_name == "hop"):
                    if (self.hop is None):
                        self.hop = RsvpStandby.RsbDetaileds.RsbDetailed.Hop()
                        self.hop.parent = self
                        self._children_name_map["hop"] = "hop"
                    return self.hop

                if (child_yang_name == "label-info"):
                    if (self.label_info is None):
                        self.label_info = RsvpStandby.RsbDetaileds.RsbDetailed.LabelInfo()
                        self.label_info.parent = self
                        self._children_name_map["label_info"] = "label-info"
                    return self.label_info

                if (child_yang_name == "policy-flags"):
                    if (self.policy_flags is None):
                        self.policy_flags = RsvpStandby.RsbDetaileds.RsbDetailed.PolicyFlags()
                        self.policy_flags.parent = self
                        self._children_name_map["policy_flags"] = "policy-flags"
                    return self.policy_flags

                if (child_yang_name == "policy-query-flags"):
                    if (self.policy_query_flags is None):
                        self.policy_query_flags = RsvpStandby.RsbDetaileds.RsbDetailed.PolicyQueryFlags()
                        self.policy_query_flags.parent = self
                        self._children_name_map["policy_query_flags"] = "policy-query-flags"
                    return self.policy_query_flags

                if (child_yang_name == "policy-sources"):
                    if (self.policy_sources is None):
                        self.policy_sources = RsvpStandby.RsbDetaileds.RsbDetailed.PolicySources()
                        self.policy_sources.parent = self
                        self._children_name_map["policy_sources"] = "policy-sources"
                    return self.policy_sources

                if (child_yang_name == "rsb-flags"):
                    if (self.rsb_flags is None):
                        self.rsb_flags = RsvpStandby.RsbDetaileds.RsbDetailed.RsbFlags()
                        self.rsb_flags.parent = self
                        self._children_name_map["rsb_flags"] = "rsb-flags"
                    return self.rsb_flags

                if (child_yang_name == "s2l-sub-lsp"):
                    if (self.s2l_sub_lsp is None):
                        self.s2l_sub_lsp = RsvpStandby.RsbDetaileds.RsbDetailed.S2LSubLsp()
                        self.s2l_sub_lsp.parent = self
                        self._children_name_map["s2l_sub_lsp"] = "s2l-sub-lsp"
                    return self.s2l_sub_lsp

                if (child_yang_name == "session"):
                    if (self.session is None):
                        self.session = RsvpStandby.RsbDetaileds.RsbDetailed.Session()
                        self.session.parent = self
                        self._children_name_map["session"] = "session"
                    return self.session

                if (child_yang_name == "style"):
                    if (self.style is None):
                        self.style = RsvpStandby.RsbDetaileds.RsbDetailed.Style()
                        self.style.parent = self
                        self._children_name_map["style"] = "style"
                    return self.style

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "expiry-time" or name == "filter" or name == "flow-spec" or name == "generic-flow-spec" or name == "header" or name == "hop" or name == "label-info" or name == "policy-flags" or name == "policy-query-flags" or name == "policy-sources" or name == "rsb-flags" or name == "s2l-sub-lsp" or name == "session" or name == "style" or name == "destination-address" or name == "destination-port" or name == "extended-tunnel-id" or name == "input-adjusted-interface" or name == "input-physical-interface" or name == "p2mp-id" or name == "protocol" or name == "session-type" or name == "source-address" or name == "source-port" or name == "sub-group-id" or name == "sub-group-origin" or name == "vrf-name"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "destination-address"):
                    self.destination_address = value
                    self.destination_address.value_namespace = name_space
                    self.destination_address.value_namespace_prefix = name_space_prefix
                if(value_path == "destination-port"):
                    self.destination_port = value
                    self.destination_port.value_namespace = name_space
                    self.destination_port.value_namespace_prefix = name_space_prefix
                if(value_path == "extended-tunnel-id"):
                    self.extended_tunnel_id = value
                    self.extended_tunnel_id.value_namespace = name_space
                    self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                if(value_path == "input-adjusted-interface"):
                    self.input_adjusted_interface = value
                    self.input_adjusted_interface.value_namespace = name_space
                    self.input_adjusted_interface.value_namespace_prefix = name_space_prefix
                if(value_path == "input-physical-interface"):
                    self.input_physical_interface = value
                    self.input_physical_interface.value_namespace = name_space
                    self.input_physical_interface.value_namespace_prefix = name_space_prefix
                if(value_path == "p2mp-id"):
                    self.p2mp_id = value
                    self.p2mp_id.value_namespace = name_space
                    self.p2mp_id.value_namespace_prefix = name_space_prefix
                if(value_path == "protocol"):
                    self.protocol = value
                    self.protocol.value_namespace = name_space
                    self.protocol.value_namespace_prefix = name_space_prefix
                if(value_path == "session-type"):
                    self.session_type = value
                    self.session_type.value_namespace = name_space
                    self.session_type.value_namespace_prefix = name_space_prefix
                if(value_path == "source-address"):
                    self.source_address = value
                    self.source_address.value_namespace = name_space
                    self.source_address.value_namespace_prefix = name_space_prefix
                if(value_path == "source-port"):
                    self.source_port = value
                    self.source_port.value_namespace = name_space
                    self.source_port.value_namespace_prefix = name_space_prefix
                if(value_path == "sub-group-id"):
                    self.sub_group_id = value
                    self.sub_group_id.value_namespace = name_space
                    self.sub_group_id.value_namespace_prefix = name_space_prefix
                if(value_path == "sub-group-origin"):
                    self.sub_group_origin = value
                    self.sub_group_origin.value_namespace = name_space
                    self.sub_group_origin.value_namespace_prefix = name_space_prefix
                if(value_path == "vrf-name"):
                    self.vrf_name = value
                    self.vrf_name.value_namespace = name_space
                    self.vrf_name.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.rsb_detailed:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.rsb_detailed:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "rsb-detaileds" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "rsb-detailed"):
                for c in self.rsb_detailed:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = RsvpStandby.RsbDetaileds.RsbDetailed()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.rsb_detailed.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "rsb-detailed"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class InterfaceSummaries(Entity):
        """
        Table of summary info about RSVP\-enabled
        interfaces
        
        .. attribute:: interface_summary
        
        	Summary info about an RSVP\-enabled interface
        	**type**\: list of    :py:class:`InterfaceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.InterfaceSummaries.InterfaceSummary>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(RsvpStandby.InterfaceSummaries, self).__init__()

            self.yang_name = "interface-summaries"
            self.yang_parent_name = "rsvp-standby"

            self.interface_summary = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(RsvpStandby.InterfaceSummaries, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(RsvpStandby.InterfaceSummaries, self).__setattr__(name, value)


        class InterfaceSummary(Entity):
            """
            Summary info about an RSVP\-enabled interface
            
            .. attribute:: interface_name  <key>
            
            	Interface Name
            	**type**\:  str
            
            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
            
            .. attribute:: bandwidth_information
            
            	Interface bandwidth information
            	**type**\:   :py:class:`BandwidthInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.InterfaceSummaries.InterfaceSummary.BandwidthInformation>`
            
            .. attribute:: interface_name_xr
            
            	Interface Name
            	**type**\:  str
            
            .. attribute:: paths_in
            
            	Number of locally created and incoming path states
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: paths_out
            
            	Number of outgoing path states
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: reservations_in
            
            	Number of locally created and incoming reservation states
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: reservations_out
            
            	Number of outgoing reservation states
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(RsvpStandby.InterfaceSummaries.InterfaceSummary, self).__init__()

                self.yang_name = "interface-summary"
                self.yang_parent_name = "interface-summaries"

                self.interface_name = YLeaf(YType.str, "interface-name")

                self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                self.paths_in = YLeaf(YType.uint32, "paths-in")

                self.paths_out = YLeaf(YType.uint32, "paths-out")

                self.reservations_in = YLeaf(YType.uint32, "reservations-in")

                self.reservations_out = YLeaf(YType.uint32, "reservations-out")

                self.bandwidth_information = RsvpStandby.InterfaceSummaries.InterfaceSummary.BandwidthInformation()
                self.bandwidth_information.parent = self
                self._children_name_map["bandwidth_information"] = "bandwidth-information"
                self._children_yang_names.add("bandwidth-information")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("interface_name",
                                "interface_name_xr",
                                "paths_in",
                                "paths_out",
                                "reservations_in",
                                "reservations_out") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(RsvpStandby.InterfaceSummaries.InterfaceSummary, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(RsvpStandby.InterfaceSummaries.InterfaceSummary, self).__setattr__(name, value)


            class BandwidthInformation(Entity):
                """
                Interface bandwidth information
                
                .. attribute:: dste_mode
                
                	DSTEMode
                	**type**\:   :py:class:`RsvpMgmtDsteModes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtDsteModes>`
                
                .. attribute:: pre_standard_dste_interface
                
                	Prestandard DSTE interface information
                	**type**\:   :py:class:`PreStandardDsteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.InterfaceSummaries.InterfaceSummary.BandwidthInformation.PreStandardDsteInterface>`
                
                .. attribute:: standard_dste_interface
                
                	Standard DSTE interface information
                	**type**\:   :py:class:`StandardDsteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.InterfaceSummaries.InterfaceSummary.BandwidthInformation.StandardDsteInterface>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.InterfaceSummaries.InterfaceSummary.BandwidthInformation, self).__init__()

                    self.yang_name = "bandwidth-information"
                    self.yang_parent_name = "interface-summary"

                    self.dste_mode = YLeaf(YType.enumeration, "dste-mode")

                    self.pre_standard_dste_interface = RsvpStandby.InterfaceSummaries.InterfaceSummary.BandwidthInformation.PreStandardDsteInterface()
                    self.pre_standard_dste_interface.parent = self
                    self._children_name_map["pre_standard_dste_interface"] = "pre-standard-dste-interface"
                    self._children_yang_names.add("pre-standard-dste-interface")

                    self.standard_dste_interface = RsvpStandby.InterfaceSummaries.InterfaceSummary.BandwidthInformation.StandardDsteInterface()
                    self.standard_dste_interface.parent = self
                    self._children_name_map["standard_dste_interface"] = "standard-dste-interface"
                    self._children_yang_names.add("standard-dste-interface")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("dste_mode") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.InterfaceSummaries.InterfaceSummary.BandwidthInformation, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.InterfaceSummaries.InterfaceSummary.BandwidthInformation, self).__setattr__(name, value)


                class PreStandardDsteInterface(Entity):
                    """
                    Prestandard DSTE interface information
                    
                    .. attribute:: allocated_bit_rate
                    
                    	Bandwidth (bits per second) now allocated
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: is_max_bandwidth_absolute
                    
                    	True if the Max B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: is_max_subpool_bandwidth_absolute
                    
                    	True if the Max sub\-pool B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: max_bandwidth
                    
                    	Max bandwidth (bits per second) allowed
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_flow_bandwidth
                    
                    	Max bandwidth (bits per second) allowed per flow
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_subpool_bandwidth
                    
                    	Max bandwidth (bits per second) allowed in subpool
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.InterfaceSummaries.InterfaceSummary.BandwidthInformation.PreStandardDsteInterface, self).__init__()

                        self.yang_name = "pre-standard-dste-interface"
                        self.yang_parent_name = "bandwidth-information"

                        self.allocated_bit_rate = YLeaf(YType.uint64, "allocated-bit-rate")

                        self.is_max_bandwidth_absolute = YLeaf(YType.boolean, "is-max-bandwidth-absolute")

                        self.is_max_subpool_bandwidth_absolute = YLeaf(YType.boolean, "is-max-subpool-bandwidth-absolute")

                        self.max_bandwidth = YLeaf(YType.uint64, "max-bandwidth")

                        self.max_flow_bandwidth = YLeaf(YType.uint64, "max-flow-bandwidth")

                        self.max_subpool_bandwidth = YLeaf(YType.uint64, "max-subpool-bandwidth")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("allocated_bit_rate",
                                        "is_max_bandwidth_absolute",
                                        "is_max_subpool_bandwidth_absolute",
                                        "max_bandwidth",
                                        "max_flow_bandwidth",
                                        "max_subpool_bandwidth") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.InterfaceSummaries.InterfaceSummary.BandwidthInformation.PreStandardDsteInterface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.InterfaceSummaries.InterfaceSummary.BandwidthInformation.PreStandardDsteInterface, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.allocated_bit_rate.is_set or
                            self.is_max_bandwidth_absolute.is_set or
                            self.is_max_subpool_bandwidth_absolute.is_set or
                            self.max_bandwidth.is_set or
                            self.max_flow_bandwidth.is_set or
                            self.max_subpool_bandwidth.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.allocated_bit_rate.yfilter != YFilter.not_set or
                            self.is_max_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.is_max_subpool_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.max_bandwidth.yfilter != YFilter.not_set or
                            self.max_flow_bandwidth.yfilter != YFilter.not_set or
                            self.max_subpool_bandwidth.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "pre-standard-dste-interface" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.allocated_bit_rate.is_set or self.allocated_bit_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.allocated_bit_rate.get_name_leafdata())
                        if (self.is_max_bandwidth_absolute.is_set or self.is_max_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_bandwidth_absolute.get_name_leafdata())
                        if (self.is_max_subpool_bandwidth_absolute.is_set or self.is_max_subpool_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_subpool_bandwidth_absolute.get_name_leafdata())
                        if (self.max_bandwidth.is_set or self.max_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_bandwidth.get_name_leafdata())
                        if (self.max_flow_bandwidth.is_set or self.max_flow_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_flow_bandwidth.get_name_leafdata())
                        if (self.max_subpool_bandwidth.is_set or self.max_subpool_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_subpool_bandwidth.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "allocated-bit-rate" or name == "is-max-bandwidth-absolute" or name == "is-max-subpool-bandwidth-absolute" or name == "max-bandwidth" or name == "max-flow-bandwidth" or name == "max-subpool-bandwidth"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "allocated-bit-rate"):
                            self.allocated_bit_rate = value
                            self.allocated_bit_rate.value_namespace = name_space
                            self.allocated_bit_rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-bandwidth-absolute"):
                            self.is_max_bandwidth_absolute = value
                            self.is_max_bandwidth_absolute.value_namespace = name_space
                            self.is_max_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-subpool-bandwidth-absolute"):
                            self.is_max_subpool_bandwidth_absolute = value
                            self.is_max_subpool_bandwidth_absolute.value_namespace = name_space
                            self.is_max_subpool_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-bandwidth"):
                            self.max_bandwidth = value
                            self.max_bandwidth.value_namespace = name_space
                            self.max_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-flow-bandwidth"):
                            self.max_flow_bandwidth = value
                            self.max_flow_bandwidth.value_namespace = name_space
                            self.max_flow_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-subpool-bandwidth"):
                            self.max_subpool_bandwidth = value
                            self.max_subpool_bandwidth.value_namespace = name_space
                            self.max_subpool_bandwidth.value_namespace_prefix = name_space_prefix


                class StandardDsteInterface(Entity):
                    """
                    Standard DSTE interface information
                    
                    .. attribute:: allocated_bit_rate
                    
                    	Bandwidth (bits per second) now allocated
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: is_max_bandwidth_absolute
                    
                    	True if the Max B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: is_max_bc0_bandwidth_absolute
                    
                    	True if the Max BC0 B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: is_max_bc1_bandwidth_absolute
                    
                    	True if the Max BC1 sub\-pool B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: max_bandwidth
                    
                    	Max bandwidth (bits per second) allowed
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_flow_bandwidth
                    
                    	Max bandwidth (bits per second) allowed per flow
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_pool0_bandwidth
                    
                    	Max bandwidth (bits per second) allowed in BC0 pool
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_pool1_bandwidth
                    
                    	Max bandwidth (bits per second) allowed in BC1 pool
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.InterfaceSummaries.InterfaceSummary.BandwidthInformation.StandardDsteInterface, self).__init__()

                        self.yang_name = "standard-dste-interface"
                        self.yang_parent_name = "bandwidth-information"

                        self.allocated_bit_rate = YLeaf(YType.uint64, "allocated-bit-rate")

                        self.is_max_bandwidth_absolute = YLeaf(YType.boolean, "is-max-bandwidth-absolute")

                        self.is_max_bc0_bandwidth_absolute = YLeaf(YType.boolean, "is-max-bc0-bandwidth-absolute")

                        self.is_max_bc1_bandwidth_absolute = YLeaf(YType.boolean, "is-max-bc1-bandwidth-absolute")

                        self.max_bandwidth = YLeaf(YType.uint64, "max-bandwidth")

                        self.max_flow_bandwidth = YLeaf(YType.uint64, "max-flow-bandwidth")

                        self.max_pool0_bandwidth = YLeaf(YType.uint64, "max-pool0-bandwidth")

                        self.max_pool1_bandwidth = YLeaf(YType.uint64, "max-pool1-bandwidth")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("allocated_bit_rate",
                                        "is_max_bandwidth_absolute",
                                        "is_max_bc0_bandwidth_absolute",
                                        "is_max_bc1_bandwidth_absolute",
                                        "max_bandwidth",
                                        "max_flow_bandwidth",
                                        "max_pool0_bandwidth",
                                        "max_pool1_bandwidth") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.InterfaceSummaries.InterfaceSummary.BandwidthInformation.StandardDsteInterface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.InterfaceSummaries.InterfaceSummary.BandwidthInformation.StandardDsteInterface, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.allocated_bit_rate.is_set or
                            self.is_max_bandwidth_absolute.is_set or
                            self.is_max_bc0_bandwidth_absolute.is_set or
                            self.is_max_bc1_bandwidth_absolute.is_set or
                            self.max_bandwidth.is_set or
                            self.max_flow_bandwidth.is_set or
                            self.max_pool0_bandwidth.is_set or
                            self.max_pool1_bandwidth.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.allocated_bit_rate.yfilter != YFilter.not_set or
                            self.is_max_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.is_max_bc0_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.is_max_bc1_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.max_bandwidth.yfilter != YFilter.not_set or
                            self.max_flow_bandwidth.yfilter != YFilter.not_set or
                            self.max_pool0_bandwidth.yfilter != YFilter.not_set or
                            self.max_pool1_bandwidth.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "standard-dste-interface" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.allocated_bit_rate.is_set or self.allocated_bit_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.allocated_bit_rate.get_name_leafdata())
                        if (self.is_max_bandwidth_absolute.is_set or self.is_max_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_bandwidth_absolute.get_name_leafdata())
                        if (self.is_max_bc0_bandwidth_absolute.is_set or self.is_max_bc0_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_bc0_bandwidth_absolute.get_name_leafdata())
                        if (self.is_max_bc1_bandwidth_absolute.is_set or self.is_max_bc1_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_bc1_bandwidth_absolute.get_name_leafdata())
                        if (self.max_bandwidth.is_set or self.max_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_bandwidth.get_name_leafdata())
                        if (self.max_flow_bandwidth.is_set or self.max_flow_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_flow_bandwidth.get_name_leafdata())
                        if (self.max_pool0_bandwidth.is_set or self.max_pool0_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_pool0_bandwidth.get_name_leafdata())
                        if (self.max_pool1_bandwidth.is_set or self.max_pool1_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_pool1_bandwidth.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "allocated-bit-rate" or name == "is-max-bandwidth-absolute" or name == "is-max-bc0-bandwidth-absolute" or name == "is-max-bc1-bandwidth-absolute" or name == "max-bandwidth" or name == "max-flow-bandwidth" or name == "max-pool0-bandwidth" or name == "max-pool1-bandwidth"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "allocated-bit-rate"):
                            self.allocated_bit_rate = value
                            self.allocated_bit_rate.value_namespace = name_space
                            self.allocated_bit_rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-bandwidth-absolute"):
                            self.is_max_bandwidth_absolute = value
                            self.is_max_bandwidth_absolute.value_namespace = name_space
                            self.is_max_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-bc0-bandwidth-absolute"):
                            self.is_max_bc0_bandwidth_absolute = value
                            self.is_max_bc0_bandwidth_absolute.value_namespace = name_space
                            self.is_max_bc0_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-bc1-bandwidth-absolute"):
                            self.is_max_bc1_bandwidth_absolute = value
                            self.is_max_bc1_bandwidth_absolute.value_namespace = name_space
                            self.is_max_bc1_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-bandwidth"):
                            self.max_bandwidth = value
                            self.max_bandwidth.value_namespace = name_space
                            self.max_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-flow-bandwidth"):
                            self.max_flow_bandwidth = value
                            self.max_flow_bandwidth.value_namespace = name_space
                            self.max_flow_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-pool0-bandwidth"):
                            self.max_pool0_bandwidth = value
                            self.max_pool0_bandwidth.value_namespace = name_space
                            self.max_pool0_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-pool1-bandwidth"):
                            self.max_pool1_bandwidth = value
                            self.max_pool1_bandwidth.value_namespace = name_space
                            self.max_pool1_bandwidth.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.dste_mode.is_set or
                        (self.pre_standard_dste_interface is not None and self.pre_standard_dste_interface.has_data()) or
                        (self.standard_dste_interface is not None and self.standard_dste_interface.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.dste_mode.yfilter != YFilter.not_set or
                        (self.pre_standard_dste_interface is not None and self.pre_standard_dste_interface.has_operation()) or
                        (self.standard_dste_interface is not None and self.standard_dste_interface.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bandwidth-information" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.dste_mode.is_set or self.dste_mode.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.dste_mode.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "pre-standard-dste-interface"):
                        if (self.pre_standard_dste_interface is None):
                            self.pre_standard_dste_interface = RsvpStandby.InterfaceSummaries.InterfaceSummary.BandwidthInformation.PreStandardDsteInterface()
                            self.pre_standard_dste_interface.parent = self
                            self._children_name_map["pre_standard_dste_interface"] = "pre-standard-dste-interface"
                        return self.pre_standard_dste_interface

                    if (child_yang_name == "standard-dste-interface"):
                        if (self.standard_dste_interface is None):
                            self.standard_dste_interface = RsvpStandby.InterfaceSummaries.InterfaceSummary.BandwidthInformation.StandardDsteInterface()
                            self.standard_dste_interface.parent = self
                            self._children_name_map["standard_dste_interface"] = "standard-dste-interface"
                        return self.standard_dste_interface

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "pre-standard-dste-interface" or name == "standard-dste-interface" or name == "dste-mode"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "dste-mode"):
                        self.dste_mode = value
                        self.dste_mode.value_namespace = name_space
                        self.dste_mode.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.interface_name.is_set or
                    self.interface_name_xr.is_set or
                    self.paths_in.is_set or
                    self.paths_out.is_set or
                    self.reservations_in.is_set or
                    self.reservations_out.is_set or
                    (self.bandwidth_information is not None and self.bandwidth_information.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.interface_name.yfilter != YFilter.not_set or
                    self.interface_name_xr.yfilter != YFilter.not_set or
                    self.paths_in.yfilter != YFilter.not_set or
                    self.paths_out.yfilter != YFilter.not_set or
                    self.reservations_in.yfilter != YFilter.not_set or
                    self.reservations_out.yfilter != YFilter.not_set or
                    (self.bandwidth_information is not None and self.bandwidth_information.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "interface-summary" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/interface-summaries/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                if (self.paths_in.is_set or self.paths_in.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.paths_in.get_name_leafdata())
                if (self.paths_out.is_set or self.paths_out.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.paths_out.get_name_leafdata())
                if (self.reservations_in.is_set or self.reservations_in.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.reservations_in.get_name_leafdata())
                if (self.reservations_out.is_set or self.reservations_out.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.reservations_out.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "bandwidth-information"):
                    if (self.bandwidth_information is None):
                        self.bandwidth_information = RsvpStandby.InterfaceSummaries.InterfaceSummary.BandwidthInformation()
                        self.bandwidth_information.parent = self
                        self._children_name_map["bandwidth_information"] = "bandwidth-information"
                    return self.bandwidth_information

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "bandwidth-information" or name == "interface-name" or name == "interface-name-xr" or name == "paths-in" or name == "paths-out" or name == "reservations-in" or name == "reservations-out"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "interface-name"):
                    self.interface_name = value
                    self.interface_name.value_namespace = name_space
                    self.interface_name.value_namespace_prefix = name_space_prefix
                if(value_path == "interface-name-xr"):
                    self.interface_name_xr = value
                    self.interface_name_xr.value_namespace = name_space
                    self.interface_name_xr.value_namespace_prefix = name_space_prefix
                if(value_path == "paths-in"):
                    self.paths_in = value
                    self.paths_in.value_namespace = name_space
                    self.paths_in.value_namespace_prefix = name_space_prefix
                if(value_path == "paths-out"):
                    self.paths_out = value
                    self.paths_out.value_namespace = name_space
                    self.paths_out.value_namespace_prefix = name_space_prefix
                if(value_path == "reservations-in"):
                    self.reservations_in = value
                    self.reservations_in.value_namespace = name_space
                    self.reservations_in.value_namespace_prefix = name_space_prefix
                if(value_path == "reservations-out"):
                    self.reservations_out = value
                    self.reservations_out.value_namespace = name_space
                    self.reservations_out.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.interface_summary:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.interface_summary:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "interface-summaries" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "interface-summary"):
                for c in self.interface_summary:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = RsvpStandby.InterfaceSummaries.InterfaceSummary()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.interface_summary.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "interface-summary"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class HelloInstanceBriefs(Entity):
        """
        Table of brief info about hello instances
        
        .. attribute:: hello_instance_brief
        
        	Brief info for a single hello instance
        	**type**\: list of    :py:class:`HelloInstanceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.HelloInstanceBriefs.HelloInstanceBrief>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(RsvpStandby.HelloInstanceBriefs, self).__init__()

            self.yang_name = "hello-instance-briefs"
            self.yang_parent_name = "rsvp-standby"

            self.hello_instance_brief = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(RsvpStandby.HelloInstanceBriefs, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(RsvpStandby.HelloInstanceBriefs, self).__setattr__(name, value)


        class HelloInstanceBrief(Entity):
            """
            Brief info for a single hello instance
            
            .. attribute:: source_address  <key>
            
            	Source Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: destination_address  <key>
            
            	Destination Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: destination_address_xr
            
            	Destination address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: hello_interface
            
            	Interface to use
            	**type**\:  str
            
            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
            
            .. attribute:: instance_type
            
            	Hello instance type
            	**type**\:   :py:class:`RsvpMgmtHelloInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtHelloInstance>`
            
            .. attribute:: lost_communication_total
            
            	Total number of times communication got lost
            	**type**\:  int
            
            	**range:** 0..65535
            
            .. attribute:: neighbor_hello_state
            
            	Neighbor Hello state
            	**type**\:   :py:class:`RsvpMgmtHelloState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtHelloState>`
            
            .. attribute:: source_address_xr
            
            	Source address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(RsvpStandby.HelloInstanceBriefs.HelloInstanceBrief, self).__init__()

                self.yang_name = "hello-instance-brief"
                self.yang_parent_name = "hello-instance-briefs"

                self.source_address = YLeaf(YType.str, "source-address")

                self.destination_address = YLeaf(YType.str, "destination-address")

                self.destination_address_xr = YLeaf(YType.str, "destination-address-xr")

                self.hello_interface = YLeaf(YType.str, "hello-interface")

                self.instance_type = YLeaf(YType.enumeration, "instance-type")

                self.lost_communication_total = YLeaf(YType.uint16, "lost-communication-total")

                self.neighbor_hello_state = YLeaf(YType.enumeration, "neighbor-hello-state")

                self.source_address_xr = YLeaf(YType.str, "source-address-xr")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("source_address",
                                "destination_address",
                                "destination_address_xr",
                                "hello_interface",
                                "instance_type",
                                "lost_communication_total",
                                "neighbor_hello_state",
                                "source_address_xr") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(RsvpStandby.HelloInstanceBriefs.HelloInstanceBrief, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(RsvpStandby.HelloInstanceBriefs.HelloInstanceBrief, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.source_address.is_set or
                    self.destination_address.is_set or
                    self.destination_address_xr.is_set or
                    self.hello_interface.is_set or
                    self.instance_type.is_set or
                    self.lost_communication_total.is_set or
                    self.neighbor_hello_state.is_set or
                    self.source_address_xr.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.source_address.yfilter != YFilter.not_set or
                    self.destination_address.yfilter != YFilter.not_set or
                    self.destination_address_xr.yfilter != YFilter.not_set or
                    self.hello_interface.yfilter != YFilter.not_set or
                    self.instance_type.yfilter != YFilter.not_set or
                    self.lost_communication_total.yfilter != YFilter.not_set or
                    self.neighbor_hello_state.yfilter != YFilter.not_set or
                    self.source_address_xr.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "hello-instance-brief" + "[source-address='" + self.source_address.get() + "']" + "[destination-address='" + self.destination_address.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/hello-instance-briefs/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_address.get_name_leafdata())
                if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_address.get_name_leafdata())
                if (self.destination_address_xr.is_set or self.destination_address_xr.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_address_xr.get_name_leafdata())
                if (self.hello_interface.is_set or self.hello_interface.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.hello_interface.get_name_leafdata())
                if (self.instance_type.is_set or self.instance_type.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.instance_type.get_name_leafdata())
                if (self.lost_communication_total.is_set or self.lost_communication_total.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.lost_communication_total.get_name_leafdata())
                if (self.neighbor_hello_state.is_set or self.neighbor_hello_state.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.neighbor_hello_state.get_name_leafdata())
                if (self.source_address_xr.is_set or self.source_address_xr.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_address_xr.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "source-address" or name == "destination-address" or name == "destination-address-xr" or name == "hello-interface" or name == "instance-type" or name == "lost-communication-total" or name == "neighbor-hello-state" or name == "source-address-xr"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "source-address"):
                    self.source_address = value
                    self.source_address.value_namespace = name_space
                    self.source_address.value_namespace_prefix = name_space_prefix
                if(value_path == "destination-address"):
                    self.destination_address = value
                    self.destination_address.value_namespace = name_space
                    self.destination_address.value_namespace_prefix = name_space_prefix
                if(value_path == "destination-address-xr"):
                    self.destination_address_xr = value
                    self.destination_address_xr.value_namespace = name_space
                    self.destination_address_xr.value_namespace_prefix = name_space_prefix
                if(value_path == "hello-interface"):
                    self.hello_interface = value
                    self.hello_interface.value_namespace = name_space
                    self.hello_interface.value_namespace_prefix = name_space_prefix
                if(value_path == "instance-type"):
                    self.instance_type = value
                    self.instance_type.value_namespace = name_space
                    self.instance_type.value_namespace_prefix = name_space_prefix
                if(value_path == "lost-communication-total"):
                    self.lost_communication_total = value
                    self.lost_communication_total.value_namespace = name_space
                    self.lost_communication_total.value_namespace_prefix = name_space_prefix
                if(value_path == "neighbor-hello-state"):
                    self.neighbor_hello_state = value
                    self.neighbor_hello_state.value_namespace = name_space
                    self.neighbor_hello_state.value_namespace_prefix = name_space_prefix
                if(value_path == "source-address-xr"):
                    self.source_address_xr = value
                    self.source_address_xr.value_namespace = name_space
                    self.source_address_xr.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.hello_instance_brief:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.hello_instance_brief:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "hello-instance-briefs" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "hello-instance-brief"):
                for c in self.hello_instance_brief:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = RsvpStandby.HelloInstanceBriefs.HelloInstanceBrief()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.hello_instance_brief.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "hello-instance-brief"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class AuthenticationDetails(Entity):
        """
        Table for detailed authentication related
        information
        
        .. attribute:: authentication_detail
        
        	Brief Authentication information
        	**type**\: list of    :py:class:`AuthenticationDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.AuthenticationDetails.AuthenticationDetail>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(RsvpStandby.AuthenticationDetails, self).__init__()

            self.yang_name = "authentication-details"
            self.yang_parent_name = "rsvp-standby"

            self.authentication_detail = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(RsvpStandby.AuthenticationDetails, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(RsvpStandby.AuthenticationDetails, self).__setattr__(name, value)


        class AuthenticationDetail(Entity):
            """
            Brief Authentication information
            
            .. attribute:: source_address  <key>
            
            	Source Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: destination_address  <key>
            
            	Destination Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: mode_id  <key>
            
            	Mode (Tx or Rx)
            	**type**\:   :py:class:`RsvpMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMode>`
            
            .. attribute:: interface_name  <key>
            
            	InterfaceName
            	**type**\:  str
            
            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
            
            .. attribute:: auth_compact
            
            	Basic authentication data
            	**type**\:   :py:class:`AuthCompact <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.AuthenticationDetails.AuthenticationDetail.AuthCompact>`
            
            .. attribute:: challenge_status
            
            	Challenge status
            	**type**\:   :py:class:`RsvpMgmtAuthChallengeStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtAuthChallengeStatus>`
            
            .. attribute:: direction_info
            
            	direction info
            	**type**\:   :py:class:`DirectionInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.AuthenticationDetails.AuthenticationDetail.DirectionInfo>`
            
            .. attribute:: key_digest_info
            
            	Direction
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: key_status
            
            	Key status
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: lifetime
            
            	Lifetime (seconds)
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            	**units**\: second
            
            .. attribute:: lifetime_left
            
            	Remaining lifetime (seconds)
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            	**units**\: second
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(RsvpStandby.AuthenticationDetails.AuthenticationDetail, self).__init__()

                self.yang_name = "authentication-detail"
                self.yang_parent_name = "authentication-details"

                self.source_address = YLeaf(YType.str, "source-address")

                self.destination_address = YLeaf(YType.str, "destination-address")

                self.mode_id = YLeaf(YType.enumeration, "mode-id")

                self.interface_name = YLeaf(YType.str, "interface-name")

                self.challenge_status = YLeaf(YType.enumeration, "challenge-status")

                self.key_digest_info = YLeaf(YType.uint32, "key-digest-info")

                self.key_status = YLeaf(YType.uint32, "key-status")

                self.lifetime = YLeaf(YType.uint32, "lifetime")

                self.lifetime_left = YLeaf(YType.uint32, "lifetime-left")

                self.auth_compact = RsvpStandby.AuthenticationDetails.AuthenticationDetail.AuthCompact()
                self.auth_compact.parent = self
                self._children_name_map["auth_compact"] = "auth-compact"
                self._children_yang_names.add("auth-compact")

                self.direction_info = RsvpStandby.AuthenticationDetails.AuthenticationDetail.DirectionInfo()
                self.direction_info.parent = self
                self._children_name_map["direction_info"] = "direction-info"
                self._children_yang_names.add("direction-info")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("source_address",
                                "destination_address",
                                "mode_id",
                                "interface_name",
                                "challenge_status",
                                "key_digest_info",
                                "key_status",
                                "lifetime",
                                "lifetime_left") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(RsvpStandby.AuthenticationDetails.AuthenticationDetail, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(RsvpStandby.AuthenticationDetails.AuthenticationDetail, self).__setattr__(name, value)


            class AuthCompact(Entity):
                """
                Basic authentication data
                
                .. attribute:: destination_address_xr
                
                	Destination address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: direction
                
                	Direction
                	**type**\:   :py:class:`RsvpMgmtAuthDirection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtAuthDirection>`
                
                .. attribute:: key_id
                
                	Key ID
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: key_id_valid
                
                	Key validity
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: key_source
                
                	Key source
                	**type**\:  str
                
                .. attribute:: key_type
                
                	Key type
                	**type**\:   :py:class:`RsvpMgmtAuthKi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtAuthKi>`
                
                .. attribute:: neighbor_address
                
                	Neighbor address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: source_address_xr
                
                	Source address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.AuthenticationDetails.AuthenticationDetail.AuthCompact, self).__init__()

                    self.yang_name = "auth-compact"
                    self.yang_parent_name = "authentication-detail"

                    self.destination_address_xr = YLeaf(YType.str, "destination-address-xr")

                    self.direction = YLeaf(YType.enumeration, "direction")

                    self.key_id = YLeaf(YType.uint64, "key-id")

                    self.key_id_valid = YLeaf(YType.uint32, "key-id-valid")

                    self.key_source = YLeaf(YType.str, "key-source")

                    self.key_type = YLeaf(YType.enumeration, "key-type")

                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                    self.source_address_xr = YLeaf(YType.str, "source-address-xr")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("destination_address_xr",
                                    "direction",
                                    "key_id",
                                    "key_id_valid",
                                    "key_source",
                                    "key_type",
                                    "neighbor_address",
                                    "source_address_xr") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.AuthenticationDetails.AuthenticationDetail.AuthCompact, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.AuthenticationDetails.AuthenticationDetail.AuthCompact, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.destination_address_xr.is_set or
                        self.direction.is_set or
                        self.key_id.is_set or
                        self.key_id_valid.is_set or
                        self.key_source.is_set or
                        self.key_type.is_set or
                        self.neighbor_address.is_set or
                        self.source_address_xr.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.destination_address_xr.yfilter != YFilter.not_set or
                        self.direction.yfilter != YFilter.not_set or
                        self.key_id.yfilter != YFilter.not_set or
                        self.key_id_valid.yfilter != YFilter.not_set or
                        self.key_source.yfilter != YFilter.not_set or
                        self.key_type.yfilter != YFilter.not_set or
                        self.neighbor_address.yfilter != YFilter.not_set or
                        self.source_address_xr.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "auth-compact" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.destination_address_xr.is_set or self.destination_address_xr.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.destination_address_xr.get_name_leafdata())
                    if (self.direction.is_set or self.direction.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.direction.get_name_leafdata())
                    if (self.key_id.is_set or self.key_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.key_id.get_name_leafdata())
                    if (self.key_id_valid.is_set or self.key_id_valid.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.key_id_valid.get_name_leafdata())
                    if (self.key_source.is_set or self.key_source.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.key_source.get_name_leafdata())
                    if (self.key_type.is_set or self.key_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.key_type.get_name_leafdata())
                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                    if (self.source_address_xr.is_set or self.source_address_xr.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.source_address_xr.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "destination-address-xr" or name == "direction" or name == "key-id" or name == "key-id-valid" or name == "key-source" or name == "key-type" or name == "neighbor-address" or name == "source-address-xr"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "destination-address-xr"):
                        self.destination_address_xr = value
                        self.destination_address_xr.value_namespace = name_space
                        self.destination_address_xr.value_namespace_prefix = name_space_prefix
                    if(value_path == "direction"):
                        self.direction = value
                        self.direction.value_namespace = name_space
                        self.direction.value_namespace_prefix = name_space_prefix
                    if(value_path == "key-id"):
                        self.key_id = value
                        self.key_id.value_namespace = name_space
                        self.key_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "key-id-valid"):
                        self.key_id_valid = value
                        self.key_id_valid.value_namespace = name_space
                        self.key_id_valid.value_namespace_prefix = name_space_prefix
                    if(value_path == "key-source"):
                        self.key_source = value
                        self.key_source.value_namespace = name_space
                        self.key_source.value_namespace_prefix = name_space_prefix
                    if(value_path == "key-type"):
                        self.key_type = value
                        self.key_type.value_namespace = name_space
                        self.key_type.value_namespace_prefix = name_space_prefix
                    if(value_path == "neighbor-address"):
                        self.neighbor_address = value
                        self.neighbor_address.value_namespace = name_space
                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "source-address-xr"):
                        self.source_address_xr = value
                        self.source_address_xr.value_namespace = name_space
                        self.source_address_xr.value_namespace_prefix = name_space_prefix


            class DirectionInfo(Entity):
                """
                direction info
                
                .. attribute:: auth_direction
                
                	AuthDirection
                	**type**\:   :py:class:`RsvpMgmtAuthDirection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtAuthDirection>`
                
                .. attribute:: receive_info
                
                	receive info
                	**type**\:   :py:class:`ReceiveInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.AuthenticationDetails.AuthenticationDetail.DirectionInfo.ReceiveInfo>`
                
                .. attribute:: send_info
                
                	send info
                	**type**\:   :py:class:`SendInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.AuthenticationDetails.AuthenticationDetail.DirectionInfo.SendInfo>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.AuthenticationDetails.AuthenticationDetail.DirectionInfo, self).__init__()

                    self.yang_name = "direction-info"
                    self.yang_parent_name = "authentication-detail"

                    self.auth_direction = YLeaf(YType.enumeration, "auth-direction")

                    self.receive_info = RsvpStandby.AuthenticationDetails.AuthenticationDetail.DirectionInfo.ReceiveInfo()
                    self.receive_info.parent = self
                    self._children_name_map["receive_info"] = "receive-info"
                    self._children_yang_names.add("receive-info")

                    self.send_info = RsvpStandby.AuthenticationDetails.AuthenticationDetail.DirectionInfo.SendInfo()
                    self.send_info.parent = self
                    self._children_name_map["send_info"] = "send-info"
                    self._children_yang_names.add("send-info")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("auth_direction") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.AuthenticationDetails.AuthenticationDetail.DirectionInfo, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.AuthenticationDetails.AuthenticationDetail.DirectionInfo, self).__setattr__(name, value)


                class SendInfo(Entity):
                    """
                    send info
                    
                    .. attribute:: counters
                    
                    	Counters
                    	**type**\:   :py:class:`Counters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.AuthenticationDetails.AuthenticationDetail.DirectionInfo.SendInfo.Counters>`
                    
                    .. attribute:: sequence
                    
                    	Sequence number
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.AuthenticationDetails.AuthenticationDetail.DirectionInfo.SendInfo, self).__init__()

                        self.yang_name = "send-info"
                        self.yang_parent_name = "direction-info"

                        self.sequence = YLeaf(YType.uint64, "sequence")

                        self.counters = RsvpStandby.AuthenticationDetails.AuthenticationDetail.DirectionInfo.SendInfo.Counters()
                        self.counters.parent = self
                        self._children_name_map["counters"] = "counters"
                        self._children_yang_names.add("counters")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("sequence") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.AuthenticationDetails.AuthenticationDetail.DirectionInfo.SendInfo, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.AuthenticationDetails.AuthenticationDetail.DirectionInfo.SendInfo, self).__setattr__(name, value)


                    class Counters(Entity):
                        """
                        Counters
                        
                        .. attribute:: authentication_challenge_responses_sent
                        
                        	Challenge responses sent
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: authentication_failures
                        
                        	Failures
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: authentication_send_challenges_received
                        
                        	Challenges received
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: authentication_sent
                        
                        	Messages sent
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.AuthenticationDetails.AuthenticationDetail.DirectionInfo.SendInfo.Counters, self).__init__()

                            self.yang_name = "counters"
                            self.yang_parent_name = "send-info"

                            self.authentication_challenge_responses_sent = YLeaf(YType.uint32, "authentication-challenge-responses-sent")

                            self.authentication_failures = YLeaf(YType.uint32, "authentication-failures")

                            self.authentication_send_challenges_received = YLeaf(YType.uint32, "authentication-send-challenges-received")

                            self.authentication_sent = YLeaf(YType.uint32, "authentication-sent")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("authentication_challenge_responses_sent",
                                            "authentication_failures",
                                            "authentication_send_challenges_received",
                                            "authentication_sent") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.AuthenticationDetails.AuthenticationDetail.DirectionInfo.SendInfo.Counters, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.AuthenticationDetails.AuthenticationDetail.DirectionInfo.SendInfo.Counters, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.authentication_challenge_responses_sent.is_set or
                                self.authentication_failures.is_set or
                                self.authentication_send_challenges_received.is_set or
                                self.authentication_sent.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.authentication_challenge_responses_sent.yfilter != YFilter.not_set or
                                self.authentication_failures.yfilter != YFilter.not_set or
                                self.authentication_send_challenges_received.yfilter != YFilter.not_set or
                                self.authentication_sent.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "counters" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.authentication_challenge_responses_sent.is_set or self.authentication_challenge_responses_sent.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.authentication_challenge_responses_sent.get_name_leafdata())
                            if (self.authentication_failures.is_set or self.authentication_failures.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.authentication_failures.get_name_leafdata())
                            if (self.authentication_send_challenges_received.is_set or self.authentication_send_challenges_received.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.authentication_send_challenges_received.get_name_leafdata())
                            if (self.authentication_sent.is_set or self.authentication_sent.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.authentication_sent.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "authentication-challenge-responses-sent" or name == "authentication-failures" or name == "authentication-send-challenges-received" or name == "authentication-sent"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "authentication-challenge-responses-sent"):
                                self.authentication_challenge_responses_sent = value
                                self.authentication_challenge_responses_sent.value_namespace = name_space
                                self.authentication_challenge_responses_sent.value_namespace_prefix = name_space_prefix
                            if(value_path == "authentication-failures"):
                                self.authentication_failures = value
                                self.authentication_failures.value_namespace = name_space
                                self.authentication_failures.value_namespace_prefix = name_space_prefix
                            if(value_path == "authentication-send-challenges-received"):
                                self.authentication_send_challenges_received = value
                                self.authentication_send_challenges_received.value_namespace = name_space
                                self.authentication_send_challenges_received.value_namespace_prefix = name_space_prefix
                            if(value_path == "authentication-sent"):
                                self.authentication_sent = value
                                self.authentication_sent.value_namespace = name_space
                                self.authentication_sent.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.sequence.is_set or
                            (self.counters is not None and self.counters.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.sequence.yfilter != YFilter.not_set or
                            (self.counters is not None and self.counters.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "send-info" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.sequence.is_set or self.sequence.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sequence.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "counters"):
                            if (self.counters is None):
                                self.counters = RsvpStandby.AuthenticationDetails.AuthenticationDetail.DirectionInfo.SendInfo.Counters()
                                self.counters.parent = self
                                self._children_name_map["counters"] = "counters"
                            return self.counters

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "counters" or name == "sequence"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "sequence"):
                            self.sequence = value
                            self.sequence.value_namespace = name_space
                            self.sequence.value_namespace_prefix = name_space_prefix


                class ReceiveInfo(Entity):
                    """
                    receive info
                    
                    .. attribute:: counters
                    
                    	Counters
                    	**type**\:   :py:class:`Counters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.AuthenticationDetails.AuthenticationDetail.DirectionInfo.ReceiveInfo.Counters>`
                    
                    .. attribute:: sequence
                    
                    	Sequence number
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: sequence_window
                    
                    	Sequence window
                    	**type**\:  list of int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: sequence_window_count
                    
                    	Sequence window count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sequence_window_size
                    
                    	Sequence window size
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.AuthenticationDetails.AuthenticationDetail.DirectionInfo.ReceiveInfo, self).__init__()

                        self.yang_name = "receive-info"
                        self.yang_parent_name = "direction-info"

                        self.sequence = YLeaf(YType.uint64, "sequence")

                        self.sequence_window = YLeafList(YType.uint64, "sequence-window")

                        self.sequence_window_count = YLeaf(YType.uint32, "sequence-window-count")

                        self.sequence_window_size = YLeaf(YType.uint32, "sequence-window-size")

                        self.counters = RsvpStandby.AuthenticationDetails.AuthenticationDetail.DirectionInfo.ReceiveInfo.Counters()
                        self.counters.parent = self
                        self._children_name_map["counters"] = "counters"
                        self._children_yang_names.add("counters")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("sequence",
                                        "sequence_window",
                                        "sequence_window_count",
                                        "sequence_window_size") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.AuthenticationDetails.AuthenticationDetail.DirectionInfo.ReceiveInfo, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.AuthenticationDetails.AuthenticationDetail.DirectionInfo.ReceiveInfo, self).__setattr__(name, value)


                    class Counters(Entity):
                        """
                        Counters
                        
                        .. attribute:: authentication_received_bad_digest
                        
                        	Authentication received with bad digest
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: authentication_received_bad_message_format
                        
                        	Authentication received with bad mesage format
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: authentication_received_challenge_response
                        
                        	Challenge responses received
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: authentication_received_challenge_timeouts
                        
                        	Challenge timeouts
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: authentication_received_challenges_resent
                        
                        	Challenges resent
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: authentication_received_challenges_response_duplicate
                        
                        	Duplicate challenge responses received
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: authentication_received_challenges_sent
                        
                        	Challenges sent
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: authentication_received_during_challenge
                        
                        	Authentication received during challenge
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: authentication_received_incomplete
                        
                        	Authentication received incomplete
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: authentication_received_no_integrity
                        
                        	Authentication received with no integrity
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: authentication_received_response_late
                        
                        	Challenge responses received late
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: authentication_received_sequence_number_duplicate
                        
                        	Authentication received with duplicate sequence number
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: authentication_received_sequence_number_outof_range
                        
                        	Authentication received with sequence number out of range
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: authentication_received_valid_messages
                        
                        	Valid messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: authentication_received_wrong_challenges_response
                        
                        	Incorect challenge responses received
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: authentication_received_wrong_digest_type
                        
                        	Authentication received with wrong digest type
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.AuthenticationDetails.AuthenticationDetail.DirectionInfo.ReceiveInfo.Counters, self).__init__()

                            self.yang_name = "counters"
                            self.yang_parent_name = "receive-info"

                            self.authentication_received_bad_digest = YLeaf(YType.uint32, "authentication-received-bad-digest")

                            self.authentication_received_bad_message_format = YLeaf(YType.uint32, "authentication-received-bad-message-format")

                            self.authentication_received_challenge_response = YLeaf(YType.uint32, "authentication-received-challenge-response")

                            self.authentication_received_challenge_timeouts = YLeaf(YType.uint32, "authentication-received-challenge-timeouts")

                            self.authentication_received_challenges_resent = YLeaf(YType.uint32, "authentication-received-challenges-resent")

                            self.authentication_received_challenges_response_duplicate = YLeaf(YType.uint32, "authentication-received-challenges-response-duplicate")

                            self.authentication_received_challenges_sent = YLeaf(YType.uint32, "authentication-received-challenges-sent")

                            self.authentication_received_during_challenge = YLeaf(YType.uint32, "authentication-received-during-challenge")

                            self.authentication_received_incomplete = YLeaf(YType.uint32, "authentication-received-incomplete")

                            self.authentication_received_no_integrity = YLeaf(YType.uint32, "authentication-received-no-integrity")

                            self.authentication_received_response_late = YLeaf(YType.uint32, "authentication-received-response-late")

                            self.authentication_received_sequence_number_duplicate = YLeaf(YType.uint32, "authentication-received-sequence-number-duplicate")

                            self.authentication_received_sequence_number_outof_range = YLeaf(YType.uint32, "authentication-received-sequence-number-outof-range")

                            self.authentication_received_valid_messages = YLeaf(YType.uint32, "authentication-received-valid-messages")

                            self.authentication_received_wrong_challenges_response = YLeaf(YType.uint32, "authentication-received-wrong-challenges-response")

                            self.authentication_received_wrong_digest_type = YLeaf(YType.uint32, "authentication-received-wrong-digest-type")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("authentication_received_bad_digest",
                                            "authentication_received_bad_message_format",
                                            "authentication_received_challenge_response",
                                            "authentication_received_challenge_timeouts",
                                            "authentication_received_challenges_resent",
                                            "authentication_received_challenges_response_duplicate",
                                            "authentication_received_challenges_sent",
                                            "authentication_received_during_challenge",
                                            "authentication_received_incomplete",
                                            "authentication_received_no_integrity",
                                            "authentication_received_response_late",
                                            "authentication_received_sequence_number_duplicate",
                                            "authentication_received_sequence_number_outof_range",
                                            "authentication_received_valid_messages",
                                            "authentication_received_wrong_challenges_response",
                                            "authentication_received_wrong_digest_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.AuthenticationDetails.AuthenticationDetail.DirectionInfo.ReceiveInfo.Counters, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.AuthenticationDetails.AuthenticationDetail.DirectionInfo.ReceiveInfo.Counters, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.authentication_received_bad_digest.is_set or
                                self.authentication_received_bad_message_format.is_set or
                                self.authentication_received_challenge_response.is_set or
                                self.authentication_received_challenge_timeouts.is_set or
                                self.authentication_received_challenges_resent.is_set or
                                self.authentication_received_challenges_response_duplicate.is_set or
                                self.authentication_received_challenges_sent.is_set or
                                self.authentication_received_during_challenge.is_set or
                                self.authentication_received_incomplete.is_set or
                                self.authentication_received_no_integrity.is_set or
                                self.authentication_received_response_late.is_set or
                                self.authentication_received_sequence_number_duplicate.is_set or
                                self.authentication_received_sequence_number_outof_range.is_set or
                                self.authentication_received_valid_messages.is_set or
                                self.authentication_received_wrong_challenges_response.is_set or
                                self.authentication_received_wrong_digest_type.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.authentication_received_bad_digest.yfilter != YFilter.not_set or
                                self.authentication_received_bad_message_format.yfilter != YFilter.not_set or
                                self.authentication_received_challenge_response.yfilter != YFilter.not_set or
                                self.authentication_received_challenge_timeouts.yfilter != YFilter.not_set or
                                self.authentication_received_challenges_resent.yfilter != YFilter.not_set or
                                self.authentication_received_challenges_response_duplicate.yfilter != YFilter.not_set or
                                self.authentication_received_challenges_sent.yfilter != YFilter.not_set or
                                self.authentication_received_during_challenge.yfilter != YFilter.not_set or
                                self.authentication_received_incomplete.yfilter != YFilter.not_set or
                                self.authentication_received_no_integrity.yfilter != YFilter.not_set or
                                self.authentication_received_response_late.yfilter != YFilter.not_set or
                                self.authentication_received_sequence_number_duplicate.yfilter != YFilter.not_set or
                                self.authentication_received_sequence_number_outof_range.yfilter != YFilter.not_set or
                                self.authentication_received_valid_messages.yfilter != YFilter.not_set or
                                self.authentication_received_wrong_challenges_response.yfilter != YFilter.not_set or
                                self.authentication_received_wrong_digest_type.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "counters" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.authentication_received_bad_digest.is_set or self.authentication_received_bad_digest.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.authentication_received_bad_digest.get_name_leafdata())
                            if (self.authentication_received_bad_message_format.is_set or self.authentication_received_bad_message_format.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.authentication_received_bad_message_format.get_name_leafdata())
                            if (self.authentication_received_challenge_response.is_set or self.authentication_received_challenge_response.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.authentication_received_challenge_response.get_name_leafdata())
                            if (self.authentication_received_challenge_timeouts.is_set or self.authentication_received_challenge_timeouts.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.authentication_received_challenge_timeouts.get_name_leafdata())
                            if (self.authentication_received_challenges_resent.is_set or self.authentication_received_challenges_resent.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.authentication_received_challenges_resent.get_name_leafdata())
                            if (self.authentication_received_challenges_response_duplicate.is_set or self.authentication_received_challenges_response_duplicate.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.authentication_received_challenges_response_duplicate.get_name_leafdata())
                            if (self.authentication_received_challenges_sent.is_set or self.authentication_received_challenges_sent.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.authentication_received_challenges_sent.get_name_leafdata())
                            if (self.authentication_received_during_challenge.is_set or self.authentication_received_during_challenge.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.authentication_received_during_challenge.get_name_leafdata())
                            if (self.authentication_received_incomplete.is_set or self.authentication_received_incomplete.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.authentication_received_incomplete.get_name_leafdata())
                            if (self.authentication_received_no_integrity.is_set or self.authentication_received_no_integrity.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.authentication_received_no_integrity.get_name_leafdata())
                            if (self.authentication_received_response_late.is_set or self.authentication_received_response_late.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.authentication_received_response_late.get_name_leafdata())
                            if (self.authentication_received_sequence_number_duplicate.is_set or self.authentication_received_sequence_number_duplicate.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.authentication_received_sequence_number_duplicate.get_name_leafdata())
                            if (self.authentication_received_sequence_number_outof_range.is_set or self.authentication_received_sequence_number_outof_range.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.authentication_received_sequence_number_outof_range.get_name_leafdata())
                            if (self.authentication_received_valid_messages.is_set or self.authentication_received_valid_messages.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.authentication_received_valid_messages.get_name_leafdata())
                            if (self.authentication_received_wrong_challenges_response.is_set or self.authentication_received_wrong_challenges_response.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.authentication_received_wrong_challenges_response.get_name_leafdata())
                            if (self.authentication_received_wrong_digest_type.is_set or self.authentication_received_wrong_digest_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.authentication_received_wrong_digest_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "authentication-received-bad-digest" or name == "authentication-received-bad-message-format" or name == "authentication-received-challenge-response" or name == "authentication-received-challenge-timeouts" or name == "authentication-received-challenges-resent" or name == "authentication-received-challenges-response-duplicate" or name == "authentication-received-challenges-sent" or name == "authentication-received-during-challenge" or name == "authentication-received-incomplete" or name == "authentication-received-no-integrity" or name == "authentication-received-response-late" or name == "authentication-received-sequence-number-duplicate" or name == "authentication-received-sequence-number-outof-range" or name == "authentication-received-valid-messages" or name == "authentication-received-wrong-challenges-response" or name == "authentication-received-wrong-digest-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "authentication-received-bad-digest"):
                                self.authentication_received_bad_digest = value
                                self.authentication_received_bad_digest.value_namespace = name_space
                                self.authentication_received_bad_digest.value_namespace_prefix = name_space_prefix
                            if(value_path == "authentication-received-bad-message-format"):
                                self.authentication_received_bad_message_format = value
                                self.authentication_received_bad_message_format.value_namespace = name_space
                                self.authentication_received_bad_message_format.value_namespace_prefix = name_space_prefix
                            if(value_path == "authentication-received-challenge-response"):
                                self.authentication_received_challenge_response = value
                                self.authentication_received_challenge_response.value_namespace = name_space
                                self.authentication_received_challenge_response.value_namespace_prefix = name_space_prefix
                            if(value_path == "authentication-received-challenge-timeouts"):
                                self.authentication_received_challenge_timeouts = value
                                self.authentication_received_challenge_timeouts.value_namespace = name_space
                                self.authentication_received_challenge_timeouts.value_namespace_prefix = name_space_prefix
                            if(value_path == "authentication-received-challenges-resent"):
                                self.authentication_received_challenges_resent = value
                                self.authentication_received_challenges_resent.value_namespace = name_space
                                self.authentication_received_challenges_resent.value_namespace_prefix = name_space_prefix
                            if(value_path == "authentication-received-challenges-response-duplicate"):
                                self.authentication_received_challenges_response_duplicate = value
                                self.authentication_received_challenges_response_duplicate.value_namespace = name_space
                                self.authentication_received_challenges_response_duplicate.value_namespace_prefix = name_space_prefix
                            if(value_path == "authentication-received-challenges-sent"):
                                self.authentication_received_challenges_sent = value
                                self.authentication_received_challenges_sent.value_namespace = name_space
                                self.authentication_received_challenges_sent.value_namespace_prefix = name_space_prefix
                            if(value_path == "authentication-received-during-challenge"):
                                self.authentication_received_during_challenge = value
                                self.authentication_received_during_challenge.value_namespace = name_space
                                self.authentication_received_during_challenge.value_namespace_prefix = name_space_prefix
                            if(value_path == "authentication-received-incomplete"):
                                self.authentication_received_incomplete = value
                                self.authentication_received_incomplete.value_namespace = name_space
                                self.authentication_received_incomplete.value_namespace_prefix = name_space_prefix
                            if(value_path == "authentication-received-no-integrity"):
                                self.authentication_received_no_integrity = value
                                self.authentication_received_no_integrity.value_namespace = name_space
                                self.authentication_received_no_integrity.value_namespace_prefix = name_space_prefix
                            if(value_path == "authentication-received-response-late"):
                                self.authentication_received_response_late = value
                                self.authentication_received_response_late.value_namespace = name_space
                                self.authentication_received_response_late.value_namespace_prefix = name_space_prefix
                            if(value_path == "authentication-received-sequence-number-duplicate"):
                                self.authentication_received_sequence_number_duplicate = value
                                self.authentication_received_sequence_number_duplicate.value_namespace = name_space
                                self.authentication_received_sequence_number_duplicate.value_namespace_prefix = name_space_prefix
                            if(value_path == "authentication-received-sequence-number-outof-range"):
                                self.authentication_received_sequence_number_outof_range = value
                                self.authentication_received_sequence_number_outof_range.value_namespace = name_space
                                self.authentication_received_sequence_number_outof_range.value_namespace_prefix = name_space_prefix
                            if(value_path == "authentication-received-valid-messages"):
                                self.authentication_received_valid_messages = value
                                self.authentication_received_valid_messages.value_namespace = name_space
                                self.authentication_received_valid_messages.value_namespace_prefix = name_space_prefix
                            if(value_path == "authentication-received-wrong-challenges-response"):
                                self.authentication_received_wrong_challenges_response = value
                                self.authentication_received_wrong_challenges_response.value_namespace = name_space
                                self.authentication_received_wrong_challenges_response.value_namespace_prefix = name_space_prefix
                            if(value_path == "authentication-received-wrong-digest-type"):
                                self.authentication_received_wrong_digest_type = value
                                self.authentication_received_wrong_digest_type.value_namespace = name_space
                                self.authentication_received_wrong_digest_type.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for leaf in self.sequence_window.getYLeafs():
                            if (leaf.yfilter != YFilter.not_set):
                                return True
                        return (
                            self.sequence.is_set or
                            self.sequence_window_count.is_set or
                            self.sequence_window_size.is_set or
                            (self.counters is not None and self.counters.has_data()))

                    def has_operation(self):
                        for leaf in self.sequence_window.getYLeafs():
                            if (leaf.is_set):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.sequence.yfilter != YFilter.not_set or
                            self.sequence_window.yfilter != YFilter.not_set or
                            self.sequence_window_count.yfilter != YFilter.not_set or
                            self.sequence_window_size.yfilter != YFilter.not_set or
                            (self.counters is not None and self.counters.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "receive-info" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.sequence.is_set or self.sequence.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sequence.get_name_leafdata())
                        if (self.sequence_window_count.is_set or self.sequence_window_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sequence_window_count.get_name_leafdata())
                        if (self.sequence_window_size.is_set or self.sequence_window_size.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sequence_window_size.get_name_leafdata())

                        leaf_name_data.extend(self.sequence_window.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "counters"):
                            if (self.counters is None):
                                self.counters = RsvpStandby.AuthenticationDetails.AuthenticationDetail.DirectionInfo.ReceiveInfo.Counters()
                                self.counters.parent = self
                                self._children_name_map["counters"] = "counters"
                            return self.counters

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "counters" or name == "sequence" or name == "sequence-window" or name == "sequence-window-count" or name == "sequence-window-size"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "sequence"):
                            self.sequence = value
                            self.sequence.value_namespace = name_space
                            self.sequence.value_namespace_prefix = name_space_prefix
                        if(value_path == "sequence-window"):
                            self.sequence_window.append(value)
                        if(value_path == "sequence-window-count"):
                            self.sequence_window_count = value
                            self.sequence_window_count.value_namespace = name_space
                            self.sequence_window_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "sequence-window-size"):
                            self.sequence_window_size = value
                            self.sequence_window_size.value_namespace = name_space
                            self.sequence_window_size.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.auth_direction.is_set or
                        (self.receive_info is not None and self.receive_info.has_data()) or
                        (self.send_info is not None and self.send_info.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.auth_direction.yfilter != YFilter.not_set or
                        (self.receive_info is not None and self.receive_info.has_operation()) or
                        (self.send_info is not None and self.send_info.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "direction-info" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.auth_direction.is_set or self.auth_direction.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.auth_direction.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "receive-info"):
                        if (self.receive_info is None):
                            self.receive_info = RsvpStandby.AuthenticationDetails.AuthenticationDetail.DirectionInfo.ReceiveInfo()
                            self.receive_info.parent = self
                            self._children_name_map["receive_info"] = "receive-info"
                        return self.receive_info

                    if (child_yang_name == "send-info"):
                        if (self.send_info is None):
                            self.send_info = RsvpStandby.AuthenticationDetails.AuthenticationDetail.DirectionInfo.SendInfo()
                            self.send_info.parent = self
                            self._children_name_map["send_info"] = "send-info"
                        return self.send_info

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "receive-info" or name == "send-info" or name == "auth-direction"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "auth-direction"):
                        self.auth_direction = value
                        self.auth_direction.value_namespace = name_space
                        self.auth_direction.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.source_address.is_set or
                    self.destination_address.is_set or
                    self.mode_id.is_set or
                    self.interface_name.is_set or
                    self.challenge_status.is_set or
                    self.key_digest_info.is_set or
                    self.key_status.is_set or
                    self.lifetime.is_set or
                    self.lifetime_left.is_set or
                    (self.auth_compact is not None and self.auth_compact.has_data()) or
                    (self.direction_info is not None and self.direction_info.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.source_address.yfilter != YFilter.not_set or
                    self.destination_address.yfilter != YFilter.not_set or
                    self.mode_id.yfilter != YFilter.not_set or
                    self.interface_name.yfilter != YFilter.not_set or
                    self.challenge_status.yfilter != YFilter.not_set or
                    self.key_digest_info.yfilter != YFilter.not_set or
                    self.key_status.yfilter != YFilter.not_set or
                    self.lifetime.yfilter != YFilter.not_set or
                    self.lifetime_left.yfilter != YFilter.not_set or
                    (self.auth_compact is not None and self.auth_compact.has_operation()) or
                    (self.direction_info is not None and self.direction_info.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "authentication-detail" + "[source-address='" + self.source_address.get() + "']" + "[destination-address='" + self.destination_address.get() + "']" + "[mode-id='" + self.mode_id.get() + "']" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/authentication-details/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_address.get_name_leafdata())
                if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_address.get_name_leafdata())
                if (self.mode_id.is_set or self.mode_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.mode_id.get_name_leafdata())
                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                if (self.challenge_status.is_set or self.challenge_status.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.challenge_status.get_name_leafdata())
                if (self.key_digest_info.is_set or self.key_digest_info.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.key_digest_info.get_name_leafdata())
                if (self.key_status.is_set or self.key_status.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.key_status.get_name_leafdata())
                if (self.lifetime.is_set or self.lifetime.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.lifetime.get_name_leafdata())
                if (self.lifetime_left.is_set or self.lifetime_left.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.lifetime_left.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "auth-compact"):
                    if (self.auth_compact is None):
                        self.auth_compact = RsvpStandby.AuthenticationDetails.AuthenticationDetail.AuthCompact()
                        self.auth_compact.parent = self
                        self._children_name_map["auth_compact"] = "auth-compact"
                    return self.auth_compact

                if (child_yang_name == "direction-info"):
                    if (self.direction_info is None):
                        self.direction_info = RsvpStandby.AuthenticationDetails.AuthenticationDetail.DirectionInfo()
                        self.direction_info.parent = self
                        self._children_name_map["direction_info"] = "direction-info"
                    return self.direction_info

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "auth-compact" or name == "direction-info" or name == "source-address" or name == "destination-address" or name == "mode-id" or name == "interface-name" or name == "challenge-status" or name == "key-digest-info" or name == "key-status" or name == "lifetime" or name == "lifetime-left"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "source-address"):
                    self.source_address = value
                    self.source_address.value_namespace = name_space
                    self.source_address.value_namespace_prefix = name_space_prefix
                if(value_path == "destination-address"):
                    self.destination_address = value
                    self.destination_address.value_namespace = name_space
                    self.destination_address.value_namespace_prefix = name_space_prefix
                if(value_path == "mode-id"):
                    self.mode_id = value
                    self.mode_id.value_namespace = name_space
                    self.mode_id.value_namespace_prefix = name_space_prefix
                if(value_path == "interface-name"):
                    self.interface_name = value
                    self.interface_name.value_namespace = name_space
                    self.interface_name.value_namespace_prefix = name_space_prefix
                if(value_path == "challenge-status"):
                    self.challenge_status = value
                    self.challenge_status.value_namespace = name_space
                    self.challenge_status.value_namespace_prefix = name_space_prefix
                if(value_path == "key-digest-info"):
                    self.key_digest_info = value
                    self.key_digest_info.value_namespace = name_space
                    self.key_digest_info.value_namespace_prefix = name_space_prefix
                if(value_path == "key-status"):
                    self.key_status = value
                    self.key_status.value_namespace = name_space
                    self.key_status.value_namespace_prefix = name_space_prefix
                if(value_path == "lifetime"):
                    self.lifetime = value
                    self.lifetime.value_namespace = name_space
                    self.lifetime.value_namespace_prefix = name_space_prefix
                if(value_path == "lifetime-left"):
                    self.lifetime_left = value
                    self.lifetime_left.value_namespace = name_space
                    self.lifetime_left.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.authentication_detail:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.authentication_detail:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "authentication-details" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "authentication-detail"):
                for c in self.authentication_detail:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = RsvpStandby.AuthenticationDetails.AuthenticationDetail()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.authentication_detail.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "authentication-detail"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class RsbBriefs(Entity):
        """
        Table of brief info about reservation state
        blocks
        
        .. attribute:: rsb_brief
        
        	Brief info for a single reservation state block
        	**type**\: list of    :py:class:`RsbBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RsbBriefs.RsbBrief>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(RsvpStandby.RsbBriefs, self).__init__()

            self.yang_name = "rsb-briefs"
            self.yang_parent_name = "rsvp-standby"

            self.rsb_brief = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(RsvpStandby.RsbBriefs, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(RsvpStandby.RsbBriefs, self).__setattr__(name, value)


        class RsbBrief(Entity):
            """
            Brief info for a single reservation state block
            
            .. attribute:: destination_address
            
            	Destination Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: destination_port
            
            	Destination Port
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: extended_tunnel_id
            
            	Extended Tunnel ID
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: filter
            
            	RSVP Filter
            	**type**\:   :py:class:`Filter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RsbBriefs.RsbBrief.Filter>`
            
            .. attribute:: flow_spec
            
            	Flow Spec Information
            	**type**\:   :py:class:`FlowSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RsbBriefs.RsbBrief.FlowSpec>`
            
            .. attribute:: generic_flow_spec
            
            	Generic Flow Spec Info
            	**type**\:   :py:class:`GenericFlowSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RsbBriefs.RsbBrief.GenericFlowSpec>`
            
            .. attribute:: input_interface
            
            	Reservation Input Interface
            	**type**\:  str
            
            .. attribute:: p2mp_id
            
            	P2MP ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: protocol
            
            	Protocol
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: s2l_sub_lsp
            
            	RSVP S2L Sub\-LSP information
            	**type**\:   :py:class:`S2LSubLsp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RsbBriefs.RsbBrief.S2LSubLsp>`
            
            .. attribute:: session
            
            	RSVP Session Information
            	**type**\:   :py:class:`Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RsbBriefs.RsbBrief.Session>`
            
            .. attribute:: session_type
            
            	Session Type
            	**type**\:   :py:class:`RsvpSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpSession>`
            
            .. attribute:: source_address
            
            	Source Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: source_port
            
            	Source Port 
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: style
            
            	RSVP Style
            	**type**\:   :py:class:`Style <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RsbBriefs.RsbBrief.Style>`
            
            .. attribute:: sub_group_id
            
            	Subgroup ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: sub_group_origin
            
            	Subgroup Origin
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: vrf_name
            
            	VRF Name
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(RsvpStandby.RsbBriefs.RsbBrief, self).__init__()

                self.yang_name = "rsb-brief"
                self.yang_parent_name = "rsb-briefs"

                self.destination_address = YLeaf(YType.str, "destination-address")

                self.destination_port = YLeaf(YType.int32, "destination-port")

                self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                self.input_interface = YLeaf(YType.str, "input-interface")

                self.p2mp_id = YLeaf(YType.int32, "p2mp-id")

                self.protocol = YLeaf(YType.int32, "protocol")

                self.session_type = YLeaf(YType.enumeration, "session-type")

                self.source_address = YLeaf(YType.str, "source-address")

                self.source_port = YLeaf(YType.int32, "source-port")

                self.sub_group_id = YLeaf(YType.int32, "sub-group-id")

                self.sub_group_origin = YLeaf(YType.str, "sub-group-origin")

                self.vrf_name = YLeaf(YType.str, "vrf-name")

                self.filter = RsvpStandby.RsbBriefs.RsbBrief.Filter()
                self.filter.parent = self
                self._children_name_map["filter"] = "filter"
                self._children_yang_names.add("filter")

                self.flow_spec = RsvpStandby.RsbBriefs.RsbBrief.FlowSpec()
                self.flow_spec.parent = self
                self._children_name_map["flow_spec"] = "flow-spec"
                self._children_yang_names.add("flow-spec")

                self.generic_flow_spec = RsvpStandby.RsbBriefs.RsbBrief.GenericFlowSpec()
                self.generic_flow_spec.parent = self
                self._children_name_map["generic_flow_spec"] = "generic-flow-spec"
                self._children_yang_names.add("generic-flow-spec")

                self.s2l_sub_lsp = RsvpStandby.RsbBriefs.RsbBrief.S2LSubLsp()
                self.s2l_sub_lsp.parent = self
                self._children_name_map["s2l_sub_lsp"] = "s2l-sub-lsp"
                self._children_yang_names.add("s2l-sub-lsp")

                self.session = RsvpStandby.RsbBriefs.RsbBrief.Session()
                self.session.parent = self
                self._children_name_map["session"] = "session"
                self._children_yang_names.add("session")

                self.style = RsvpStandby.RsbBriefs.RsbBrief.Style()
                self.style.parent = self
                self._children_name_map["style"] = "style"
                self._children_yang_names.add("style")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("destination_address",
                                "destination_port",
                                "extended_tunnel_id",
                                "input_interface",
                                "p2mp_id",
                                "protocol",
                                "session_type",
                                "source_address",
                                "source_port",
                                "sub_group_id",
                                "sub_group_origin",
                                "vrf_name") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(RsvpStandby.RsbBriefs.RsbBrief, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(RsvpStandby.RsbBriefs.RsbBrief, self).__setattr__(name, value)


            class Session(Entity):
                """
                RSVP Session Information
                
                .. attribute:: rsvp_session
                
                	RSVP Session
                	**type**\:   :py:class:`RsvpSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RsbBriefs.RsbBrief.Session.RsvpSession>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.RsbBriefs.RsbBrief.Session, self).__init__()

                    self.yang_name = "session"
                    self.yang_parent_name = "rsb-brief"

                    self.rsvp_session = RsvpStandby.RsbBriefs.RsbBrief.Session.RsvpSession()
                    self.rsvp_session.parent = self
                    self._children_name_map["rsvp_session"] = "rsvp-session"
                    self._children_yang_names.add("rsvp-session")


                class RsvpSession(Entity):
                    """
                    RSVP Session
                    
                    .. attribute:: ipv4
                    
                    	UDP IPv4 session
                    	**type**\:   :py:class:`Ipv4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RsbBriefs.RsbBrief.Session.RsvpSession.Ipv4>`
                    
                    .. attribute:: ipv4_lsp_session
                    
                    	IPv4 LSP session
                    	**type**\:   :py:class:`Ipv4LspSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RsbBriefs.RsbBrief.Session.RsvpSession.Ipv4LspSession>`
                    
                    .. attribute:: ipv4_p2mp_lsp_session
                    
                    	IPv4 P2MP LSP session
                    	**type**\:   :py:class:`Ipv4P2MpLspSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RsbBriefs.RsbBrief.Session.RsvpSession.Ipv4P2MpLspSession>`
                    
                    .. attribute:: ipv4_uni_session
                    
                    	IPv4 UNI session
                    	**type**\:   :py:class:`Ipv4UniSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RsbBriefs.RsbBrief.Session.RsvpSession.Ipv4UniSession>`
                    
                    .. attribute:: session_type
                    
                    	SessionType
                    	**type**\:   :py:class:`RsvpMgmtSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtSession>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.RsbBriefs.RsbBrief.Session.RsvpSession, self).__init__()

                        self.yang_name = "rsvp-session"
                        self.yang_parent_name = "session"

                        self.session_type = YLeaf(YType.enumeration, "session-type")

                        self.ipv4 = RsvpStandby.RsbBriefs.RsbBrief.Session.RsvpSession.Ipv4()
                        self.ipv4.parent = self
                        self._children_name_map["ipv4"] = "ipv4"
                        self._children_yang_names.add("ipv4")

                        self.ipv4_lsp_session = RsvpStandby.RsbBriefs.RsbBrief.Session.RsvpSession.Ipv4LspSession()
                        self.ipv4_lsp_session.parent = self
                        self._children_name_map["ipv4_lsp_session"] = "ipv4-lsp-session"
                        self._children_yang_names.add("ipv4-lsp-session")

                        self.ipv4_p2mp_lsp_session = RsvpStandby.RsbBriefs.RsbBrief.Session.RsvpSession.Ipv4P2MpLspSession()
                        self.ipv4_p2mp_lsp_session.parent = self
                        self._children_name_map["ipv4_p2mp_lsp_session"] = "ipv4-p2mp-lsp-session"
                        self._children_yang_names.add("ipv4-p2mp-lsp-session")

                        self.ipv4_uni_session = RsvpStandby.RsbBriefs.RsbBrief.Session.RsvpSession.Ipv4UniSession()
                        self.ipv4_uni_session.parent = self
                        self._children_name_map["ipv4_uni_session"] = "ipv4-uni-session"
                        self._children_yang_names.add("ipv4-uni-session")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("session_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.RsbBriefs.RsbBrief.Session.RsvpSession, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.RsbBriefs.RsbBrief.Session.RsvpSession, self).__setattr__(name, value)


                    class Ipv4(Entity):
                        """
                        UDP IPv4 session
                        
                        .. attribute:: destination_address
                        
                        	Destination address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: destination_port
                        
                        	The Session Destination Port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: protocol
                        
                        	Protocol type (originally defined in RFC 790, further values in subsequent RFCs)
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.RsbBriefs.RsbBrief.Session.RsvpSession.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "rsvp-session"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.destination_port = YLeaf(YType.uint16, "destination-port")

                            self.protocol = YLeaf(YType.uint8, "protocol")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "destination_port",
                                            "protocol") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.RsbBriefs.RsbBrief.Session.RsvpSession.Ipv4, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.RsbBriefs.RsbBrief.Session.RsvpSession.Ipv4, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination_address.is_set or
                                self.destination_port.is_set or
                                self.protocol.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.destination_port.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/rsb-briefs/rsb-brief/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.destination_port.is_set or self.destination_port.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_port.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "destination-port" or name == "protocol"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "destination-port"):
                                self.destination_port = value
                                self.destination_port.value_namespace = name_space
                                self.destination_port.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix


                    class Ipv4LspSession(Entity):
                        """
                        IPv4 LSP session
                        
                        .. attribute:: destination_address
                        
                        	Destination address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: extended_tunnel_id
                        
                        	The Session Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: tunnel_id
                        
                        	The Session Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.RsbBriefs.RsbBrief.Session.RsvpSession.Ipv4LspSession, self).__init__()

                            self.yang_name = "ipv4-lsp-session"
                            self.yang_parent_name = "rsvp-session"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                            self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "extended_tunnel_id",
                                            "tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.RsbBriefs.RsbBrief.Session.RsvpSession.Ipv4LspSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.RsbBriefs.RsbBrief.Session.RsvpSession.Ipv4LspSession, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination_address.is_set or
                                self.extended_tunnel_id.is_set or
                                self.tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.extended_tunnel_id.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-lsp-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/rsb-briefs/rsb-brief/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "extended-tunnel-id" or name == "tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "extended-tunnel-id"):
                                self.extended_tunnel_id = value
                                self.extended_tunnel_id.value_namespace = name_space
                                self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix


                    class Ipv4UniSession(Entity):
                        """
                        IPv4 UNI session
                        
                        .. attribute:: destination_address
                        
                        	Destination address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: extended_address
                        
                        	The Session Extended Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: tunnel_id
                        
                        	The Session Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.RsbBriefs.RsbBrief.Session.RsvpSession.Ipv4UniSession, self).__init__()

                            self.yang_name = "ipv4-uni-session"
                            self.yang_parent_name = "rsvp-session"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.extended_address = YLeaf(YType.str, "extended-address")

                            self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "extended_address",
                                            "tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.RsbBriefs.RsbBrief.Session.RsvpSession.Ipv4UniSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.RsbBriefs.RsbBrief.Session.RsvpSession.Ipv4UniSession, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination_address.is_set or
                                self.extended_address.is_set or
                                self.tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.extended_address.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-uni-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/rsb-briefs/rsb-brief/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.extended_address.is_set or self.extended_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_address.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "extended-address" or name == "tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "extended-address"):
                                self.extended_address = value
                                self.extended_address.value_namespace = name_space
                                self.extended_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix


                    class Ipv4P2MpLspSession(Entity):
                        """
                        IPv4 P2MP LSP session
                        
                        .. attribute:: extended_tunnel_id
                        
                        	The Session Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: p2mp_id
                        
                        	The Point to Multipoint ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tunnel_id
                        
                        	The Session Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.RsbBriefs.RsbBrief.Session.RsvpSession.Ipv4P2MpLspSession, self).__init__()

                            self.yang_name = "ipv4-p2mp-lsp-session"
                            self.yang_parent_name = "rsvp-session"

                            self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                            self.p2mp_id = YLeaf(YType.uint32, "p2mp-id")

                            self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("extended_tunnel_id",
                                            "p2mp_id",
                                            "tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.RsbBriefs.RsbBrief.Session.RsvpSession.Ipv4P2MpLspSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.RsbBriefs.RsbBrief.Session.RsvpSession.Ipv4P2MpLspSession, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.extended_tunnel_id.is_set or
                                self.p2mp_id.is_set or
                                self.tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.extended_tunnel_id.yfilter != YFilter.not_set or
                                self.p2mp_id.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-p2mp-lsp-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/rsb-briefs/rsb-brief/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                            if (self.p2mp_id.is_set or self.p2mp_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.p2mp_id.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "extended-tunnel-id" or name == "p2mp-id" or name == "tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "extended-tunnel-id"):
                                self.extended_tunnel_id = value
                                self.extended_tunnel_id.value_namespace = name_space
                                self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "p2mp-id"):
                                self.p2mp_id = value
                                self.p2mp_id.value_namespace = name_space
                                self.p2mp_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.session_type.is_set or
                            (self.ipv4 is not None and self.ipv4.has_data()) or
                            (self.ipv4_lsp_session is not None and self.ipv4_lsp_session.has_data()) or
                            (self.ipv4_p2mp_lsp_session is not None and self.ipv4_p2mp_lsp_session.has_data()) or
                            (self.ipv4_uni_session is not None and self.ipv4_uni_session.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.session_type.yfilter != YFilter.not_set or
                            (self.ipv4 is not None and self.ipv4.has_operation()) or
                            (self.ipv4_lsp_session is not None and self.ipv4_lsp_session.has_operation()) or
                            (self.ipv4_p2mp_lsp_session is not None and self.ipv4_p2mp_lsp_session.has_operation()) or
                            (self.ipv4_uni_session is not None and self.ipv4_uni_session.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rsvp-session" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/rsb-briefs/rsb-brief/session/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.session_type.is_set or self.session_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.session_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "ipv4"):
                            if (self.ipv4 is None):
                                self.ipv4 = RsvpStandby.RsbBriefs.RsbBrief.Session.RsvpSession.Ipv4()
                                self.ipv4.parent = self
                                self._children_name_map["ipv4"] = "ipv4"
                            return self.ipv4

                        if (child_yang_name == "ipv4-lsp-session"):
                            if (self.ipv4_lsp_session is None):
                                self.ipv4_lsp_session = RsvpStandby.RsbBriefs.RsbBrief.Session.RsvpSession.Ipv4LspSession()
                                self.ipv4_lsp_session.parent = self
                                self._children_name_map["ipv4_lsp_session"] = "ipv4-lsp-session"
                            return self.ipv4_lsp_session

                        if (child_yang_name == "ipv4-p2mp-lsp-session"):
                            if (self.ipv4_p2mp_lsp_session is None):
                                self.ipv4_p2mp_lsp_session = RsvpStandby.RsbBriefs.RsbBrief.Session.RsvpSession.Ipv4P2MpLspSession()
                                self.ipv4_p2mp_lsp_session.parent = self
                                self._children_name_map["ipv4_p2mp_lsp_session"] = "ipv4-p2mp-lsp-session"
                            return self.ipv4_p2mp_lsp_session

                        if (child_yang_name == "ipv4-uni-session"):
                            if (self.ipv4_uni_session is None):
                                self.ipv4_uni_session = RsvpStandby.RsbBriefs.RsbBrief.Session.RsvpSession.Ipv4UniSession()
                                self.ipv4_uni_session.parent = self
                                self._children_name_map["ipv4_uni_session"] = "ipv4-uni-session"
                            return self.ipv4_uni_session

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ipv4" or name == "ipv4-lsp-session" or name == "ipv4-p2mp-lsp-session" or name == "ipv4-uni-session" or name == "session-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "session-type"):
                            self.session_type = value
                            self.session_type.value_namespace = name_space
                            self.session_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (self.rsvp_session is not None and self.rsvp_session.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.rsvp_session is not None and self.rsvp_session.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "session" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/rsb-briefs/rsb-brief/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "rsvp-session"):
                        if (self.rsvp_session is None):
                            self.rsvp_session = RsvpStandby.RsbBriefs.RsbBrief.Session.RsvpSession()
                            self.rsvp_session.parent = self
                            self._children_name_map["rsvp_session"] = "rsvp-session"
                        return self.rsvp_session

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "rsvp-session"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class S2LSubLsp(Entity):
                """
                RSVP S2L Sub\-LSP information
                
                .. attribute:: s2l_destination_address
                
                	S2L Sub\-LSP Destination Address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.RsbBriefs.RsbBrief.S2LSubLsp, self).__init__()

                    self.yang_name = "s2l-sub-lsp"
                    self.yang_parent_name = "rsb-brief"

                    self.s2l_destination_address = YLeaf(YType.str, "s2l-destination-address")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("s2l_destination_address") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.RsbBriefs.RsbBrief.S2LSubLsp, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.RsbBriefs.RsbBrief.S2LSubLsp, self).__setattr__(name, value)

                def has_data(self):
                    return self.s2l_destination_address.is_set

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.s2l_destination_address.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "s2l-sub-lsp" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/rsb-briefs/rsb-brief/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.s2l_destination_address.is_set or self.s2l_destination_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.s2l_destination_address.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "s2l-destination-address"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "s2l-destination-address"):
                        self.s2l_destination_address = value
                        self.s2l_destination_address.value_namespace = name_space
                        self.s2l_destination_address.value_namespace_prefix = name_space_prefix


            class FlowSpec(Entity):
                """
                Flow Spec Information
                
                .. attribute:: flow_average_rate
                
                	The Flow Average Rate in bytes per second
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: byte/s
                
                .. attribute:: flow_max_burst
                
                	The Flow Maximum Burst
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: flow_max_unit
                
                	The Flow Maximum Unit
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: flow_min_unit
                
                	The Flow Minimum Unit
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: flow_peak_rate
                
                	The Flow Peak Rate in bytes per second
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: byte/s
                
                .. attribute:: flow_qos
                
                	The Flow Quality of Service
                	**type**\:   :py:class:`RsvpMgmtQosServiceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtQosServiceEnum>`
                
                .. attribute:: flow_requested_rate
                
                	The Flow Requested Rate in bytes per second
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: byte/s
                
                .. attribute:: flow_slack
                
                	The Flow Slack
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.RsbBriefs.RsbBrief.FlowSpec, self).__init__()

                    self.yang_name = "flow-spec"
                    self.yang_parent_name = "rsb-brief"

                    self.flow_average_rate = YLeaf(YType.uint64, "flow-average-rate")

                    self.flow_max_burst = YLeaf(YType.uint64, "flow-max-burst")

                    self.flow_max_unit = YLeaf(YType.uint32, "flow-max-unit")

                    self.flow_min_unit = YLeaf(YType.uint32, "flow-min-unit")

                    self.flow_peak_rate = YLeaf(YType.uint64, "flow-peak-rate")

                    self.flow_qos = YLeaf(YType.enumeration, "flow-qos")

                    self.flow_requested_rate = YLeaf(YType.uint64, "flow-requested-rate")

                    self.flow_slack = YLeaf(YType.uint32, "flow-slack")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("flow_average_rate",
                                    "flow_max_burst",
                                    "flow_max_unit",
                                    "flow_min_unit",
                                    "flow_peak_rate",
                                    "flow_qos",
                                    "flow_requested_rate",
                                    "flow_slack") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.RsbBriefs.RsbBrief.FlowSpec, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.RsbBriefs.RsbBrief.FlowSpec, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.flow_average_rate.is_set or
                        self.flow_max_burst.is_set or
                        self.flow_max_unit.is_set or
                        self.flow_min_unit.is_set or
                        self.flow_peak_rate.is_set or
                        self.flow_qos.is_set or
                        self.flow_requested_rate.is_set or
                        self.flow_slack.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.flow_average_rate.yfilter != YFilter.not_set or
                        self.flow_max_burst.yfilter != YFilter.not_set or
                        self.flow_max_unit.yfilter != YFilter.not_set or
                        self.flow_min_unit.yfilter != YFilter.not_set or
                        self.flow_peak_rate.yfilter != YFilter.not_set or
                        self.flow_qos.yfilter != YFilter.not_set or
                        self.flow_requested_rate.yfilter != YFilter.not_set or
                        self.flow_slack.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "flow-spec" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/rsb-briefs/rsb-brief/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.flow_average_rate.is_set or self.flow_average_rate.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_average_rate.get_name_leafdata())
                    if (self.flow_max_burst.is_set or self.flow_max_burst.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_max_burst.get_name_leafdata())
                    if (self.flow_max_unit.is_set or self.flow_max_unit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_max_unit.get_name_leafdata())
                    if (self.flow_min_unit.is_set or self.flow_min_unit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_min_unit.get_name_leafdata())
                    if (self.flow_peak_rate.is_set or self.flow_peak_rate.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_peak_rate.get_name_leafdata())
                    if (self.flow_qos.is_set or self.flow_qos.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_qos.get_name_leafdata())
                    if (self.flow_requested_rate.is_set or self.flow_requested_rate.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_requested_rate.get_name_leafdata())
                    if (self.flow_slack.is_set or self.flow_slack.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_slack.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "flow-average-rate" or name == "flow-max-burst" or name == "flow-max-unit" or name == "flow-min-unit" or name == "flow-peak-rate" or name == "flow-qos" or name == "flow-requested-rate" or name == "flow-slack"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "flow-average-rate"):
                        self.flow_average_rate = value
                        self.flow_average_rate.value_namespace = name_space
                        self.flow_average_rate.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-max-burst"):
                        self.flow_max_burst = value
                        self.flow_max_burst.value_namespace = name_space
                        self.flow_max_burst.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-max-unit"):
                        self.flow_max_unit = value
                        self.flow_max_unit.value_namespace = name_space
                        self.flow_max_unit.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-min-unit"):
                        self.flow_min_unit = value
                        self.flow_min_unit.value_namespace = name_space
                        self.flow_min_unit.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-peak-rate"):
                        self.flow_peak_rate = value
                        self.flow_peak_rate.value_namespace = name_space
                        self.flow_peak_rate.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-qos"):
                        self.flow_qos = value
                        self.flow_qos.value_namespace = name_space
                        self.flow_qos.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-requested-rate"):
                        self.flow_requested_rate = value
                        self.flow_requested_rate.value_namespace = name_space
                        self.flow_requested_rate.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-slack"):
                        self.flow_slack = value
                        self.flow_slack.value_namespace = name_space
                        self.flow_slack.value_namespace_prefix = name_space_prefix


            class GenericFlowSpec(Entity):
                """
                Generic Flow Spec Info
                
                .. attribute:: flow_spec_type
                
                	FlowSpecType
                	**type**\:   :py:class:`RsvpMgmtFlowSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtFlowSpec>`
                
                .. attribute:: g709otn_flow_spec
                
                	G709 OTN FlowSpec
                	**type**\:   :py:class:`G709OtnFlowSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RsbBriefs.RsbBrief.GenericFlowSpec.G709OtnFlowSpec>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.RsbBriefs.RsbBrief.GenericFlowSpec, self).__init__()

                    self.yang_name = "generic-flow-spec"
                    self.yang_parent_name = "rsb-brief"

                    self.flow_spec_type = YLeaf(YType.enumeration, "flow-spec-type")

                    self.g709otn_flow_spec = RsvpStandby.RsbBriefs.RsbBrief.GenericFlowSpec.G709OtnFlowSpec()
                    self.g709otn_flow_spec.parent = self
                    self._children_name_map["g709otn_flow_spec"] = "g709otn-flow-spec"
                    self._children_yang_names.add("g709otn-flow-spec")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("flow_spec_type") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.RsbBriefs.RsbBrief.GenericFlowSpec, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.RsbBriefs.RsbBrief.GenericFlowSpec, self).__setattr__(name, value)


                class G709OtnFlowSpec(Entity):
                    """
                    G709 OTN FlowSpec
                    
                    .. attribute:: flow_bit_rate
                    
                    	G709 OTN Flow Bit Rate
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: flow_multiplier
                    
                    	G709 OTN Flow Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: flow_nvc
                    
                    	G709 OTN Flow NVC
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: flow_signal_type
                    
                    	G709 OTN Flow Signal Type (Refer G709 v3)
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.RsbBriefs.RsbBrief.GenericFlowSpec.G709OtnFlowSpec, self).__init__()

                        self.yang_name = "g709otn-flow-spec"
                        self.yang_parent_name = "generic-flow-spec"

                        self.flow_bit_rate = YLeaf(YType.uint64, "flow-bit-rate")

                        self.flow_multiplier = YLeaf(YType.uint16, "flow-multiplier")

                        self.flow_nvc = YLeaf(YType.uint16, "flow-nvc")

                        self.flow_signal_type = YLeaf(YType.uint8, "flow-signal-type")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("flow_bit_rate",
                                        "flow_multiplier",
                                        "flow_nvc",
                                        "flow_signal_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.RsbBriefs.RsbBrief.GenericFlowSpec.G709OtnFlowSpec, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.RsbBriefs.RsbBrief.GenericFlowSpec.G709OtnFlowSpec, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.flow_bit_rate.is_set or
                            self.flow_multiplier.is_set or
                            self.flow_nvc.is_set or
                            self.flow_signal_type.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.flow_bit_rate.yfilter != YFilter.not_set or
                            self.flow_multiplier.yfilter != YFilter.not_set or
                            self.flow_nvc.yfilter != YFilter.not_set or
                            self.flow_signal_type.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "g709otn-flow-spec" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/rsb-briefs/rsb-brief/generic-flow-spec/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.flow_bit_rate.is_set or self.flow_bit_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.flow_bit_rate.get_name_leafdata())
                        if (self.flow_multiplier.is_set or self.flow_multiplier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.flow_multiplier.get_name_leafdata())
                        if (self.flow_nvc.is_set or self.flow_nvc.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.flow_nvc.get_name_leafdata())
                        if (self.flow_signal_type.is_set or self.flow_signal_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.flow_signal_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "flow-bit-rate" or name == "flow-multiplier" or name == "flow-nvc" or name == "flow-signal-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "flow-bit-rate"):
                            self.flow_bit_rate = value
                            self.flow_bit_rate.value_namespace = name_space
                            self.flow_bit_rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "flow-multiplier"):
                            self.flow_multiplier = value
                            self.flow_multiplier.value_namespace = name_space
                            self.flow_multiplier.value_namespace_prefix = name_space_prefix
                        if(value_path == "flow-nvc"):
                            self.flow_nvc = value
                            self.flow_nvc.value_namespace = name_space
                            self.flow_nvc.value_namespace_prefix = name_space_prefix
                        if(value_path == "flow-signal-type"):
                            self.flow_signal_type = value
                            self.flow_signal_type.value_namespace = name_space
                            self.flow_signal_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.flow_spec_type.is_set or
                        (self.g709otn_flow_spec is not None and self.g709otn_flow_spec.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.flow_spec_type.yfilter != YFilter.not_set or
                        (self.g709otn_flow_spec is not None and self.g709otn_flow_spec.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "generic-flow-spec" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/rsb-briefs/rsb-brief/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.flow_spec_type.is_set or self.flow_spec_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_spec_type.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "g709otn-flow-spec"):
                        if (self.g709otn_flow_spec is None):
                            self.g709otn_flow_spec = RsvpStandby.RsbBriefs.RsbBrief.GenericFlowSpec.G709OtnFlowSpec()
                            self.g709otn_flow_spec.parent = self
                            self._children_name_map["g709otn_flow_spec"] = "g709otn-flow-spec"
                        return self.g709otn_flow_spec

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "g709otn-flow-spec" or name == "flow-spec-type"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "flow-spec-type"):
                        self.flow_spec_type = value
                        self.flow_spec_type.value_namespace = name_space
                        self.flow_spec_type.value_namespace_prefix = name_space_prefix


            class Style(Entity):
                """
                RSVP Style
                
                .. attribute:: reservation_type
                
                	The Reservation Type\: WF, SE or FF
                	**type**\:   :py:class:`RsvpMgmtReservationTypeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtReservationTypeEnum>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.RsbBriefs.RsbBrief.Style, self).__init__()

                    self.yang_name = "style"
                    self.yang_parent_name = "rsb-brief"

                    self.reservation_type = YLeaf(YType.enumeration, "reservation-type")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("reservation_type") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.RsbBriefs.RsbBrief.Style, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.RsbBriefs.RsbBrief.Style, self).__setattr__(name, value)

                def has_data(self):
                    return self.reservation_type.is_set

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.reservation_type.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "style" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/rsb-briefs/rsb-brief/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.reservation_type.is_set or self.reservation_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reservation_type.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "reservation-type"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "reservation-type"):
                        self.reservation_type = value
                        self.reservation_type.value_namespace = name_space
                        self.reservation_type.value_namespace_prefix = name_space_prefix


            class Filter(Entity):
                """
                RSVP Filter
                
                .. attribute:: rsvp_filter
                
                	RSVP Filter
                	**type**\:   :py:class:`RsvpFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RsbBriefs.RsbBrief.Filter.RsvpFilter>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.RsbBriefs.RsbBrief.Filter, self).__init__()

                    self.yang_name = "filter"
                    self.yang_parent_name = "rsb-brief"

                    self.rsvp_filter = RsvpStandby.RsbBriefs.RsbBrief.Filter.RsvpFilter()
                    self.rsvp_filter.parent = self
                    self._children_name_map["rsvp_filter"] = "rsvp-filter"
                    self._children_yang_names.add("rsvp-filter")


                class RsvpFilter(Entity):
                    """
                    RSVP Filter
                    
                    .. attribute:: filter_type
                    
                    	FilterType
                    	**type**\:   :py:class:`RsvpMgmtFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtFilter>`
                    
                    .. attribute:: p2mp_ipv4_session
                    
                    	IPv4 P2MP LSP FilterSpec
                    	**type**\:   :py:class:`P2MpIpv4Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RsbBriefs.RsbBrief.Filter.RsvpFilter.P2MpIpv4Session>`
                    
                    .. attribute:: udp_ipv4_session
                    
                    	UDP IPV4 FilterSpec
                    	**type**\:   :py:class:`UdpIpv4Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RsbBriefs.RsbBrief.Filter.RsvpFilter.UdpIpv4Session>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.RsbBriefs.RsbBrief.Filter.RsvpFilter, self).__init__()

                        self.yang_name = "rsvp-filter"
                        self.yang_parent_name = "filter"

                        self.filter_type = YLeaf(YType.enumeration, "filter-type")

                        self.p2mp_ipv4_session = RsvpStandby.RsbBriefs.RsbBrief.Filter.RsvpFilter.P2MpIpv4Session()
                        self.p2mp_ipv4_session.parent = self
                        self._children_name_map["p2mp_ipv4_session"] = "p2mp-ipv4-session"
                        self._children_yang_names.add("p2mp-ipv4-session")

                        self.udp_ipv4_session = RsvpStandby.RsbBriefs.RsbBrief.Filter.RsvpFilter.UdpIpv4Session()
                        self.udp_ipv4_session.parent = self
                        self._children_name_map["udp_ipv4_session"] = "udp-ipv4-session"
                        self._children_yang_names.add("udp-ipv4-session")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("filter_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.RsbBriefs.RsbBrief.Filter.RsvpFilter, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.RsbBriefs.RsbBrief.Filter.RsvpFilter, self).__setattr__(name, value)


                    class UdpIpv4Session(Entity):
                        """
                        UDP IPV4 FilterSpec
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source_port
                        
                        	Source Port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.RsbBriefs.RsbBrief.Filter.RsvpFilter.UdpIpv4Session, self).__init__()

                            self.yang_name = "udp-ipv4-session"
                            self.yang_parent_name = "rsvp-filter"

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.source_port = YLeaf(YType.uint16, "source-port")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("source_address",
                                            "source_port") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.RsbBriefs.RsbBrief.Filter.RsvpFilter.UdpIpv4Session, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.RsbBriefs.RsbBrief.Filter.RsvpFilter.UdpIpv4Session, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.source_address.is_set or
                                self.source_port.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                self.source_port.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "udp-ipv4-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/rsb-briefs/rsb-brief/filter/rsvp-filter/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())
                            if (self.source_port.is_set or self.source_port.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_port.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "source-address" or name == "source-port"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-port"):
                                self.source_port = value
                                self.source_port.value_namespace = name_space
                                self.source_port.value_namespace_prefix = name_space_prefix


                    class P2MpIpv4Session(Entity):
                        """
                        IPv4 P2MP LSP FilterSpec
                        
                        .. attribute:: p2mp_sub_group_origin
                        
                        	Point to Multipoint SubGroup Origin
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source_port
                        
                        	Source Port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: sub_group_id
                        
                        	Point to Multipoint Subgroup ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.RsbBriefs.RsbBrief.Filter.RsvpFilter.P2MpIpv4Session, self).__init__()

                            self.yang_name = "p2mp-ipv4-session"
                            self.yang_parent_name = "rsvp-filter"

                            self.p2mp_sub_group_origin = YLeaf(YType.str, "p2mp-sub-group-origin")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.source_port = YLeaf(YType.uint16, "source-port")

                            self.sub_group_id = YLeaf(YType.uint16, "sub-group-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("p2mp_sub_group_origin",
                                            "source_address",
                                            "source_port",
                                            "sub_group_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.RsbBriefs.RsbBrief.Filter.RsvpFilter.P2MpIpv4Session, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.RsbBriefs.RsbBrief.Filter.RsvpFilter.P2MpIpv4Session, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.p2mp_sub_group_origin.is_set or
                                self.source_address.is_set or
                                self.source_port.is_set or
                                self.sub_group_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.p2mp_sub_group_origin.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                self.source_port.yfilter != YFilter.not_set or
                                self.sub_group_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "p2mp-ipv4-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/rsb-briefs/rsb-brief/filter/rsvp-filter/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.p2mp_sub_group_origin.is_set or self.p2mp_sub_group_origin.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.p2mp_sub_group_origin.get_name_leafdata())
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())
                            if (self.source_port.is_set or self.source_port.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_port.get_name_leafdata())
                            if (self.sub_group_id.is_set or self.sub_group_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sub_group_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "p2mp-sub-group-origin" or name == "source-address" or name == "source-port" or name == "sub-group-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "p2mp-sub-group-origin"):
                                self.p2mp_sub_group_origin = value
                                self.p2mp_sub_group_origin.value_namespace = name_space
                                self.p2mp_sub_group_origin.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-port"):
                                self.source_port = value
                                self.source_port.value_namespace = name_space
                                self.source_port.value_namespace_prefix = name_space_prefix
                            if(value_path == "sub-group-id"):
                                self.sub_group_id = value
                                self.sub_group_id.value_namespace = name_space
                                self.sub_group_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.filter_type.is_set or
                            (self.p2mp_ipv4_session is not None and self.p2mp_ipv4_session.has_data()) or
                            (self.udp_ipv4_session is not None and self.udp_ipv4_session.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.filter_type.yfilter != YFilter.not_set or
                            (self.p2mp_ipv4_session is not None and self.p2mp_ipv4_session.has_operation()) or
                            (self.udp_ipv4_session is not None and self.udp_ipv4_session.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rsvp-filter" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/rsb-briefs/rsb-brief/filter/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.filter_type.is_set or self.filter_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.filter_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "p2mp-ipv4-session"):
                            if (self.p2mp_ipv4_session is None):
                                self.p2mp_ipv4_session = RsvpStandby.RsbBriefs.RsbBrief.Filter.RsvpFilter.P2MpIpv4Session()
                                self.p2mp_ipv4_session.parent = self
                                self._children_name_map["p2mp_ipv4_session"] = "p2mp-ipv4-session"
                            return self.p2mp_ipv4_session

                        if (child_yang_name == "udp-ipv4-session"):
                            if (self.udp_ipv4_session is None):
                                self.udp_ipv4_session = RsvpStandby.RsbBriefs.RsbBrief.Filter.RsvpFilter.UdpIpv4Session()
                                self.udp_ipv4_session.parent = self
                                self._children_name_map["udp_ipv4_session"] = "udp-ipv4-session"
                            return self.udp_ipv4_session

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "p2mp-ipv4-session" or name == "udp-ipv4-session" or name == "filter-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "filter-type"):
                            self.filter_type = value
                            self.filter_type.value_namespace = name_space
                            self.filter_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (self.rsvp_filter is not None and self.rsvp_filter.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.rsvp_filter is not None and self.rsvp_filter.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "filter" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/rsb-briefs/rsb-brief/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "rsvp-filter"):
                        if (self.rsvp_filter is None):
                            self.rsvp_filter = RsvpStandby.RsbBriefs.RsbBrief.Filter.RsvpFilter()
                            self.rsvp_filter.parent = self
                            self._children_name_map["rsvp_filter"] = "rsvp-filter"
                        return self.rsvp_filter

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "rsvp-filter"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (
                    self.destination_address.is_set or
                    self.destination_port.is_set or
                    self.extended_tunnel_id.is_set or
                    self.input_interface.is_set or
                    self.p2mp_id.is_set or
                    self.protocol.is_set or
                    self.session_type.is_set or
                    self.source_address.is_set or
                    self.source_port.is_set or
                    self.sub_group_id.is_set or
                    self.sub_group_origin.is_set or
                    self.vrf_name.is_set or
                    (self.filter is not None and self.filter.has_data()) or
                    (self.flow_spec is not None and self.flow_spec.has_data()) or
                    (self.generic_flow_spec is not None and self.generic_flow_spec.has_data()) or
                    (self.s2l_sub_lsp is not None and self.s2l_sub_lsp.has_data()) or
                    (self.session is not None and self.session.has_data()) or
                    (self.style is not None and self.style.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.destination_address.yfilter != YFilter.not_set or
                    self.destination_port.yfilter != YFilter.not_set or
                    self.extended_tunnel_id.yfilter != YFilter.not_set or
                    self.input_interface.yfilter != YFilter.not_set or
                    self.p2mp_id.yfilter != YFilter.not_set or
                    self.protocol.yfilter != YFilter.not_set or
                    self.session_type.yfilter != YFilter.not_set or
                    self.source_address.yfilter != YFilter.not_set or
                    self.source_port.yfilter != YFilter.not_set or
                    self.sub_group_id.yfilter != YFilter.not_set or
                    self.sub_group_origin.yfilter != YFilter.not_set or
                    self.vrf_name.yfilter != YFilter.not_set or
                    (self.filter is not None and self.filter.has_operation()) or
                    (self.flow_spec is not None and self.flow_spec.has_operation()) or
                    (self.generic_flow_spec is not None and self.generic_flow_spec.has_operation()) or
                    (self.s2l_sub_lsp is not None and self.s2l_sub_lsp.has_operation()) or
                    (self.session is not None and self.session.has_operation()) or
                    (self.style is not None and self.style.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "rsb-brief" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/rsb-briefs/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_address.get_name_leafdata())
                if (self.destination_port.is_set or self.destination_port.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_port.get_name_leafdata())
                if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                if (self.input_interface.is_set or self.input_interface.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.input_interface.get_name_leafdata())
                if (self.p2mp_id.is_set or self.p2mp_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.p2mp_id.get_name_leafdata())
                if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.protocol.get_name_leafdata())
                if (self.session_type.is_set or self.session_type.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.session_type.get_name_leafdata())
                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_address.get_name_leafdata())
                if (self.source_port.is_set or self.source_port.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_port.get_name_leafdata())
                if (self.sub_group_id.is_set or self.sub_group_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.sub_group_id.get_name_leafdata())
                if (self.sub_group_origin.is_set or self.sub_group_origin.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.sub_group_origin.get_name_leafdata())
                if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.vrf_name.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "filter"):
                    if (self.filter is None):
                        self.filter = RsvpStandby.RsbBriefs.RsbBrief.Filter()
                        self.filter.parent = self
                        self._children_name_map["filter"] = "filter"
                    return self.filter

                if (child_yang_name == "flow-spec"):
                    if (self.flow_spec is None):
                        self.flow_spec = RsvpStandby.RsbBriefs.RsbBrief.FlowSpec()
                        self.flow_spec.parent = self
                        self._children_name_map["flow_spec"] = "flow-spec"
                    return self.flow_spec

                if (child_yang_name == "generic-flow-spec"):
                    if (self.generic_flow_spec is None):
                        self.generic_flow_spec = RsvpStandby.RsbBriefs.RsbBrief.GenericFlowSpec()
                        self.generic_flow_spec.parent = self
                        self._children_name_map["generic_flow_spec"] = "generic-flow-spec"
                    return self.generic_flow_spec

                if (child_yang_name == "s2l-sub-lsp"):
                    if (self.s2l_sub_lsp is None):
                        self.s2l_sub_lsp = RsvpStandby.RsbBriefs.RsbBrief.S2LSubLsp()
                        self.s2l_sub_lsp.parent = self
                        self._children_name_map["s2l_sub_lsp"] = "s2l-sub-lsp"
                    return self.s2l_sub_lsp

                if (child_yang_name == "session"):
                    if (self.session is None):
                        self.session = RsvpStandby.RsbBriefs.RsbBrief.Session()
                        self.session.parent = self
                        self._children_name_map["session"] = "session"
                    return self.session

                if (child_yang_name == "style"):
                    if (self.style is None):
                        self.style = RsvpStandby.RsbBriefs.RsbBrief.Style()
                        self.style.parent = self
                        self._children_name_map["style"] = "style"
                    return self.style

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "filter" or name == "flow-spec" or name == "generic-flow-spec" or name == "s2l-sub-lsp" or name == "session" or name == "style" or name == "destination-address" or name == "destination-port" or name == "extended-tunnel-id" or name == "input-interface" or name == "p2mp-id" or name == "protocol" or name == "session-type" or name == "source-address" or name == "source-port" or name == "sub-group-id" or name == "sub-group-origin" or name == "vrf-name"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "destination-address"):
                    self.destination_address = value
                    self.destination_address.value_namespace = name_space
                    self.destination_address.value_namespace_prefix = name_space_prefix
                if(value_path == "destination-port"):
                    self.destination_port = value
                    self.destination_port.value_namespace = name_space
                    self.destination_port.value_namespace_prefix = name_space_prefix
                if(value_path == "extended-tunnel-id"):
                    self.extended_tunnel_id = value
                    self.extended_tunnel_id.value_namespace = name_space
                    self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                if(value_path == "input-interface"):
                    self.input_interface = value
                    self.input_interface.value_namespace = name_space
                    self.input_interface.value_namespace_prefix = name_space_prefix
                if(value_path == "p2mp-id"):
                    self.p2mp_id = value
                    self.p2mp_id.value_namespace = name_space
                    self.p2mp_id.value_namespace_prefix = name_space_prefix
                if(value_path == "protocol"):
                    self.protocol = value
                    self.protocol.value_namespace = name_space
                    self.protocol.value_namespace_prefix = name_space_prefix
                if(value_path == "session-type"):
                    self.session_type = value
                    self.session_type.value_namespace = name_space
                    self.session_type.value_namespace_prefix = name_space_prefix
                if(value_path == "source-address"):
                    self.source_address = value
                    self.source_address.value_namespace = name_space
                    self.source_address.value_namespace_prefix = name_space_prefix
                if(value_path == "source-port"):
                    self.source_port = value
                    self.source_port.value_namespace = name_space
                    self.source_port.value_namespace_prefix = name_space_prefix
                if(value_path == "sub-group-id"):
                    self.sub_group_id = value
                    self.sub_group_id.value_namespace = name_space
                    self.sub_group_id.value_namespace_prefix = name_space_prefix
                if(value_path == "sub-group-origin"):
                    self.sub_group_origin = value
                    self.sub_group_origin.value_namespace = name_space
                    self.sub_group_origin.value_namespace_prefix = name_space_prefix
                if(value_path == "vrf-name"):
                    self.vrf_name = value
                    self.vrf_name.value_namespace = name_space
                    self.vrf_name.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.rsb_brief:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.rsb_brief:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "rsb-briefs" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "rsb-brief"):
                for c in self.rsb_brief:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = RsvpStandby.RsbBriefs.RsbBrief()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.rsb_brief.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "rsb-brief"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class OpenConfig(Entity):
        """
        OpenConfig info
        
        .. attribute:: global_counters
        
        	Platform wide RSVP statistics and counters
        	**type**\:   :py:class:`GlobalCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.OpenConfig.GlobalCounters>`
        
        .. attribute:: interface_counters
        
        	Table of info about RSVP\-enabled interface counters for OpenConfig
        	**type**\:   :py:class:`InterfaceCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.OpenConfig.InterfaceCounters>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(RsvpStandby.OpenConfig, self).__init__()

            self.yang_name = "open-config"
            self.yang_parent_name = "rsvp-standby"

            self.global_counters = RsvpStandby.OpenConfig.GlobalCounters()
            self.global_counters.parent = self
            self._children_name_map["global_counters"] = "global-counters"
            self._children_yang_names.add("global-counters")

            self.interface_counters = RsvpStandby.OpenConfig.InterfaceCounters()
            self.interface_counters.parent = self
            self._children_name_map["interface_counters"] = "interface-counters"
            self._children_yang_names.add("interface-counters")


        class GlobalCounters(Entity):
            """
            Platform wide RSVP statistics and counters
            
            .. attribute:: in_ack_messages
            
            	Global count of ack messages received
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: in_hello_messages
            
            	Global count of hello messages received
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: in_path_error_messages
            
            	Global count of path error messages received
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: in_path_messages
            
            	Global count of path messages received
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: in_path_tear_messages
            
            	Global count of path tear messages received
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: in_reservation_error_messages
            
            	Global count of reservation error messages received
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: in_reservation_messages
            
            	Global count of reservation messages received
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: in_reservation_tear_messages
            
            	Global count of reservation tear messages received
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: in_srefresh_messages
            
            	Global count of srefresh messages received
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: out_ack_messages
            
            	Global count of ack messages send
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: out_hello_messages
            
            	Global count of hello messages send
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: out_path_error_messages
            
            	Global count of path error messages send
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: out_path_messages
            
            	Global count of path messages send
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: out_path_tear_messages
            
            	Global count of path tear messages send
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: out_reservation_error_messages
            
            	Global count of reservation error messages send
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: out_reservation_messages
            
            	Global count of reservation messages send
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: out_reservation_tear_messages
            
            	Global count of reservation tear messages send
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: out_srefresh_messages
            
            	Global count of srefresh messages send
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: path_timeouts
            
            	Global count of Path Timeouts
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: rate_limited_messages
            
            	Global count of rate limited messages
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: reservation_timeouts
            
            	Global count of reservation timeouts
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(RsvpStandby.OpenConfig.GlobalCounters, self).__init__()

                self.yang_name = "global-counters"
                self.yang_parent_name = "open-config"

                self.in_ack_messages = YLeaf(YType.uint64, "in-ack-messages")

                self.in_hello_messages = YLeaf(YType.uint64, "in-hello-messages")

                self.in_path_error_messages = YLeaf(YType.uint64, "in-path-error-messages")

                self.in_path_messages = YLeaf(YType.uint64, "in-path-messages")

                self.in_path_tear_messages = YLeaf(YType.uint64, "in-path-tear-messages")

                self.in_reservation_error_messages = YLeaf(YType.uint64, "in-reservation-error-messages")

                self.in_reservation_messages = YLeaf(YType.uint64, "in-reservation-messages")

                self.in_reservation_tear_messages = YLeaf(YType.uint64, "in-reservation-tear-messages")

                self.in_srefresh_messages = YLeaf(YType.uint64, "in-srefresh-messages")

                self.out_ack_messages = YLeaf(YType.uint64, "out-ack-messages")

                self.out_hello_messages = YLeaf(YType.uint64, "out-hello-messages")

                self.out_path_error_messages = YLeaf(YType.uint64, "out-path-error-messages")

                self.out_path_messages = YLeaf(YType.uint64, "out-path-messages")

                self.out_path_tear_messages = YLeaf(YType.uint64, "out-path-tear-messages")

                self.out_reservation_error_messages = YLeaf(YType.uint64, "out-reservation-error-messages")

                self.out_reservation_messages = YLeaf(YType.uint64, "out-reservation-messages")

                self.out_reservation_tear_messages = YLeaf(YType.uint64, "out-reservation-tear-messages")

                self.out_srefresh_messages = YLeaf(YType.uint64, "out-srefresh-messages")

                self.path_timeouts = YLeaf(YType.uint64, "path-timeouts")

                self.rate_limited_messages = YLeaf(YType.uint64, "rate-limited-messages")

                self.reservation_timeouts = YLeaf(YType.uint64, "reservation-timeouts")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("in_ack_messages",
                                "in_hello_messages",
                                "in_path_error_messages",
                                "in_path_messages",
                                "in_path_tear_messages",
                                "in_reservation_error_messages",
                                "in_reservation_messages",
                                "in_reservation_tear_messages",
                                "in_srefresh_messages",
                                "out_ack_messages",
                                "out_hello_messages",
                                "out_path_error_messages",
                                "out_path_messages",
                                "out_path_tear_messages",
                                "out_reservation_error_messages",
                                "out_reservation_messages",
                                "out_reservation_tear_messages",
                                "out_srefresh_messages",
                                "path_timeouts",
                                "rate_limited_messages",
                                "reservation_timeouts") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(RsvpStandby.OpenConfig.GlobalCounters, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(RsvpStandby.OpenConfig.GlobalCounters, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.in_ack_messages.is_set or
                    self.in_hello_messages.is_set or
                    self.in_path_error_messages.is_set or
                    self.in_path_messages.is_set or
                    self.in_path_tear_messages.is_set or
                    self.in_reservation_error_messages.is_set or
                    self.in_reservation_messages.is_set or
                    self.in_reservation_tear_messages.is_set or
                    self.in_srefresh_messages.is_set or
                    self.out_ack_messages.is_set or
                    self.out_hello_messages.is_set or
                    self.out_path_error_messages.is_set or
                    self.out_path_messages.is_set or
                    self.out_path_tear_messages.is_set or
                    self.out_reservation_error_messages.is_set or
                    self.out_reservation_messages.is_set or
                    self.out_reservation_tear_messages.is_set or
                    self.out_srefresh_messages.is_set or
                    self.path_timeouts.is_set or
                    self.rate_limited_messages.is_set or
                    self.reservation_timeouts.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.in_ack_messages.yfilter != YFilter.not_set or
                    self.in_hello_messages.yfilter != YFilter.not_set or
                    self.in_path_error_messages.yfilter != YFilter.not_set or
                    self.in_path_messages.yfilter != YFilter.not_set or
                    self.in_path_tear_messages.yfilter != YFilter.not_set or
                    self.in_reservation_error_messages.yfilter != YFilter.not_set or
                    self.in_reservation_messages.yfilter != YFilter.not_set or
                    self.in_reservation_tear_messages.yfilter != YFilter.not_set or
                    self.in_srefresh_messages.yfilter != YFilter.not_set or
                    self.out_ack_messages.yfilter != YFilter.not_set or
                    self.out_hello_messages.yfilter != YFilter.not_set or
                    self.out_path_error_messages.yfilter != YFilter.not_set or
                    self.out_path_messages.yfilter != YFilter.not_set or
                    self.out_path_tear_messages.yfilter != YFilter.not_set or
                    self.out_reservation_error_messages.yfilter != YFilter.not_set or
                    self.out_reservation_messages.yfilter != YFilter.not_set or
                    self.out_reservation_tear_messages.yfilter != YFilter.not_set or
                    self.out_srefresh_messages.yfilter != YFilter.not_set or
                    self.path_timeouts.yfilter != YFilter.not_set or
                    self.rate_limited_messages.yfilter != YFilter.not_set or
                    self.reservation_timeouts.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "global-counters" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/open-config/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.in_ack_messages.is_set or self.in_ack_messages.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.in_ack_messages.get_name_leafdata())
                if (self.in_hello_messages.is_set or self.in_hello_messages.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.in_hello_messages.get_name_leafdata())
                if (self.in_path_error_messages.is_set or self.in_path_error_messages.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.in_path_error_messages.get_name_leafdata())
                if (self.in_path_messages.is_set or self.in_path_messages.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.in_path_messages.get_name_leafdata())
                if (self.in_path_tear_messages.is_set or self.in_path_tear_messages.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.in_path_tear_messages.get_name_leafdata())
                if (self.in_reservation_error_messages.is_set or self.in_reservation_error_messages.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.in_reservation_error_messages.get_name_leafdata())
                if (self.in_reservation_messages.is_set or self.in_reservation_messages.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.in_reservation_messages.get_name_leafdata())
                if (self.in_reservation_tear_messages.is_set or self.in_reservation_tear_messages.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.in_reservation_tear_messages.get_name_leafdata())
                if (self.in_srefresh_messages.is_set or self.in_srefresh_messages.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.in_srefresh_messages.get_name_leafdata())
                if (self.out_ack_messages.is_set or self.out_ack_messages.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.out_ack_messages.get_name_leafdata())
                if (self.out_hello_messages.is_set or self.out_hello_messages.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.out_hello_messages.get_name_leafdata())
                if (self.out_path_error_messages.is_set or self.out_path_error_messages.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.out_path_error_messages.get_name_leafdata())
                if (self.out_path_messages.is_set or self.out_path_messages.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.out_path_messages.get_name_leafdata())
                if (self.out_path_tear_messages.is_set or self.out_path_tear_messages.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.out_path_tear_messages.get_name_leafdata())
                if (self.out_reservation_error_messages.is_set or self.out_reservation_error_messages.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.out_reservation_error_messages.get_name_leafdata())
                if (self.out_reservation_messages.is_set or self.out_reservation_messages.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.out_reservation_messages.get_name_leafdata())
                if (self.out_reservation_tear_messages.is_set or self.out_reservation_tear_messages.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.out_reservation_tear_messages.get_name_leafdata())
                if (self.out_srefresh_messages.is_set or self.out_srefresh_messages.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.out_srefresh_messages.get_name_leafdata())
                if (self.path_timeouts.is_set or self.path_timeouts.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.path_timeouts.get_name_leafdata())
                if (self.rate_limited_messages.is_set or self.rate_limited_messages.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.rate_limited_messages.get_name_leafdata())
                if (self.reservation_timeouts.is_set or self.reservation_timeouts.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.reservation_timeouts.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "in-ack-messages" or name == "in-hello-messages" or name == "in-path-error-messages" or name == "in-path-messages" or name == "in-path-tear-messages" or name == "in-reservation-error-messages" or name == "in-reservation-messages" or name == "in-reservation-tear-messages" or name == "in-srefresh-messages" or name == "out-ack-messages" or name == "out-hello-messages" or name == "out-path-error-messages" or name == "out-path-messages" or name == "out-path-tear-messages" or name == "out-reservation-error-messages" or name == "out-reservation-messages" or name == "out-reservation-tear-messages" or name == "out-srefresh-messages" or name == "path-timeouts" or name == "rate-limited-messages" or name == "reservation-timeouts"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "in-ack-messages"):
                    self.in_ack_messages = value
                    self.in_ack_messages.value_namespace = name_space
                    self.in_ack_messages.value_namespace_prefix = name_space_prefix
                if(value_path == "in-hello-messages"):
                    self.in_hello_messages = value
                    self.in_hello_messages.value_namespace = name_space
                    self.in_hello_messages.value_namespace_prefix = name_space_prefix
                if(value_path == "in-path-error-messages"):
                    self.in_path_error_messages = value
                    self.in_path_error_messages.value_namespace = name_space
                    self.in_path_error_messages.value_namespace_prefix = name_space_prefix
                if(value_path == "in-path-messages"):
                    self.in_path_messages = value
                    self.in_path_messages.value_namespace = name_space
                    self.in_path_messages.value_namespace_prefix = name_space_prefix
                if(value_path == "in-path-tear-messages"):
                    self.in_path_tear_messages = value
                    self.in_path_tear_messages.value_namespace = name_space
                    self.in_path_tear_messages.value_namespace_prefix = name_space_prefix
                if(value_path == "in-reservation-error-messages"):
                    self.in_reservation_error_messages = value
                    self.in_reservation_error_messages.value_namespace = name_space
                    self.in_reservation_error_messages.value_namespace_prefix = name_space_prefix
                if(value_path == "in-reservation-messages"):
                    self.in_reservation_messages = value
                    self.in_reservation_messages.value_namespace = name_space
                    self.in_reservation_messages.value_namespace_prefix = name_space_prefix
                if(value_path == "in-reservation-tear-messages"):
                    self.in_reservation_tear_messages = value
                    self.in_reservation_tear_messages.value_namespace = name_space
                    self.in_reservation_tear_messages.value_namespace_prefix = name_space_prefix
                if(value_path == "in-srefresh-messages"):
                    self.in_srefresh_messages = value
                    self.in_srefresh_messages.value_namespace = name_space
                    self.in_srefresh_messages.value_namespace_prefix = name_space_prefix
                if(value_path == "out-ack-messages"):
                    self.out_ack_messages = value
                    self.out_ack_messages.value_namespace = name_space
                    self.out_ack_messages.value_namespace_prefix = name_space_prefix
                if(value_path == "out-hello-messages"):
                    self.out_hello_messages = value
                    self.out_hello_messages.value_namespace = name_space
                    self.out_hello_messages.value_namespace_prefix = name_space_prefix
                if(value_path == "out-path-error-messages"):
                    self.out_path_error_messages = value
                    self.out_path_error_messages.value_namespace = name_space
                    self.out_path_error_messages.value_namespace_prefix = name_space_prefix
                if(value_path == "out-path-messages"):
                    self.out_path_messages = value
                    self.out_path_messages.value_namespace = name_space
                    self.out_path_messages.value_namespace_prefix = name_space_prefix
                if(value_path == "out-path-tear-messages"):
                    self.out_path_tear_messages = value
                    self.out_path_tear_messages.value_namespace = name_space
                    self.out_path_tear_messages.value_namespace_prefix = name_space_prefix
                if(value_path == "out-reservation-error-messages"):
                    self.out_reservation_error_messages = value
                    self.out_reservation_error_messages.value_namespace = name_space
                    self.out_reservation_error_messages.value_namespace_prefix = name_space_prefix
                if(value_path == "out-reservation-messages"):
                    self.out_reservation_messages = value
                    self.out_reservation_messages.value_namespace = name_space
                    self.out_reservation_messages.value_namespace_prefix = name_space_prefix
                if(value_path == "out-reservation-tear-messages"):
                    self.out_reservation_tear_messages = value
                    self.out_reservation_tear_messages.value_namespace = name_space
                    self.out_reservation_tear_messages.value_namespace_prefix = name_space_prefix
                if(value_path == "out-srefresh-messages"):
                    self.out_srefresh_messages = value
                    self.out_srefresh_messages.value_namespace = name_space
                    self.out_srefresh_messages.value_namespace_prefix = name_space_prefix
                if(value_path == "path-timeouts"):
                    self.path_timeouts = value
                    self.path_timeouts.value_namespace = name_space
                    self.path_timeouts.value_namespace_prefix = name_space_prefix
                if(value_path == "rate-limited-messages"):
                    self.rate_limited_messages = value
                    self.rate_limited_messages.value_namespace = name_space
                    self.rate_limited_messages.value_namespace_prefix = name_space_prefix
                if(value_path == "reservation-timeouts"):
                    self.reservation_timeouts = value
                    self.reservation_timeouts.value_namespace = name_space
                    self.reservation_timeouts.value_namespace_prefix = name_space_prefix


        class InterfaceCounters(Entity):
            """
            Table of info about RSVP\-enabled interface
            counters for OpenConfig
            
            .. attribute:: interface_counter
            
            	Info about an RSVP\-enabled interface counters
            	**type**\: list of    :py:class:`InterfaceCounter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.OpenConfig.InterfaceCounters.InterfaceCounter>`
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(RsvpStandby.OpenConfig.InterfaceCounters, self).__init__()

                self.yang_name = "interface-counters"
                self.yang_parent_name = "open-config"

                self.interface_counter = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(RsvpStandby.OpenConfig.InterfaceCounters, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(RsvpStandby.OpenConfig.InterfaceCounters, self).__setattr__(name, value)


            class InterfaceCounter(Entity):
                """
                Info about an RSVP\-enabled interface counters
                
                .. attribute:: interface_name  <key>
                
                	Interface name
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: in_ack_messages
                
                	Per interface count of ack messages received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: in_hello_messages
                
                	Per interface count of hello messages received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: in_path_error_messages
                
                	Per interface count of path error messages received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: in_path_messages
                
                	Per interface count of path messages received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: in_path_tear_messages
                
                	Per interface count of path tear messages received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: in_reservation_error_messages
                
                	Per interface count of reservation error messages received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: in_reservation_messages
                
                	Per interface count of reservation messages received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: in_reservation_tear_messages
                
                	Per interface count of reservation tear messages received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: in_srefresh_messages
                
                	Per interface count of srefresh messages received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: interface_name_xr
                
                	Interface name
                	**type**\:  str
                
                .. attribute:: out_ack_messages
                
                	Per interface count of ack messages send
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: out_hello_messages
                
                	Per interface count of hello messages send
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: out_path_error_messages
                
                	Per interface count of path error messages send
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: out_path_messages
                
                	Per interface count of path messages send
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: out_path_tear_messages
                
                	Per interface count of path tear messages send
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: out_reservation_error_messages
                
                	Per interface count of reservation error messages send
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: out_reservation_messages
                
                	Per interface count of reservation messages send
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: out_reservation_tear_messages
                
                	Per interface count of reservation tear messages send
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: out_srefresh_messages
                
                	Per interface count of srefresh messages send
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.OpenConfig.InterfaceCounters.InterfaceCounter, self).__init__()

                    self.yang_name = "interface-counter"
                    self.yang_parent_name = "interface-counters"

                    self.interface_name = YLeaf(YType.str, "interface-name")

                    self.in_ack_messages = YLeaf(YType.uint64, "in-ack-messages")

                    self.in_hello_messages = YLeaf(YType.uint64, "in-hello-messages")

                    self.in_path_error_messages = YLeaf(YType.uint64, "in-path-error-messages")

                    self.in_path_messages = YLeaf(YType.uint64, "in-path-messages")

                    self.in_path_tear_messages = YLeaf(YType.uint64, "in-path-tear-messages")

                    self.in_reservation_error_messages = YLeaf(YType.uint64, "in-reservation-error-messages")

                    self.in_reservation_messages = YLeaf(YType.uint64, "in-reservation-messages")

                    self.in_reservation_tear_messages = YLeaf(YType.uint64, "in-reservation-tear-messages")

                    self.in_srefresh_messages = YLeaf(YType.uint64, "in-srefresh-messages")

                    self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                    self.out_ack_messages = YLeaf(YType.uint64, "out-ack-messages")

                    self.out_hello_messages = YLeaf(YType.uint64, "out-hello-messages")

                    self.out_path_error_messages = YLeaf(YType.uint64, "out-path-error-messages")

                    self.out_path_messages = YLeaf(YType.uint64, "out-path-messages")

                    self.out_path_tear_messages = YLeaf(YType.uint64, "out-path-tear-messages")

                    self.out_reservation_error_messages = YLeaf(YType.uint64, "out-reservation-error-messages")

                    self.out_reservation_messages = YLeaf(YType.uint64, "out-reservation-messages")

                    self.out_reservation_tear_messages = YLeaf(YType.uint64, "out-reservation-tear-messages")

                    self.out_srefresh_messages = YLeaf(YType.uint64, "out-srefresh-messages")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("interface_name",
                                    "in_ack_messages",
                                    "in_hello_messages",
                                    "in_path_error_messages",
                                    "in_path_messages",
                                    "in_path_tear_messages",
                                    "in_reservation_error_messages",
                                    "in_reservation_messages",
                                    "in_reservation_tear_messages",
                                    "in_srefresh_messages",
                                    "interface_name_xr",
                                    "out_ack_messages",
                                    "out_hello_messages",
                                    "out_path_error_messages",
                                    "out_path_messages",
                                    "out_path_tear_messages",
                                    "out_reservation_error_messages",
                                    "out_reservation_messages",
                                    "out_reservation_tear_messages",
                                    "out_srefresh_messages") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.OpenConfig.InterfaceCounters.InterfaceCounter, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.OpenConfig.InterfaceCounters.InterfaceCounter, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.interface_name.is_set or
                        self.in_ack_messages.is_set or
                        self.in_hello_messages.is_set or
                        self.in_path_error_messages.is_set or
                        self.in_path_messages.is_set or
                        self.in_path_tear_messages.is_set or
                        self.in_reservation_error_messages.is_set or
                        self.in_reservation_messages.is_set or
                        self.in_reservation_tear_messages.is_set or
                        self.in_srefresh_messages.is_set or
                        self.interface_name_xr.is_set or
                        self.out_ack_messages.is_set or
                        self.out_hello_messages.is_set or
                        self.out_path_error_messages.is_set or
                        self.out_path_messages.is_set or
                        self.out_path_tear_messages.is_set or
                        self.out_reservation_error_messages.is_set or
                        self.out_reservation_messages.is_set or
                        self.out_reservation_tear_messages.is_set or
                        self.out_srefresh_messages.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.interface_name.yfilter != YFilter.not_set or
                        self.in_ack_messages.yfilter != YFilter.not_set or
                        self.in_hello_messages.yfilter != YFilter.not_set or
                        self.in_path_error_messages.yfilter != YFilter.not_set or
                        self.in_path_messages.yfilter != YFilter.not_set or
                        self.in_path_tear_messages.yfilter != YFilter.not_set or
                        self.in_reservation_error_messages.yfilter != YFilter.not_set or
                        self.in_reservation_messages.yfilter != YFilter.not_set or
                        self.in_reservation_tear_messages.yfilter != YFilter.not_set or
                        self.in_srefresh_messages.yfilter != YFilter.not_set or
                        self.interface_name_xr.yfilter != YFilter.not_set or
                        self.out_ack_messages.yfilter != YFilter.not_set or
                        self.out_hello_messages.yfilter != YFilter.not_set or
                        self.out_path_error_messages.yfilter != YFilter.not_set or
                        self.out_path_messages.yfilter != YFilter.not_set or
                        self.out_path_tear_messages.yfilter != YFilter.not_set or
                        self.out_reservation_error_messages.yfilter != YFilter.not_set or
                        self.out_reservation_messages.yfilter != YFilter.not_set or
                        self.out_reservation_tear_messages.yfilter != YFilter.not_set or
                        self.out_srefresh_messages.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "interface-counter" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/open-config/interface-counters/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                    if (self.in_ack_messages.is_set or self.in_ack_messages.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_ack_messages.get_name_leafdata())
                    if (self.in_hello_messages.is_set or self.in_hello_messages.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_hello_messages.get_name_leafdata())
                    if (self.in_path_error_messages.is_set or self.in_path_error_messages.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_path_error_messages.get_name_leafdata())
                    if (self.in_path_messages.is_set or self.in_path_messages.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_path_messages.get_name_leafdata())
                    if (self.in_path_tear_messages.is_set or self.in_path_tear_messages.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_path_tear_messages.get_name_leafdata())
                    if (self.in_reservation_error_messages.is_set or self.in_reservation_error_messages.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_reservation_error_messages.get_name_leafdata())
                    if (self.in_reservation_messages.is_set or self.in_reservation_messages.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_reservation_messages.get_name_leafdata())
                    if (self.in_reservation_tear_messages.is_set or self.in_reservation_tear_messages.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_reservation_tear_messages.get_name_leafdata())
                    if (self.in_srefresh_messages.is_set or self.in_srefresh_messages.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_srefresh_messages.get_name_leafdata())
                    if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                    if (self.out_ack_messages.is_set or self.out_ack_messages.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.out_ack_messages.get_name_leafdata())
                    if (self.out_hello_messages.is_set or self.out_hello_messages.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.out_hello_messages.get_name_leafdata())
                    if (self.out_path_error_messages.is_set or self.out_path_error_messages.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.out_path_error_messages.get_name_leafdata())
                    if (self.out_path_messages.is_set or self.out_path_messages.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.out_path_messages.get_name_leafdata())
                    if (self.out_path_tear_messages.is_set or self.out_path_tear_messages.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.out_path_tear_messages.get_name_leafdata())
                    if (self.out_reservation_error_messages.is_set or self.out_reservation_error_messages.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.out_reservation_error_messages.get_name_leafdata())
                    if (self.out_reservation_messages.is_set or self.out_reservation_messages.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.out_reservation_messages.get_name_leafdata())
                    if (self.out_reservation_tear_messages.is_set or self.out_reservation_tear_messages.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.out_reservation_tear_messages.get_name_leafdata())
                    if (self.out_srefresh_messages.is_set or self.out_srefresh_messages.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.out_srefresh_messages.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface-name" or name == "in-ack-messages" or name == "in-hello-messages" or name == "in-path-error-messages" or name == "in-path-messages" or name == "in-path-tear-messages" or name == "in-reservation-error-messages" or name == "in-reservation-messages" or name == "in-reservation-tear-messages" or name == "in-srefresh-messages" or name == "interface-name-xr" or name == "out-ack-messages" or name == "out-hello-messages" or name == "out-path-error-messages" or name == "out-path-messages" or name == "out-path-tear-messages" or name == "out-reservation-error-messages" or name == "out-reservation-messages" or name == "out-reservation-tear-messages" or name == "out-srefresh-messages"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "interface-name"):
                        self.interface_name = value
                        self.interface_name.value_namespace = name_space
                        self.interface_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "in-ack-messages"):
                        self.in_ack_messages = value
                        self.in_ack_messages.value_namespace = name_space
                        self.in_ack_messages.value_namespace_prefix = name_space_prefix
                    if(value_path == "in-hello-messages"):
                        self.in_hello_messages = value
                        self.in_hello_messages.value_namespace = name_space
                        self.in_hello_messages.value_namespace_prefix = name_space_prefix
                    if(value_path == "in-path-error-messages"):
                        self.in_path_error_messages = value
                        self.in_path_error_messages.value_namespace = name_space
                        self.in_path_error_messages.value_namespace_prefix = name_space_prefix
                    if(value_path == "in-path-messages"):
                        self.in_path_messages = value
                        self.in_path_messages.value_namespace = name_space
                        self.in_path_messages.value_namespace_prefix = name_space_prefix
                    if(value_path == "in-path-tear-messages"):
                        self.in_path_tear_messages = value
                        self.in_path_tear_messages.value_namespace = name_space
                        self.in_path_tear_messages.value_namespace_prefix = name_space_prefix
                    if(value_path == "in-reservation-error-messages"):
                        self.in_reservation_error_messages = value
                        self.in_reservation_error_messages.value_namespace = name_space
                        self.in_reservation_error_messages.value_namespace_prefix = name_space_prefix
                    if(value_path == "in-reservation-messages"):
                        self.in_reservation_messages = value
                        self.in_reservation_messages.value_namespace = name_space
                        self.in_reservation_messages.value_namespace_prefix = name_space_prefix
                    if(value_path == "in-reservation-tear-messages"):
                        self.in_reservation_tear_messages = value
                        self.in_reservation_tear_messages.value_namespace = name_space
                        self.in_reservation_tear_messages.value_namespace_prefix = name_space_prefix
                    if(value_path == "in-srefresh-messages"):
                        self.in_srefresh_messages = value
                        self.in_srefresh_messages.value_namespace = name_space
                        self.in_srefresh_messages.value_namespace_prefix = name_space_prefix
                    if(value_path == "interface-name-xr"):
                        self.interface_name_xr = value
                        self.interface_name_xr.value_namespace = name_space
                        self.interface_name_xr.value_namespace_prefix = name_space_prefix
                    if(value_path == "out-ack-messages"):
                        self.out_ack_messages = value
                        self.out_ack_messages.value_namespace = name_space
                        self.out_ack_messages.value_namespace_prefix = name_space_prefix
                    if(value_path == "out-hello-messages"):
                        self.out_hello_messages = value
                        self.out_hello_messages.value_namespace = name_space
                        self.out_hello_messages.value_namespace_prefix = name_space_prefix
                    if(value_path == "out-path-error-messages"):
                        self.out_path_error_messages = value
                        self.out_path_error_messages.value_namespace = name_space
                        self.out_path_error_messages.value_namespace_prefix = name_space_prefix
                    if(value_path == "out-path-messages"):
                        self.out_path_messages = value
                        self.out_path_messages.value_namespace = name_space
                        self.out_path_messages.value_namespace_prefix = name_space_prefix
                    if(value_path == "out-path-tear-messages"):
                        self.out_path_tear_messages = value
                        self.out_path_tear_messages.value_namespace = name_space
                        self.out_path_tear_messages.value_namespace_prefix = name_space_prefix
                    if(value_path == "out-reservation-error-messages"):
                        self.out_reservation_error_messages = value
                        self.out_reservation_error_messages.value_namespace = name_space
                        self.out_reservation_error_messages.value_namespace_prefix = name_space_prefix
                    if(value_path == "out-reservation-messages"):
                        self.out_reservation_messages = value
                        self.out_reservation_messages.value_namespace = name_space
                        self.out_reservation_messages.value_namespace_prefix = name_space_prefix
                    if(value_path == "out-reservation-tear-messages"):
                        self.out_reservation_tear_messages = value
                        self.out_reservation_tear_messages.value_namespace = name_space
                        self.out_reservation_tear_messages.value_namespace_prefix = name_space_prefix
                    if(value_path == "out-srefresh-messages"):
                        self.out_srefresh_messages = value
                        self.out_srefresh_messages.value_namespace = name_space
                        self.out_srefresh_messages.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.interface_counter:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.interface_counter:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "interface-counters" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/open-config/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "interface-counter"):
                    for c in self.interface_counter:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = RsvpStandby.OpenConfig.InterfaceCounters.InterfaceCounter()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.interface_counter.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "interface-counter"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass

        def has_data(self):
            return (
                (self.global_counters is not None and self.global_counters.has_data()) or
                (self.interface_counters is not None and self.interface_counters.has_data()))

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.global_counters is not None and self.global_counters.has_operation()) or
                (self.interface_counters is not None and self.interface_counters.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "open-config" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "global-counters"):
                if (self.global_counters is None):
                    self.global_counters = RsvpStandby.OpenConfig.GlobalCounters()
                    self.global_counters.parent = self
                    self._children_name_map["global_counters"] = "global-counters"
                return self.global_counters

            if (child_yang_name == "interface-counters"):
                if (self.interface_counters is None):
                    self.interface_counters = RsvpStandby.OpenConfig.InterfaceCounters()
                    self.interface_counters.parent = self
                    self._children_name_map["interface_counters"] = "interface-counters"
                return self.interface_counters

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "global-counters" or name == "interface-counters"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class Counters(Entity):
        """
        Counters
        
        .. attribute:: database
        
        	Summary information for all RSVP database counters
        	**type**\:   :py:class:`Database <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Counters.Database>`
        
        .. attribute:: event_syncs
        
        	Table containing event sync counters
        	**type**\:   :py:class:`EventSyncs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Counters.EventSyncs>`
        
        .. attribute:: interface_events
        
        	Event counters
        	**type**\:   :py:class:`InterfaceEvents <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Counters.InterfaceEvents>`
        
        .. attribute:: interface_messages
        
        	Table of message counters
        	**type**\:   :py:class:`InterfaceMessages <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Counters.InterfaceMessages>`
        
        .. attribute:: issu
        
        	Summary information for all RSVP ISSU counters
        	**type**\:   :py:class:`Issu <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Counters.Issu>`
        
        .. attribute:: message_summary
        
        	Summary information for all RSVP message counters
        	**type**\:   :py:class:`MessageSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Counters.MessageSummary>`
        
        .. attribute:: nsr
        
        	Summary information for all RSVP NSR counters
        	**type**\:   :py:class:`Nsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Counters.Nsr>`
        
        .. attribute:: out_of_resource
        
        	Out of resource counters
        	**type**\:   :py:class:`OutOfResource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Counters.OutOfResource>`
        
        .. attribute:: prefix_filtering
        
        	Prefix filtering counters
        	**type**\:   :py:class:`PrefixFiltering <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Counters.PrefixFiltering>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(RsvpStandby.Counters, self).__init__()

            self.yang_name = "counters"
            self.yang_parent_name = "rsvp-standby"

            self.database = RsvpStandby.Counters.Database()
            self.database.parent = self
            self._children_name_map["database"] = "database"
            self._children_yang_names.add("database")

            self.event_syncs = RsvpStandby.Counters.EventSyncs()
            self.event_syncs.parent = self
            self._children_name_map["event_syncs"] = "event-syncs"
            self._children_yang_names.add("event-syncs")

            self.interface_events = RsvpStandby.Counters.InterfaceEvents()
            self.interface_events.parent = self
            self._children_name_map["interface_events"] = "interface-events"
            self._children_yang_names.add("interface-events")

            self.interface_messages = RsvpStandby.Counters.InterfaceMessages()
            self.interface_messages.parent = self
            self._children_name_map["interface_messages"] = "interface-messages"
            self._children_yang_names.add("interface-messages")

            self.issu = RsvpStandby.Counters.Issu()
            self.issu.parent = self
            self._children_name_map["issu"] = "issu"
            self._children_yang_names.add("issu")

            self.message_summary = RsvpStandby.Counters.MessageSummary()
            self.message_summary.parent = self
            self._children_name_map["message_summary"] = "message-summary"
            self._children_yang_names.add("message-summary")

            self.nsr = RsvpStandby.Counters.Nsr()
            self.nsr.parent = self
            self._children_name_map["nsr"] = "nsr"
            self._children_yang_names.add("nsr")

            self.out_of_resource = RsvpStandby.Counters.OutOfResource()
            self.out_of_resource.parent = self
            self._children_name_map["out_of_resource"] = "out-of-resource"
            self._children_yang_names.add("out-of-resource")

            self.prefix_filtering = RsvpStandby.Counters.PrefixFiltering()
            self.prefix_filtering.parent = self
            self._children_name_map["prefix_filtering"] = "prefix-filtering"
            self._children_yang_names.add("prefix-filtering")


        class InterfaceMessages(Entity):
            """
            Table of message counters
            
            .. attribute:: interface_message
            
            	Interface message counters
            	**type**\: list of    :py:class:`InterfaceMessage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Counters.InterfaceMessages.InterfaceMessage>`
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(RsvpStandby.Counters.InterfaceMessages, self).__init__()

                self.yang_name = "interface-messages"
                self.yang_parent_name = "counters"

                self.interface_message = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(RsvpStandby.Counters.InterfaceMessages, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(RsvpStandby.Counters.InterfaceMessages, self).__setattr__(name, value)


            class InterfaceMessage(Entity):
                """
                Interface message counters
                
                .. attribute:: interface_name  <key>
                
                	Interface Name. 'None' is used internally where the true interface is unknown (e.g. for routed packets)
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: bundle_received_messages
                
                	Count of Bundle messages received
                	**type**\:   :py:class:`BundleReceivedMessages <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Counters.InterfaceMessages.InterfaceMessage.BundleReceivedMessages>`
                
                .. attribute:: bundle_transmitted_messages
                
                	Count of Bundle messages transmitted
                	**type**\:   :py:class:`BundleTransmittedMessages <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Counters.InterfaceMessages.InterfaceMessage.BundleTransmittedMessages>`
                
                .. attribute:: out_of_order_messages
                
                	Count of Out of Order messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rate_limited_messages
                
                	Count of Rate Limited messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: received_messages
                
                	Count of messages received
                	**type**\:   :py:class:`ReceivedMessages <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Counters.InterfaceMessages.InterfaceMessage.ReceivedMessages>`
                
                .. attribute:: retransmitted_messages
                
                	Count of messages retransmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: transmitted_messages
                
                	Count of messages transmitted
                	**type**\:   :py:class:`TransmittedMessages <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Counters.InterfaceMessages.InterfaceMessage.TransmittedMessages>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.Counters.InterfaceMessages.InterfaceMessage, self).__init__()

                    self.yang_name = "interface-message"
                    self.yang_parent_name = "interface-messages"

                    self.interface_name = YLeaf(YType.str, "interface-name")

                    self.out_of_order_messages = YLeaf(YType.uint32, "out-of-order-messages")

                    self.rate_limited_messages = YLeaf(YType.uint32, "rate-limited-messages")

                    self.retransmitted_messages = YLeaf(YType.uint32, "retransmitted-messages")

                    self.bundle_received_messages = RsvpStandby.Counters.InterfaceMessages.InterfaceMessage.BundleReceivedMessages()
                    self.bundle_received_messages.parent = self
                    self._children_name_map["bundle_received_messages"] = "bundle-received-messages"
                    self._children_yang_names.add("bundle-received-messages")

                    self.bundle_transmitted_messages = RsvpStandby.Counters.InterfaceMessages.InterfaceMessage.BundleTransmittedMessages()
                    self.bundle_transmitted_messages.parent = self
                    self._children_name_map["bundle_transmitted_messages"] = "bundle-transmitted-messages"
                    self._children_yang_names.add("bundle-transmitted-messages")

                    self.received_messages = RsvpStandby.Counters.InterfaceMessages.InterfaceMessage.ReceivedMessages()
                    self.received_messages.parent = self
                    self._children_name_map["received_messages"] = "received-messages"
                    self._children_yang_names.add("received-messages")

                    self.transmitted_messages = RsvpStandby.Counters.InterfaceMessages.InterfaceMessage.TransmittedMessages()
                    self.transmitted_messages.parent = self
                    self._children_name_map["transmitted_messages"] = "transmitted-messages"
                    self._children_yang_names.add("transmitted-messages")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("interface_name",
                                    "out_of_order_messages",
                                    "rate_limited_messages",
                                    "retransmitted_messages") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.Counters.InterfaceMessages.InterfaceMessage, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.Counters.InterfaceMessages.InterfaceMessage, self).__setattr__(name, value)


                class ReceivedMessages(Entity):
                    """
                    Count of messages received
                    
                    .. attribute:: ack
                    
                    	Count of ACK messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bundle
                    
                    	Count of Bundle messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: challenge
                    
                    	Count of Integrity Challenge messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello
                    
                    	Count of Hello messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: path
                    
                    	Count of Path messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: path_error
                    
                    	Count of PathError messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: path_tear
                    
                    	Count of PathTear messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: reservation
                    
                    	Count of Reservation messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: reservation_confirm
                    
                    	Count of ReservationConfirm messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: reservation_error
                    
                    	Count of ReservationError messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: reservation_tear
                    
                    	Count of ReservationTear messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: response
                    
                    	Count of Integrity Response messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: srefresh
                    
                    	Count of Srefresh messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.Counters.InterfaceMessages.InterfaceMessage.ReceivedMessages, self).__init__()

                        self.yang_name = "received-messages"
                        self.yang_parent_name = "interface-message"

                        self.ack = YLeaf(YType.uint32, "ack")

                        self.bundle = YLeaf(YType.uint32, "bundle")

                        self.challenge = YLeaf(YType.uint32, "challenge")

                        self.hello = YLeaf(YType.uint32, "hello")

                        self.path = YLeaf(YType.uint32, "path")

                        self.path_error = YLeaf(YType.uint32, "path-error")

                        self.path_tear = YLeaf(YType.uint32, "path-tear")

                        self.reservation = YLeaf(YType.uint32, "reservation")

                        self.reservation_confirm = YLeaf(YType.uint32, "reservation-confirm")

                        self.reservation_error = YLeaf(YType.uint32, "reservation-error")

                        self.reservation_tear = YLeaf(YType.uint32, "reservation-tear")

                        self.response = YLeaf(YType.uint32, "response")

                        self.srefresh = YLeaf(YType.uint32, "srefresh")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("ack",
                                        "bundle",
                                        "challenge",
                                        "hello",
                                        "path",
                                        "path_error",
                                        "path_tear",
                                        "reservation",
                                        "reservation_confirm",
                                        "reservation_error",
                                        "reservation_tear",
                                        "response",
                                        "srefresh") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.Counters.InterfaceMessages.InterfaceMessage.ReceivedMessages, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.Counters.InterfaceMessages.InterfaceMessage.ReceivedMessages, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.ack.is_set or
                            self.bundle.is_set or
                            self.challenge.is_set or
                            self.hello.is_set or
                            self.path.is_set or
                            self.path_error.is_set or
                            self.path_tear.is_set or
                            self.reservation.is_set or
                            self.reservation_confirm.is_set or
                            self.reservation_error.is_set or
                            self.reservation_tear.is_set or
                            self.response.is_set or
                            self.srefresh.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.ack.yfilter != YFilter.not_set or
                            self.bundle.yfilter != YFilter.not_set or
                            self.challenge.yfilter != YFilter.not_set or
                            self.hello.yfilter != YFilter.not_set or
                            self.path.yfilter != YFilter.not_set or
                            self.path_error.yfilter != YFilter.not_set or
                            self.path_tear.yfilter != YFilter.not_set or
                            self.reservation.yfilter != YFilter.not_set or
                            self.reservation_confirm.yfilter != YFilter.not_set or
                            self.reservation_error.yfilter != YFilter.not_set or
                            self.reservation_tear.yfilter != YFilter.not_set or
                            self.response.yfilter != YFilter.not_set or
                            self.srefresh.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "received-messages" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.ack.is_set or self.ack.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ack.get_name_leafdata())
                        if (self.bundle.is_set or self.bundle.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bundle.get_name_leafdata())
                        if (self.challenge.is_set or self.challenge.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.challenge.get_name_leafdata())
                        if (self.hello.is_set or self.hello.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.hello.get_name_leafdata())
                        if (self.path.is_set or self.path.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.path.get_name_leafdata())
                        if (self.path_error.is_set or self.path_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.path_error.get_name_leafdata())
                        if (self.path_tear.is_set or self.path_tear.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.path_tear.get_name_leafdata())
                        if (self.reservation.is_set or self.reservation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.reservation.get_name_leafdata())
                        if (self.reservation_confirm.is_set or self.reservation_confirm.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.reservation_confirm.get_name_leafdata())
                        if (self.reservation_error.is_set or self.reservation_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.reservation_error.get_name_leafdata())
                        if (self.reservation_tear.is_set or self.reservation_tear.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.reservation_tear.get_name_leafdata())
                        if (self.response.is_set or self.response.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.response.get_name_leafdata())
                        if (self.srefresh.is_set or self.srefresh.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.srefresh.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ack" or name == "bundle" or name == "challenge" or name == "hello" or name == "path" or name == "path-error" or name == "path-tear" or name == "reservation" or name == "reservation-confirm" or name == "reservation-error" or name == "reservation-tear" or name == "response" or name == "srefresh"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "ack"):
                            self.ack = value
                            self.ack.value_namespace = name_space
                            self.ack.value_namespace_prefix = name_space_prefix
                        if(value_path == "bundle"):
                            self.bundle = value
                            self.bundle.value_namespace = name_space
                            self.bundle.value_namespace_prefix = name_space_prefix
                        if(value_path == "challenge"):
                            self.challenge = value
                            self.challenge.value_namespace = name_space
                            self.challenge.value_namespace_prefix = name_space_prefix
                        if(value_path == "hello"):
                            self.hello = value
                            self.hello.value_namespace = name_space
                            self.hello.value_namespace_prefix = name_space_prefix
                        if(value_path == "path"):
                            self.path = value
                            self.path.value_namespace = name_space
                            self.path.value_namespace_prefix = name_space_prefix
                        if(value_path == "path-error"):
                            self.path_error = value
                            self.path_error.value_namespace = name_space
                            self.path_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "path-tear"):
                            self.path_tear = value
                            self.path_tear.value_namespace = name_space
                            self.path_tear.value_namespace_prefix = name_space_prefix
                        if(value_path == "reservation"):
                            self.reservation = value
                            self.reservation.value_namespace = name_space
                            self.reservation.value_namespace_prefix = name_space_prefix
                        if(value_path == "reservation-confirm"):
                            self.reservation_confirm = value
                            self.reservation_confirm.value_namespace = name_space
                            self.reservation_confirm.value_namespace_prefix = name_space_prefix
                        if(value_path == "reservation-error"):
                            self.reservation_error = value
                            self.reservation_error.value_namespace = name_space
                            self.reservation_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "reservation-tear"):
                            self.reservation_tear = value
                            self.reservation_tear.value_namespace = name_space
                            self.reservation_tear.value_namespace_prefix = name_space_prefix
                        if(value_path == "response"):
                            self.response = value
                            self.response.value_namespace = name_space
                            self.response.value_namespace_prefix = name_space_prefix
                        if(value_path == "srefresh"):
                            self.srefresh = value
                            self.srefresh.value_namespace = name_space
                            self.srefresh.value_namespace_prefix = name_space_prefix


                class TransmittedMessages(Entity):
                    """
                    Count of messages transmitted
                    
                    .. attribute:: ack
                    
                    	Count of ACK messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bundle
                    
                    	Count of Bundle messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: challenge
                    
                    	Count of Integrity Challenge messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello
                    
                    	Count of Hello messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: path
                    
                    	Count of Path messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: path_error
                    
                    	Count of PathError messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: path_tear
                    
                    	Count of PathTear messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: reservation
                    
                    	Count of Reservation messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: reservation_confirm
                    
                    	Count of ReservationConfirm messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: reservation_error
                    
                    	Count of ReservationError messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: reservation_tear
                    
                    	Count of ReservationTear messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: response
                    
                    	Count of Integrity Response messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: srefresh
                    
                    	Count of Srefresh messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.Counters.InterfaceMessages.InterfaceMessage.TransmittedMessages, self).__init__()

                        self.yang_name = "transmitted-messages"
                        self.yang_parent_name = "interface-message"

                        self.ack = YLeaf(YType.uint32, "ack")

                        self.bundle = YLeaf(YType.uint32, "bundle")

                        self.challenge = YLeaf(YType.uint32, "challenge")

                        self.hello = YLeaf(YType.uint32, "hello")

                        self.path = YLeaf(YType.uint32, "path")

                        self.path_error = YLeaf(YType.uint32, "path-error")

                        self.path_tear = YLeaf(YType.uint32, "path-tear")

                        self.reservation = YLeaf(YType.uint32, "reservation")

                        self.reservation_confirm = YLeaf(YType.uint32, "reservation-confirm")

                        self.reservation_error = YLeaf(YType.uint32, "reservation-error")

                        self.reservation_tear = YLeaf(YType.uint32, "reservation-tear")

                        self.response = YLeaf(YType.uint32, "response")

                        self.srefresh = YLeaf(YType.uint32, "srefresh")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("ack",
                                        "bundle",
                                        "challenge",
                                        "hello",
                                        "path",
                                        "path_error",
                                        "path_tear",
                                        "reservation",
                                        "reservation_confirm",
                                        "reservation_error",
                                        "reservation_tear",
                                        "response",
                                        "srefresh") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.Counters.InterfaceMessages.InterfaceMessage.TransmittedMessages, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.Counters.InterfaceMessages.InterfaceMessage.TransmittedMessages, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.ack.is_set or
                            self.bundle.is_set or
                            self.challenge.is_set or
                            self.hello.is_set or
                            self.path.is_set or
                            self.path_error.is_set or
                            self.path_tear.is_set or
                            self.reservation.is_set or
                            self.reservation_confirm.is_set or
                            self.reservation_error.is_set or
                            self.reservation_tear.is_set or
                            self.response.is_set or
                            self.srefresh.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.ack.yfilter != YFilter.not_set or
                            self.bundle.yfilter != YFilter.not_set or
                            self.challenge.yfilter != YFilter.not_set or
                            self.hello.yfilter != YFilter.not_set or
                            self.path.yfilter != YFilter.not_set or
                            self.path_error.yfilter != YFilter.not_set or
                            self.path_tear.yfilter != YFilter.not_set or
                            self.reservation.yfilter != YFilter.not_set or
                            self.reservation_confirm.yfilter != YFilter.not_set or
                            self.reservation_error.yfilter != YFilter.not_set or
                            self.reservation_tear.yfilter != YFilter.not_set or
                            self.response.yfilter != YFilter.not_set or
                            self.srefresh.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "transmitted-messages" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.ack.is_set or self.ack.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ack.get_name_leafdata())
                        if (self.bundle.is_set or self.bundle.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bundle.get_name_leafdata())
                        if (self.challenge.is_set or self.challenge.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.challenge.get_name_leafdata())
                        if (self.hello.is_set or self.hello.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.hello.get_name_leafdata())
                        if (self.path.is_set or self.path.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.path.get_name_leafdata())
                        if (self.path_error.is_set or self.path_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.path_error.get_name_leafdata())
                        if (self.path_tear.is_set or self.path_tear.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.path_tear.get_name_leafdata())
                        if (self.reservation.is_set or self.reservation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.reservation.get_name_leafdata())
                        if (self.reservation_confirm.is_set or self.reservation_confirm.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.reservation_confirm.get_name_leafdata())
                        if (self.reservation_error.is_set or self.reservation_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.reservation_error.get_name_leafdata())
                        if (self.reservation_tear.is_set or self.reservation_tear.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.reservation_tear.get_name_leafdata())
                        if (self.response.is_set or self.response.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.response.get_name_leafdata())
                        if (self.srefresh.is_set or self.srefresh.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.srefresh.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ack" or name == "bundle" or name == "challenge" or name == "hello" or name == "path" or name == "path-error" or name == "path-tear" or name == "reservation" or name == "reservation-confirm" or name == "reservation-error" or name == "reservation-tear" or name == "response" or name == "srefresh"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "ack"):
                            self.ack = value
                            self.ack.value_namespace = name_space
                            self.ack.value_namespace_prefix = name_space_prefix
                        if(value_path == "bundle"):
                            self.bundle = value
                            self.bundle.value_namespace = name_space
                            self.bundle.value_namespace_prefix = name_space_prefix
                        if(value_path == "challenge"):
                            self.challenge = value
                            self.challenge.value_namespace = name_space
                            self.challenge.value_namespace_prefix = name_space_prefix
                        if(value_path == "hello"):
                            self.hello = value
                            self.hello.value_namespace = name_space
                            self.hello.value_namespace_prefix = name_space_prefix
                        if(value_path == "path"):
                            self.path = value
                            self.path.value_namespace = name_space
                            self.path.value_namespace_prefix = name_space_prefix
                        if(value_path == "path-error"):
                            self.path_error = value
                            self.path_error.value_namespace = name_space
                            self.path_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "path-tear"):
                            self.path_tear = value
                            self.path_tear.value_namespace = name_space
                            self.path_tear.value_namespace_prefix = name_space_prefix
                        if(value_path == "reservation"):
                            self.reservation = value
                            self.reservation.value_namespace = name_space
                            self.reservation.value_namespace_prefix = name_space_prefix
                        if(value_path == "reservation-confirm"):
                            self.reservation_confirm = value
                            self.reservation_confirm.value_namespace = name_space
                            self.reservation_confirm.value_namespace_prefix = name_space_prefix
                        if(value_path == "reservation-error"):
                            self.reservation_error = value
                            self.reservation_error.value_namespace = name_space
                            self.reservation_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "reservation-tear"):
                            self.reservation_tear = value
                            self.reservation_tear.value_namespace = name_space
                            self.reservation_tear.value_namespace_prefix = name_space_prefix
                        if(value_path == "response"):
                            self.response = value
                            self.response.value_namespace = name_space
                            self.response.value_namespace_prefix = name_space_prefix
                        if(value_path == "srefresh"):
                            self.srefresh = value
                            self.srefresh.value_namespace = name_space
                            self.srefresh.value_namespace_prefix = name_space_prefix


                class BundleReceivedMessages(Entity):
                    """
                    Count of Bundle messages received
                    
                    .. attribute:: ack
                    
                    	Count of ACK messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bundle
                    
                    	Count of Bundle messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: challenge
                    
                    	Count of Integrity Challenge messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello
                    
                    	Count of Hello messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: path
                    
                    	Count of Path messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: path_error
                    
                    	Count of PathError messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: path_tear
                    
                    	Count of PathTear messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: reservation
                    
                    	Count of Reservation messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: reservation_confirm
                    
                    	Count of ReservationConfirm messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: reservation_error
                    
                    	Count of ReservationError messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: reservation_tear
                    
                    	Count of ReservationTear messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: response
                    
                    	Count of Integrity Response messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: srefresh
                    
                    	Count of Srefresh messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.Counters.InterfaceMessages.InterfaceMessage.BundleReceivedMessages, self).__init__()

                        self.yang_name = "bundle-received-messages"
                        self.yang_parent_name = "interface-message"

                        self.ack = YLeaf(YType.uint32, "ack")

                        self.bundle = YLeaf(YType.uint32, "bundle")

                        self.challenge = YLeaf(YType.uint32, "challenge")

                        self.hello = YLeaf(YType.uint32, "hello")

                        self.path = YLeaf(YType.uint32, "path")

                        self.path_error = YLeaf(YType.uint32, "path-error")

                        self.path_tear = YLeaf(YType.uint32, "path-tear")

                        self.reservation = YLeaf(YType.uint32, "reservation")

                        self.reservation_confirm = YLeaf(YType.uint32, "reservation-confirm")

                        self.reservation_error = YLeaf(YType.uint32, "reservation-error")

                        self.reservation_tear = YLeaf(YType.uint32, "reservation-tear")

                        self.response = YLeaf(YType.uint32, "response")

                        self.srefresh = YLeaf(YType.uint32, "srefresh")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("ack",
                                        "bundle",
                                        "challenge",
                                        "hello",
                                        "path",
                                        "path_error",
                                        "path_tear",
                                        "reservation",
                                        "reservation_confirm",
                                        "reservation_error",
                                        "reservation_tear",
                                        "response",
                                        "srefresh") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.Counters.InterfaceMessages.InterfaceMessage.BundleReceivedMessages, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.Counters.InterfaceMessages.InterfaceMessage.BundleReceivedMessages, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.ack.is_set or
                            self.bundle.is_set or
                            self.challenge.is_set or
                            self.hello.is_set or
                            self.path.is_set or
                            self.path_error.is_set or
                            self.path_tear.is_set or
                            self.reservation.is_set or
                            self.reservation_confirm.is_set or
                            self.reservation_error.is_set or
                            self.reservation_tear.is_set or
                            self.response.is_set or
                            self.srefresh.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.ack.yfilter != YFilter.not_set or
                            self.bundle.yfilter != YFilter.not_set or
                            self.challenge.yfilter != YFilter.not_set or
                            self.hello.yfilter != YFilter.not_set or
                            self.path.yfilter != YFilter.not_set or
                            self.path_error.yfilter != YFilter.not_set or
                            self.path_tear.yfilter != YFilter.not_set or
                            self.reservation.yfilter != YFilter.not_set or
                            self.reservation_confirm.yfilter != YFilter.not_set or
                            self.reservation_error.yfilter != YFilter.not_set or
                            self.reservation_tear.yfilter != YFilter.not_set or
                            self.response.yfilter != YFilter.not_set or
                            self.srefresh.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bundle-received-messages" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.ack.is_set or self.ack.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ack.get_name_leafdata())
                        if (self.bundle.is_set or self.bundle.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bundle.get_name_leafdata())
                        if (self.challenge.is_set or self.challenge.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.challenge.get_name_leafdata())
                        if (self.hello.is_set or self.hello.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.hello.get_name_leafdata())
                        if (self.path.is_set or self.path.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.path.get_name_leafdata())
                        if (self.path_error.is_set or self.path_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.path_error.get_name_leafdata())
                        if (self.path_tear.is_set or self.path_tear.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.path_tear.get_name_leafdata())
                        if (self.reservation.is_set or self.reservation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.reservation.get_name_leafdata())
                        if (self.reservation_confirm.is_set or self.reservation_confirm.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.reservation_confirm.get_name_leafdata())
                        if (self.reservation_error.is_set or self.reservation_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.reservation_error.get_name_leafdata())
                        if (self.reservation_tear.is_set or self.reservation_tear.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.reservation_tear.get_name_leafdata())
                        if (self.response.is_set or self.response.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.response.get_name_leafdata())
                        if (self.srefresh.is_set or self.srefresh.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.srefresh.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ack" or name == "bundle" or name == "challenge" or name == "hello" or name == "path" or name == "path-error" or name == "path-tear" or name == "reservation" or name == "reservation-confirm" or name == "reservation-error" or name == "reservation-tear" or name == "response" or name == "srefresh"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "ack"):
                            self.ack = value
                            self.ack.value_namespace = name_space
                            self.ack.value_namespace_prefix = name_space_prefix
                        if(value_path == "bundle"):
                            self.bundle = value
                            self.bundle.value_namespace = name_space
                            self.bundle.value_namespace_prefix = name_space_prefix
                        if(value_path == "challenge"):
                            self.challenge = value
                            self.challenge.value_namespace = name_space
                            self.challenge.value_namespace_prefix = name_space_prefix
                        if(value_path == "hello"):
                            self.hello = value
                            self.hello.value_namespace = name_space
                            self.hello.value_namespace_prefix = name_space_prefix
                        if(value_path == "path"):
                            self.path = value
                            self.path.value_namespace = name_space
                            self.path.value_namespace_prefix = name_space_prefix
                        if(value_path == "path-error"):
                            self.path_error = value
                            self.path_error.value_namespace = name_space
                            self.path_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "path-tear"):
                            self.path_tear = value
                            self.path_tear.value_namespace = name_space
                            self.path_tear.value_namespace_prefix = name_space_prefix
                        if(value_path == "reservation"):
                            self.reservation = value
                            self.reservation.value_namespace = name_space
                            self.reservation.value_namespace_prefix = name_space_prefix
                        if(value_path == "reservation-confirm"):
                            self.reservation_confirm = value
                            self.reservation_confirm.value_namespace = name_space
                            self.reservation_confirm.value_namespace_prefix = name_space_prefix
                        if(value_path == "reservation-error"):
                            self.reservation_error = value
                            self.reservation_error.value_namespace = name_space
                            self.reservation_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "reservation-tear"):
                            self.reservation_tear = value
                            self.reservation_tear.value_namespace = name_space
                            self.reservation_tear.value_namespace_prefix = name_space_prefix
                        if(value_path == "response"):
                            self.response = value
                            self.response.value_namespace = name_space
                            self.response.value_namespace_prefix = name_space_prefix
                        if(value_path == "srefresh"):
                            self.srefresh = value
                            self.srefresh.value_namespace = name_space
                            self.srefresh.value_namespace_prefix = name_space_prefix


                class BundleTransmittedMessages(Entity):
                    """
                    Count of Bundle messages transmitted
                    
                    .. attribute:: ack
                    
                    	Count of ACK messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bundle
                    
                    	Count of Bundle messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: challenge
                    
                    	Count of Integrity Challenge messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello
                    
                    	Count of Hello messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: path
                    
                    	Count of Path messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: path_error
                    
                    	Count of PathError messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: path_tear
                    
                    	Count of PathTear messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: reservation
                    
                    	Count of Reservation messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: reservation_confirm
                    
                    	Count of ReservationConfirm messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: reservation_error
                    
                    	Count of ReservationError messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: reservation_tear
                    
                    	Count of ReservationTear messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: response
                    
                    	Count of Integrity Response messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: srefresh
                    
                    	Count of Srefresh messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.Counters.InterfaceMessages.InterfaceMessage.BundleTransmittedMessages, self).__init__()

                        self.yang_name = "bundle-transmitted-messages"
                        self.yang_parent_name = "interface-message"

                        self.ack = YLeaf(YType.uint32, "ack")

                        self.bundle = YLeaf(YType.uint32, "bundle")

                        self.challenge = YLeaf(YType.uint32, "challenge")

                        self.hello = YLeaf(YType.uint32, "hello")

                        self.path = YLeaf(YType.uint32, "path")

                        self.path_error = YLeaf(YType.uint32, "path-error")

                        self.path_tear = YLeaf(YType.uint32, "path-tear")

                        self.reservation = YLeaf(YType.uint32, "reservation")

                        self.reservation_confirm = YLeaf(YType.uint32, "reservation-confirm")

                        self.reservation_error = YLeaf(YType.uint32, "reservation-error")

                        self.reservation_tear = YLeaf(YType.uint32, "reservation-tear")

                        self.response = YLeaf(YType.uint32, "response")

                        self.srefresh = YLeaf(YType.uint32, "srefresh")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("ack",
                                        "bundle",
                                        "challenge",
                                        "hello",
                                        "path",
                                        "path_error",
                                        "path_tear",
                                        "reservation",
                                        "reservation_confirm",
                                        "reservation_error",
                                        "reservation_tear",
                                        "response",
                                        "srefresh") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.Counters.InterfaceMessages.InterfaceMessage.BundleTransmittedMessages, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.Counters.InterfaceMessages.InterfaceMessage.BundleTransmittedMessages, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.ack.is_set or
                            self.bundle.is_set or
                            self.challenge.is_set or
                            self.hello.is_set or
                            self.path.is_set or
                            self.path_error.is_set or
                            self.path_tear.is_set or
                            self.reservation.is_set or
                            self.reservation_confirm.is_set or
                            self.reservation_error.is_set or
                            self.reservation_tear.is_set or
                            self.response.is_set or
                            self.srefresh.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.ack.yfilter != YFilter.not_set or
                            self.bundle.yfilter != YFilter.not_set or
                            self.challenge.yfilter != YFilter.not_set or
                            self.hello.yfilter != YFilter.not_set or
                            self.path.yfilter != YFilter.not_set or
                            self.path_error.yfilter != YFilter.not_set or
                            self.path_tear.yfilter != YFilter.not_set or
                            self.reservation.yfilter != YFilter.not_set or
                            self.reservation_confirm.yfilter != YFilter.not_set or
                            self.reservation_error.yfilter != YFilter.not_set or
                            self.reservation_tear.yfilter != YFilter.not_set or
                            self.response.yfilter != YFilter.not_set or
                            self.srefresh.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bundle-transmitted-messages" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.ack.is_set or self.ack.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ack.get_name_leafdata())
                        if (self.bundle.is_set or self.bundle.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bundle.get_name_leafdata())
                        if (self.challenge.is_set or self.challenge.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.challenge.get_name_leafdata())
                        if (self.hello.is_set or self.hello.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.hello.get_name_leafdata())
                        if (self.path.is_set or self.path.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.path.get_name_leafdata())
                        if (self.path_error.is_set or self.path_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.path_error.get_name_leafdata())
                        if (self.path_tear.is_set or self.path_tear.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.path_tear.get_name_leafdata())
                        if (self.reservation.is_set or self.reservation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.reservation.get_name_leafdata())
                        if (self.reservation_confirm.is_set or self.reservation_confirm.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.reservation_confirm.get_name_leafdata())
                        if (self.reservation_error.is_set or self.reservation_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.reservation_error.get_name_leafdata())
                        if (self.reservation_tear.is_set or self.reservation_tear.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.reservation_tear.get_name_leafdata())
                        if (self.response.is_set or self.response.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.response.get_name_leafdata())
                        if (self.srefresh.is_set or self.srefresh.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.srefresh.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ack" or name == "bundle" or name == "challenge" or name == "hello" or name == "path" or name == "path-error" or name == "path-tear" or name == "reservation" or name == "reservation-confirm" or name == "reservation-error" or name == "reservation-tear" or name == "response" or name == "srefresh"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "ack"):
                            self.ack = value
                            self.ack.value_namespace = name_space
                            self.ack.value_namespace_prefix = name_space_prefix
                        if(value_path == "bundle"):
                            self.bundle = value
                            self.bundle.value_namespace = name_space
                            self.bundle.value_namespace_prefix = name_space_prefix
                        if(value_path == "challenge"):
                            self.challenge = value
                            self.challenge.value_namespace = name_space
                            self.challenge.value_namespace_prefix = name_space_prefix
                        if(value_path == "hello"):
                            self.hello = value
                            self.hello.value_namespace = name_space
                            self.hello.value_namespace_prefix = name_space_prefix
                        if(value_path == "path"):
                            self.path = value
                            self.path.value_namespace = name_space
                            self.path.value_namespace_prefix = name_space_prefix
                        if(value_path == "path-error"):
                            self.path_error = value
                            self.path_error.value_namespace = name_space
                            self.path_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "path-tear"):
                            self.path_tear = value
                            self.path_tear.value_namespace = name_space
                            self.path_tear.value_namespace_prefix = name_space_prefix
                        if(value_path == "reservation"):
                            self.reservation = value
                            self.reservation.value_namespace = name_space
                            self.reservation.value_namespace_prefix = name_space_prefix
                        if(value_path == "reservation-confirm"):
                            self.reservation_confirm = value
                            self.reservation_confirm.value_namespace = name_space
                            self.reservation_confirm.value_namespace_prefix = name_space_prefix
                        if(value_path == "reservation-error"):
                            self.reservation_error = value
                            self.reservation_error.value_namespace = name_space
                            self.reservation_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "reservation-tear"):
                            self.reservation_tear = value
                            self.reservation_tear.value_namespace = name_space
                            self.reservation_tear.value_namespace_prefix = name_space_prefix
                        if(value_path == "response"):
                            self.response = value
                            self.response.value_namespace = name_space
                            self.response.value_namespace_prefix = name_space_prefix
                        if(value_path == "srefresh"):
                            self.srefresh = value
                            self.srefresh.value_namespace = name_space
                            self.srefresh.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.interface_name.is_set or
                        self.out_of_order_messages.is_set or
                        self.rate_limited_messages.is_set or
                        self.retransmitted_messages.is_set or
                        (self.bundle_received_messages is not None and self.bundle_received_messages.has_data()) or
                        (self.bundle_transmitted_messages is not None and self.bundle_transmitted_messages.has_data()) or
                        (self.received_messages is not None and self.received_messages.has_data()) or
                        (self.transmitted_messages is not None and self.transmitted_messages.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.interface_name.yfilter != YFilter.not_set or
                        self.out_of_order_messages.yfilter != YFilter.not_set or
                        self.rate_limited_messages.yfilter != YFilter.not_set or
                        self.retransmitted_messages.yfilter != YFilter.not_set or
                        (self.bundle_received_messages is not None and self.bundle_received_messages.has_operation()) or
                        (self.bundle_transmitted_messages is not None and self.bundle_transmitted_messages.has_operation()) or
                        (self.received_messages is not None and self.received_messages.has_operation()) or
                        (self.transmitted_messages is not None and self.transmitted_messages.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "interface-message" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/counters/interface-messages/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                    if (self.out_of_order_messages.is_set or self.out_of_order_messages.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.out_of_order_messages.get_name_leafdata())
                    if (self.rate_limited_messages.is_set or self.rate_limited_messages.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rate_limited_messages.get_name_leafdata())
                    if (self.retransmitted_messages.is_set or self.retransmitted_messages.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.retransmitted_messages.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "bundle-received-messages"):
                        if (self.bundle_received_messages is None):
                            self.bundle_received_messages = RsvpStandby.Counters.InterfaceMessages.InterfaceMessage.BundleReceivedMessages()
                            self.bundle_received_messages.parent = self
                            self._children_name_map["bundle_received_messages"] = "bundle-received-messages"
                        return self.bundle_received_messages

                    if (child_yang_name == "bundle-transmitted-messages"):
                        if (self.bundle_transmitted_messages is None):
                            self.bundle_transmitted_messages = RsvpStandby.Counters.InterfaceMessages.InterfaceMessage.BundleTransmittedMessages()
                            self.bundle_transmitted_messages.parent = self
                            self._children_name_map["bundle_transmitted_messages"] = "bundle-transmitted-messages"
                        return self.bundle_transmitted_messages

                    if (child_yang_name == "received-messages"):
                        if (self.received_messages is None):
                            self.received_messages = RsvpStandby.Counters.InterfaceMessages.InterfaceMessage.ReceivedMessages()
                            self.received_messages.parent = self
                            self._children_name_map["received_messages"] = "received-messages"
                        return self.received_messages

                    if (child_yang_name == "transmitted-messages"):
                        if (self.transmitted_messages is None):
                            self.transmitted_messages = RsvpStandby.Counters.InterfaceMessages.InterfaceMessage.TransmittedMessages()
                            self.transmitted_messages.parent = self
                            self._children_name_map["transmitted_messages"] = "transmitted-messages"
                        return self.transmitted_messages

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bundle-received-messages" or name == "bundle-transmitted-messages" or name == "received-messages" or name == "transmitted-messages" or name == "interface-name" or name == "out-of-order-messages" or name == "rate-limited-messages" or name == "retransmitted-messages"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "interface-name"):
                        self.interface_name = value
                        self.interface_name.value_namespace = name_space
                        self.interface_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "out-of-order-messages"):
                        self.out_of_order_messages = value
                        self.out_of_order_messages.value_namespace = name_space
                        self.out_of_order_messages.value_namespace_prefix = name_space_prefix
                    if(value_path == "rate-limited-messages"):
                        self.rate_limited_messages = value
                        self.rate_limited_messages.value_namespace = name_space
                        self.rate_limited_messages.value_namespace_prefix = name_space_prefix
                    if(value_path == "retransmitted-messages"):
                        self.retransmitted_messages = value
                        self.retransmitted_messages.value_namespace = name_space
                        self.retransmitted_messages.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.interface_message:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.interface_message:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "interface-messages" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/counters/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "interface-message"):
                    for c in self.interface_message:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = RsvpStandby.Counters.InterfaceMessages.InterfaceMessage()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.interface_message.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "interface-message"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class MessageSummary(Entity):
            """
            Summary information for all RSVP message
            counters
            
            .. attribute:: bundle_received_messages
            
            	Count of Bundle messages received
            	**type**\:   :py:class:`BundleReceivedMessages <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Counters.MessageSummary.BundleReceivedMessages>`
            
            .. attribute:: bundle_transmitted_messages
            
            	Count of Bundle messages transmitted
            	**type**\:   :py:class:`BundleTransmittedMessages <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Counters.MessageSummary.BundleTransmittedMessages>`
            
            .. attribute:: out_of_order_messages
            
            	Count of Out of Order messages
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: rate_limited_messages
            
            	Count of Rate Limited messages
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: received_messages
            
            	Count of messages received
            	**type**\:   :py:class:`ReceivedMessages <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Counters.MessageSummary.ReceivedMessages>`
            
            .. attribute:: retransmitted_messages
            
            	Count of messages retransmitted
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: transmitted_messages
            
            	Count of messages transmitted
            	**type**\:   :py:class:`TransmittedMessages <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Counters.MessageSummary.TransmittedMessages>`
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(RsvpStandby.Counters.MessageSummary, self).__init__()

                self.yang_name = "message-summary"
                self.yang_parent_name = "counters"

                self.out_of_order_messages = YLeaf(YType.uint32, "out-of-order-messages")

                self.rate_limited_messages = YLeaf(YType.uint32, "rate-limited-messages")

                self.retransmitted_messages = YLeaf(YType.uint32, "retransmitted-messages")

                self.bundle_received_messages = RsvpStandby.Counters.MessageSummary.BundleReceivedMessages()
                self.bundle_received_messages.parent = self
                self._children_name_map["bundle_received_messages"] = "bundle-received-messages"
                self._children_yang_names.add("bundle-received-messages")

                self.bundle_transmitted_messages = RsvpStandby.Counters.MessageSummary.BundleTransmittedMessages()
                self.bundle_transmitted_messages.parent = self
                self._children_name_map["bundle_transmitted_messages"] = "bundle-transmitted-messages"
                self._children_yang_names.add("bundle-transmitted-messages")

                self.received_messages = RsvpStandby.Counters.MessageSummary.ReceivedMessages()
                self.received_messages.parent = self
                self._children_name_map["received_messages"] = "received-messages"
                self._children_yang_names.add("received-messages")

                self.transmitted_messages = RsvpStandby.Counters.MessageSummary.TransmittedMessages()
                self.transmitted_messages.parent = self
                self._children_name_map["transmitted_messages"] = "transmitted-messages"
                self._children_yang_names.add("transmitted-messages")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("out_of_order_messages",
                                "rate_limited_messages",
                                "retransmitted_messages") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(RsvpStandby.Counters.MessageSummary, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(RsvpStandby.Counters.MessageSummary, self).__setattr__(name, value)


            class ReceivedMessages(Entity):
                """
                Count of messages received
                
                .. attribute:: ack
                
                	Count of ACK messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bundle
                
                	Count of Bundle messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: challenge
                
                	Count of Integrity Challenge messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: hello
                
                	Count of Hello messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: path
                
                	Count of Path messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: path_error
                
                	Count of PathError messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: path_tear
                
                	Count of PathTear messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: reservation
                
                	Count of Reservation messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: reservation_confirm
                
                	Count of ReservationConfirm messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: reservation_error
                
                	Count of ReservationError messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: reservation_tear
                
                	Count of ReservationTear messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: response
                
                	Count of Integrity Response messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: srefresh
                
                	Count of Srefresh messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.Counters.MessageSummary.ReceivedMessages, self).__init__()

                    self.yang_name = "received-messages"
                    self.yang_parent_name = "message-summary"

                    self.ack = YLeaf(YType.uint32, "ack")

                    self.bundle = YLeaf(YType.uint32, "bundle")

                    self.challenge = YLeaf(YType.uint32, "challenge")

                    self.hello = YLeaf(YType.uint32, "hello")

                    self.path = YLeaf(YType.uint32, "path")

                    self.path_error = YLeaf(YType.uint32, "path-error")

                    self.path_tear = YLeaf(YType.uint32, "path-tear")

                    self.reservation = YLeaf(YType.uint32, "reservation")

                    self.reservation_confirm = YLeaf(YType.uint32, "reservation-confirm")

                    self.reservation_error = YLeaf(YType.uint32, "reservation-error")

                    self.reservation_tear = YLeaf(YType.uint32, "reservation-tear")

                    self.response = YLeaf(YType.uint32, "response")

                    self.srefresh = YLeaf(YType.uint32, "srefresh")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("ack",
                                    "bundle",
                                    "challenge",
                                    "hello",
                                    "path",
                                    "path_error",
                                    "path_tear",
                                    "reservation",
                                    "reservation_confirm",
                                    "reservation_error",
                                    "reservation_tear",
                                    "response",
                                    "srefresh") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.Counters.MessageSummary.ReceivedMessages, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.Counters.MessageSummary.ReceivedMessages, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.ack.is_set or
                        self.bundle.is_set or
                        self.challenge.is_set or
                        self.hello.is_set or
                        self.path.is_set or
                        self.path_error.is_set or
                        self.path_tear.is_set or
                        self.reservation.is_set or
                        self.reservation_confirm.is_set or
                        self.reservation_error.is_set or
                        self.reservation_tear.is_set or
                        self.response.is_set or
                        self.srefresh.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.ack.yfilter != YFilter.not_set or
                        self.bundle.yfilter != YFilter.not_set or
                        self.challenge.yfilter != YFilter.not_set or
                        self.hello.yfilter != YFilter.not_set or
                        self.path.yfilter != YFilter.not_set or
                        self.path_error.yfilter != YFilter.not_set or
                        self.path_tear.yfilter != YFilter.not_set or
                        self.reservation.yfilter != YFilter.not_set or
                        self.reservation_confirm.yfilter != YFilter.not_set or
                        self.reservation_error.yfilter != YFilter.not_set or
                        self.reservation_tear.yfilter != YFilter.not_set or
                        self.response.yfilter != YFilter.not_set or
                        self.srefresh.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "received-messages" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/counters/message-summary/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.ack.is_set or self.ack.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ack.get_name_leafdata())
                    if (self.bundle.is_set or self.bundle.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bundle.get_name_leafdata())
                    if (self.challenge.is_set or self.challenge.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.challenge.get_name_leafdata())
                    if (self.hello.is_set or self.hello.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.hello.get_name_leafdata())
                    if (self.path.is_set or self.path.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.path.get_name_leafdata())
                    if (self.path_error.is_set or self.path_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.path_error.get_name_leafdata())
                    if (self.path_tear.is_set or self.path_tear.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.path_tear.get_name_leafdata())
                    if (self.reservation.is_set or self.reservation.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reservation.get_name_leafdata())
                    if (self.reservation_confirm.is_set or self.reservation_confirm.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reservation_confirm.get_name_leafdata())
                    if (self.reservation_error.is_set or self.reservation_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reservation_error.get_name_leafdata())
                    if (self.reservation_tear.is_set or self.reservation_tear.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reservation_tear.get_name_leafdata())
                    if (self.response.is_set or self.response.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.response.get_name_leafdata())
                    if (self.srefresh.is_set or self.srefresh.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.srefresh.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ack" or name == "bundle" or name == "challenge" or name == "hello" or name == "path" or name == "path-error" or name == "path-tear" or name == "reservation" or name == "reservation-confirm" or name == "reservation-error" or name == "reservation-tear" or name == "response" or name == "srefresh"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "ack"):
                        self.ack = value
                        self.ack.value_namespace = name_space
                        self.ack.value_namespace_prefix = name_space_prefix
                    if(value_path == "bundle"):
                        self.bundle = value
                        self.bundle.value_namespace = name_space
                        self.bundle.value_namespace_prefix = name_space_prefix
                    if(value_path == "challenge"):
                        self.challenge = value
                        self.challenge.value_namespace = name_space
                        self.challenge.value_namespace_prefix = name_space_prefix
                    if(value_path == "hello"):
                        self.hello = value
                        self.hello.value_namespace = name_space
                        self.hello.value_namespace_prefix = name_space_prefix
                    if(value_path == "path"):
                        self.path = value
                        self.path.value_namespace = name_space
                        self.path.value_namespace_prefix = name_space_prefix
                    if(value_path == "path-error"):
                        self.path_error = value
                        self.path_error.value_namespace = name_space
                        self.path_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "path-tear"):
                        self.path_tear = value
                        self.path_tear.value_namespace = name_space
                        self.path_tear.value_namespace_prefix = name_space_prefix
                    if(value_path == "reservation"):
                        self.reservation = value
                        self.reservation.value_namespace = name_space
                        self.reservation.value_namespace_prefix = name_space_prefix
                    if(value_path == "reservation-confirm"):
                        self.reservation_confirm = value
                        self.reservation_confirm.value_namespace = name_space
                        self.reservation_confirm.value_namespace_prefix = name_space_prefix
                    if(value_path == "reservation-error"):
                        self.reservation_error = value
                        self.reservation_error.value_namespace = name_space
                        self.reservation_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "reservation-tear"):
                        self.reservation_tear = value
                        self.reservation_tear.value_namespace = name_space
                        self.reservation_tear.value_namespace_prefix = name_space_prefix
                    if(value_path == "response"):
                        self.response = value
                        self.response.value_namespace = name_space
                        self.response.value_namespace_prefix = name_space_prefix
                    if(value_path == "srefresh"):
                        self.srefresh = value
                        self.srefresh.value_namespace = name_space
                        self.srefresh.value_namespace_prefix = name_space_prefix


            class TransmittedMessages(Entity):
                """
                Count of messages transmitted
                
                .. attribute:: ack
                
                	Count of ACK messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bundle
                
                	Count of Bundle messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: challenge
                
                	Count of Integrity Challenge messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: hello
                
                	Count of Hello messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: path
                
                	Count of Path messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: path_error
                
                	Count of PathError messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: path_tear
                
                	Count of PathTear messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: reservation
                
                	Count of Reservation messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: reservation_confirm
                
                	Count of ReservationConfirm messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: reservation_error
                
                	Count of ReservationError messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: reservation_tear
                
                	Count of ReservationTear messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: response
                
                	Count of Integrity Response messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: srefresh
                
                	Count of Srefresh messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.Counters.MessageSummary.TransmittedMessages, self).__init__()

                    self.yang_name = "transmitted-messages"
                    self.yang_parent_name = "message-summary"

                    self.ack = YLeaf(YType.uint32, "ack")

                    self.bundle = YLeaf(YType.uint32, "bundle")

                    self.challenge = YLeaf(YType.uint32, "challenge")

                    self.hello = YLeaf(YType.uint32, "hello")

                    self.path = YLeaf(YType.uint32, "path")

                    self.path_error = YLeaf(YType.uint32, "path-error")

                    self.path_tear = YLeaf(YType.uint32, "path-tear")

                    self.reservation = YLeaf(YType.uint32, "reservation")

                    self.reservation_confirm = YLeaf(YType.uint32, "reservation-confirm")

                    self.reservation_error = YLeaf(YType.uint32, "reservation-error")

                    self.reservation_tear = YLeaf(YType.uint32, "reservation-tear")

                    self.response = YLeaf(YType.uint32, "response")

                    self.srefresh = YLeaf(YType.uint32, "srefresh")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("ack",
                                    "bundle",
                                    "challenge",
                                    "hello",
                                    "path",
                                    "path_error",
                                    "path_tear",
                                    "reservation",
                                    "reservation_confirm",
                                    "reservation_error",
                                    "reservation_tear",
                                    "response",
                                    "srefresh") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.Counters.MessageSummary.TransmittedMessages, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.Counters.MessageSummary.TransmittedMessages, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.ack.is_set or
                        self.bundle.is_set or
                        self.challenge.is_set or
                        self.hello.is_set or
                        self.path.is_set or
                        self.path_error.is_set or
                        self.path_tear.is_set or
                        self.reservation.is_set or
                        self.reservation_confirm.is_set or
                        self.reservation_error.is_set or
                        self.reservation_tear.is_set or
                        self.response.is_set or
                        self.srefresh.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.ack.yfilter != YFilter.not_set or
                        self.bundle.yfilter != YFilter.not_set or
                        self.challenge.yfilter != YFilter.not_set or
                        self.hello.yfilter != YFilter.not_set or
                        self.path.yfilter != YFilter.not_set or
                        self.path_error.yfilter != YFilter.not_set or
                        self.path_tear.yfilter != YFilter.not_set or
                        self.reservation.yfilter != YFilter.not_set or
                        self.reservation_confirm.yfilter != YFilter.not_set or
                        self.reservation_error.yfilter != YFilter.not_set or
                        self.reservation_tear.yfilter != YFilter.not_set or
                        self.response.yfilter != YFilter.not_set or
                        self.srefresh.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "transmitted-messages" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/counters/message-summary/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.ack.is_set or self.ack.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ack.get_name_leafdata())
                    if (self.bundle.is_set or self.bundle.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bundle.get_name_leafdata())
                    if (self.challenge.is_set or self.challenge.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.challenge.get_name_leafdata())
                    if (self.hello.is_set or self.hello.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.hello.get_name_leafdata())
                    if (self.path.is_set or self.path.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.path.get_name_leafdata())
                    if (self.path_error.is_set or self.path_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.path_error.get_name_leafdata())
                    if (self.path_tear.is_set or self.path_tear.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.path_tear.get_name_leafdata())
                    if (self.reservation.is_set or self.reservation.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reservation.get_name_leafdata())
                    if (self.reservation_confirm.is_set or self.reservation_confirm.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reservation_confirm.get_name_leafdata())
                    if (self.reservation_error.is_set or self.reservation_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reservation_error.get_name_leafdata())
                    if (self.reservation_tear.is_set or self.reservation_tear.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reservation_tear.get_name_leafdata())
                    if (self.response.is_set or self.response.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.response.get_name_leafdata())
                    if (self.srefresh.is_set or self.srefresh.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.srefresh.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ack" or name == "bundle" or name == "challenge" or name == "hello" or name == "path" or name == "path-error" or name == "path-tear" or name == "reservation" or name == "reservation-confirm" or name == "reservation-error" or name == "reservation-tear" or name == "response" or name == "srefresh"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "ack"):
                        self.ack = value
                        self.ack.value_namespace = name_space
                        self.ack.value_namespace_prefix = name_space_prefix
                    if(value_path == "bundle"):
                        self.bundle = value
                        self.bundle.value_namespace = name_space
                        self.bundle.value_namespace_prefix = name_space_prefix
                    if(value_path == "challenge"):
                        self.challenge = value
                        self.challenge.value_namespace = name_space
                        self.challenge.value_namespace_prefix = name_space_prefix
                    if(value_path == "hello"):
                        self.hello = value
                        self.hello.value_namespace = name_space
                        self.hello.value_namespace_prefix = name_space_prefix
                    if(value_path == "path"):
                        self.path = value
                        self.path.value_namespace = name_space
                        self.path.value_namespace_prefix = name_space_prefix
                    if(value_path == "path-error"):
                        self.path_error = value
                        self.path_error.value_namespace = name_space
                        self.path_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "path-tear"):
                        self.path_tear = value
                        self.path_tear.value_namespace = name_space
                        self.path_tear.value_namespace_prefix = name_space_prefix
                    if(value_path == "reservation"):
                        self.reservation = value
                        self.reservation.value_namespace = name_space
                        self.reservation.value_namespace_prefix = name_space_prefix
                    if(value_path == "reservation-confirm"):
                        self.reservation_confirm = value
                        self.reservation_confirm.value_namespace = name_space
                        self.reservation_confirm.value_namespace_prefix = name_space_prefix
                    if(value_path == "reservation-error"):
                        self.reservation_error = value
                        self.reservation_error.value_namespace = name_space
                        self.reservation_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "reservation-tear"):
                        self.reservation_tear = value
                        self.reservation_tear.value_namespace = name_space
                        self.reservation_tear.value_namespace_prefix = name_space_prefix
                    if(value_path == "response"):
                        self.response = value
                        self.response.value_namespace = name_space
                        self.response.value_namespace_prefix = name_space_prefix
                    if(value_path == "srefresh"):
                        self.srefresh = value
                        self.srefresh.value_namespace = name_space
                        self.srefresh.value_namespace_prefix = name_space_prefix


            class BundleReceivedMessages(Entity):
                """
                Count of Bundle messages received
                
                .. attribute:: ack
                
                	Count of ACK messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bundle
                
                	Count of Bundle messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: challenge
                
                	Count of Integrity Challenge messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: hello
                
                	Count of Hello messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: path
                
                	Count of Path messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: path_error
                
                	Count of PathError messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: path_tear
                
                	Count of PathTear messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: reservation
                
                	Count of Reservation messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: reservation_confirm
                
                	Count of ReservationConfirm messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: reservation_error
                
                	Count of ReservationError messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: reservation_tear
                
                	Count of ReservationTear messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: response
                
                	Count of Integrity Response messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: srefresh
                
                	Count of Srefresh messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.Counters.MessageSummary.BundleReceivedMessages, self).__init__()

                    self.yang_name = "bundle-received-messages"
                    self.yang_parent_name = "message-summary"

                    self.ack = YLeaf(YType.uint32, "ack")

                    self.bundle = YLeaf(YType.uint32, "bundle")

                    self.challenge = YLeaf(YType.uint32, "challenge")

                    self.hello = YLeaf(YType.uint32, "hello")

                    self.path = YLeaf(YType.uint32, "path")

                    self.path_error = YLeaf(YType.uint32, "path-error")

                    self.path_tear = YLeaf(YType.uint32, "path-tear")

                    self.reservation = YLeaf(YType.uint32, "reservation")

                    self.reservation_confirm = YLeaf(YType.uint32, "reservation-confirm")

                    self.reservation_error = YLeaf(YType.uint32, "reservation-error")

                    self.reservation_tear = YLeaf(YType.uint32, "reservation-tear")

                    self.response = YLeaf(YType.uint32, "response")

                    self.srefresh = YLeaf(YType.uint32, "srefresh")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("ack",
                                    "bundle",
                                    "challenge",
                                    "hello",
                                    "path",
                                    "path_error",
                                    "path_tear",
                                    "reservation",
                                    "reservation_confirm",
                                    "reservation_error",
                                    "reservation_tear",
                                    "response",
                                    "srefresh") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.Counters.MessageSummary.BundleReceivedMessages, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.Counters.MessageSummary.BundleReceivedMessages, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.ack.is_set or
                        self.bundle.is_set or
                        self.challenge.is_set or
                        self.hello.is_set or
                        self.path.is_set or
                        self.path_error.is_set or
                        self.path_tear.is_set or
                        self.reservation.is_set or
                        self.reservation_confirm.is_set or
                        self.reservation_error.is_set or
                        self.reservation_tear.is_set or
                        self.response.is_set or
                        self.srefresh.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.ack.yfilter != YFilter.not_set or
                        self.bundle.yfilter != YFilter.not_set or
                        self.challenge.yfilter != YFilter.not_set or
                        self.hello.yfilter != YFilter.not_set or
                        self.path.yfilter != YFilter.not_set or
                        self.path_error.yfilter != YFilter.not_set or
                        self.path_tear.yfilter != YFilter.not_set or
                        self.reservation.yfilter != YFilter.not_set or
                        self.reservation_confirm.yfilter != YFilter.not_set or
                        self.reservation_error.yfilter != YFilter.not_set or
                        self.reservation_tear.yfilter != YFilter.not_set or
                        self.response.yfilter != YFilter.not_set or
                        self.srefresh.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bundle-received-messages" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/counters/message-summary/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.ack.is_set or self.ack.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ack.get_name_leafdata())
                    if (self.bundle.is_set or self.bundle.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bundle.get_name_leafdata())
                    if (self.challenge.is_set or self.challenge.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.challenge.get_name_leafdata())
                    if (self.hello.is_set or self.hello.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.hello.get_name_leafdata())
                    if (self.path.is_set or self.path.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.path.get_name_leafdata())
                    if (self.path_error.is_set or self.path_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.path_error.get_name_leafdata())
                    if (self.path_tear.is_set or self.path_tear.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.path_tear.get_name_leafdata())
                    if (self.reservation.is_set or self.reservation.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reservation.get_name_leafdata())
                    if (self.reservation_confirm.is_set or self.reservation_confirm.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reservation_confirm.get_name_leafdata())
                    if (self.reservation_error.is_set or self.reservation_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reservation_error.get_name_leafdata())
                    if (self.reservation_tear.is_set or self.reservation_tear.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reservation_tear.get_name_leafdata())
                    if (self.response.is_set or self.response.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.response.get_name_leafdata())
                    if (self.srefresh.is_set or self.srefresh.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.srefresh.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ack" or name == "bundle" or name == "challenge" or name == "hello" or name == "path" or name == "path-error" or name == "path-tear" or name == "reservation" or name == "reservation-confirm" or name == "reservation-error" or name == "reservation-tear" or name == "response" or name == "srefresh"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "ack"):
                        self.ack = value
                        self.ack.value_namespace = name_space
                        self.ack.value_namespace_prefix = name_space_prefix
                    if(value_path == "bundle"):
                        self.bundle = value
                        self.bundle.value_namespace = name_space
                        self.bundle.value_namespace_prefix = name_space_prefix
                    if(value_path == "challenge"):
                        self.challenge = value
                        self.challenge.value_namespace = name_space
                        self.challenge.value_namespace_prefix = name_space_prefix
                    if(value_path == "hello"):
                        self.hello = value
                        self.hello.value_namespace = name_space
                        self.hello.value_namespace_prefix = name_space_prefix
                    if(value_path == "path"):
                        self.path = value
                        self.path.value_namespace = name_space
                        self.path.value_namespace_prefix = name_space_prefix
                    if(value_path == "path-error"):
                        self.path_error = value
                        self.path_error.value_namespace = name_space
                        self.path_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "path-tear"):
                        self.path_tear = value
                        self.path_tear.value_namespace = name_space
                        self.path_tear.value_namespace_prefix = name_space_prefix
                    if(value_path == "reservation"):
                        self.reservation = value
                        self.reservation.value_namespace = name_space
                        self.reservation.value_namespace_prefix = name_space_prefix
                    if(value_path == "reservation-confirm"):
                        self.reservation_confirm = value
                        self.reservation_confirm.value_namespace = name_space
                        self.reservation_confirm.value_namespace_prefix = name_space_prefix
                    if(value_path == "reservation-error"):
                        self.reservation_error = value
                        self.reservation_error.value_namespace = name_space
                        self.reservation_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "reservation-tear"):
                        self.reservation_tear = value
                        self.reservation_tear.value_namespace = name_space
                        self.reservation_tear.value_namespace_prefix = name_space_prefix
                    if(value_path == "response"):
                        self.response = value
                        self.response.value_namespace = name_space
                        self.response.value_namespace_prefix = name_space_prefix
                    if(value_path == "srefresh"):
                        self.srefresh = value
                        self.srefresh.value_namespace = name_space
                        self.srefresh.value_namespace_prefix = name_space_prefix


            class BundleTransmittedMessages(Entity):
                """
                Count of Bundle messages transmitted
                
                .. attribute:: ack
                
                	Count of ACK messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bundle
                
                	Count of Bundle messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: challenge
                
                	Count of Integrity Challenge messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: hello
                
                	Count of Hello messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: path
                
                	Count of Path messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: path_error
                
                	Count of PathError messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: path_tear
                
                	Count of PathTear messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: reservation
                
                	Count of Reservation messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: reservation_confirm
                
                	Count of ReservationConfirm messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: reservation_error
                
                	Count of ReservationError messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: reservation_tear
                
                	Count of ReservationTear messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: response
                
                	Count of Integrity Response messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: srefresh
                
                	Count of Srefresh messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.Counters.MessageSummary.BundleTransmittedMessages, self).__init__()

                    self.yang_name = "bundle-transmitted-messages"
                    self.yang_parent_name = "message-summary"

                    self.ack = YLeaf(YType.uint32, "ack")

                    self.bundle = YLeaf(YType.uint32, "bundle")

                    self.challenge = YLeaf(YType.uint32, "challenge")

                    self.hello = YLeaf(YType.uint32, "hello")

                    self.path = YLeaf(YType.uint32, "path")

                    self.path_error = YLeaf(YType.uint32, "path-error")

                    self.path_tear = YLeaf(YType.uint32, "path-tear")

                    self.reservation = YLeaf(YType.uint32, "reservation")

                    self.reservation_confirm = YLeaf(YType.uint32, "reservation-confirm")

                    self.reservation_error = YLeaf(YType.uint32, "reservation-error")

                    self.reservation_tear = YLeaf(YType.uint32, "reservation-tear")

                    self.response = YLeaf(YType.uint32, "response")

                    self.srefresh = YLeaf(YType.uint32, "srefresh")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("ack",
                                    "bundle",
                                    "challenge",
                                    "hello",
                                    "path",
                                    "path_error",
                                    "path_tear",
                                    "reservation",
                                    "reservation_confirm",
                                    "reservation_error",
                                    "reservation_tear",
                                    "response",
                                    "srefresh") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.Counters.MessageSummary.BundleTransmittedMessages, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.Counters.MessageSummary.BundleTransmittedMessages, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.ack.is_set or
                        self.bundle.is_set or
                        self.challenge.is_set or
                        self.hello.is_set or
                        self.path.is_set or
                        self.path_error.is_set or
                        self.path_tear.is_set or
                        self.reservation.is_set or
                        self.reservation_confirm.is_set or
                        self.reservation_error.is_set or
                        self.reservation_tear.is_set or
                        self.response.is_set or
                        self.srefresh.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.ack.yfilter != YFilter.not_set or
                        self.bundle.yfilter != YFilter.not_set or
                        self.challenge.yfilter != YFilter.not_set or
                        self.hello.yfilter != YFilter.not_set or
                        self.path.yfilter != YFilter.not_set or
                        self.path_error.yfilter != YFilter.not_set or
                        self.path_tear.yfilter != YFilter.not_set or
                        self.reservation.yfilter != YFilter.not_set or
                        self.reservation_confirm.yfilter != YFilter.not_set or
                        self.reservation_error.yfilter != YFilter.not_set or
                        self.reservation_tear.yfilter != YFilter.not_set or
                        self.response.yfilter != YFilter.not_set or
                        self.srefresh.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bundle-transmitted-messages" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/counters/message-summary/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.ack.is_set or self.ack.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ack.get_name_leafdata())
                    if (self.bundle.is_set or self.bundle.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bundle.get_name_leafdata())
                    if (self.challenge.is_set or self.challenge.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.challenge.get_name_leafdata())
                    if (self.hello.is_set or self.hello.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.hello.get_name_leafdata())
                    if (self.path.is_set or self.path.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.path.get_name_leafdata())
                    if (self.path_error.is_set or self.path_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.path_error.get_name_leafdata())
                    if (self.path_tear.is_set or self.path_tear.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.path_tear.get_name_leafdata())
                    if (self.reservation.is_set or self.reservation.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reservation.get_name_leafdata())
                    if (self.reservation_confirm.is_set or self.reservation_confirm.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reservation_confirm.get_name_leafdata())
                    if (self.reservation_error.is_set or self.reservation_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reservation_error.get_name_leafdata())
                    if (self.reservation_tear.is_set or self.reservation_tear.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reservation_tear.get_name_leafdata())
                    if (self.response.is_set or self.response.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.response.get_name_leafdata())
                    if (self.srefresh.is_set or self.srefresh.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.srefresh.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ack" or name == "bundle" or name == "challenge" or name == "hello" or name == "path" or name == "path-error" or name == "path-tear" or name == "reservation" or name == "reservation-confirm" or name == "reservation-error" or name == "reservation-tear" or name == "response" or name == "srefresh"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "ack"):
                        self.ack = value
                        self.ack.value_namespace = name_space
                        self.ack.value_namespace_prefix = name_space_prefix
                    if(value_path == "bundle"):
                        self.bundle = value
                        self.bundle.value_namespace = name_space
                        self.bundle.value_namespace_prefix = name_space_prefix
                    if(value_path == "challenge"):
                        self.challenge = value
                        self.challenge.value_namespace = name_space
                        self.challenge.value_namespace_prefix = name_space_prefix
                    if(value_path == "hello"):
                        self.hello = value
                        self.hello.value_namespace = name_space
                        self.hello.value_namespace_prefix = name_space_prefix
                    if(value_path == "path"):
                        self.path = value
                        self.path.value_namespace = name_space
                        self.path.value_namespace_prefix = name_space_prefix
                    if(value_path == "path-error"):
                        self.path_error = value
                        self.path_error.value_namespace = name_space
                        self.path_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "path-tear"):
                        self.path_tear = value
                        self.path_tear.value_namespace = name_space
                        self.path_tear.value_namespace_prefix = name_space_prefix
                    if(value_path == "reservation"):
                        self.reservation = value
                        self.reservation.value_namespace = name_space
                        self.reservation.value_namespace_prefix = name_space_prefix
                    if(value_path == "reservation-confirm"):
                        self.reservation_confirm = value
                        self.reservation_confirm.value_namespace = name_space
                        self.reservation_confirm.value_namespace_prefix = name_space_prefix
                    if(value_path == "reservation-error"):
                        self.reservation_error = value
                        self.reservation_error.value_namespace = name_space
                        self.reservation_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "reservation-tear"):
                        self.reservation_tear = value
                        self.reservation_tear.value_namespace = name_space
                        self.reservation_tear.value_namespace_prefix = name_space_prefix
                    if(value_path == "response"):
                        self.response = value
                        self.response.value_namespace = name_space
                        self.response.value_namespace_prefix = name_space_prefix
                    if(value_path == "srefresh"):
                        self.srefresh = value
                        self.srefresh.value_namespace = name_space
                        self.srefresh.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.out_of_order_messages.is_set or
                    self.rate_limited_messages.is_set or
                    self.retransmitted_messages.is_set or
                    (self.bundle_received_messages is not None and self.bundle_received_messages.has_data()) or
                    (self.bundle_transmitted_messages is not None and self.bundle_transmitted_messages.has_data()) or
                    (self.received_messages is not None and self.received_messages.has_data()) or
                    (self.transmitted_messages is not None and self.transmitted_messages.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.out_of_order_messages.yfilter != YFilter.not_set or
                    self.rate_limited_messages.yfilter != YFilter.not_set or
                    self.retransmitted_messages.yfilter != YFilter.not_set or
                    (self.bundle_received_messages is not None and self.bundle_received_messages.has_operation()) or
                    (self.bundle_transmitted_messages is not None and self.bundle_transmitted_messages.has_operation()) or
                    (self.received_messages is not None and self.received_messages.has_operation()) or
                    (self.transmitted_messages is not None and self.transmitted_messages.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "message-summary" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/counters/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.out_of_order_messages.is_set or self.out_of_order_messages.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.out_of_order_messages.get_name_leafdata())
                if (self.rate_limited_messages.is_set or self.rate_limited_messages.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.rate_limited_messages.get_name_leafdata())
                if (self.retransmitted_messages.is_set or self.retransmitted_messages.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.retransmitted_messages.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "bundle-received-messages"):
                    if (self.bundle_received_messages is None):
                        self.bundle_received_messages = RsvpStandby.Counters.MessageSummary.BundleReceivedMessages()
                        self.bundle_received_messages.parent = self
                        self._children_name_map["bundle_received_messages"] = "bundle-received-messages"
                    return self.bundle_received_messages

                if (child_yang_name == "bundle-transmitted-messages"):
                    if (self.bundle_transmitted_messages is None):
                        self.bundle_transmitted_messages = RsvpStandby.Counters.MessageSummary.BundleTransmittedMessages()
                        self.bundle_transmitted_messages.parent = self
                        self._children_name_map["bundle_transmitted_messages"] = "bundle-transmitted-messages"
                    return self.bundle_transmitted_messages

                if (child_yang_name == "received-messages"):
                    if (self.received_messages is None):
                        self.received_messages = RsvpStandby.Counters.MessageSummary.ReceivedMessages()
                        self.received_messages.parent = self
                        self._children_name_map["received_messages"] = "received-messages"
                    return self.received_messages

                if (child_yang_name == "transmitted-messages"):
                    if (self.transmitted_messages is None):
                        self.transmitted_messages = RsvpStandby.Counters.MessageSummary.TransmittedMessages()
                        self.transmitted_messages.parent = self
                        self._children_name_map["transmitted_messages"] = "transmitted-messages"
                    return self.transmitted_messages

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "bundle-received-messages" or name == "bundle-transmitted-messages" or name == "received-messages" or name == "transmitted-messages" or name == "out-of-order-messages" or name == "rate-limited-messages" or name == "retransmitted-messages"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "out-of-order-messages"):
                    self.out_of_order_messages = value
                    self.out_of_order_messages.value_namespace = name_space
                    self.out_of_order_messages.value_namespace_prefix = name_space_prefix
                if(value_path == "rate-limited-messages"):
                    self.rate_limited_messages = value
                    self.rate_limited_messages.value_namespace = name_space
                    self.rate_limited_messages.value_namespace_prefix = name_space_prefix
                if(value_path == "retransmitted-messages"):
                    self.retransmitted_messages = value
                    self.retransmitted_messages.value_namespace = name_space
                    self.retransmitted_messages.value_namespace_prefix = name_space_prefix


        class PrefixFiltering(Entity):
            """
            Prefix filtering counters
            
            .. attribute:: accesses
            
            	AccessList specific prefix filtering counters
            	**type**\:   :py:class:`Accesses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Counters.PrefixFiltering.Accesses>`
            
            .. attribute:: interfaces
            
            	Interface specific prefix filtering counters
            	**type**\:   :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Counters.PrefixFiltering.Interfaces>`
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(RsvpStandby.Counters.PrefixFiltering, self).__init__()

                self.yang_name = "prefix-filtering"
                self.yang_parent_name = "counters"

                self.accesses = RsvpStandby.Counters.PrefixFiltering.Accesses()
                self.accesses.parent = self
                self._children_name_map["accesses"] = "accesses"
                self._children_yang_names.add("accesses")

                self.interfaces = RsvpStandby.Counters.PrefixFiltering.Interfaces()
                self.interfaces.parent = self
                self._children_name_map["interfaces"] = "interfaces"
                self._children_yang_names.add("interfaces")


            class Accesses(Entity):
                """
                AccessList specific prefix filtering counters
                
                .. attribute:: access
                
                	Prefix filtering counters for a specific AccessList
                	**type**\: list of    :py:class:`Access <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Counters.PrefixFiltering.Accesses.Access>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.Counters.PrefixFiltering.Accesses, self).__init__()

                    self.yang_name = "accesses"
                    self.yang_parent_name = "prefix-filtering"

                    self.access = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.Counters.PrefixFiltering.Accesses, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.Counters.PrefixFiltering.Accesses, self).__setattr__(name, value)


                class Access(Entity):
                    """
                    Prefix filtering counters for a specific
                    AccessList
                    
                    .. attribute:: access_list_name  <key>
                    
                    	AccessList Name
                    	**type**\:  str
                    
                    	**length:** 1..65
                    
                    .. attribute:: dropped
                    
                    	Count of messages dropped
                    	**type**\:   :py:class:`Dropped <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Counters.PrefixFiltering.Accesses.Access.Dropped>`
                    
                    .. attribute:: forwarded
                    
                    	Count of messages which got forwarded
                    	**type**\:   :py:class:`Forwarded <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Counters.PrefixFiltering.Accesses.Access.Forwarded>`
                    
                    .. attribute:: locally_destined
                    
                    	Count of locally destined messages
                    	**type**\:   :py:class:`LocallyDestined <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Counters.PrefixFiltering.Accesses.Access.LocallyDestined>`
                    
                    .. attribute:: total
                    
                    	Count of total messages
                    	**type**\:   :py:class:`Total <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Counters.PrefixFiltering.Accesses.Access.Total>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.Counters.PrefixFiltering.Accesses.Access, self).__init__()

                        self.yang_name = "access"
                        self.yang_parent_name = "accesses"

                        self.access_list_name = YLeaf(YType.str, "access-list-name")

                        self.dropped = RsvpStandby.Counters.PrefixFiltering.Accesses.Access.Dropped()
                        self.dropped.parent = self
                        self._children_name_map["dropped"] = "dropped"
                        self._children_yang_names.add("dropped")

                        self.forwarded = RsvpStandby.Counters.PrefixFiltering.Accesses.Access.Forwarded()
                        self.forwarded.parent = self
                        self._children_name_map["forwarded"] = "forwarded"
                        self._children_yang_names.add("forwarded")

                        self.locally_destined = RsvpStandby.Counters.PrefixFiltering.Accesses.Access.LocallyDestined()
                        self.locally_destined.parent = self
                        self._children_name_map["locally_destined"] = "locally-destined"
                        self._children_yang_names.add("locally-destined")

                        self.total = RsvpStandby.Counters.PrefixFiltering.Accesses.Access.Total()
                        self.total.parent = self
                        self._children_name_map["total"] = "total"
                        self._children_yang_names.add("total")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("access_list_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.Counters.PrefixFiltering.Accesses.Access, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.Counters.PrefixFiltering.Accesses.Access, self).__setattr__(name, value)


                    class Forwarded(Entity):
                        """
                        Count of messages which got forwarded
                        
                        .. attribute:: path
                        
                        	Count of Path messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: path_tear
                        
                        	Count of PathTear messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: reservation_confirm
                        
                        	Count of ReservationConfirm messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total
                        
                        	Total count of messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.Counters.PrefixFiltering.Accesses.Access.Forwarded, self).__init__()

                            self.yang_name = "forwarded"
                            self.yang_parent_name = "access"

                            self.path = YLeaf(YType.uint32, "path")

                            self.path_tear = YLeaf(YType.uint32, "path-tear")

                            self.reservation_confirm = YLeaf(YType.uint32, "reservation-confirm")

                            self.total = YLeaf(YType.uint32, "total")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("path",
                                            "path_tear",
                                            "reservation_confirm",
                                            "total") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.Counters.PrefixFiltering.Accesses.Access.Forwarded, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.Counters.PrefixFiltering.Accesses.Access.Forwarded, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.path.is_set or
                                self.path_tear.is_set or
                                self.reservation_confirm.is_set or
                                self.total.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.path.yfilter != YFilter.not_set or
                                self.path_tear.yfilter != YFilter.not_set or
                                self.reservation_confirm.yfilter != YFilter.not_set or
                                self.total.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "forwarded" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.path.is_set or self.path.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.path.get_name_leafdata())
                            if (self.path_tear.is_set or self.path_tear.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.path_tear.get_name_leafdata())
                            if (self.reservation_confirm.is_set or self.reservation_confirm.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.reservation_confirm.get_name_leafdata())
                            if (self.total.is_set or self.total.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.total.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "path" or name == "path-tear" or name == "reservation-confirm" or name == "total"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "path"):
                                self.path = value
                                self.path.value_namespace = name_space
                                self.path.value_namespace_prefix = name_space_prefix
                            if(value_path == "path-tear"):
                                self.path_tear = value
                                self.path_tear.value_namespace = name_space
                                self.path_tear.value_namespace_prefix = name_space_prefix
                            if(value_path == "reservation-confirm"):
                                self.reservation_confirm = value
                                self.reservation_confirm.value_namespace = name_space
                                self.reservation_confirm.value_namespace_prefix = name_space_prefix
                            if(value_path == "total"):
                                self.total = value
                                self.total.value_namespace = name_space
                                self.total.value_namespace_prefix = name_space_prefix


                    class LocallyDestined(Entity):
                        """
                        Count of locally destined messages
                        
                        .. attribute:: path
                        
                        	Count of Path messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: path_tear
                        
                        	Count of PathTear messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: reservation_confirm
                        
                        	Count of ReservationConfirm messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total
                        
                        	Total count of messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.Counters.PrefixFiltering.Accesses.Access.LocallyDestined, self).__init__()

                            self.yang_name = "locally-destined"
                            self.yang_parent_name = "access"

                            self.path = YLeaf(YType.uint32, "path")

                            self.path_tear = YLeaf(YType.uint32, "path-tear")

                            self.reservation_confirm = YLeaf(YType.uint32, "reservation-confirm")

                            self.total = YLeaf(YType.uint32, "total")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("path",
                                            "path_tear",
                                            "reservation_confirm",
                                            "total") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.Counters.PrefixFiltering.Accesses.Access.LocallyDestined, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.Counters.PrefixFiltering.Accesses.Access.LocallyDestined, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.path.is_set or
                                self.path_tear.is_set or
                                self.reservation_confirm.is_set or
                                self.total.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.path.yfilter != YFilter.not_set or
                                self.path_tear.yfilter != YFilter.not_set or
                                self.reservation_confirm.yfilter != YFilter.not_set or
                                self.total.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "locally-destined" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.path.is_set or self.path.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.path.get_name_leafdata())
                            if (self.path_tear.is_set or self.path_tear.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.path_tear.get_name_leafdata())
                            if (self.reservation_confirm.is_set or self.reservation_confirm.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.reservation_confirm.get_name_leafdata())
                            if (self.total.is_set or self.total.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.total.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "path" or name == "path-tear" or name == "reservation-confirm" or name == "total"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "path"):
                                self.path = value
                                self.path.value_namespace = name_space
                                self.path.value_namespace_prefix = name_space_prefix
                            if(value_path == "path-tear"):
                                self.path_tear = value
                                self.path_tear.value_namespace = name_space
                                self.path_tear.value_namespace_prefix = name_space_prefix
                            if(value_path == "reservation-confirm"):
                                self.reservation_confirm = value
                                self.reservation_confirm.value_namespace = name_space
                                self.reservation_confirm.value_namespace_prefix = name_space_prefix
                            if(value_path == "total"):
                                self.total = value
                                self.total.value_namespace = name_space
                                self.total.value_namespace_prefix = name_space_prefix


                    class Dropped(Entity):
                        """
                        Count of messages dropped
                        
                        .. attribute:: path
                        
                        	Count of Path messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: path_tear
                        
                        	Count of PathTear messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: reservation_confirm
                        
                        	Count of ReservationConfirm messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total
                        
                        	Total count of messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.Counters.PrefixFiltering.Accesses.Access.Dropped, self).__init__()

                            self.yang_name = "dropped"
                            self.yang_parent_name = "access"

                            self.path = YLeaf(YType.uint32, "path")

                            self.path_tear = YLeaf(YType.uint32, "path-tear")

                            self.reservation_confirm = YLeaf(YType.uint32, "reservation-confirm")

                            self.total = YLeaf(YType.uint32, "total")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("path",
                                            "path_tear",
                                            "reservation_confirm",
                                            "total") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.Counters.PrefixFiltering.Accesses.Access.Dropped, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.Counters.PrefixFiltering.Accesses.Access.Dropped, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.path.is_set or
                                self.path_tear.is_set or
                                self.reservation_confirm.is_set or
                                self.total.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.path.yfilter != YFilter.not_set or
                                self.path_tear.yfilter != YFilter.not_set or
                                self.reservation_confirm.yfilter != YFilter.not_set or
                                self.total.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "dropped" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.path.is_set or self.path.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.path.get_name_leafdata())
                            if (self.path_tear.is_set or self.path_tear.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.path_tear.get_name_leafdata())
                            if (self.reservation_confirm.is_set or self.reservation_confirm.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.reservation_confirm.get_name_leafdata())
                            if (self.total.is_set or self.total.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.total.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "path" or name == "path-tear" or name == "reservation-confirm" or name == "total"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "path"):
                                self.path = value
                                self.path.value_namespace = name_space
                                self.path.value_namespace_prefix = name_space_prefix
                            if(value_path == "path-tear"):
                                self.path_tear = value
                                self.path_tear.value_namespace = name_space
                                self.path_tear.value_namespace_prefix = name_space_prefix
                            if(value_path == "reservation-confirm"):
                                self.reservation_confirm = value
                                self.reservation_confirm.value_namespace = name_space
                                self.reservation_confirm.value_namespace_prefix = name_space_prefix
                            if(value_path == "total"):
                                self.total = value
                                self.total.value_namespace = name_space
                                self.total.value_namespace_prefix = name_space_prefix


                    class Total(Entity):
                        """
                        Count of total messages
                        
                        .. attribute:: path
                        
                        	Count of Path messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: path_tear
                        
                        	Count of PathTear messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: reservation_confirm
                        
                        	Count of ReservationConfirm messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total
                        
                        	Total count of messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.Counters.PrefixFiltering.Accesses.Access.Total, self).__init__()

                            self.yang_name = "total"
                            self.yang_parent_name = "access"

                            self.path = YLeaf(YType.uint32, "path")

                            self.path_tear = YLeaf(YType.uint32, "path-tear")

                            self.reservation_confirm = YLeaf(YType.uint32, "reservation-confirm")

                            self.total = YLeaf(YType.uint32, "total")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("path",
                                            "path_tear",
                                            "reservation_confirm",
                                            "total") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.Counters.PrefixFiltering.Accesses.Access.Total, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.Counters.PrefixFiltering.Accesses.Access.Total, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.path.is_set or
                                self.path_tear.is_set or
                                self.reservation_confirm.is_set or
                                self.total.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.path.yfilter != YFilter.not_set or
                                self.path_tear.yfilter != YFilter.not_set or
                                self.reservation_confirm.yfilter != YFilter.not_set or
                                self.total.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "total" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.path.is_set or self.path.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.path.get_name_leafdata())
                            if (self.path_tear.is_set or self.path_tear.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.path_tear.get_name_leafdata())
                            if (self.reservation_confirm.is_set or self.reservation_confirm.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.reservation_confirm.get_name_leafdata())
                            if (self.total.is_set or self.total.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.total.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "path" or name == "path-tear" or name == "reservation-confirm" or name == "total"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "path"):
                                self.path = value
                                self.path.value_namespace = name_space
                                self.path.value_namespace_prefix = name_space_prefix
                            if(value_path == "path-tear"):
                                self.path_tear = value
                                self.path_tear.value_namespace = name_space
                                self.path_tear.value_namespace_prefix = name_space_prefix
                            if(value_path == "reservation-confirm"):
                                self.reservation_confirm = value
                                self.reservation_confirm.value_namespace = name_space
                                self.reservation_confirm.value_namespace_prefix = name_space_prefix
                            if(value_path == "total"):
                                self.total = value
                                self.total.value_namespace = name_space
                                self.total.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.access_list_name.is_set or
                            (self.dropped is not None and self.dropped.has_data()) or
                            (self.forwarded is not None and self.forwarded.has_data()) or
                            (self.locally_destined is not None and self.locally_destined.has_data()) or
                            (self.total is not None and self.total.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.access_list_name.yfilter != YFilter.not_set or
                            (self.dropped is not None and self.dropped.has_operation()) or
                            (self.forwarded is not None and self.forwarded.has_operation()) or
                            (self.locally_destined is not None and self.locally_destined.has_operation()) or
                            (self.total is not None and self.total.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "access" + "[access-list-name='" + self.access_list_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/counters/prefix-filtering/accesses/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.access_list_name.is_set or self.access_list_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.access_list_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "dropped"):
                            if (self.dropped is None):
                                self.dropped = RsvpStandby.Counters.PrefixFiltering.Accesses.Access.Dropped()
                                self.dropped.parent = self
                                self._children_name_map["dropped"] = "dropped"
                            return self.dropped

                        if (child_yang_name == "forwarded"):
                            if (self.forwarded is None):
                                self.forwarded = RsvpStandby.Counters.PrefixFiltering.Accesses.Access.Forwarded()
                                self.forwarded.parent = self
                                self._children_name_map["forwarded"] = "forwarded"
                            return self.forwarded

                        if (child_yang_name == "locally-destined"):
                            if (self.locally_destined is None):
                                self.locally_destined = RsvpStandby.Counters.PrefixFiltering.Accesses.Access.LocallyDestined()
                                self.locally_destined.parent = self
                                self._children_name_map["locally_destined"] = "locally-destined"
                            return self.locally_destined

                        if (child_yang_name == "total"):
                            if (self.total is None):
                                self.total = RsvpStandby.Counters.PrefixFiltering.Accesses.Access.Total()
                                self.total.parent = self
                                self._children_name_map["total"] = "total"
                            return self.total

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "dropped" or name == "forwarded" or name == "locally-destined" or name == "total" or name == "access-list-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "access-list-name"):
                            self.access_list_name = value
                            self.access_list_name.value_namespace = name_space
                            self.access_list_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.access:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.access:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "accesses" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/counters/prefix-filtering/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "access"):
                        for c in self.access:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = RsvpStandby.Counters.PrefixFiltering.Accesses.Access()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.access.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "access"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Interfaces(Entity):
                """
                Interface specific prefix filtering counters
                
                .. attribute:: interfaces
                
                	Table of interface specific prefix filtering counters
                	**type**\:   :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Counters.PrefixFiltering.Interfaces.Interfaces>`
                
                .. attribute:: summary
                
                	Summary of prefix filtering counts for all interfaces
                	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Counters.PrefixFiltering.Interfaces.Summary>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.Counters.PrefixFiltering.Interfaces, self).__init__()

                    self.yang_name = "interfaces"
                    self.yang_parent_name = "prefix-filtering"

                    self.interfaces = RsvpStandby.Counters.PrefixFiltering.Interfaces.Interfaces()
                    self.interfaces.parent = self
                    self._children_name_map["interfaces"] = "interfaces"
                    self._children_yang_names.add("interfaces")

                    self.summary = RsvpStandby.Counters.PrefixFiltering.Interfaces.Summary()
                    self.summary.parent = self
                    self._children_name_map["summary"] = "summary"
                    self._children_yang_names.add("summary")


                class Summary(Entity):
                    """
                    Summary of prefix filtering counts for all
                    interfaces
                    
                    .. attribute:: default_action_dropped
                    
                    	Count of messages which got dropped due to default ACL action
                    	**type**\:   :py:class:`DefaultActionDropped <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Counters.PrefixFiltering.Interfaces.Summary.DefaultActionDropped>`
                    
                    .. attribute:: default_action_processed
                    
                    	Count of messages which were processed due to default ACL action
                    	**type**\:   :py:class:`DefaultActionProcessed <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Counters.PrefixFiltering.Interfaces.Summary.DefaultActionProcessed>`
                    
                    .. attribute:: dropped
                    
                    	Count of messages dropped
                    	**type**\:   :py:class:`Dropped <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Counters.PrefixFiltering.Interfaces.Summary.Dropped>`
                    
                    .. attribute:: forwarded
                    
                    	Count of messages which got forwarded
                    	**type**\:   :py:class:`Forwarded <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Counters.PrefixFiltering.Interfaces.Summary.Forwarded>`
                    
                    .. attribute:: locally_destined
                    
                    	Count of locally destined messages
                    	**type**\:   :py:class:`LocallyDestined <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Counters.PrefixFiltering.Interfaces.Summary.LocallyDestined>`
                    
                    .. attribute:: total
                    
                    	Count of total messages
                    	**type**\:   :py:class:`Total <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Counters.PrefixFiltering.Interfaces.Summary.Total>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.Counters.PrefixFiltering.Interfaces.Summary, self).__init__()

                        self.yang_name = "summary"
                        self.yang_parent_name = "interfaces"

                        self.default_action_dropped = RsvpStandby.Counters.PrefixFiltering.Interfaces.Summary.DefaultActionDropped()
                        self.default_action_dropped.parent = self
                        self._children_name_map["default_action_dropped"] = "default-action-dropped"
                        self._children_yang_names.add("default-action-dropped")

                        self.default_action_processed = RsvpStandby.Counters.PrefixFiltering.Interfaces.Summary.DefaultActionProcessed()
                        self.default_action_processed.parent = self
                        self._children_name_map["default_action_processed"] = "default-action-processed"
                        self._children_yang_names.add("default-action-processed")

                        self.dropped = RsvpStandby.Counters.PrefixFiltering.Interfaces.Summary.Dropped()
                        self.dropped.parent = self
                        self._children_name_map["dropped"] = "dropped"
                        self._children_yang_names.add("dropped")

                        self.forwarded = RsvpStandby.Counters.PrefixFiltering.Interfaces.Summary.Forwarded()
                        self.forwarded.parent = self
                        self._children_name_map["forwarded"] = "forwarded"
                        self._children_yang_names.add("forwarded")

                        self.locally_destined = RsvpStandby.Counters.PrefixFiltering.Interfaces.Summary.LocallyDestined()
                        self.locally_destined.parent = self
                        self._children_name_map["locally_destined"] = "locally-destined"
                        self._children_yang_names.add("locally-destined")

                        self.total = RsvpStandby.Counters.PrefixFiltering.Interfaces.Summary.Total()
                        self.total.parent = self
                        self._children_name_map["total"] = "total"
                        self._children_yang_names.add("total")


                    class Forwarded(Entity):
                        """
                        Count of messages which got forwarded
                        
                        .. attribute:: path
                        
                        	Count of Path messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: path_tear
                        
                        	Count of PathTear messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: reservation_confirm
                        
                        	Count of ReservationConfirm messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total
                        
                        	Total count of messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.Counters.PrefixFiltering.Interfaces.Summary.Forwarded, self).__init__()

                            self.yang_name = "forwarded"
                            self.yang_parent_name = "summary"

                            self.path = YLeaf(YType.uint32, "path")

                            self.path_tear = YLeaf(YType.uint32, "path-tear")

                            self.reservation_confirm = YLeaf(YType.uint32, "reservation-confirm")

                            self.total = YLeaf(YType.uint32, "total")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("path",
                                            "path_tear",
                                            "reservation_confirm",
                                            "total") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.Counters.PrefixFiltering.Interfaces.Summary.Forwarded, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.Counters.PrefixFiltering.Interfaces.Summary.Forwarded, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.path.is_set or
                                self.path_tear.is_set or
                                self.reservation_confirm.is_set or
                                self.total.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.path.yfilter != YFilter.not_set or
                                self.path_tear.yfilter != YFilter.not_set or
                                self.reservation_confirm.yfilter != YFilter.not_set or
                                self.total.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "forwarded" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/counters/prefix-filtering/interfaces/summary/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.path.is_set or self.path.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.path.get_name_leafdata())
                            if (self.path_tear.is_set or self.path_tear.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.path_tear.get_name_leafdata())
                            if (self.reservation_confirm.is_set or self.reservation_confirm.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.reservation_confirm.get_name_leafdata())
                            if (self.total.is_set or self.total.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.total.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "path" or name == "path-tear" or name == "reservation-confirm" or name == "total"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "path"):
                                self.path = value
                                self.path.value_namespace = name_space
                                self.path.value_namespace_prefix = name_space_prefix
                            if(value_path == "path-tear"):
                                self.path_tear = value
                                self.path_tear.value_namespace = name_space
                                self.path_tear.value_namespace_prefix = name_space_prefix
                            if(value_path == "reservation-confirm"):
                                self.reservation_confirm = value
                                self.reservation_confirm.value_namespace = name_space
                                self.reservation_confirm.value_namespace_prefix = name_space_prefix
                            if(value_path == "total"):
                                self.total = value
                                self.total.value_namespace = name_space
                                self.total.value_namespace_prefix = name_space_prefix


                    class LocallyDestined(Entity):
                        """
                        Count of locally destined messages
                        
                        .. attribute:: path
                        
                        	Count of Path messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: path_tear
                        
                        	Count of PathTear messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: reservation_confirm
                        
                        	Count of ReservationConfirm messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total
                        
                        	Total count of messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.Counters.PrefixFiltering.Interfaces.Summary.LocallyDestined, self).__init__()

                            self.yang_name = "locally-destined"
                            self.yang_parent_name = "summary"

                            self.path = YLeaf(YType.uint32, "path")

                            self.path_tear = YLeaf(YType.uint32, "path-tear")

                            self.reservation_confirm = YLeaf(YType.uint32, "reservation-confirm")

                            self.total = YLeaf(YType.uint32, "total")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("path",
                                            "path_tear",
                                            "reservation_confirm",
                                            "total") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.Counters.PrefixFiltering.Interfaces.Summary.LocallyDestined, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.Counters.PrefixFiltering.Interfaces.Summary.LocallyDestined, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.path.is_set or
                                self.path_tear.is_set or
                                self.reservation_confirm.is_set or
                                self.total.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.path.yfilter != YFilter.not_set or
                                self.path_tear.yfilter != YFilter.not_set or
                                self.reservation_confirm.yfilter != YFilter.not_set or
                                self.total.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "locally-destined" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/counters/prefix-filtering/interfaces/summary/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.path.is_set or self.path.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.path.get_name_leafdata())
                            if (self.path_tear.is_set or self.path_tear.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.path_tear.get_name_leafdata())
                            if (self.reservation_confirm.is_set or self.reservation_confirm.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.reservation_confirm.get_name_leafdata())
                            if (self.total.is_set or self.total.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.total.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "path" or name == "path-tear" or name == "reservation-confirm" or name == "total"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "path"):
                                self.path = value
                                self.path.value_namespace = name_space
                                self.path.value_namespace_prefix = name_space_prefix
                            if(value_path == "path-tear"):
                                self.path_tear = value
                                self.path_tear.value_namespace = name_space
                                self.path_tear.value_namespace_prefix = name_space_prefix
                            if(value_path == "reservation-confirm"):
                                self.reservation_confirm = value
                                self.reservation_confirm.value_namespace = name_space
                                self.reservation_confirm.value_namespace_prefix = name_space_prefix
                            if(value_path == "total"):
                                self.total = value
                                self.total.value_namespace = name_space
                                self.total.value_namespace_prefix = name_space_prefix


                    class Dropped(Entity):
                        """
                        Count of messages dropped
                        
                        .. attribute:: path
                        
                        	Count of Path messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: path_tear
                        
                        	Count of PathTear messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: reservation_confirm
                        
                        	Count of ReservationConfirm messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total
                        
                        	Total count of messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.Counters.PrefixFiltering.Interfaces.Summary.Dropped, self).__init__()

                            self.yang_name = "dropped"
                            self.yang_parent_name = "summary"

                            self.path = YLeaf(YType.uint32, "path")

                            self.path_tear = YLeaf(YType.uint32, "path-tear")

                            self.reservation_confirm = YLeaf(YType.uint32, "reservation-confirm")

                            self.total = YLeaf(YType.uint32, "total")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("path",
                                            "path_tear",
                                            "reservation_confirm",
                                            "total") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.Counters.PrefixFiltering.Interfaces.Summary.Dropped, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.Counters.PrefixFiltering.Interfaces.Summary.Dropped, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.path.is_set or
                                self.path_tear.is_set or
                                self.reservation_confirm.is_set or
                                self.total.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.path.yfilter != YFilter.not_set or
                                self.path_tear.yfilter != YFilter.not_set or
                                self.reservation_confirm.yfilter != YFilter.not_set or
                                self.total.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "dropped" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/counters/prefix-filtering/interfaces/summary/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.path.is_set or self.path.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.path.get_name_leafdata())
                            if (self.path_tear.is_set or self.path_tear.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.path_tear.get_name_leafdata())
                            if (self.reservation_confirm.is_set or self.reservation_confirm.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.reservation_confirm.get_name_leafdata())
                            if (self.total.is_set or self.total.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.total.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "path" or name == "path-tear" or name == "reservation-confirm" or name == "total"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "path"):
                                self.path = value
                                self.path.value_namespace = name_space
                                self.path.value_namespace_prefix = name_space_prefix
                            if(value_path == "path-tear"):
                                self.path_tear = value
                                self.path_tear.value_namespace = name_space
                                self.path_tear.value_namespace_prefix = name_space_prefix
                            if(value_path == "reservation-confirm"):
                                self.reservation_confirm = value
                                self.reservation_confirm.value_namespace = name_space
                                self.reservation_confirm.value_namespace_prefix = name_space_prefix
                            if(value_path == "total"):
                                self.total = value
                                self.total.value_namespace = name_space
                                self.total.value_namespace_prefix = name_space_prefix


                    class DefaultActionDropped(Entity):
                        """
                        Count of messages which got dropped due to
                        default ACL action
                        
                        .. attribute:: path
                        
                        	Count of Path messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: path_tear
                        
                        	Count of PathTear messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: reservation_confirm
                        
                        	Count of ReservationConfirm messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total
                        
                        	Total count of messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.Counters.PrefixFiltering.Interfaces.Summary.DefaultActionDropped, self).__init__()

                            self.yang_name = "default-action-dropped"
                            self.yang_parent_name = "summary"

                            self.path = YLeaf(YType.uint32, "path")

                            self.path_tear = YLeaf(YType.uint32, "path-tear")

                            self.reservation_confirm = YLeaf(YType.uint32, "reservation-confirm")

                            self.total = YLeaf(YType.uint32, "total")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("path",
                                            "path_tear",
                                            "reservation_confirm",
                                            "total") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.Counters.PrefixFiltering.Interfaces.Summary.DefaultActionDropped, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.Counters.PrefixFiltering.Interfaces.Summary.DefaultActionDropped, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.path.is_set or
                                self.path_tear.is_set or
                                self.reservation_confirm.is_set or
                                self.total.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.path.yfilter != YFilter.not_set or
                                self.path_tear.yfilter != YFilter.not_set or
                                self.reservation_confirm.yfilter != YFilter.not_set or
                                self.total.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "default-action-dropped" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/counters/prefix-filtering/interfaces/summary/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.path.is_set or self.path.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.path.get_name_leafdata())
                            if (self.path_tear.is_set or self.path_tear.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.path_tear.get_name_leafdata())
                            if (self.reservation_confirm.is_set or self.reservation_confirm.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.reservation_confirm.get_name_leafdata())
                            if (self.total.is_set or self.total.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.total.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "path" or name == "path-tear" or name == "reservation-confirm" or name == "total"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "path"):
                                self.path = value
                                self.path.value_namespace = name_space
                                self.path.value_namespace_prefix = name_space_prefix
                            if(value_path == "path-tear"):
                                self.path_tear = value
                                self.path_tear.value_namespace = name_space
                                self.path_tear.value_namespace_prefix = name_space_prefix
                            if(value_path == "reservation-confirm"):
                                self.reservation_confirm = value
                                self.reservation_confirm.value_namespace = name_space
                                self.reservation_confirm.value_namespace_prefix = name_space_prefix
                            if(value_path == "total"):
                                self.total = value
                                self.total.value_namespace = name_space
                                self.total.value_namespace_prefix = name_space_prefix


                    class DefaultActionProcessed(Entity):
                        """
                        Count of messages which were processed due to
                        default ACL action
                        
                        .. attribute:: path
                        
                        	Count of Path messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: path_tear
                        
                        	Count of PathTear messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: reservation_confirm
                        
                        	Count of ReservationConfirm messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total
                        
                        	Total count of messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.Counters.PrefixFiltering.Interfaces.Summary.DefaultActionProcessed, self).__init__()

                            self.yang_name = "default-action-processed"
                            self.yang_parent_name = "summary"

                            self.path = YLeaf(YType.uint32, "path")

                            self.path_tear = YLeaf(YType.uint32, "path-tear")

                            self.reservation_confirm = YLeaf(YType.uint32, "reservation-confirm")

                            self.total = YLeaf(YType.uint32, "total")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("path",
                                            "path_tear",
                                            "reservation_confirm",
                                            "total") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.Counters.PrefixFiltering.Interfaces.Summary.DefaultActionProcessed, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.Counters.PrefixFiltering.Interfaces.Summary.DefaultActionProcessed, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.path.is_set or
                                self.path_tear.is_set or
                                self.reservation_confirm.is_set or
                                self.total.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.path.yfilter != YFilter.not_set or
                                self.path_tear.yfilter != YFilter.not_set or
                                self.reservation_confirm.yfilter != YFilter.not_set or
                                self.total.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "default-action-processed" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/counters/prefix-filtering/interfaces/summary/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.path.is_set or self.path.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.path.get_name_leafdata())
                            if (self.path_tear.is_set or self.path_tear.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.path_tear.get_name_leafdata())
                            if (self.reservation_confirm.is_set or self.reservation_confirm.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.reservation_confirm.get_name_leafdata())
                            if (self.total.is_set or self.total.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.total.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "path" or name == "path-tear" or name == "reservation-confirm" or name == "total"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "path"):
                                self.path = value
                                self.path.value_namespace = name_space
                                self.path.value_namespace_prefix = name_space_prefix
                            if(value_path == "path-tear"):
                                self.path_tear = value
                                self.path_tear.value_namespace = name_space
                                self.path_tear.value_namespace_prefix = name_space_prefix
                            if(value_path == "reservation-confirm"):
                                self.reservation_confirm = value
                                self.reservation_confirm.value_namespace = name_space
                                self.reservation_confirm.value_namespace_prefix = name_space_prefix
                            if(value_path == "total"):
                                self.total = value
                                self.total.value_namespace = name_space
                                self.total.value_namespace_prefix = name_space_prefix


                    class Total(Entity):
                        """
                        Count of total messages
                        
                        .. attribute:: path
                        
                        	Count of Path messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: path_tear
                        
                        	Count of PathTear messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: reservation_confirm
                        
                        	Count of ReservationConfirm messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total
                        
                        	Total count of messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.Counters.PrefixFiltering.Interfaces.Summary.Total, self).__init__()

                            self.yang_name = "total"
                            self.yang_parent_name = "summary"

                            self.path = YLeaf(YType.uint32, "path")

                            self.path_tear = YLeaf(YType.uint32, "path-tear")

                            self.reservation_confirm = YLeaf(YType.uint32, "reservation-confirm")

                            self.total = YLeaf(YType.uint32, "total")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("path",
                                            "path_tear",
                                            "reservation_confirm",
                                            "total") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.Counters.PrefixFiltering.Interfaces.Summary.Total, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.Counters.PrefixFiltering.Interfaces.Summary.Total, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.path.is_set or
                                self.path_tear.is_set or
                                self.reservation_confirm.is_set or
                                self.total.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.path.yfilter != YFilter.not_set or
                                self.path_tear.yfilter != YFilter.not_set or
                                self.reservation_confirm.yfilter != YFilter.not_set or
                                self.total.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "total" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/counters/prefix-filtering/interfaces/summary/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.path.is_set or self.path.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.path.get_name_leafdata())
                            if (self.path_tear.is_set or self.path_tear.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.path_tear.get_name_leafdata())
                            if (self.reservation_confirm.is_set or self.reservation_confirm.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.reservation_confirm.get_name_leafdata())
                            if (self.total.is_set or self.total.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.total.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "path" or name == "path-tear" or name == "reservation-confirm" or name == "total"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "path"):
                                self.path = value
                                self.path.value_namespace = name_space
                                self.path.value_namespace_prefix = name_space_prefix
                            if(value_path == "path-tear"):
                                self.path_tear = value
                                self.path_tear.value_namespace = name_space
                                self.path_tear.value_namespace_prefix = name_space_prefix
                            if(value_path == "reservation-confirm"):
                                self.reservation_confirm = value
                                self.reservation_confirm.value_namespace = name_space
                                self.reservation_confirm.value_namespace_prefix = name_space_prefix
                            if(value_path == "total"):
                                self.total = value
                                self.total.value_namespace = name_space
                                self.total.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            (self.default_action_dropped is not None and self.default_action_dropped.has_data()) or
                            (self.default_action_processed is not None and self.default_action_processed.has_data()) or
                            (self.dropped is not None and self.dropped.has_data()) or
                            (self.forwarded is not None and self.forwarded.has_data()) or
                            (self.locally_destined is not None and self.locally_destined.has_data()) or
                            (self.total is not None and self.total.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.default_action_dropped is not None and self.default_action_dropped.has_operation()) or
                            (self.default_action_processed is not None and self.default_action_processed.has_operation()) or
                            (self.dropped is not None and self.dropped.has_operation()) or
                            (self.forwarded is not None and self.forwarded.has_operation()) or
                            (self.locally_destined is not None and self.locally_destined.has_operation()) or
                            (self.total is not None and self.total.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "summary" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/counters/prefix-filtering/interfaces/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "default-action-dropped"):
                            if (self.default_action_dropped is None):
                                self.default_action_dropped = RsvpStandby.Counters.PrefixFiltering.Interfaces.Summary.DefaultActionDropped()
                                self.default_action_dropped.parent = self
                                self._children_name_map["default_action_dropped"] = "default-action-dropped"
                            return self.default_action_dropped

                        if (child_yang_name == "default-action-processed"):
                            if (self.default_action_processed is None):
                                self.default_action_processed = RsvpStandby.Counters.PrefixFiltering.Interfaces.Summary.DefaultActionProcessed()
                                self.default_action_processed.parent = self
                                self._children_name_map["default_action_processed"] = "default-action-processed"
                            return self.default_action_processed

                        if (child_yang_name == "dropped"):
                            if (self.dropped is None):
                                self.dropped = RsvpStandby.Counters.PrefixFiltering.Interfaces.Summary.Dropped()
                                self.dropped.parent = self
                                self._children_name_map["dropped"] = "dropped"
                            return self.dropped

                        if (child_yang_name == "forwarded"):
                            if (self.forwarded is None):
                                self.forwarded = RsvpStandby.Counters.PrefixFiltering.Interfaces.Summary.Forwarded()
                                self.forwarded.parent = self
                                self._children_name_map["forwarded"] = "forwarded"
                            return self.forwarded

                        if (child_yang_name == "locally-destined"):
                            if (self.locally_destined is None):
                                self.locally_destined = RsvpStandby.Counters.PrefixFiltering.Interfaces.Summary.LocallyDestined()
                                self.locally_destined.parent = self
                                self._children_name_map["locally_destined"] = "locally-destined"
                            return self.locally_destined

                        if (child_yang_name == "total"):
                            if (self.total is None):
                                self.total = RsvpStandby.Counters.PrefixFiltering.Interfaces.Summary.Total()
                                self.total.parent = self
                                self._children_name_map["total"] = "total"
                            return self.total

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "default-action-dropped" or name == "default-action-processed" or name == "dropped" or name == "forwarded" or name == "locally-destined" or name == "total"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class Interfaces(Entity):
                    """
                    Table of interface specific prefix filtering
                    counters
                    
                    .. attribute:: interface
                    
                    	Prefix filtering counters for a specific interface
                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Counters.PrefixFiltering.Interfaces.Interfaces.Interface>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.Counters.PrefixFiltering.Interfaces.Interfaces, self).__init__()

                        self.yang_name = "interfaces"
                        self.yang_parent_name = "interfaces"

                        self.interface = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.Counters.PrefixFiltering.Interfaces.Interfaces, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.Counters.PrefixFiltering.Interfaces.Interfaces, self).__setattr__(name, value)


                    class Interface(Entity):
                        """
                        Prefix filtering counters for a specific
                        interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface Name. 'None' is used internally where the true interface is unknown (e.g. for routed packets)
                        	**type**\:  str
                        
                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                        
                        .. attribute:: default_action_dropped
                        
                        	Count of messages which got dropped due to default ACL action
                        	**type**\:   :py:class:`DefaultActionDropped <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.DefaultActionDropped>`
                        
                        .. attribute:: default_action_processed
                        
                        	Count of messages which were processed due to default ACL action
                        	**type**\:   :py:class:`DefaultActionProcessed <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.DefaultActionProcessed>`
                        
                        .. attribute:: dropped
                        
                        	Count of messages dropped
                        	**type**\:   :py:class:`Dropped <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.Dropped>`
                        
                        .. attribute:: forwarded
                        
                        	Count of messages which got forwarded
                        	**type**\:   :py:class:`Forwarded <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.Forwarded>`
                        
                        .. attribute:: locally_destined
                        
                        	Count of locally destined messages
                        	**type**\:   :py:class:`LocallyDestined <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.LocallyDestined>`
                        
                        .. attribute:: total
                        
                        	Count of total messages
                        	**type**\:   :py:class:`Total <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.Total>`
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.Counters.PrefixFiltering.Interfaces.Interfaces.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "interfaces"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.default_action_dropped = RsvpStandby.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.DefaultActionDropped()
                            self.default_action_dropped.parent = self
                            self._children_name_map["default_action_dropped"] = "default-action-dropped"
                            self._children_yang_names.add("default-action-dropped")

                            self.default_action_processed = RsvpStandby.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.DefaultActionProcessed()
                            self.default_action_processed.parent = self
                            self._children_name_map["default_action_processed"] = "default-action-processed"
                            self._children_yang_names.add("default-action-processed")

                            self.dropped = RsvpStandby.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.Dropped()
                            self.dropped.parent = self
                            self._children_name_map["dropped"] = "dropped"
                            self._children_yang_names.add("dropped")

                            self.forwarded = RsvpStandby.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.Forwarded()
                            self.forwarded.parent = self
                            self._children_name_map["forwarded"] = "forwarded"
                            self._children_yang_names.add("forwarded")

                            self.locally_destined = RsvpStandby.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.LocallyDestined()
                            self.locally_destined.parent = self
                            self._children_name_map["locally_destined"] = "locally-destined"
                            self._children_yang_names.add("locally-destined")

                            self.total = RsvpStandby.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.Total()
                            self.total.parent = self
                            self._children_name_map["total"] = "total"
                            self._children_yang_names.add("total")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.Counters.PrefixFiltering.Interfaces.Interfaces.Interface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.Counters.PrefixFiltering.Interfaces.Interfaces.Interface, self).__setattr__(name, value)


                        class Forwarded(Entity):
                            """
                            Count of messages which got forwarded
                            
                            .. attribute:: path
                            
                            	Count of Path messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: path_tear
                            
                            	Count of PathTear messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: reservation_confirm
                            
                            	Count of ReservationConfirm messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: total
                            
                            	Total count of messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(RsvpStandby.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.Forwarded, self).__init__()

                                self.yang_name = "forwarded"
                                self.yang_parent_name = "interface"

                                self.path = YLeaf(YType.uint32, "path")

                                self.path_tear = YLeaf(YType.uint32, "path-tear")

                                self.reservation_confirm = YLeaf(YType.uint32, "reservation-confirm")

                                self.total = YLeaf(YType.uint32, "total")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("path",
                                                "path_tear",
                                                "reservation_confirm",
                                                "total") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(RsvpStandby.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.Forwarded, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(RsvpStandby.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.Forwarded, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.path.is_set or
                                    self.path_tear.is_set or
                                    self.reservation_confirm.is_set or
                                    self.total.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.path.yfilter != YFilter.not_set or
                                    self.path_tear.yfilter != YFilter.not_set or
                                    self.reservation_confirm.yfilter != YFilter.not_set or
                                    self.total.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "forwarded" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.path.is_set or self.path.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path.get_name_leafdata())
                                if (self.path_tear.is_set or self.path_tear.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path_tear.get_name_leafdata())
                                if (self.reservation_confirm.is_set or self.reservation_confirm.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.reservation_confirm.get_name_leafdata())
                                if (self.total.is_set or self.total.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.total.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "path" or name == "path-tear" or name == "reservation-confirm" or name == "total"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "path"):
                                    self.path = value
                                    self.path.value_namespace = name_space
                                    self.path.value_namespace_prefix = name_space_prefix
                                if(value_path == "path-tear"):
                                    self.path_tear = value
                                    self.path_tear.value_namespace = name_space
                                    self.path_tear.value_namespace_prefix = name_space_prefix
                                if(value_path == "reservation-confirm"):
                                    self.reservation_confirm = value
                                    self.reservation_confirm.value_namespace = name_space
                                    self.reservation_confirm.value_namespace_prefix = name_space_prefix
                                if(value_path == "total"):
                                    self.total = value
                                    self.total.value_namespace = name_space
                                    self.total.value_namespace_prefix = name_space_prefix


                        class LocallyDestined(Entity):
                            """
                            Count of locally destined messages
                            
                            .. attribute:: path
                            
                            	Count of Path messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: path_tear
                            
                            	Count of PathTear messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: reservation_confirm
                            
                            	Count of ReservationConfirm messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: total
                            
                            	Total count of messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(RsvpStandby.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.LocallyDestined, self).__init__()

                                self.yang_name = "locally-destined"
                                self.yang_parent_name = "interface"

                                self.path = YLeaf(YType.uint32, "path")

                                self.path_tear = YLeaf(YType.uint32, "path-tear")

                                self.reservation_confirm = YLeaf(YType.uint32, "reservation-confirm")

                                self.total = YLeaf(YType.uint32, "total")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("path",
                                                "path_tear",
                                                "reservation_confirm",
                                                "total") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(RsvpStandby.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.LocallyDestined, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(RsvpStandby.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.LocallyDestined, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.path.is_set or
                                    self.path_tear.is_set or
                                    self.reservation_confirm.is_set or
                                    self.total.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.path.yfilter != YFilter.not_set or
                                    self.path_tear.yfilter != YFilter.not_set or
                                    self.reservation_confirm.yfilter != YFilter.not_set or
                                    self.total.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "locally-destined" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.path.is_set or self.path.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path.get_name_leafdata())
                                if (self.path_tear.is_set or self.path_tear.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path_tear.get_name_leafdata())
                                if (self.reservation_confirm.is_set or self.reservation_confirm.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.reservation_confirm.get_name_leafdata())
                                if (self.total.is_set or self.total.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.total.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "path" or name == "path-tear" or name == "reservation-confirm" or name == "total"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "path"):
                                    self.path = value
                                    self.path.value_namespace = name_space
                                    self.path.value_namespace_prefix = name_space_prefix
                                if(value_path == "path-tear"):
                                    self.path_tear = value
                                    self.path_tear.value_namespace = name_space
                                    self.path_tear.value_namespace_prefix = name_space_prefix
                                if(value_path == "reservation-confirm"):
                                    self.reservation_confirm = value
                                    self.reservation_confirm.value_namespace = name_space
                                    self.reservation_confirm.value_namespace_prefix = name_space_prefix
                                if(value_path == "total"):
                                    self.total = value
                                    self.total.value_namespace = name_space
                                    self.total.value_namespace_prefix = name_space_prefix


                        class Dropped(Entity):
                            """
                            Count of messages dropped
                            
                            .. attribute:: path
                            
                            	Count of Path messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: path_tear
                            
                            	Count of PathTear messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: reservation_confirm
                            
                            	Count of ReservationConfirm messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: total
                            
                            	Total count of messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(RsvpStandby.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.Dropped, self).__init__()

                                self.yang_name = "dropped"
                                self.yang_parent_name = "interface"

                                self.path = YLeaf(YType.uint32, "path")

                                self.path_tear = YLeaf(YType.uint32, "path-tear")

                                self.reservation_confirm = YLeaf(YType.uint32, "reservation-confirm")

                                self.total = YLeaf(YType.uint32, "total")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("path",
                                                "path_tear",
                                                "reservation_confirm",
                                                "total") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(RsvpStandby.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.Dropped, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(RsvpStandby.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.Dropped, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.path.is_set or
                                    self.path_tear.is_set or
                                    self.reservation_confirm.is_set or
                                    self.total.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.path.yfilter != YFilter.not_set or
                                    self.path_tear.yfilter != YFilter.not_set or
                                    self.reservation_confirm.yfilter != YFilter.not_set or
                                    self.total.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "dropped" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.path.is_set or self.path.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path.get_name_leafdata())
                                if (self.path_tear.is_set or self.path_tear.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path_tear.get_name_leafdata())
                                if (self.reservation_confirm.is_set or self.reservation_confirm.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.reservation_confirm.get_name_leafdata())
                                if (self.total.is_set or self.total.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.total.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "path" or name == "path-tear" or name == "reservation-confirm" or name == "total"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "path"):
                                    self.path = value
                                    self.path.value_namespace = name_space
                                    self.path.value_namespace_prefix = name_space_prefix
                                if(value_path == "path-tear"):
                                    self.path_tear = value
                                    self.path_tear.value_namespace = name_space
                                    self.path_tear.value_namespace_prefix = name_space_prefix
                                if(value_path == "reservation-confirm"):
                                    self.reservation_confirm = value
                                    self.reservation_confirm.value_namespace = name_space
                                    self.reservation_confirm.value_namespace_prefix = name_space_prefix
                                if(value_path == "total"):
                                    self.total = value
                                    self.total.value_namespace = name_space
                                    self.total.value_namespace_prefix = name_space_prefix


                        class DefaultActionDropped(Entity):
                            """
                            Count of messages which got dropped due to
                            default ACL action
                            
                            .. attribute:: path
                            
                            	Count of Path messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: path_tear
                            
                            	Count of PathTear messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: reservation_confirm
                            
                            	Count of ReservationConfirm messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: total
                            
                            	Total count of messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(RsvpStandby.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.DefaultActionDropped, self).__init__()

                                self.yang_name = "default-action-dropped"
                                self.yang_parent_name = "interface"

                                self.path = YLeaf(YType.uint32, "path")

                                self.path_tear = YLeaf(YType.uint32, "path-tear")

                                self.reservation_confirm = YLeaf(YType.uint32, "reservation-confirm")

                                self.total = YLeaf(YType.uint32, "total")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("path",
                                                "path_tear",
                                                "reservation_confirm",
                                                "total") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(RsvpStandby.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.DefaultActionDropped, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(RsvpStandby.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.DefaultActionDropped, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.path.is_set or
                                    self.path_tear.is_set or
                                    self.reservation_confirm.is_set or
                                    self.total.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.path.yfilter != YFilter.not_set or
                                    self.path_tear.yfilter != YFilter.not_set or
                                    self.reservation_confirm.yfilter != YFilter.not_set or
                                    self.total.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "default-action-dropped" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.path.is_set or self.path.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path.get_name_leafdata())
                                if (self.path_tear.is_set or self.path_tear.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path_tear.get_name_leafdata())
                                if (self.reservation_confirm.is_set or self.reservation_confirm.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.reservation_confirm.get_name_leafdata())
                                if (self.total.is_set or self.total.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.total.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "path" or name == "path-tear" or name == "reservation-confirm" or name == "total"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "path"):
                                    self.path = value
                                    self.path.value_namespace = name_space
                                    self.path.value_namespace_prefix = name_space_prefix
                                if(value_path == "path-tear"):
                                    self.path_tear = value
                                    self.path_tear.value_namespace = name_space
                                    self.path_tear.value_namespace_prefix = name_space_prefix
                                if(value_path == "reservation-confirm"):
                                    self.reservation_confirm = value
                                    self.reservation_confirm.value_namespace = name_space
                                    self.reservation_confirm.value_namespace_prefix = name_space_prefix
                                if(value_path == "total"):
                                    self.total = value
                                    self.total.value_namespace = name_space
                                    self.total.value_namespace_prefix = name_space_prefix


                        class DefaultActionProcessed(Entity):
                            """
                            Count of messages which were processed due to
                            default ACL action
                            
                            .. attribute:: path
                            
                            	Count of Path messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: path_tear
                            
                            	Count of PathTear messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: reservation_confirm
                            
                            	Count of ReservationConfirm messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: total
                            
                            	Total count of messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(RsvpStandby.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.DefaultActionProcessed, self).__init__()

                                self.yang_name = "default-action-processed"
                                self.yang_parent_name = "interface"

                                self.path = YLeaf(YType.uint32, "path")

                                self.path_tear = YLeaf(YType.uint32, "path-tear")

                                self.reservation_confirm = YLeaf(YType.uint32, "reservation-confirm")

                                self.total = YLeaf(YType.uint32, "total")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("path",
                                                "path_tear",
                                                "reservation_confirm",
                                                "total") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(RsvpStandby.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.DefaultActionProcessed, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(RsvpStandby.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.DefaultActionProcessed, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.path.is_set or
                                    self.path_tear.is_set or
                                    self.reservation_confirm.is_set or
                                    self.total.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.path.yfilter != YFilter.not_set or
                                    self.path_tear.yfilter != YFilter.not_set or
                                    self.reservation_confirm.yfilter != YFilter.not_set or
                                    self.total.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "default-action-processed" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.path.is_set or self.path.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path.get_name_leafdata())
                                if (self.path_tear.is_set or self.path_tear.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path_tear.get_name_leafdata())
                                if (self.reservation_confirm.is_set or self.reservation_confirm.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.reservation_confirm.get_name_leafdata())
                                if (self.total.is_set or self.total.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.total.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "path" or name == "path-tear" or name == "reservation-confirm" or name == "total"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "path"):
                                    self.path = value
                                    self.path.value_namespace = name_space
                                    self.path.value_namespace_prefix = name_space_prefix
                                if(value_path == "path-tear"):
                                    self.path_tear = value
                                    self.path_tear.value_namespace = name_space
                                    self.path_tear.value_namespace_prefix = name_space_prefix
                                if(value_path == "reservation-confirm"):
                                    self.reservation_confirm = value
                                    self.reservation_confirm.value_namespace = name_space
                                    self.reservation_confirm.value_namespace_prefix = name_space_prefix
                                if(value_path == "total"):
                                    self.total = value
                                    self.total.value_namespace = name_space
                                    self.total.value_namespace_prefix = name_space_prefix


                        class Total(Entity):
                            """
                            Count of total messages
                            
                            .. attribute:: path
                            
                            	Count of Path messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: path_tear
                            
                            	Count of PathTear messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: reservation_confirm
                            
                            	Count of ReservationConfirm messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: total
                            
                            	Total count of messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(RsvpStandby.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.Total, self).__init__()

                                self.yang_name = "total"
                                self.yang_parent_name = "interface"

                                self.path = YLeaf(YType.uint32, "path")

                                self.path_tear = YLeaf(YType.uint32, "path-tear")

                                self.reservation_confirm = YLeaf(YType.uint32, "reservation-confirm")

                                self.total = YLeaf(YType.uint32, "total")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("path",
                                                "path_tear",
                                                "reservation_confirm",
                                                "total") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(RsvpStandby.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.Total, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(RsvpStandby.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.Total, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.path.is_set or
                                    self.path_tear.is_set or
                                    self.reservation_confirm.is_set or
                                    self.total.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.path.yfilter != YFilter.not_set or
                                    self.path_tear.yfilter != YFilter.not_set or
                                    self.reservation_confirm.yfilter != YFilter.not_set or
                                    self.total.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "total" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.path.is_set or self.path.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path.get_name_leafdata())
                                if (self.path_tear.is_set or self.path_tear.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path_tear.get_name_leafdata())
                                if (self.reservation_confirm.is_set or self.reservation_confirm.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.reservation_confirm.get_name_leafdata())
                                if (self.total.is_set or self.total.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.total.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "path" or name == "path-tear" or name == "reservation-confirm" or name == "total"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "path"):
                                    self.path = value
                                    self.path.value_namespace = name_space
                                    self.path.value_namespace_prefix = name_space_prefix
                                if(value_path == "path-tear"):
                                    self.path_tear = value
                                    self.path_tear.value_namespace = name_space
                                    self.path_tear.value_namespace_prefix = name_space_prefix
                                if(value_path == "reservation-confirm"):
                                    self.reservation_confirm = value
                                    self.reservation_confirm.value_namespace = name_space
                                    self.reservation_confirm.value_namespace_prefix = name_space_prefix
                                if(value_path == "total"):
                                    self.total = value
                                    self.total.value_namespace = name_space
                                    self.total.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.interface_name.is_set or
                                (self.default_action_dropped is not None and self.default_action_dropped.has_data()) or
                                (self.default_action_processed is not None and self.default_action_processed.has_data()) or
                                (self.dropped is not None and self.dropped.has_data()) or
                                (self.forwarded is not None and self.forwarded.has_data()) or
                                (self.locally_destined is not None and self.locally_destined.has_data()) or
                                (self.total is not None and self.total.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                (self.default_action_dropped is not None and self.default_action_dropped.has_operation()) or
                                (self.default_action_processed is not None and self.default_action_processed.has_operation()) or
                                (self.dropped is not None and self.dropped.has_operation()) or
                                (self.forwarded is not None and self.forwarded.has_operation()) or
                                (self.locally_destined is not None and self.locally_destined.has_operation()) or
                                (self.total is not None and self.total.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/counters/prefix-filtering/interfaces/interfaces/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "default-action-dropped"):
                                if (self.default_action_dropped is None):
                                    self.default_action_dropped = RsvpStandby.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.DefaultActionDropped()
                                    self.default_action_dropped.parent = self
                                    self._children_name_map["default_action_dropped"] = "default-action-dropped"
                                return self.default_action_dropped

                            if (child_yang_name == "default-action-processed"):
                                if (self.default_action_processed is None):
                                    self.default_action_processed = RsvpStandby.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.DefaultActionProcessed()
                                    self.default_action_processed.parent = self
                                    self._children_name_map["default_action_processed"] = "default-action-processed"
                                return self.default_action_processed

                            if (child_yang_name == "dropped"):
                                if (self.dropped is None):
                                    self.dropped = RsvpStandby.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.Dropped()
                                    self.dropped.parent = self
                                    self._children_name_map["dropped"] = "dropped"
                                return self.dropped

                            if (child_yang_name == "forwarded"):
                                if (self.forwarded is None):
                                    self.forwarded = RsvpStandby.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.Forwarded()
                                    self.forwarded.parent = self
                                    self._children_name_map["forwarded"] = "forwarded"
                                return self.forwarded

                            if (child_yang_name == "locally-destined"):
                                if (self.locally_destined is None):
                                    self.locally_destined = RsvpStandby.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.LocallyDestined()
                                    self.locally_destined.parent = self
                                    self._children_name_map["locally_destined"] = "locally-destined"
                                return self.locally_destined

                            if (child_yang_name == "total"):
                                if (self.total is None):
                                    self.total = RsvpStandby.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.Total()
                                    self.total.parent = self
                                    self._children_name_map["total"] = "total"
                                return self.total

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "default-action-dropped" or name == "default-action-processed" or name == "dropped" or name == "forwarded" or name == "locally-destined" or name == "total" or name == "interface-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.interface:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interfaces" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/counters/prefix-filtering/interfaces/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "interface"):
                            for c in self.interface:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = RsvpStandby.Counters.PrefixFiltering.Interfaces.Interfaces.Interface()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        (self.interfaces is not None and self.interfaces.has_data()) or
                        (self.summary is not None and self.summary.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.interfaces is not None and self.interfaces.has_operation()) or
                        (self.summary is not None and self.summary.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "interfaces" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/counters/prefix-filtering/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interfaces"):
                        if (self.interfaces is None):
                            self.interfaces = RsvpStandby.Counters.PrefixFiltering.Interfaces.Interfaces()
                            self.interfaces.parent = self
                            self._children_name_map["interfaces"] = "interfaces"
                        return self.interfaces

                    if (child_yang_name == "summary"):
                        if (self.summary is None):
                            self.summary = RsvpStandby.Counters.PrefixFiltering.Interfaces.Summary()
                            self.summary.parent = self
                            self._children_name_map["summary"] = "summary"
                        return self.summary

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interfaces" or name == "summary"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (
                    (self.accesses is not None and self.accesses.has_data()) or
                    (self.interfaces is not None and self.interfaces.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.accesses is not None and self.accesses.has_operation()) or
                    (self.interfaces is not None and self.interfaces.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "prefix-filtering" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/counters/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "accesses"):
                    if (self.accesses is None):
                        self.accesses = RsvpStandby.Counters.PrefixFiltering.Accesses()
                        self.accesses.parent = self
                        self._children_name_map["accesses"] = "accesses"
                    return self.accesses

                if (child_yang_name == "interfaces"):
                    if (self.interfaces is None):
                        self.interfaces = RsvpStandby.Counters.PrefixFiltering.Interfaces()
                        self.interfaces.parent = self
                        self._children_name_map["interfaces"] = "interfaces"
                    return self.interfaces

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "accesses" or name == "interfaces"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class OutOfResource(Entity):
            """
            Out of resource counters
            
            .. attribute:: interfaces
            
            	Interface specific out of resource counters
            	**type**\:   :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Counters.OutOfResource.Interfaces>`
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(RsvpStandby.Counters.OutOfResource, self).__init__()

                self.yang_name = "out-of-resource"
                self.yang_parent_name = "counters"

                self.interfaces = RsvpStandby.Counters.OutOfResource.Interfaces()
                self.interfaces.parent = self
                self._children_name_map["interfaces"] = "interfaces"
                self._children_yang_names.add("interfaces")


            class Interfaces(Entity):
                """
                Interface specific out of resource counters
                
                .. attribute:: interfaces
                
                	Table of interface specific out of resource counters
                	**type**\:   :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Counters.OutOfResource.Interfaces.Interfaces>`
                
                .. attribute:: summary
                
                	Summary of out of resource counts for all interfaces
                	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Counters.OutOfResource.Interfaces.Summary>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.Counters.OutOfResource.Interfaces, self).__init__()

                    self.yang_name = "interfaces"
                    self.yang_parent_name = "out-of-resource"

                    self.interfaces = RsvpStandby.Counters.OutOfResource.Interfaces.Interfaces()
                    self.interfaces.parent = self
                    self._children_name_map["interfaces"] = "interfaces"
                    self._children_yang_names.add("interfaces")

                    self.summary = RsvpStandby.Counters.OutOfResource.Interfaces.Summary()
                    self.summary.parent = self
                    self._children_name_map["summary"] = "summary"
                    self._children_yang_names.add("summary")


                class Summary(Entity):
                    """
                    Summary of out of resource counts for all
                    interfaces
                    
                    .. attribute:: dropped_path_messages
                    
                    	Count of Path messages dropped due to an out of resource condition
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.Counters.OutOfResource.Interfaces.Summary, self).__init__()

                        self.yang_name = "summary"
                        self.yang_parent_name = "interfaces"

                        self.dropped_path_messages = YLeaf(YType.uint32, "dropped-path-messages")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("dropped_path_messages") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.Counters.OutOfResource.Interfaces.Summary, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.Counters.OutOfResource.Interfaces.Summary, self).__setattr__(name, value)

                    def has_data(self):
                        return self.dropped_path_messages.is_set

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.dropped_path_messages.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "summary" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/counters/out-of-resource/interfaces/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.dropped_path_messages.is_set or self.dropped_path_messages.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.dropped_path_messages.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "dropped-path-messages"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "dropped-path-messages"):
                            self.dropped_path_messages = value
                            self.dropped_path_messages.value_namespace = name_space
                            self.dropped_path_messages.value_namespace_prefix = name_space_prefix


                class Interfaces(Entity):
                    """
                    Table of interface specific out of resource
                    counters
                    
                    .. attribute:: interface
                    
                    	Out of resource counters for a specific interface
                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Counters.OutOfResource.Interfaces.Interfaces.Interface>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.Counters.OutOfResource.Interfaces.Interfaces, self).__init__()

                        self.yang_name = "interfaces"
                        self.yang_parent_name = "interfaces"

                        self.interface = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.Counters.OutOfResource.Interfaces.Interfaces, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.Counters.OutOfResource.Interfaces.Interfaces, self).__setattr__(name, value)


                    class Interface(Entity):
                        """
                        Out of resource counters for a specific
                        interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface Name. 'None' is used internally where the true interface is unknown (e.g. for routed packets)
                        	**type**\:  str
                        
                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                        
                        .. attribute:: dropped_path_messages
                        
                        	Count of Path messages dropped due to an out of resource condition
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.Counters.OutOfResource.Interfaces.Interfaces.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "interfaces"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.dropped_path_messages = YLeaf(YType.uint32, "dropped-path-messages")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "dropped_path_messages") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.Counters.OutOfResource.Interfaces.Interfaces.Interface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.Counters.OutOfResource.Interfaces.Interfaces.Interface, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.interface_name.is_set or
                                self.dropped_path_messages.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.dropped_path_messages.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/counters/out-of-resource/interfaces/interfaces/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.dropped_path_messages.is_set or self.dropped_path_messages.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.dropped_path_messages.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "interface-name" or name == "dropped-path-messages"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "dropped-path-messages"):
                                self.dropped_path_messages = value
                                self.dropped_path_messages.value_namespace = name_space
                                self.dropped_path_messages.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.interface:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interfaces" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/counters/out-of-resource/interfaces/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "interface"):
                            for c in self.interface:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = RsvpStandby.Counters.OutOfResource.Interfaces.Interfaces.Interface()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        (self.interfaces is not None and self.interfaces.has_data()) or
                        (self.summary is not None and self.summary.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.interfaces is not None and self.interfaces.has_operation()) or
                        (self.summary is not None and self.summary.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "interfaces" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/counters/out-of-resource/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interfaces"):
                        if (self.interfaces is None):
                            self.interfaces = RsvpStandby.Counters.OutOfResource.Interfaces.Interfaces()
                            self.interfaces.parent = self
                            self._children_name_map["interfaces"] = "interfaces"
                        return self.interfaces

                    if (child_yang_name == "summary"):
                        if (self.summary is None):
                            self.summary = RsvpStandby.Counters.OutOfResource.Interfaces.Summary()
                            self.summary.parent = self
                            self._children_name_map["summary"] = "summary"
                        return self.summary

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interfaces" or name == "summary"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (self.interfaces is not None and self.interfaces.has_data())

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.interfaces is not None and self.interfaces.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "out-of-resource" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/counters/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "interfaces"):
                    if (self.interfaces is None):
                        self.interfaces = RsvpStandby.Counters.OutOfResource.Interfaces()
                        self.interfaces.parent = self
                        self._children_name_map["interfaces"] = "interfaces"
                    return self.interfaces

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "interfaces"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class InterfaceEvents(Entity):
            """
            Event counters
            
            .. attribute:: interface_event
            
            	Event counters for an interface
            	**type**\: list of    :py:class:`InterfaceEvent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Counters.InterfaceEvents.InterfaceEvent>`
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(RsvpStandby.Counters.InterfaceEvents, self).__init__()

                self.yang_name = "interface-events"
                self.yang_parent_name = "counters"

                self.interface_event = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(RsvpStandby.Counters.InterfaceEvents, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(RsvpStandby.Counters.InterfaceEvents, self).__setattr__(name, value)


            class InterfaceEvent(Entity):
                """
                Event counters for an interface
                
                .. attribute:: interface_name  <key>
                
                	Interface Name. 'None' is used internally where the true interface is unknown (e.g. for routed packets)
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: expired_paths
                
                	Counter for Expired Path states
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: expired_reservations
                
                	Counter for Expired Reservation states
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: nac_ks
                
                	Counter for NACKs received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.Counters.InterfaceEvents.InterfaceEvent, self).__init__()

                    self.yang_name = "interface-event"
                    self.yang_parent_name = "interface-events"

                    self.interface_name = YLeaf(YType.str, "interface-name")

                    self.expired_paths = YLeaf(YType.uint32, "expired-paths")

                    self.expired_reservations = YLeaf(YType.uint32, "expired-reservations")

                    self.nac_ks = YLeaf(YType.uint32, "nac-ks")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("interface_name",
                                    "expired_paths",
                                    "expired_reservations",
                                    "nac_ks") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.Counters.InterfaceEvents.InterfaceEvent, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.Counters.InterfaceEvents.InterfaceEvent, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.interface_name.is_set or
                        self.expired_paths.is_set or
                        self.expired_reservations.is_set or
                        self.nac_ks.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.interface_name.yfilter != YFilter.not_set or
                        self.expired_paths.yfilter != YFilter.not_set or
                        self.expired_reservations.yfilter != YFilter.not_set or
                        self.nac_ks.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "interface-event" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/counters/interface-events/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                    if (self.expired_paths.is_set or self.expired_paths.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.expired_paths.get_name_leafdata())
                    if (self.expired_reservations.is_set or self.expired_reservations.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.expired_reservations.get_name_leafdata())
                    if (self.nac_ks.is_set or self.nac_ks.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.nac_ks.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface-name" or name == "expired-paths" or name == "expired-reservations" or name == "nac-ks"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "interface-name"):
                        self.interface_name = value
                        self.interface_name.value_namespace = name_space
                        self.interface_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "expired-paths"):
                        self.expired_paths = value
                        self.expired_paths.value_namespace = name_space
                        self.expired_paths.value_namespace_prefix = name_space_prefix
                    if(value_path == "expired-reservations"):
                        self.expired_reservations = value
                        self.expired_reservations.value_namespace = name_space
                        self.expired_reservations.value_namespace_prefix = name_space_prefix
                    if(value_path == "nac-ks"):
                        self.nac_ks = value
                        self.nac_ks.value_namespace = name_space
                        self.nac_ks.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.interface_event:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.interface_event:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "interface-events" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/counters/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "interface-event"):
                    for c in self.interface_event:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = RsvpStandby.Counters.InterfaceEvents.InterfaceEvent()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.interface_event.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "interface-event"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class Nsr(Entity):
            """
            Summary information for all RSVP NSR counters
            
            .. attribute:: last_cleared_timestamp
            
            	The timestamp, in seconds, when these statistics are cleared              since 00\:00\:00 UTC, January 1, 1970
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            	**units**\: second
            
            .. attribute:: last_idt_states
            
            	Last IDT number of states
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: rsvp_process_role
            
            	Process role
            	**type**\:   :py:class:`RsvpProcRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpProcRole>`
            
            .. attribute:: total_deletions
            
            	Total number of deletions
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: total_id_ts
            
            	Total number of IDTs
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: total_nacks
            
            	Total number of NACKs
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: total_states
            
            	Total number of states
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(RsvpStandby.Counters.Nsr, self).__init__()

                self.yang_name = "nsr"
                self.yang_parent_name = "counters"

                self.last_cleared_timestamp = YLeaf(YType.uint32, "last-cleared-timestamp")

                self.last_idt_states = YLeaf(YType.uint32, "last-idt-states")

                self.rsvp_process_role = YLeaf(YType.enumeration, "rsvp-process-role")

                self.total_deletions = YLeaf(YType.uint32, "total-deletions")

                self.total_id_ts = YLeaf(YType.uint32, "total-id-ts")

                self.total_nacks = YLeaf(YType.uint64, "total-nacks")

                self.total_states = YLeaf(YType.uint32, "total-states")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("last_cleared_timestamp",
                                "last_idt_states",
                                "rsvp_process_role",
                                "total_deletions",
                                "total_id_ts",
                                "total_nacks",
                                "total_states") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(RsvpStandby.Counters.Nsr, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(RsvpStandby.Counters.Nsr, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.last_cleared_timestamp.is_set or
                    self.last_idt_states.is_set or
                    self.rsvp_process_role.is_set or
                    self.total_deletions.is_set or
                    self.total_id_ts.is_set or
                    self.total_nacks.is_set or
                    self.total_states.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.last_cleared_timestamp.yfilter != YFilter.not_set or
                    self.last_idt_states.yfilter != YFilter.not_set or
                    self.rsvp_process_role.yfilter != YFilter.not_set or
                    self.total_deletions.yfilter != YFilter.not_set or
                    self.total_id_ts.yfilter != YFilter.not_set or
                    self.total_nacks.yfilter != YFilter.not_set or
                    self.total_states.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "nsr" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/counters/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.last_cleared_timestamp.is_set or self.last_cleared_timestamp.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.last_cleared_timestamp.get_name_leafdata())
                if (self.last_idt_states.is_set or self.last_idt_states.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.last_idt_states.get_name_leafdata())
                if (self.rsvp_process_role.is_set or self.rsvp_process_role.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.rsvp_process_role.get_name_leafdata())
                if (self.total_deletions.is_set or self.total_deletions.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.total_deletions.get_name_leafdata())
                if (self.total_id_ts.is_set or self.total_id_ts.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.total_id_ts.get_name_leafdata())
                if (self.total_nacks.is_set or self.total_nacks.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.total_nacks.get_name_leafdata())
                if (self.total_states.is_set or self.total_states.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.total_states.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "last-cleared-timestamp" or name == "last-idt-states" or name == "rsvp-process-role" or name == "total-deletions" or name == "total-id-ts" or name == "total-nacks" or name == "total-states"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "last-cleared-timestamp"):
                    self.last_cleared_timestamp = value
                    self.last_cleared_timestamp.value_namespace = name_space
                    self.last_cleared_timestamp.value_namespace_prefix = name_space_prefix
                if(value_path == "last-idt-states"):
                    self.last_idt_states = value
                    self.last_idt_states.value_namespace = name_space
                    self.last_idt_states.value_namespace_prefix = name_space_prefix
                if(value_path == "rsvp-process-role"):
                    self.rsvp_process_role = value
                    self.rsvp_process_role.value_namespace = name_space
                    self.rsvp_process_role.value_namespace_prefix = name_space_prefix
                if(value_path == "total-deletions"):
                    self.total_deletions = value
                    self.total_deletions.value_namespace = name_space
                    self.total_deletions.value_namespace_prefix = name_space_prefix
                if(value_path == "total-id-ts"):
                    self.total_id_ts = value
                    self.total_id_ts.value_namespace = name_space
                    self.total_id_ts.value_namespace_prefix = name_space_prefix
                if(value_path == "total-nacks"):
                    self.total_nacks = value
                    self.total_nacks.value_namespace = name_space
                    self.total_nacks.value_namespace_prefix = name_space_prefix
                if(value_path == "total-states"):
                    self.total_states = value
                    self.total_states.value_namespace = name_space
                    self.total_states.value_namespace_prefix = name_space_prefix


        class Issu(Entity):
            """
            Summary information for all RSVP ISSU counters
            
            .. attribute:: last_cleared_timestamp
            
            	The timestamp, in seconds, when these statistics are cleared              since 00\:00\:00 UTC, January 1, 1970
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            	**units**\: second
            
            .. attribute:: last_idt_states
            
            	Last IDT number of states
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: rsvp_process_role
            
            	Process role
            	**type**\:   :py:class:`RsvpProcRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpProcRole>`
            
            .. attribute:: total_deletions
            
            	Total number of deletions
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: total_id_ts
            
            	Total number of IDTs
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: total_nacks
            
            	Total number of NACKs
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: total_states
            
            	Total number of states
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(RsvpStandby.Counters.Issu, self).__init__()

                self.yang_name = "issu"
                self.yang_parent_name = "counters"

                self.last_cleared_timestamp = YLeaf(YType.uint32, "last-cleared-timestamp")

                self.last_idt_states = YLeaf(YType.uint32, "last-idt-states")

                self.rsvp_process_role = YLeaf(YType.enumeration, "rsvp-process-role")

                self.total_deletions = YLeaf(YType.uint32, "total-deletions")

                self.total_id_ts = YLeaf(YType.uint32, "total-id-ts")

                self.total_nacks = YLeaf(YType.uint64, "total-nacks")

                self.total_states = YLeaf(YType.uint32, "total-states")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("last_cleared_timestamp",
                                "last_idt_states",
                                "rsvp_process_role",
                                "total_deletions",
                                "total_id_ts",
                                "total_nacks",
                                "total_states") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(RsvpStandby.Counters.Issu, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(RsvpStandby.Counters.Issu, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.last_cleared_timestamp.is_set or
                    self.last_idt_states.is_set or
                    self.rsvp_process_role.is_set or
                    self.total_deletions.is_set or
                    self.total_id_ts.is_set or
                    self.total_nacks.is_set or
                    self.total_states.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.last_cleared_timestamp.yfilter != YFilter.not_set or
                    self.last_idt_states.yfilter != YFilter.not_set or
                    self.rsvp_process_role.yfilter != YFilter.not_set or
                    self.total_deletions.yfilter != YFilter.not_set or
                    self.total_id_ts.yfilter != YFilter.not_set or
                    self.total_nacks.yfilter != YFilter.not_set or
                    self.total_states.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "issu" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/counters/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.last_cleared_timestamp.is_set or self.last_cleared_timestamp.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.last_cleared_timestamp.get_name_leafdata())
                if (self.last_idt_states.is_set or self.last_idt_states.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.last_idt_states.get_name_leafdata())
                if (self.rsvp_process_role.is_set or self.rsvp_process_role.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.rsvp_process_role.get_name_leafdata())
                if (self.total_deletions.is_set or self.total_deletions.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.total_deletions.get_name_leafdata())
                if (self.total_id_ts.is_set or self.total_id_ts.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.total_id_ts.get_name_leafdata())
                if (self.total_nacks.is_set or self.total_nacks.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.total_nacks.get_name_leafdata())
                if (self.total_states.is_set or self.total_states.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.total_states.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "last-cleared-timestamp" or name == "last-idt-states" or name == "rsvp-process-role" or name == "total-deletions" or name == "total-id-ts" or name == "total-nacks" or name == "total-states"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "last-cleared-timestamp"):
                    self.last_cleared_timestamp = value
                    self.last_cleared_timestamp.value_namespace = name_space
                    self.last_cleared_timestamp.value_namespace_prefix = name_space_prefix
                if(value_path == "last-idt-states"):
                    self.last_idt_states = value
                    self.last_idt_states.value_namespace = name_space
                    self.last_idt_states.value_namespace_prefix = name_space_prefix
                if(value_path == "rsvp-process-role"):
                    self.rsvp_process_role = value
                    self.rsvp_process_role.value_namespace = name_space
                    self.rsvp_process_role.value_namespace_prefix = name_space_prefix
                if(value_path == "total-deletions"):
                    self.total_deletions = value
                    self.total_deletions.value_namespace = name_space
                    self.total_deletions.value_namespace_prefix = name_space_prefix
                if(value_path == "total-id-ts"):
                    self.total_id_ts = value
                    self.total_id_ts.value_namespace = name_space
                    self.total_id_ts.value_namespace_prefix = name_space_prefix
                if(value_path == "total-nacks"):
                    self.total_nacks = value
                    self.total_nacks.value_namespace = name_space
                    self.total_nacks.value_namespace_prefix = name_space_prefix
                if(value_path == "total-states"):
                    self.total_states = value
                    self.total_states.value_namespace = name_space
                    self.total_states.value_namespace_prefix = name_space_prefix


        class Database(Entity):
            """
            Summary information for all RSVP database
            counters
            
            .. attribute:: incoming_paths
            
            	Number of locally created and incoming path states
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: incoming_reservations
            
            	Number of locally created and incoming reservation states
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: interfaces
            
            	Number of Interfaces
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: outgoing_paths
            
            	Number of outgoing path states
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: outgoing_reservations
            
            	Number of outgoing reservation states
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: sessions
            
            	Number of sessions
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(RsvpStandby.Counters.Database, self).__init__()

                self.yang_name = "database"
                self.yang_parent_name = "counters"

                self.incoming_paths = YLeaf(YType.uint32, "incoming-paths")

                self.incoming_reservations = YLeaf(YType.uint32, "incoming-reservations")

                self.interfaces = YLeaf(YType.uint32, "interfaces")

                self.outgoing_paths = YLeaf(YType.uint32, "outgoing-paths")

                self.outgoing_reservations = YLeaf(YType.uint32, "outgoing-reservations")

                self.sessions = YLeaf(YType.uint32, "sessions")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("incoming_paths",
                                "incoming_reservations",
                                "interfaces",
                                "outgoing_paths",
                                "outgoing_reservations",
                                "sessions") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(RsvpStandby.Counters.Database, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(RsvpStandby.Counters.Database, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.incoming_paths.is_set or
                    self.incoming_reservations.is_set or
                    self.interfaces.is_set or
                    self.outgoing_paths.is_set or
                    self.outgoing_reservations.is_set or
                    self.sessions.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.incoming_paths.yfilter != YFilter.not_set or
                    self.incoming_reservations.yfilter != YFilter.not_set or
                    self.interfaces.yfilter != YFilter.not_set or
                    self.outgoing_paths.yfilter != YFilter.not_set or
                    self.outgoing_reservations.yfilter != YFilter.not_set or
                    self.sessions.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "database" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/counters/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.incoming_paths.is_set or self.incoming_paths.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.incoming_paths.get_name_leafdata())
                if (self.incoming_reservations.is_set or self.incoming_reservations.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.incoming_reservations.get_name_leafdata())
                if (self.interfaces.is_set or self.interfaces.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.interfaces.get_name_leafdata())
                if (self.outgoing_paths.is_set or self.outgoing_paths.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.outgoing_paths.get_name_leafdata())
                if (self.outgoing_reservations.is_set or self.outgoing_reservations.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.outgoing_reservations.get_name_leafdata())
                if (self.sessions.is_set or self.sessions.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.sessions.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "incoming-paths" or name == "incoming-reservations" or name == "interfaces" or name == "outgoing-paths" or name == "outgoing-reservations" or name == "sessions"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "incoming-paths"):
                    self.incoming_paths = value
                    self.incoming_paths.value_namespace = name_space
                    self.incoming_paths.value_namespace_prefix = name_space_prefix
                if(value_path == "incoming-reservations"):
                    self.incoming_reservations = value
                    self.incoming_reservations.value_namespace = name_space
                    self.incoming_reservations.value_namespace_prefix = name_space_prefix
                if(value_path == "interfaces"):
                    self.interfaces = value
                    self.interfaces.value_namespace = name_space
                    self.interfaces.value_namespace_prefix = name_space_prefix
                if(value_path == "outgoing-paths"):
                    self.outgoing_paths = value
                    self.outgoing_paths.value_namespace = name_space
                    self.outgoing_paths.value_namespace_prefix = name_space_prefix
                if(value_path == "outgoing-reservations"):
                    self.outgoing_reservations = value
                    self.outgoing_reservations.value_namespace = name_space
                    self.outgoing_reservations.value_namespace_prefix = name_space_prefix
                if(value_path == "sessions"):
                    self.sessions = value
                    self.sessions.value_namespace = name_space
                    self.sessions.value_namespace_prefix = name_space_prefix


        class EventSyncs(Entity):
            """
            Table containing event sync counters
            
            .. attribute:: event_sync
            
            	Event sync counters
            	**type**\: list of    :py:class:`EventSync <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Counters.EventSyncs.EventSync>`
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(RsvpStandby.Counters.EventSyncs, self).__init__()

                self.yang_name = "event-syncs"
                self.yang_parent_name = "counters"

                self.event_sync = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(RsvpStandby.Counters.EventSyncs, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(RsvpStandby.Counters.EventSyncs, self).__setattr__(name, value)


            class EventSync(Entity):
                """
                Event sync counters
                
                .. attribute:: interface_name  <key>
                
                	Interface Name
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: expired_paths
                
                	Counter for Expired Path states
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: expired_reservations
                
                	Counter for Expired Reservation states
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: nac_ks
                
                	Counter for NACKs received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.Counters.EventSyncs.EventSync, self).__init__()

                    self.yang_name = "event-sync"
                    self.yang_parent_name = "event-syncs"

                    self.interface_name = YLeaf(YType.str, "interface-name")

                    self.expired_paths = YLeaf(YType.uint32, "expired-paths")

                    self.expired_reservations = YLeaf(YType.uint32, "expired-reservations")

                    self.nac_ks = YLeaf(YType.uint32, "nac-ks")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("interface_name",
                                    "expired_paths",
                                    "expired_reservations",
                                    "nac_ks") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.Counters.EventSyncs.EventSync, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.Counters.EventSyncs.EventSync, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.interface_name.is_set or
                        self.expired_paths.is_set or
                        self.expired_reservations.is_set or
                        self.nac_ks.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.interface_name.yfilter != YFilter.not_set or
                        self.expired_paths.yfilter != YFilter.not_set or
                        self.expired_reservations.yfilter != YFilter.not_set or
                        self.nac_ks.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "event-sync" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/counters/event-syncs/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                    if (self.expired_paths.is_set or self.expired_paths.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.expired_paths.get_name_leafdata())
                    if (self.expired_reservations.is_set or self.expired_reservations.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.expired_reservations.get_name_leafdata())
                    if (self.nac_ks.is_set or self.nac_ks.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.nac_ks.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface-name" or name == "expired-paths" or name == "expired-reservations" or name == "nac-ks"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "interface-name"):
                        self.interface_name = value
                        self.interface_name.value_namespace = name_space
                        self.interface_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "expired-paths"):
                        self.expired_paths = value
                        self.expired_paths.value_namespace = name_space
                        self.expired_paths.value_namespace_prefix = name_space_prefix
                    if(value_path == "expired-reservations"):
                        self.expired_reservations = value
                        self.expired_reservations.value_namespace = name_space
                        self.expired_reservations.value_namespace_prefix = name_space_prefix
                    if(value_path == "nac-ks"):
                        self.nac_ks = value
                        self.nac_ks.value_namespace = name_space
                        self.nac_ks.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.event_sync:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.event_sync:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "event-syncs" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/counters/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "event-sync"):
                    for c in self.event_sync:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = RsvpStandby.Counters.EventSyncs.EventSync()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.event_sync.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "event-sync"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass

        def has_data(self):
            return (
                (self.database is not None and self.database.has_data()) or
                (self.event_syncs is not None and self.event_syncs.has_data()) or
                (self.interface_events is not None and self.interface_events.has_data()) or
                (self.interface_messages is not None and self.interface_messages.has_data()) or
                (self.issu is not None and self.issu.has_data()) or
                (self.message_summary is not None and self.message_summary.has_data()) or
                (self.nsr is not None and self.nsr.has_data()) or
                (self.out_of_resource is not None and self.out_of_resource.has_data()) or
                (self.prefix_filtering is not None and self.prefix_filtering.has_data()))

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.database is not None and self.database.has_operation()) or
                (self.event_syncs is not None and self.event_syncs.has_operation()) or
                (self.interface_events is not None and self.interface_events.has_operation()) or
                (self.interface_messages is not None and self.interface_messages.has_operation()) or
                (self.issu is not None and self.issu.has_operation()) or
                (self.message_summary is not None and self.message_summary.has_operation()) or
                (self.nsr is not None and self.nsr.has_operation()) or
                (self.out_of_resource is not None and self.out_of_resource.has_operation()) or
                (self.prefix_filtering is not None and self.prefix_filtering.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "counters" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "database"):
                if (self.database is None):
                    self.database = RsvpStandby.Counters.Database()
                    self.database.parent = self
                    self._children_name_map["database"] = "database"
                return self.database

            if (child_yang_name == "event-syncs"):
                if (self.event_syncs is None):
                    self.event_syncs = RsvpStandby.Counters.EventSyncs()
                    self.event_syncs.parent = self
                    self._children_name_map["event_syncs"] = "event-syncs"
                return self.event_syncs

            if (child_yang_name == "interface-events"):
                if (self.interface_events is None):
                    self.interface_events = RsvpStandby.Counters.InterfaceEvents()
                    self.interface_events.parent = self
                    self._children_name_map["interface_events"] = "interface-events"
                return self.interface_events

            if (child_yang_name == "interface-messages"):
                if (self.interface_messages is None):
                    self.interface_messages = RsvpStandby.Counters.InterfaceMessages()
                    self.interface_messages.parent = self
                    self._children_name_map["interface_messages"] = "interface-messages"
                return self.interface_messages

            if (child_yang_name == "issu"):
                if (self.issu is None):
                    self.issu = RsvpStandby.Counters.Issu()
                    self.issu.parent = self
                    self._children_name_map["issu"] = "issu"
                return self.issu

            if (child_yang_name == "message-summary"):
                if (self.message_summary is None):
                    self.message_summary = RsvpStandby.Counters.MessageSummary()
                    self.message_summary.parent = self
                    self._children_name_map["message_summary"] = "message-summary"
                return self.message_summary

            if (child_yang_name == "nsr"):
                if (self.nsr is None):
                    self.nsr = RsvpStandby.Counters.Nsr()
                    self.nsr.parent = self
                    self._children_name_map["nsr"] = "nsr"
                return self.nsr

            if (child_yang_name == "out-of-resource"):
                if (self.out_of_resource is None):
                    self.out_of_resource = RsvpStandby.Counters.OutOfResource()
                    self.out_of_resource.parent = self
                    self._children_name_map["out_of_resource"] = "out-of-resource"
                return self.out_of_resource

            if (child_yang_name == "prefix-filtering"):
                if (self.prefix_filtering is None):
                    self.prefix_filtering = RsvpStandby.Counters.PrefixFiltering()
                    self.prefix_filtering.parent = self
                    self._children_name_map["prefix_filtering"] = "prefix-filtering"
                return self.prefix_filtering

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "database" or name == "event-syncs" or name == "interface-events" or name == "interface-messages" or name == "issu" or name == "message-summary" or name == "nsr" or name == "out-of-resource" or name == "prefix-filtering"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class InterfaceDetaileds(Entity):
        """
        Table of detailed info about RSVP\-enabled
        interfaces
        
        .. attribute:: interface_detailed
        
        	Detailed info about an RSVP\-enabled interface
        	**type**\: list of    :py:class:`InterfaceDetailed <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.InterfaceDetaileds.InterfaceDetailed>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(RsvpStandby.InterfaceDetaileds, self).__init__()

            self.yang_name = "interface-detaileds"
            self.yang_parent_name = "rsvp-standby"

            self.interface_detailed = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(RsvpStandby.InterfaceDetaileds, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(RsvpStandby.InterfaceDetaileds, self).__setattr__(name, value)


        class InterfaceDetailed(Entity):
            """
            Detailed info about an RSVP\-enabled interface
            
            .. attribute:: interface_name  <key>
            
            	Interface Name
            	**type**\:  str
            
            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
            
            .. attribute:: ack_hold_time
            
            	ACK hold time in msec
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: ack_max_size
            
            	Max size for ACK message
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: bandwidth_information
            
            	Interface bandwidth information
            	**type**\:   :py:class:`BandwidthInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.InterfaceDetaileds.InterfaceDetailed.BandwidthInformation>`
            
            .. attribute:: bundle_message_max_size
            
            	Max size in bytes of a single Bundle message
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            	**units**\: byte
            
            .. attribute:: expiry_drops_tolerated
            
            	Number of missed messages tolerated
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: expiry_interval
            
            	Expiry interval in msecs
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            	**units**\: millisecond
            
            .. attribute:: expiry_states
            
            	Number of states for expiry check
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: expiry_timer_state
            
            	Expiry timer state
            	**type**\:   :py:class:`RsvpTimerState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpTimerState>`
            
            .. attribute:: flags
            
            	Interface flags
            	**type**\:   :py:class:`Flags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.InterfaceDetaileds.InterfaceDetailed.Flags>`
            
            .. attribute:: integrity_receive_password
            
            	Integrity receive password
            	**type**\:  str
            
            	**length:** 0..40
            
            .. attribute:: integrity_receive_password_optional
            
            	Integrity recv password optional
            	**type**\:  int
            
            	**range:** 0..255
            
            .. attribute:: integrity_send_password
            
            	Integrity send password
            	**type**\:  str
            
            	**length:** 0..40
            
            .. attribute:: interface_name_xr
            
            	Interface Name
            	**type**\:  str
            
            .. attribute:: neighbor_array
            
            	Neighbor array
            	**type**\: list of    :py:class:`NeighborArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.InterfaceDetaileds.InterfaceDetailed.NeighborArray>`
            
            .. attribute:: out_of_band_expiry_drops_tolerated
            
            	Number of out\-of\-band missed messages tolerated
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: out_of_band_refresh_interval
            
            	Out\-of\-band Refresh interval in msecs
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            	**units**\: millisecond
            
            .. attribute:: pacing_interval
            
            	Pacing interval in msecs
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            	**units**\: millisecond
            
            .. attribute:: pacing_message_rate
            
            	No. of messages per interval
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: pacing_messages
            
            	Number of messages deferred for pacing
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: pacing_timer_state
            
            	State of pacing timer
            	**type**\:   :py:class:`RsvpTimerState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpTimerState>`
            
            .. attribute:: refresh_interval
            
            	Refresh interval in msecs
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            	**units**\: millisecond
            
            .. attribute:: refresh_timer_state
            
            	Refresh timer state
            	**type**\:   :py:class:`RsvpTimerState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpTimerState>`
            
            .. attribute:: retransmit_time
            
            	Retransmit time in msec
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: signalling_ip_tos
            
            	IP TOS (precedence/DSCP) to use in signalling messages
            	**type**\:  int
            
            	**range:** 0..255
            
            .. attribute:: summary_refresh_max_size
            
            	Max size in bytes of a single SRefresh
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            	**units**\: byte
            
            .. attribute:: summary_refresh_timer_state
            
            	Summary refresh timer state
            	**type**\:   :py:class:`RsvpTimerState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpTimerState>`
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(RsvpStandby.InterfaceDetaileds.InterfaceDetailed, self).__init__()

                self.yang_name = "interface-detailed"
                self.yang_parent_name = "interface-detaileds"

                self.interface_name = YLeaf(YType.str, "interface-name")

                self.ack_hold_time = YLeaf(YType.uint32, "ack-hold-time")

                self.ack_max_size = YLeaf(YType.uint32, "ack-max-size")

                self.bundle_message_max_size = YLeaf(YType.uint32, "bundle-message-max-size")

                self.expiry_drops_tolerated = YLeaf(YType.int32, "expiry-drops-tolerated")

                self.expiry_interval = YLeaf(YType.int32, "expiry-interval")

                self.expiry_states = YLeaf(YType.int32, "expiry-states")

                self.expiry_timer_state = YLeaf(YType.enumeration, "expiry-timer-state")

                self.integrity_receive_password = YLeaf(YType.str, "integrity-receive-password")

                self.integrity_receive_password_optional = YLeaf(YType.uint8, "integrity-receive-password-optional")

                self.integrity_send_password = YLeaf(YType.str, "integrity-send-password")

                self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                self.out_of_band_expiry_drops_tolerated = YLeaf(YType.uint32, "out-of-band-expiry-drops-tolerated")

                self.out_of_band_refresh_interval = YLeaf(YType.uint32, "out-of-band-refresh-interval")

                self.pacing_interval = YLeaf(YType.uint32, "pacing-interval")

                self.pacing_message_rate = YLeaf(YType.uint32, "pacing-message-rate")

                self.pacing_messages = YLeaf(YType.int32, "pacing-messages")

                self.pacing_timer_state = YLeaf(YType.enumeration, "pacing-timer-state")

                self.refresh_interval = YLeaf(YType.int32, "refresh-interval")

                self.refresh_timer_state = YLeaf(YType.enumeration, "refresh-timer-state")

                self.retransmit_time = YLeaf(YType.uint32, "retransmit-time")

                self.signalling_ip_tos = YLeaf(YType.uint8, "signalling-ip-tos")

                self.summary_refresh_max_size = YLeaf(YType.uint32, "summary-refresh-max-size")

                self.summary_refresh_timer_state = YLeaf(YType.enumeration, "summary-refresh-timer-state")

                self.bandwidth_information = RsvpStandby.InterfaceDetaileds.InterfaceDetailed.BandwidthInformation()
                self.bandwidth_information.parent = self
                self._children_name_map["bandwidth_information"] = "bandwidth-information"
                self._children_yang_names.add("bandwidth-information")

                self.flags = RsvpStandby.InterfaceDetaileds.InterfaceDetailed.Flags()
                self.flags.parent = self
                self._children_name_map["flags"] = "flags"
                self._children_yang_names.add("flags")

                self.neighbor_array = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("interface_name",
                                "ack_hold_time",
                                "ack_max_size",
                                "bundle_message_max_size",
                                "expiry_drops_tolerated",
                                "expiry_interval",
                                "expiry_states",
                                "expiry_timer_state",
                                "integrity_receive_password",
                                "integrity_receive_password_optional",
                                "integrity_send_password",
                                "interface_name_xr",
                                "out_of_band_expiry_drops_tolerated",
                                "out_of_band_refresh_interval",
                                "pacing_interval",
                                "pacing_message_rate",
                                "pacing_messages",
                                "pacing_timer_state",
                                "refresh_interval",
                                "refresh_timer_state",
                                "retransmit_time",
                                "signalling_ip_tos",
                                "summary_refresh_max_size",
                                "summary_refresh_timer_state") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(RsvpStandby.InterfaceDetaileds.InterfaceDetailed, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(RsvpStandby.InterfaceDetaileds.InterfaceDetailed, self).__setattr__(name, value)


            class BandwidthInformation(Entity):
                """
                Interface bandwidth information
                
                .. attribute:: dste_mode
                
                	DSTEMode
                	**type**\:   :py:class:`RsvpMgmtDsteModes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtDsteModes>`
                
                .. attribute:: pre_standard_dste_interface
                
                	Prestandard DSTE interface information
                	**type**\:   :py:class:`PreStandardDsteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.InterfaceDetaileds.InterfaceDetailed.BandwidthInformation.PreStandardDsteInterface>`
                
                .. attribute:: standard_dste_interface
                
                	Standard DSTE interface information
                	**type**\:   :py:class:`StandardDsteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.InterfaceDetaileds.InterfaceDetailed.BandwidthInformation.StandardDsteInterface>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.InterfaceDetaileds.InterfaceDetailed.BandwidthInformation, self).__init__()

                    self.yang_name = "bandwidth-information"
                    self.yang_parent_name = "interface-detailed"

                    self.dste_mode = YLeaf(YType.enumeration, "dste-mode")

                    self.pre_standard_dste_interface = RsvpStandby.InterfaceDetaileds.InterfaceDetailed.BandwidthInformation.PreStandardDsteInterface()
                    self.pre_standard_dste_interface.parent = self
                    self._children_name_map["pre_standard_dste_interface"] = "pre-standard-dste-interface"
                    self._children_yang_names.add("pre-standard-dste-interface")

                    self.standard_dste_interface = RsvpStandby.InterfaceDetaileds.InterfaceDetailed.BandwidthInformation.StandardDsteInterface()
                    self.standard_dste_interface.parent = self
                    self._children_name_map["standard_dste_interface"] = "standard-dste-interface"
                    self._children_yang_names.add("standard-dste-interface")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("dste_mode") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.InterfaceDetaileds.InterfaceDetailed.BandwidthInformation, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.InterfaceDetaileds.InterfaceDetailed.BandwidthInformation, self).__setattr__(name, value)


                class PreStandardDsteInterface(Entity):
                    """
                    Prestandard DSTE interface information
                    
                    .. attribute:: allocated_bit_rate
                    
                    	Bandwidth (bits per second) now allocated
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: is_max_bandwidth_absolute
                    
                    	True if the Max B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: is_max_subpool_bandwidth_absolute
                    
                    	True if the Max sub\-pool B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: max_bandwidth
                    
                    	Max bandwidth (bits per second) allowed
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_flow_bandwidth
                    
                    	Max bandwidth (bits per second) allowed per flow
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_subpool_bandwidth
                    
                    	Max bandwidth (bits per second) allowed in subpool
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.InterfaceDetaileds.InterfaceDetailed.BandwidthInformation.PreStandardDsteInterface, self).__init__()

                        self.yang_name = "pre-standard-dste-interface"
                        self.yang_parent_name = "bandwidth-information"

                        self.allocated_bit_rate = YLeaf(YType.uint64, "allocated-bit-rate")

                        self.is_max_bandwidth_absolute = YLeaf(YType.boolean, "is-max-bandwidth-absolute")

                        self.is_max_subpool_bandwidth_absolute = YLeaf(YType.boolean, "is-max-subpool-bandwidth-absolute")

                        self.max_bandwidth = YLeaf(YType.uint64, "max-bandwidth")

                        self.max_flow_bandwidth = YLeaf(YType.uint64, "max-flow-bandwidth")

                        self.max_subpool_bandwidth = YLeaf(YType.uint64, "max-subpool-bandwidth")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("allocated_bit_rate",
                                        "is_max_bandwidth_absolute",
                                        "is_max_subpool_bandwidth_absolute",
                                        "max_bandwidth",
                                        "max_flow_bandwidth",
                                        "max_subpool_bandwidth") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.InterfaceDetaileds.InterfaceDetailed.BandwidthInformation.PreStandardDsteInterface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.InterfaceDetaileds.InterfaceDetailed.BandwidthInformation.PreStandardDsteInterface, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.allocated_bit_rate.is_set or
                            self.is_max_bandwidth_absolute.is_set or
                            self.is_max_subpool_bandwidth_absolute.is_set or
                            self.max_bandwidth.is_set or
                            self.max_flow_bandwidth.is_set or
                            self.max_subpool_bandwidth.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.allocated_bit_rate.yfilter != YFilter.not_set or
                            self.is_max_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.is_max_subpool_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.max_bandwidth.yfilter != YFilter.not_set or
                            self.max_flow_bandwidth.yfilter != YFilter.not_set or
                            self.max_subpool_bandwidth.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "pre-standard-dste-interface" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.allocated_bit_rate.is_set or self.allocated_bit_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.allocated_bit_rate.get_name_leafdata())
                        if (self.is_max_bandwidth_absolute.is_set or self.is_max_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_bandwidth_absolute.get_name_leafdata())
                        if (self.is_max_subpool_bandwidth_absolute.is_set or self.is_max_subpool_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_subpool_bandwidth_absolute.get_name_leafdata())
                        if (self.max_bandwidth.is_set or self.max_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_bandwidth.get_name_leafdata())
                        if (self.max_flow_bandwidth.is_set or self.max_flow_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_flow_bandwidth.get_name_leafdata())
                        if (self.max_subpool_bandwidth.is_set or self.max_subpool_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_subpool_bandwidth.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "allocated-bit-rate" or name == "is-max-bandwidth-absolute" or name == "is-max-subpool-bandwidth-absolute" or name == "max-bandwidth" or name == "max-flow-bandwidth" or name == "max-subpool-bandwidth"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "allocated-bit-rate"):
                            self.allocated_bit_rate = value
                            self.allocated_bit_rate.value_namespace = name_space
                            self.allocated_bit_rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-bandwidth-absolute"):
                            self.is_max_bandwidth_absolute = value
                            self.is_max_bandwidth_absolute.value_namespace = name_space
                            self.is_max_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-subpool-bandwidth-absolute"):
                            self.is_max_subpool_bandwidth_absolute = value
                            self.is_max_subpool_bandwidth_absolute.value_namespace = name_space
                            self.is_max_subpool_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-bandwidth"):
                            self.max_bandwidth = value
                            self.max_bandwidth.value_namespace = name_space
                            self.max_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-flow-bandwidth"):
                            self.max_flow_bandwidth = value
                            self.max_flow_bandwidth.value_namespace = name_space
                            self.max_flow_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-subpool-bandwidth"):
                            self.max_subpool_bandwidth = value
                            self.max_subpool_bandwidth.value_namespace = name_space
                            self.max_subpool_bandwidth.value_namespace_prefix = name_space_prefix


                class StandardDsteInterface(Entity):
                    """
                    Standard DSTE interface information
                    
                    .. attribute:: allocated_bit_rate
                    
                    	Bandwidth (bits per second) now allocated
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: is_max_bandwidth_absolute
                    
                    	True if the Max B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: is_max_bc0_bandwidth_absolute
                    
                    	True if the Max BC0 B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: is_max_bc1_bandwidth_absolute
                    
                    	True if the Max BC1 sub\-pool B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: max_bandwidth
                    
                    	Max bandwidth (bits per second) allowed
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_flow_bandwidth
                    
                    	Max bandwidth (bits per second) allowed per flow
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_pool0_bandwidth
                    
                    	Max bandwidth (bits per second) allowed in BC0 pool
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_pool1_bandwidth
                    
                    	Max bandwidth (bits per second) allowed in BC1 pool
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.InterfaceDetaileds.InterfaceDetailed.BandwidthInformation.StandardDsteInterface, self).__init__()

                        self.yang_name = "standard-dste-interface"
                        self.yang_parent_name = "bandwidth-information"

                        self.allocated_bit_rate = YLeaf(YType.uint64, "allocated-bit-rate")

                        self.is_max_bandwidth_absolute = YLeaf(YType.boolean, "is-max-bandwidth-absolute")

                        self.is_max_bc0_bandwidth_absolute = YLeaf(YType.boolean, "is-max-bc0-bandwidth-absolute")

                        self.is_max_bc1_bandwidth_absolute = YLeaf(YType.boolean, "is-max-bc1-bandwidth-absolute")

                        self.max_bandwidth = YLeaf(YType.uint64, "max-bandwidth")

                        self.max_flow_bandwidth = YLeaf(YType.uint64, "max-flow-bandwidth")

                        self.max_pool0_bandwidth = YLeaf(YType.uint64, "max-pool0-bandwidth")

                        self.max_pool1_bandwidth = YLeaf(YType.uint64, "max-pool1-bandwidth")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("allocated_bit_rate",
                                        "is_max_bandwidth_absolute",
                                        "is_max_bc0_bandwidth_absolute",
                                        "is_max_bc1_bandwidth_absolute",
                                        "max_bandwidth",
                                        "max_flow_bandwidth",
                                        "max_pool0_bandwidth",
                                        "max_pool1_bandwidth") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.InterfaceDetaileds.InterfaceDetailed.BandwidthInformation.StandardDsteInterface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.InterfaceDetaileds.InterfaceDetailed.BandwidthInformation.StandardDsteInterface, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.allocated_bit_rate.is_set or
                            self.is_max_bandwidth_absolute.is_set or
                            self.is_max_bc0_bandwidth_absolute.is_set or
                            self.is_max_bc1_bandwidth_absolute.is_set or
                            self.max_bandwidth.is_set or
                            self.max_flow_bandwidth.is_set or
                            self.max_pool0_bandwidth.is_set or
                            self.max_pool1_bandwidth.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.allocated_bit_rate.yfilter != YFilter.not_set or
                            self.is_max_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.is_max_bc0_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.is_max_bc1_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.max_bandwidth.yfilter != YFilter.not_set or
                            self.max_flow_bandwidth.yfilter != YFilter.not_set or
                            self.max_pool0_bandwidth.yfilter != YFilter.not_set or
                            self.max_pool1_bandwidth.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "standard-dste-interface" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.allocated_bit_rate.is_set or self.allocated_bit_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.allocated_bit_rate.get_name_leafdata())
                        if (self.is_max_bandwidth_absolute.is_set or self.is_max_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_bandwidth_absolute.get_name_leafdata())
                        if (self.is_max_bc0_bandwidth_absolute.is_set or self.is_max_bc0_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_bc0_bandwidth_absolute.get_name_leafdata())
                        if (self.is_max_bc1_bandwidth_absolute.is_set or self.is_max_bc1_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_bc1_bandwidth_absolute.get_name_leafdata())
                        if (self.max_bandwidth.is_set or self.max_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_bandwidth.get_name_leafdata())
                        if (self.max_flow_bandwidth.is_set or self.max_flow_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_flow_bandwidth.get_name_leafdata())
                        if (self.max_pool0_bandwidth.is_set or self.max_pool0_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_pool0_bandwidth.get_name_leafdata())
                        if (self.max_pool1_bandwidth.is_set or self.max_pool1_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_pool1_bandwidth.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "allocated-bit-rate" or name == "is-max-bandwidth-absolute" or name == "is-max-bc0-bandwidth-absolute" or name == "is-max-bc1-bandwidth-absolute" or name == "max-bandwidth" or name == "max-flow-bandwidth" or name == "max-pool0-bandwidth" or name == "max-pool1-bandwidth"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "allocated-bit-rate"):
                            self.allocated_bit_rate = value
                            self.allocated_bit_rate.value_namespace = name_space
                            self.allocated_bit_rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-bandwidth-absolute"):
                            self.is_max_bandwidth_absolute = value
                            self.is_max_bandwidth_absolute.value_namespace = name_space
                            self.is_max_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-bc0-bandwidth-absolute"):
                            self.is_max_bc0_bandwidth_absolute = value
                            self.is_max_bc0_bandwidth_absolute.value_namespace = name_space
                            self.is_max_bc0_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-bc1-bandwidth-absolute"):
                            self.is_max_bc1_bandwidth_absolute = value
                            self.is_max_bc1_bandwidth_absolute.value_namespace = name_space
                            self.is_max_bc1_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-bandwidth"):
                            self.max_bandwidth = value
                            self.max_bandwidth.value_namespace = name_space
                            self.max_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-flow-bandwidth"):
                            self.max_flow_bandwidth = value
                            self.max_flow_bandwidth.value_namespace = name_space
                            self.max_flow_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-pool0-bandwidth"):
                            self.max_pool0_bandwidth = value
                            self.max_pool0_bandwidth.value_namespace = name_space
                            self.max_pool0_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-pool1-bandwidth"):
                            self.max_pool1_bandwidth = value
                            self.max_pool1_bandwidth.value_namespace = name_space
                            self.max_pool1_bandwidth.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.dste_mode.is_set or
                        (self.pre_standard_dste_interface is not None and self.pre_standard_dste_interface.has_data()) or
                        (self.standard_dste_interface is not None and self.standard_dste_interface.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.dste_mode.yfilter != YFilter.not_set or
                        (self.pre_standard_dste_interface is not None and self.pre_standard_dste_interface.has_operation()) or
                        (self.standard_dste_interface is not None and self.standard_dste_interface.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bandwidth-information" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.dste_mode.is_set or self.dste_mode.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.dste_mode.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "pre-standard-dste-interface"):
                        if (self.pre_standard_dste_interface is None):
                            self.pre_standard_dste_interface = RsvpStandby.InterfaceDetaileds.InterfaceDetailed.BandwidthInformation.PreStandardDsteInterface()
                            self.pre_standard_dste_interface.parent = self
                            self._children_name_map["pre_standard_dste_interface"] = "pre-standard-dste-interface"
                        return self.pre_standard_dste_interface

                    if (child_yang_name == "standard-dste-interface"):
                        if (self.standard_dste_interface is None):
                            self.standard_dste_interface = RsvpStandby.InterfaceDetaileds.InterfaceDetailed.BandwidthInformation.StandardDsteInterface()
                            self.standard_dste_interface.parent = self
                            self._children_name_map["standard_dste_interface"] = "standard-dste-interface"
                        return self.standard_dste_interface

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "pre-standard-dste-interface" or name == "standard-dste-interface" or name == "dste-mode"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "dste-mode"):
                        self.dste_mode = value
                        self.dste_mode.value_namespace = name_space
                        self.dste_mode.value_namespace_prefix = name_space_prefix


            class Flags(Entity):
                """
                Interface flags
                
                .. attribute:: is_backup_tunnel
                
                	This is backup tunnel
                	**type**\:  bool
                
                .. attribute:: is_interface_created
                
                	Interface is created
                	**type**\:  bool
                
                .. attribute:: is_interface_down
                
                	Interface is DOWN
                	**type**\:  bool
                
                .. attribute:: is_message_bundling_enabled
                
                	Use bundling for outgoing RSVP messages
                	**type**\:  bool
                
                .. attribute:: is_mpls_enabled
                
                	MPLS enabled on interface
                	**type**\:  bool
                
                .. attribute:: is_non_default_vrf
                
                	Interface is defined in non\-Default VRF
                	**type**\:  bool
                
                .. attribute:: is_pacing_enabled
                
                	Message pacing enabled
                	**type**\:  bool
                
                .. attribute:: is_refresh_enabled
                
                	Refresh enabled
                	**type**\:  bool
                
                .. attribute:: is_refresh_reduction_enabled
                
                	Refresh Reduction enabled
                	**type**\:  bool
                
                .. attribute:: is_rel_s_refresh_enabled
                
                	Use reliable xmt for SRefresh
                	**type**\:  bool
                
                .. attribute:: is_rsvp_configured
                
                	RSVP explicitly configured
                	**type**\:  bool
                
                .. attribute:: is_s_refresh_enabled
                
                	Summary Refresh enabled
                	**type**\:  bool
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.InterfaceDetaileds.InterfaceDetailed.Flags, self).__init__()

                    self.yang_name = "flags"
                    self.yang_parent_name = "interface-detailed"

                    self.is_backup_tunnel = YLeaf(YType.boolean, "is-backup-tunnel")

                    self.is_interface_created = YLeaf(YType.boolean, "is-interface-created")

                    self.is_interface_down = YLeaf(YType.boolean, "is-interface-down")

                    self.is_message_bundling_enabled = YLeaf(YType.boolean, "is-message-bundling-enabled")

                    self.is_mpls_enabled = YLeaf(YType.boolean, "is-mpls-enabled")

                    self.is_non_default_vrf = YLeaf(YType.boolean, "is-non-default-vrf")

                    self.is_pacing_enabled = YLeaf(YType.boolean, "is-pacing-enabled")

                    self.is_refresh_enabled = YLeaf(YType.boolean, "is-refresh-enabled")

                    self.is_refresh_reduction_enabled = YLeaf(YType.boolean, "is-refresh-reduction-enabled")

                    self.is_rel_s_refresh_enabled = YLeaf(YType.boolean, "is-rel-s-refresh-enabled")

                    self.is_rsvp_configured = YLeaf(YType.boolean, "is-rsvp-configured")

                    self.is_s_refresh_enabled = YLeaf(YType.boolean, "is-s-refresh-enabled")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("is_backup_tunnel",
                                    "is_interface_created",
                                    "is_interface_down",
                                    "is_message_bundling_enabled",
                                    "is_mpls_enabled",
                                    "is_non_default_vrf",
                                    "is_pacing_enabled",
                                    "is_refresh_enabled",
                                    "is_refresh_reduction_enabled",
                                    "is_rel_s_refresh_enabled",
                                    "is_rsvp_configured",
                                    "is_s_refresh_enabled") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.InterfaceDetaileds.InterfaceDetailed.Flags, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.InterfaceDetaileds.InterfaceDetailed.Flags, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.is_backup_tunnel.is_set or
                        self.is_interface_created.is_set or
                        self.is_interface_down.is_set or
                        self.is_message_bundling_enabled.is_set or
                        self.is_mpls_enabled.is_set or
                        self.is_non_default_vrf.is_set or
                        self.is_pacing_enabled.is_set or
                        self.is_refresh_enabled.is_set or
                        self.is_refresh_reduction_enabled.is_set or
                        self.is_rel_s_refresh_enabled.is_set or
                        self.is_rsvp_configured.is_set or
                        self.is_s_refresh_enabled.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.is_backup_tunnel.yfilter != YFilter.not_set or
                        self.is_interface_created.yfilter != YFilter.not_set or
                        self.is_interface_down.yfilter != YFilter.not_set or
                        self.is_message_bundling_enabled.yfilter != YFilter.not_set or
                        self.is_mpls_enabled.yfilter != YFilter.not_set or
                        self.is_non_default_vrf.yfilter != YFilter.not_set or
                        self.is_pacing_enabled.yfilter != YFilter.not_set or
                        self.is_refresh_enabled.yfilter != YFilter.not_set or
                        self.is_refresh_reduction_enabled.yfilter != YFilter.not_set or
                        self.is_rel_s_refresh_enabled.yfilter != YFilter.not_set or
                        self.is_rsvp_configured.yfilter != YFilter.not_set or
                        self.is_s_refresh_enabled.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "flags" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.is_backup_tunnel.is_set or self.is_backup_tunnel.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_backup_tunnel.get_name_leafdata())
                    if (self.is_interface_created.is_set or self.is_interface_created.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_interface_created.get_name_leafdata())
                    if (self.is_interface_down.is_set or self.is_interface_down.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_interface_down.get_name_leafdata())
                    if (self.is_message_bundling_enabled.is_set or self.is_message_bundling_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_message_bundling_enabled.get_name_leafdata())
                    if (self.is_mpls_enabled.is_set or self.is_mpls_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_mpls_enabled.get_name_leafdata())
                    if (self.is_non_default_vrf.is_set or self.is_non_default_vrf.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_non_default_vrf.get_name_leafdata())
                    if (self.is_pacing_enabled.is_set or self.is_pacing_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_pacing_enabled.get_name_leafdata())
                    if (self.is_refresh_enabled.is_set or self.is_refresh_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_refresh_enabled.get_name_leafdata())
                    if (self.is_refresh_reduction_enabled.is_set or self.is_refresh_reduction_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_refresh_reduction_enabled.get_name_leafdata())
                    if (self.is_rel_s_refresh_enabled.is_set or self.is_rel_s_refresh_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_rel_s_refresh_enabled.get_name_leafdata())
                    if (self.is_rsvp_configured.is_set or self.is_rsvp_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_rsvp_configured.get_name_leafdata())
                    if (self.is_s_refresh_enabled.is_set or self.is_s_refresh_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_s_refresh_enabled.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "is-backup-tunnel" or name == "is-interface-created" or name == "is-interface-down" or name == "is-message-bundling-enabled" or name == "is-mpls-enabled" or name == "is-non-default-vrf" or name == "is-pacing-enabled" or name == "is-refresh-enabled" or name == "is-refresh-reduction-enabled" or name == "is-rel-s-refresh-enabled" or name == "is-rsvp-configured" or name == "is-s-refresh-enabled"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "is-backup-tunnel"):
                        self.is_backup_tunnel = value
                        self.is_backup_tunnel.value_namespace = name_space
                        self.is_backup_tunnel.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-interface-created"):
                        self.is_interface_created = value
                        self.is_interface_created.value_namespace = name_space
                        self.is_interface_created.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-interface-down"):
                        self.is_interface_down = value
                        self.is_interface_down.value_namespace = name_space
                        self.is_interface_down.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-message-bundling-enabled"):
                        self.is_message_bundling_enabled = value
                        self.is_message_bundling_enabled.value_namespace = name_space
                        self.is_message_bundling_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-mpls-enabled"):
                        self.is_mpls_enabled = value
                        self.is_mpls_enabled.value_namespace = name_space
                        self.is_mpls_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-non-default-vrf"):
                        self.is_non_default_vrf = value
                        self.is_non_default_vrf.value_namespace = name_space
                        self.is_non_default_vrf.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-pacing-enabled"):
                        self.is_pacing_enabled = value
                        self.is_pacing_enabled.value_namespace = name_space
                        self.is_pacing_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-refresh-enabled"):
                        self.is_refresh_enabled = value
                        self.is_refresh_enabled.value_namespace = name_space
                        self.is_refresh_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-refresh-reduction-enabled"):
                        self.is_refresh_reduction_enabled = value
                        self.is_refresh_reduction_enabled.value_namespace = name_space
                        self.is_refresh_reduction_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-rel-s-refresh-enabled"):
                        self.is_rel_s_refresh_enabled = value
                        self.is_rel_s_refresh_enabled.value_namespace = name_space
                        self.is_rel_s_refresh_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-rsvp-configured"):
                        self.is_rsvp_configured = value
                        self.is_rsvp_configured.value_namespace = name_space
                        self.is_rsvp_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-s-refresh-enabled"):
                        self.is_s_refresh_enabled = value
                        self.is_s_refresh_enabled.value_namespace = name_space
                        self.is_s_refresh_enabled.value_namespace_prefix = name_space_prefix


            class NeighborArray(Entity):
                """
                Neighbor array
                
                .. attribute:: expiry_time
                
                	Expiry time
                	**type**\:   :py:class:`ExpiryTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.InterfaceDetaileds.InterfaceDetailed.NeighborArray.ExpiryTime>`
                
                .. attribute:: is_neighbor_refresh_reduction_capable
                
                	Is neighbor capable of Refresh Reduction
                	**type**\:  bool
                
                .. attribute:: message_ids
                
                	Number of MessageIDs
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: neighbor_address
                
                	IP address of the neighbor
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: neighbor_message_id
                
                	List of Neighbor MessageIDs
                	**type**\: list of    :py:class:`NeighborMessageId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.InterfaceDetaileds.InterfaceDetailed.NeighborArray.NeighborMessageId>`
                
                .. attribute:: outgoing_states
                
                	Number of outgoing states to the neighbour
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.InterfaceDetaileds.InterfaceDetailed.NeighborArray, self).__init__()

                    self.yang_name = "neighbor-array"
                    self.yang_parent_name = "interface-detailed"

                    self.is_neighbor_refresh_reduction_capable = YLeaf(YType.boolean, "is-neighbor-refresh-reduction-capable")

                    self.message_ids = YLeaf(YType.uint32, "message-ids")

                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                    self.outgoing_states = YLeaf(YType.int32, "outgoing-states")

                    self.expiry_time = RsvpStandby.InterfaceDetaileds.InterfaceDetailed.NeighborArray.ExpiryTime()
                    self.expiry_time.parent = self
                    self._children_name_map["expiry_time"] = "expiry-time"
                    self._children_yang_names.add("expiry-time")

                    self.neighbor_message_id = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("is_neighbor_refresh_reduction_capable",
                                    "message_ids",
                                    "neighbor_address",
                                    "outgoing_states") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.InterfaceDetaileds.InterfaceDetailed.NeighborArray, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.InterfaceDetaileds.InterfaceDetailed.NeighborArray, self).__setattr__(name, value)


                class ExpiryTime(Entity):
                    """
                    Expiry time
                    
                    .. attribute:: nanoseconds
                    
                    	Time Value in Nano\-seconds
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: nanosecond
                    
                    .. attribute:: seconds
                    
                    	Time Value in Seconds
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.InterfaceDetaileds.InterfaceDetailed.NeighborArray.ExpiryTime, self).__init__()

                        self.yang_name = "expiry-time"
                        self.yang_parent_name = "neighbor-array"

                        self.nanoseconds = YLeaf(YType.int32, "nanoseconds")

                        self.seconds = YLeaf(YType.int32, "seconds")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("nanoseconds",
                                        "seconds") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.InterfaceDetaileds.InterfaceDetailed.NeighborArray.ExpiryTime, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.InterfaceDetaileds.InterfaceDetailed.NeighborArray.ExpiryTime, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.nanoseconds.is_set or
                            self.seconds.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.nanoseconds.yfilter != YFilter.not_set or
                            self.seconds.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "expiry-time" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.nanoseconds.is_set or self.nanoseconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.nanoseconds.get_name_leafdata())
                        if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.seconds.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "nanoseconds" or name == "seconds"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "nanoseconds"):
                            self.nanoseconds = value
                            self.nanoseconds.value_namespace = name_space
                            self.nanoseconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "seconds"):
                            self.seconds = value
                            self.seconds.value_namespace = name_space
                            self.seconds.value_namespace_prefix = name_space_prefix


                class NeighborMessageId(Entity):
                    """
                    List of Neighbor MessageIDs
                    
                    .. attribute:: message_id
                    
                    	Message ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.InterfaceDetaileds.InterfaceDetailed.NeighborArray.NeighborMessageId, self).__init__()

                        self.yang_name = "neighbor-message-id"
                        self.yang_parent_name = "neighbor-array"

                        self.message_id = YLeaf(YType.uint32, "message-id")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("message_id") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.InterfaceDetaileds.InterfaceDetailed.NeighborArray.NeighborMessageId, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.InterfaceDetaileds.InterfaceDetailed.NeighborArray.NeighborMessageId, self).__setattr__(name, value)

                    def has_data(self):
                        return self.message_id.is_set

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.message_id.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "neighbor-message-id" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.message_id.is_set or self.message_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.message_id.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "message-id"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "message-id"):
                            self.message_id = value
                            self.message_id.value_namespace = name_space
                            self.message_id.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.neighbor_message_id:
                        if (c.has_data()):
                            return True
                    return (
                        self.is_neighbor_refresh_reduction_capable.is_set or
                        self.message_ids.is_set or
                        self.neighbor_address.is_set or
                        self.outgoing_states.is_set or
                        (self.expiry_time is not None and self.expiry_time.has_data()))

                def has_operation(self):
                    for c in self.neighbor_message_id:
                        if (c.has_operation()):
                            return True
                    return (
                        self.yfilter != YFilter.not_set or
                        self.is_neighbor_refresh_reduction_capable.yfilter != YFilter.not_set or
                        self.message_ids.yfilter != YFilter.not_set or
                        self.neighbor_address.yfilter != YFilter.not_set or
                        self.outgoing_states.yfilter != YFilter.not_set or
                        (self.expiry_time is not None and self.expiry_time.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "neighbor-array" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.is_neighbor_refresh_reduction_capable.is_set or self.is_neighbor_refresh_reduction_capable.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_neighbor_refresh_reduction_capable.get_name_leafdata())
                    if (self.message_ids.is_set or self.message_ids.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.message_ids.get_name_leafdata())
                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                    if (self.outgoing_states.is_set or self.outgoing_states.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.outgoing_states.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "expiry-time"):
                        if (self.expiry_time is None):
                            self.expiry_time = RsvpStandby.InterfaceDetaileds.InterfaceDetailed.NeighborArray.ExpiryTime()
                            self.expiry_time.parent = self
                            self._children_name_map["expiry_time"] = "expiry-time"
                        return self.expiry_time

                    if (child_yang_name == "neighbor-message-id"):
                        for c in self.neighbor_message_id:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = RsvpStandby.InterfaceDetaileds.InterfaceDetailed.NeighborArray.NeighborMessageId()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.neighbor_message_id.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "expiry-time" or name == "neighbor-message-id" or name == "is-neighbor-refresh-reduction-capable" or name == "message-ids" or name == "neighbor-address" or name == "outgoing-states"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "is-neighbor-refresh-reduction-capable"):
                        self.is_neighbor_refresh_reduction_capable = value
                        self.is_neighbor_refresh_reduction_capable.value_namespace = name_space
                        self.is_neighbor_refresh_reduction_capable.value_namespace_prefix = name_space_prefix
                    if(value_path == "message-ids"):
                        self.message_ids = value
                        self.message_ids.value_namespace = name_space
                        self.message_ids.value_namespace_prefix = name_space_prefix
                    if(value_path == "neighbor-address"):
                        self.neighbor_address = value
                        self.neighbor_address.value_namespace = name_space
                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "outgoing-states"):
                        self.outgoing_states = value
                        self.outgoing_states.value_namespace = name_space
                        self.outgoing_states.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.neighbor_array:
                    if (c.has_data()):
                        return True
                return (
                    self.interface_name.is_set or
                    self.ack_hold_time.is_set or
                    self.ack_max_size.is_set or
                    self.bundle_message_max_size.is_set or
                    self.expiry_drops_tolerated.is_set or
                    self.expiry_interval.is_set or
                    self.expiry_states.is_set or
                    self.expiry_timer_state.is_set or
                    self.integrity_receive_password.is_set or
                    self.integrity_receive_password_optional.is_set or
                    self.integrity_send_password.is_set or
                    self.interface_name_xr.is_set or
                    self.out_of_band_expiry_drops_tolerated.is_set or
                    self.out_of_band_refresh_interval.is_set or
                    self.pacing_interval.is_set or
                    self.pacing_message_rate.is_set or
                    self.pacing_messages.is_set or
                    self.pacing_timer_state.is_set or
                    self.refresh_interval.is_set or
                    self.refresh_timer_state.is_set or
                    self.retransmit_time.is_set or
                    self.signalling_ip_tos.is_set or
                    self.summary_refresh_max_size.is_set or
                    self.summary_refresh_timer_state.is_set or
                    (self.bandwidth_information is not None and self.bandwidth_information.has_data()) or
                    (self.flags is not None and self.flags.has_data()))

            def has_operation(self):
                for c in self.neighbor_array:
                    if (c.has_operation()):
                        return True
                return (
                    self.yfilter != YFilter.not_set or
                    self.interface_name.yfilter != YFilter.not_set or
                    self.ack_hold_time.yfilter != YFilter.not_set or
                    self.ack_max_size.yfilter != YFilter.not_set or
                    self.bundle_message_max_size.yfilter != YFilter.not_set or
                    self.expiry_drops_tolerated.yfilter != YFilter.not_set or
                    self.expiry_interval.yfilter != YFilter.not_set or
                    self.expiry_states.yfilter != YFilter.not_set or
                    self.expiry_timer_state.yfilter != YFilter.not_set or
                    self.integrity_receive_password.yfilter != YFilter.not_set or
                    self.integrity_receive_password_optional.yfilter != YFilter.not_set or
                    self.integrity_send_password.yfilter != YFilter.not_set or
                    self.interface_name_xr.yfilter != YFilter.not_set or
                    self.out_of_band_expiry_drops_tolerated.yfilter != YFilter.not_set or
                    self.out_of_band_refresh_interval.yfilter != YFilter.not_set or
                    self.pacing_interval.yfilter != YFilter.not_set or
                    self.pacing_message_rate.yfilter != YFilter.not_set or
                    self.pacing_messages.yfilter != YFilter.not_set or
                    self.pacing_timer_state.yfilter != YFilter.not_set or
                    self.refresh_interval.yfilter != YFilter.not_set or
                    self.refresh_timer_state.yfilter != YFilter.not_set or
                    self.retransmit_time.yfilter != YFilter.not_set or
                    self.signalling_ip_tos.yfilter != YFilter.not_set or
                    self.summary_refresh_max_size.yfilter != YFilter.not_set or
                    self.summary_refresh_timer_state.yfilter != YFilter.not_set or
                    (self.bandwidth_information is not None and self.bandwidth_information.has_operation()) or
                    (self.flags is not None and self.flags.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "interface-detailed" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/interface-detaileds/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                if (self.ack_hold_time.is_set or self.ack_hold_time.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.ack_hold_time.get_name_leafdata())
                if (self.ack_max_size.is_set or self.ack_max_size.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.ack_max_size.get_name_leafdata())
                if (self.bundle_message_max_size.is_set or self.bundle_message_max_size.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.bundle_message_max_size.get_name_leafdata())
                if (self.expiry_drops_tolerated.is_set or self.expiry_drops_tolerated.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.expiry_drops_tolerated.get_name_leafdata())
                if (self.expiry_interval.is_set or self.expiry_interval.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.expiry_interval.get_name_leafdata())
                if (self.expiry_states.is_set or self.expiry_states.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.expiry_states.get_name_leafdata())
                if (self.expiry_timer_state.is_set or self.expiry_timer_state.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.expiry_timer_state.get_name_leafdata())
                if (self.integrity_receive_password.is_set or self.integrity_receive_password.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.integrity_receive_password.get_name_leafdata())
                if (self.integrity_receive_password_optional.is_set or self.integrity_receive_password_optional.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.integrity_receive_password_optional.get_name_leafdata())
                if (self.integrity_send_password.is_set or self.integrity_send_password.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.integrity_send_password.get_name_leafdata())
                if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                if (self.out_of_band_expiry_drops_tolerated.is_set or self.out_of_band_expiry_drops_tolerated.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.out_of_band_expiry_drops_tolerated.get_name_leafdata())
                if (self.out_of_band_refresh_interval.is_set or self.out_of_band_refresh_interval.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.out_of_band_refresh_interval.get_name_leafdata())
                if (self.pacing_interval.is_set or self.pacing_interval.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.pacing_interval.get_name_leafdata())
                if (self.pacing_message_rate.is_set or self.pacing_message_rate.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.pacing_message_rate.get_name_leafdata())
                if (self.pacing_messages.is_set or self.pacing_messages.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.pacing_messages.get_name_leafdata())
                if (self.pacing_timer_state.is_set or self.pacing_timer_state.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.pacing_timer_state.get_name_leafdata())
                if (self.refresh_interval.is_set or self.refresh_interval.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.refresh_interval.get_name_leafdata())
                if (self.refresh_timer_state.is_set or self.refresh_timer_state.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.refresh_timer_state.get_name_leafdata())
                if (self.retransmit_time.is_set or self.retransmit_time.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.retransmit_time.get_name_leafdata())
                if (self.signalling_ip_tos.is_set or self.signalling_ip_tos.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.signalling_ip_tos.get_name_leafdata())
                if (self.summary_refresh_max_size.is_set or self.summary_refresh_max_size.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.summary_refresh_max_size.get_name_leafdata())
                if (self.summary_refresh_timer_state.is_set or self.summary_refresh_timer_state.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.summary_refresh_timer_state.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "bandwidth-information"):
                    if (self.bandwidth_information is None):
                        self.bandwidth_information = RsvpStandby.InterfaceDetaileds.InterfaceDetailed.BandwidthInformation()
                        self.bandwidth_information.parent = self
                        self._children_name_map["bandwidth_information"] = "bandwidth-information"
                    return self.bandwidth_information

                if (child_yang_name == "flags"):
                    if (self.flags is None):
                        self.flags = RsvpStandby.InterfaceDetaileds.InterfaceDetailed.Flags()
                        self.flags.parent = self
                        self._children_name_map["flags"] = "flags"
                    return self.flags

                if (child_yang_name == "neighbor-array"):
                    for c in self.neighbor_array:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = RsvpStandby.InterfaceDetaileds.InterfaceDetailed.NeighborArray()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.neighbor_array.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "bandwidth-information" or name == "flags" or name == "neighbor-array" or name == "interface-name" or name == "ack-hold-time" or name == "ack-max-size" or name == "bundle-message-max-size" or name == "expiry-drops-tolerated" or name == "expiry-interval" or name == "expiry-states" or name == "expiry-timer-state" or name == "integrity-receive-password" or name == "integrity-receive-password-optional" or name == "integrity-send-password" or name == "interface-name-xr" or name == "out-of-band-expiry-drops-tolerated" or name == "out-of-band-refresh-interval" or name == "pacing-interval" or name == "pacing-message-rate" or name == "pacing-messages" or name == "pacing-timer-state" or name == "refresh-interval" or name == "refresh-timer-state" or name == "retransmit-time" or name == "signalling-ip-tos" or name == "summary-refresh-max-size" or name == "summary-refresh-timer-state"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "interface-name"):
                    self.interface_name = value
                    self.interface_name.value_namespace = name_space
                    self.interface_name.value_namespace_prefix = name_space_prefix
                if(value_path == "ack-hold-time"):
                    self.ack_hold_time = value
                    self.ack_hold_time.value_namespace = name_space
                    self.ack_hold_time.value_namespace_prefix = name_space_prefix
                if(value_path == "ack-max-size"):
                    self.ack_max_size = value
                    self.ack_max_size.value_namespace = name_space
                    self.ack_max_size.value_namespace_prefix = name_space_prefix
                if(value_path == "bundle-message-max-size"):
                    self.bundle_message_max_size = value
                    self.bundle_message_max_size.value_namespace = name_space
                    self.bundle_message_max_size.value_namespace_prefix = name_space_prefix
                if(value_path == "expiry-drops-tolerated"):
                    self.expiry_drops_tolerated = value
                    self.expiry_drops_tolerated.value_namespace = name_space
                    self.expiry_drops_tolerated.value_namespace_prefix = name_space_prefix
                if(value_path == "expiry-interval"):
                    self.expiry_interval = value
                    self.expiry_interval.value_namespace = name_space
                    self.expiry_interval.value_namespace_prefix = name_space_prefix
                if(value_path == "expiry-states"):
                    self.expiry_states = value
                    self.expiry_states.value_namespace = name_space
                    self.expiry_states.value_namespace_prefix = name_space_prefix
                if(value_path == "expiry-timer-state"):
                    self.expiry_timer_state = value
                    self.expiry_timer_state.value_namespace = name_space
                    self.expiry_timer_state.value_namespace_prefix = name_space_prefix
                if(value_path == "integrity-receive-password"):
                    self.integrity_receive_password = value
                    self.integrity_receive_password.value_namespace = name_space
                    self.integrity_receive_password.value_namespace_prefix = name_space_prefix
                if(value_path == "integrity-receive-password-optional"):
                    self.integrity_receive_password_optional = value
                    self.integrity_receive_password_optional.value_namespace = name_space
                    self.integrity_receive_password_optional.value_namespace_prefix = name_space_prefix
                if(value_path == "integrity-send-password"):
                    self.integrity_send_password = value
                    self.integrity_send_password.value_namespace = name_space
                    self.integrity_send_password.value_namespace_prefix = name_space_prefix
                if(value_path == "interface-name-xr"):
                    self.interface_name_xr = value
                    self.interface_name_xr.value_namespace = name_space
                    self.interface_name_xr.value_namespace_prefix = name_space_prefix
                if(value_path == "out-of-band-expiry-drops-tolerated"):
                    self.out_of_band_expiry_drops_tolerated = value
                    self.out_of_band_expiry_drops_tolerated.value_namespace = name_space
                    self.out_of_band_expiry_drops_tolerated.value_namespace_prefix = name_space_prefix
                if(value_path == "out-of-band-refresh-interval"):
                    self.out_of_band_refresh_interval = value
                    self.out_of_band_refresh_interval.value_namespace = name_space
                    self.out_of_band_refresh_interval.value_namespace_prefix = name_space_prefix
                if(value_path == "pacing-interval"):
                    self.pacing_interval = value
                    self.pacing_interval.value_namespace = name_space
                    self.pacing_interval.value_namespace_prefix = name_space_prefix
                if(value_path == "pacing-message-rate"):
                    self.pacing_message_rate = value
                    self.pacing_message_rate.value_namespace = name_space
                    self.pacing_message_rate.value_namespace_prefix = name_space_prefix
                if(value_path == "pacing-messages"):
                    self.pacing_messages = value
                    self.pacing_messages.value_namespace = name_space
                    self.pacing_messages.value_namespace_prefix = name_space_prefix
                if(value_path == "pacing-timer-state"):
                    self.pacing_timer_state = value
                    self.pacing_timer_state.value_namespace = name_space
                    self.pacing_timer_state.value_namespace_prefix = name_space_prefix
                if(value_path == "refresh-interval"):
                    self.refresh_interval = value
                    self.refresh_interval.value_namespace = name_space
                    self.refresh_interval.value_namespace_prefix = name_space_prefix
                if(value_path == "refresh-timer-state"):
                    self.refresh_timer_state = value
                    self.refresh_timer_state.value_namespace = name_space
                    self.refresh_timer_state.value_namespace_prefix = name_space_prefix
                if(value_path == "retransmit-time"):
                    self.retransmit_time = value
                    self.retransmit_time.value_namespace = name_space
                    self.retransmit_time.value_namespace_prefix = name_space_prefix
                if(value_path == "signalling-ip-tos"):
                    self.signalling_ip_tos = value
                    self.signalling_ip_tos.value_namespace = name_space
                    self.signalling_ip_tos.value_namespace_prefix = name_space_prefix
                if(value_path == "summary-refresh-max-size"):
                    self.summary_refresh_max_size = value
                    self.summary_refresh_max_size.value_namespace = name_space
                    self.summary_refresh_max_size.value_namespace_prefix = name_space_prefix
                if(value_path == "summary-refresh-timer-state"):
                    self.summary_refresh_timer_state = value
                    self.summary_refresh_timer_state.value_namespace = name_space
                    self.summary_refresh_timer_state.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.interface_detailed:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.interface_detailed:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "interface-detaileds" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "interface-detailed"):
                for c in self.interface_detailed:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = RsvpStandby.InterfaceDetaileds.InterfaceDetailed()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.interface_detailed.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "interface-detailed"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class ControllerBriefs(Entity):
        """
        Table of brief info about RSVP\-enabled
        controller
        
        .. attribute:: controller_brief
        
        	Brief info about an RSVP\-enabled controller
        	**type**\: list of    :py:class:`ControllerBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.ControllerBriefs.ControllerBrief>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(RsvpStandby.ControllerBriefs, self).__init__()

            self.yang_name = "controller-briefs"
            self.yang_parent_name = "rsvp-standby"

            self.controller_brief = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(RsvpStandby.ControllerBriefs, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(RsvpStandby.ControllerBriefs, self).__setattr__(name, value)


        class ControllerBrief(Entity):
            """
            Brief info about an RSVP\-enabled controller
            
            .. attribute:: controller_name  <key>
            
            	Controller Name
            	**type**\:  str
            
            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
            
            .. attribute:: bandwidth_information
            
            	Interface bandwidth information
            	**type**\:   :py:class:`BandwidthInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.ControllerBriefs.ControllerBrief.BandwidthInformation>`
            
            .. attribute:: interface_name_xr
            
            	Interface Name
            	**type**\:  str
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(RsvpStandby.ControllerBriefs.ControllerBrief, self).__init__()

                self.yang_name = "controller-brief"
                self.yang_parent_name = "controller-briefs"

                self.controller_name = YLeaf(YType.str, "controller-name")

                self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                self.bandwidth_information = RsvpStandby.ControllerBriefs.ControllerBrief.BandwidthInformation()
                self.bandwidth_information.parent = self
                self._children_name_map["bandwidth_information"] = "bandwidth-information"
                self._children_yang_names.add("bandwidth-information")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("controller_name",
                                "interface_name_xr") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(RsvpStandby.ControllerBriefs.ControllerBrief, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(RsvpStandby.ControllerBriefs.ControllerBrief, self).__setattr__(name, value)


            class BandwidthInformation(Entity):
                """
                Interface bandwidth information
                
                .. attribute:: dste_mode
                
                	DSTEMode
                	**type**\:   :py:class:`RsvpMgmtDsteModes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtDsteModes>`
                
                .. attribute:: pre_standard_dste_interface
                
                	Prestandard DSTE interface information
                	**type**\:   :py:class:`PreStandardDsteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.ControllerBriefs.ControllerBrief.BandwidthInformation.PreStandardDsteInterface>`
                
                .. attribute:: standard_dste_interface
                
                	Standard DSTE interface information
                	**type**\:   :py:class:`StandardDsteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.ControllerBriefs.ControllerBrief.BandwidthInformation.StandardDsteInterface>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.ControllerBriefs.ControllerBrief.BandwidthInformation, self).__init__()

                    self.yang_name = "bandwidth-information"
                    self.yang_parent_name = "controller-brief"

                    self.dste_mode = YLeaf(YType.enumeration, "dste-mode")

                    self.pre_standard_dste_interface = RsvpStandby.ControllerBriefs.ControllerBrief.BandwidthInformation.PreStandardDsteInterface()
                    self.pre_standard_dste_interface.parent = self
                    self._children_name_map["pre_standard_dste_interface"] = "pre-standard-dste-interface"
                    self._children_yang_names.add("pre-standard-dste-interface")

                    self.standard_dste_interface = RsvpStandby.ControllerBriefs.ControllerBrief.BandwidthInformation.StandardDsteInterface()
                    self.standard_dste_interface.parent = self
                    self._children_name_map["standard_dste_interface"] = "standard-dste-interface"
                    self._children_yang_names.add("standard-dste-interface")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("dste_mode") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.ControllerBriefs.ControllerBrief.BandwidthInformation, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.ControllerBriefs.ControllerBrief.BandwidthInformation, self).__setattr__(name, value)


                class PreStandardDsteInterface(Entity):
                    """
                    Prestandard DSTE interface information
                    
                    .. attribute:: allocated_bit_rate
                    
                    	Bandwidth (bits per second) now allocated
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: is_max_bandwidth_absolute
                    
                    	True if the Max B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: is_max_subpool_bandwidth_absolute
                    
                    	True if the Max sub\-pool B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: max_bandwidth
                    
                    	Max bandwidth (bits per second) allowed
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_flow_bandwidth
                    
                    	Max bandwidth (bits per second) allowed per flow
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_subpool_bandwidth
                    
                    	Max bandwidth (bits per second) allowed in subpool
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.ControllerBriefs.ControllerBrief.BandwidthInformation.PreStandardDsteInterface, self).__init__()

                        self.yang_name = "pre-standard-dste-interface"
                        self.yang_parent_name = "bandwidth-information"

                        self.allocated_bit_rate = YLeaf(YType.uint64, "allocated-bit-rate")

                        self.is_max_bandwidth_absolute = YLeaf(YType.boolean, "is-max-bandwidth-absolute")

                        self.is_max_subpool_bandwidth_absolute = YLeaf(YType.boolean, "is-max-subpool-bandwidth-absolute")

                        self.max_bandwidth = YLeaf(YType.uint64, "max-bandwidth")

                        self.max_flow_bandwidth = YLeaf(YType.uint64, "max-flow-bandwidth")

                        self.max_subpool_bandwidth = YLeaf(YType.uint64, "max-subpool-bandwidth")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("allocated_bit_rate",
                                        "is_max_bandwidth_absolute",
                                        "is_max_subpool_bandwidth_absolute",
                                        "max_bandwidth",
                                        "max_flow_bandwidth",
                                        "max_subpool_bandwidth") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.ControllerBriefs.ControllerBrief.BandwidthInformation.PreStandardDsteInterface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.ControllerBriefs.ControllerBrief.BandwidthInformation.PreStandardDsteInterface, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.allocated_bit_rate.is_set or
                            self.is_max_bandwidth_absolute.is_set or
                            self.is_max_subpool_bandwidth_absolute.is_set or
                            self.max_bandwidth.is_set or
                            self.max_flow_bandwidth.is_set or
                            self.max_subpool_bandwidth.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.allocated_bit_rate.yfilter != YFilter.not_set or
                            self.is_max_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.is_max_subpool_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.max_bandwidth.yfilter != YFilter.not_set or
                            self.max_flow_bandwidth.yfilter != YFilter.not_set or
                            self.max_subpool_bandwidth.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "pre-standard-dste-interface" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.allocated_bit_rate.is_set or self.allocated_bit_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.allocated_bit_rate.get_name_leafdata())
                        if (self.is_max_bandwidth_absolute.is_set or self.is_max_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_bandwidth_absolute.get_name_leafdata())
                        if (self.is_max_subpool_bandwidth_absolute.is_set or self.is_max_subpool_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_subpool_bandwidth_absolute.get_name_leafdata())
                        if (self.max_bandwidth.is_set or self.max_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_bandwidth.get_name_leafdata())
                        if (self.max_flow_bandwidth.is_set or self.max_flow_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_flow_bandwidth.get_name_leafdata())
                        if (self.max_subpool_bandwidth.is_set or self.max_subpool_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_subpool_bandwidth.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "allocated-bit-rate" or name == "is-max-bandwidth-absolute" or name == "is-max-subpool-bandwidth-absolute" or name == "max-bandwidth" or name == "max-flow-bandwidth" or name == "max-subpool-bandwidth"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "allocated-bit-rate"):
                            self.allocated_bit_rate = value
                            self.allocated_bit_rate.value_namespace = name_space
                            self.allocated_bit_rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-bandwidth-absolute"):
                            self.is_max_bandwidth_absolute = value
                            self.is_max_bandwidth_absolute.value_namespace = name_space
                            self.is_max_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-subpool-bandwidth-absolute"):
                            self.is_max_subpool_bandwidth_absolute = value
                            self.is_max_subpool_bandwidth_absolute.value_namespace = name_space
                            self.is_max_subpool_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-bandwidth"):
                            self.max_bandwidth = value
                            self.max_bandwidth.value_namespace = name_space
                            self.max_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-flow-bandwidth"):
                            self.max_flow_bandwidth = value
                            self.max_flow_bandwidth.value_namespace = name_space
                            self.max_flow_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-subpool-bandwidth"):
                            self.max_subpool_bandwidth = value
                            self.max_subpool_bandwidth.value_namespace = name_space
                            self.max_subpool_bandwidth.value_namespace_prefix = name_space_prefix


                class StandardDsteInterface(Entity):
                    """
                    Standard DSTE interface information
                    
                    .. attribute:: allocated_bit_rate
                    
                    	Bandwidth (bits per second) now allocated
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: is_max_bandwidth_absolute
                    
                    	True if the Max B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: is_max_bc0_bandwidth_absolute
                    
                    	True if the Max BC0 B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: is_max_bc1_bandwidth_absolute
                    
                    	True if the Max BC1 sub\-pool B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: max_bandwidth
                    
                    	Max bandwidth (bits per second) allowed
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_flow_bandwidth
                    
                    	Max bandwidth (bits per second) allowed per flow
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_pool0_bandwidth
                    
                    	Max bandwidth (bits per second) allowed in BC0 pool
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_pool1_bandwidth
                    
                    	Max bandwidth (bits per second) allowed in BC1 pool
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.ControllerBriefs.ControllerBrief.BandwidthInformation.StandardDsteInterface, self).__init__()

                        self.yang_name = "standard-dste-interface"
                        self.yang_parent_name = "bandwidth-information"

                        self.allocated_bit_rate = YLeaf(YType.uint64, "allocated-bit-rate")

                        self.is_max_bandwidth_absolute = YLeaf(YType.boolean, "is-max-bandwidth-absolute")

                        self.is_max_bc0_bandwidth_absolute = YLeaf(YType.boolean, "is-max-bc0-bandwidth-absolute")

                        self.is_max_bc1_bandwidth_absolute = YLeaf(YType.boolean, "is-max-bc1-bandwidth-absolute")

                        self.max_bandwidth = YLeaf(YType.uint64, "max-bandwidth")

                        self.max_flow_bandwidth = YLeaf(YType.uint64, "max-flow-bandwidth")

                        self.max_pool0_bandwidth = YLeaf(YType.uint64, "max-pool0-bandwidth")

                        self.max_pool1_bandwidth = YLeaf(YType.uint64, "max-pool1-bandwidth")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("allocated_bit_rate",
                                        "is_max_bandwidth_absolute",
                                        "is_max_bc0_bandwidth_absolute",
                                        "is_max_bc1_bandwidth_absolute",
                                        "max_bandwidth",
                                        "max_flow_bandwidth",
                                        "max_pool0_bandwidth",
                                        "max_pool1_bandwidth") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.ControllerBriefs.ControllerBrief.BandwidthInformation.StandardDsteInterface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.ControllerBriefs.ControllerBrief.BandwidthInformation.StandardDsteInterface, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.allocated_bit_rate.is_set or
                            self.is_max_bandwidth_absolute.is_set or
                            self.is_max_bc0_bandwidth_absolute.is_set or
                            self.is_max_bc1_bandwidth_absolute.is_set or
                            self.max_bandwidth.is_set or
                            self.max_flow_bandwidth.is_set or
                            self.max_pool0_bandwidth.is_set or
                            self.max_pool1_bandwidth.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.allocated_bit_rate.yfilter != YFilter.not_set or
                            self.is_max_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.is_max_bc0_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.is_max_bc1_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.max_bandwidth.yfilter != YFilter.not_set or
                            self.max_flow_bandwidth.yfilter != YFilter.not_set or
                            self.max_pool0_bandwidth.yfilter != YFilter.not_set or
                            self.max_pool1_bandwidth.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "standard-dste-interface" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.allocated_bit_rate.is_set or self.allocated_bit_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.allocated_bit_rate.get_name_leafdata())
                        if (self.is_max_bandwidth_absolute.is_set or self.is_max_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_bandwidth_absolute.get_name_leafdata())
                        if (self.is_max_bc0_bandwidth_absolute.is_set or self.is_max_bc0_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_bc0_bandwidth_absolute.get_name_leafdata())
                        if (self.is_max_bc1_bandwidth_absolute.is_set or self.is_max_bc1_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_bc1_bandwidth_absolute.get_name_leafdata())
                        if (self.max_bandwidth.is_set or self.max_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_bandwidth.get_name_leafdata())
                        if (self.max_flow_bandwidth.is_set or self.max_flow_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_flow_bandwidth.get_name_leafdata())
                        if (self.max_pool0_bandwidth.is_set or self.max_pool0_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_pool0_bandwidth.get_name_leafdata())
                        if (self.max_pool1_bandwidth.is_set or self.max_pool1_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_pool1_bandwidth.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "allocated-bit-rate" or name == "is-max-bandwidth-absolute" or name == "is-max-bc0-bandwidth-absolute" or name == "is-max-bc1-bandwidth-absolute" or name == "max-bandwidth" or name == "max-flow-bandwidth" or name == "max-pool0-bandwidth" or name == "max-pool1-bandwidth"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "allocated-bit-rate"):
                            self.allocated_bit_rate = value
                            self.allocated_bit_rate.value_namespace = name_space
                            self.allocated_bit_rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-bandwidth-absolute"):
                            self.is_max_bandwidth_absolute = value
                            self.is_max_bandwidth_absolute.value_namespace = name_space
                            self.is_max_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-bc0-bandwidth-absolute"):
                            self.is_max_bc0_bandwidth_absolute = value
                            self.is_max_bc0_bandwidth_absolute.value_namespace = name_space
                            self.is_max_bc0_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-bc1-bandwidth-absolute"):
                            self.is_max_bc1_bandwidth_absolute = value
                            self.is_max_bc1_bandwidth_absolute.value_namespace = name_space
                            self.is_max_bc1_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-bandwidth"):
                            self.max_bandwidth = value
                            self.max_bandwidth.value_namespace = name_space
                            self.max_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-flow-bandwidth"):
                            self.max_flow_bandwidth = value
                            self.max_flow_bandwidth.value_namespace = name_space
                            self.max_flow_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-pool0-bandwidth"):
                            self.max_pool0_bandwidth = value
                            self.max_pool0_bandwidth.value_namespace = name_space
                            self.max_pool0_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-pool1-bandwidth"):
                            self.max_pool1_bandwidth = value
                            self.max_pool1_bandwidth.value_namespace = name_space
                            self.max_pool1_bandwidth.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.dste_mode.is_set or
                        (self.pre_standard_dste_interface is not None and self.pre_standard_dste_interface.has_data()) or
                        (self.standard_dste_interface is not None and self.standard_dste_interface.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.dste_mode.yfilter != YFilter.not_set or
                        (self.pre_standard_dste_interface is not None and self.pre_standard_dste_interface.has_operation()) or
                        (self.standard_dste_interface is not None and self.standard_dste_interface.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bandwidth-information" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.dste_mode.is_set or self.dste_mode.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.dste_mode.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "pre-standard-dste-interface"):
                        if (self.pre_standard_dste_interface is None):
                            self.pre_standard_dste_interface = RsvpStandby.ControllerBriefs.ControllerBrief.BandwidthInformation.PreStandardDsteInterface()
                            self.pre_standard_dste_interface.parent = self
                            self._children_name_map["pre_standard_dste_interface"] = "pre-standard-dste-interface"
                        return self.pre_standard_dste_interface

                    if (child_yang_name == "standard-dste-interface"):
                        if (self.standard_dste_interface is None):
                            self.standard_dste_interface = RsvpStandby.ControllerBriefs.ControllerBrief.BandwidthInformation.StandardDsteInterface()
                            self.standard_dste_interface.parent = self
                            self._children_name_map["standard_dste_interface"] = "standard-dste-interface"
                        return self.standard_dste_interface

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "pre-standard-dste-interface" or name == "standard-dste-interface" or name == "dste-mode"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "dste-mode"):
                        self.dste_mode = value
                        self.dste_mode.value_namespace = name_space
                        self.dste_mode.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.controller_name.is_set or
                    self.interface_name_xr.is_set or
                    (self.bandwidth_information is not None and self.bandwidth_information.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.controller_name.yfilter != YFilter.not_set or
                    self.interface_name_xr.yfilter != YFilter.not_set or
                    (self.bandwidth_information is not None and self.bandwidth_information.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "controller-brief" + "[controller-name='" + self.controller_name.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/controller-briefs/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.controller_name.is_set or self.controller_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.controller_name.get_name_leafdata())
                if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.interface_name_xr.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "bandwidth-information"):
                    if (self.bandwidth_information is None):
                        self.bandwidth_information = RsvpStandby.ControllerBriefs.ControllerBrief.BandwidthInformation()
                        self.bandwidth_information.parent = self
                        self._children_name_map["bandwidth_information"] = "bandwidth-information"
                    return self.bandwidth_information

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "bandwidth-information" or name == "controller-name" or name == "interface-name-xr"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "controller-name"):
                    self.controller_name = value
                    self.controller_name.value_namespace = name_space
                    self.controller_name.value_namespace_prefix = name_space_prefix
                if(value_path == "interface-name-xr"):
                    self.interface_name_xr = value
                    self.interface_name_xr.value_namespace = name_space
                    self.interface_name_xr.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.controller_brief:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.controller_brief:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "controller-briefs" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "controller-brief"):
                for c in self.controller_brief:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = RsvpStandby.ControllerBriefs.ControllerBrief()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.controller_brief.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "controller-brief"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class GracefulRestart(Entity):
        """
        Info about graceful\-restart
        
        .. attribute:: global_neighbors
        
        	Global neighbor count
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: hello_interval
        
        	Interval at which hello messages are sent
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: is_gr_enabled
        
        	Whether GR is enabled
        	**type**\:  bool
        
        .. attribute:: is_recovery_timer_running
        
        	Whether recovery timer is running
        	**type**\:  bool
        
        .. attribute:: local_node_address
        
        	Local node address
        	**type**\: list of    :py:class:`LocalNodeAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.GracefulRestart.LocalNodeAddress>`
        
        .. attribute:: missed_hellos
        
        	Max number of hellos missed before hellos declared down
        	**type**\:  int
        
        	**range:** 0..255
        
        .. attribute:: pending_states
        
        	Total number of pending states
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: recovery_time
        
        	Recovery time (milliseconds)
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        	**units**\: millisecond
        
        .. attribute:: recovery_time_left
        
        	How much recovery timer remains
        	**type**\:   :py:class:`RecoveryTimeLeft <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.GracefulRestart.RecoveryTimeLeft>`
        
        .. attribute:: recovery_timer_exp_time
        
        	Time at which recovery timer will expire
        	**type**\:   :py:class:`RecoveryTimerExpTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.GracefulRestart.RecoveryTimerExpTime>`
        
        .. attribute:: restart_time
        
        	Restart time (milliseconds)
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        	**units**\: millisecond
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(RsvpStandby.GracefulRestart, self).__init__()

            self.yang_name = "graceful-restart"
            self.yang_parent_name = "rsvp-standby"

            self.global_neighbors = YLeaf(YType.uint32, "global-neighbors")

            self.hello_interval = YLeaf(YType.uint32, "hello-interval")

            self.is_gr_enabled = YLeaf(YType.boolean, "is-gr-enabled")

            self.is_recovery_timer_running = YLeaf(YType.boolean, "is-recovery-timer-running")

            self.missed_hellos = YLeaf(YType.uint8, "missed-hellos")

            self.pending_states = YLeaf(YType.uint32, "pending-states")

            self.recovery_time = YLeaf(YType.uint32, "recovery-time")

            self.restart_time = YLeaf(YType.uint32, "restart-time")

            self.recovery_time_left = RsvpStandby.GracefulRestart.RecoveryTimeLeft()
            self.recovery_time_left.parent = self
            self._children_name_map["recovery_time_left"] = "recovery-time-left"
            self._children_yang_names.add("recovery-time-left")

            self.recovery_timer_exp_time = RsvpStandby.GracefulRestart.RecoveryTimerExpTime()
            self.recovery_timer_exp_time.parent = self
            self._children_name_map["recovery_timer_exp_time"] = "recovery-timer-exp-time"
            self._children_yang_names.add("recovery-timer-exp-time")

            self.local_node_address = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in ("global_neighbors",
                            "hello_interval",
                            "is_gr_enabled",
                            "is_recovery_timer_running",
                            "missed_hellos",
                            "pending_states",
                            "recovery_time",
                            "restart_time") and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(RsvpStandby.GracefulRestart, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(RsvpStandby.GracefulRestart, self).__setattr__(name, value)


        class RecoveryTimeLeft(Entity):
            """
            How much recovery timer remains
            
            .. attribute:: nanoseconds
            
            	Time Value in Nano\-seconds
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            	**units**\: nanosecond
            
            .. attribute:: seconds
            
            	Time Value in Seconds
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            	**units**\: second
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(RsvpStandby.GracefulRestart.RecoveryTimeLeft, self).__init__()

                self.yang_name = "recovery-time-left"
                self.yang_parent_name = "graceful-restart"

                self.nanoseconds = YLeaf(YType.int32, "nanoseconds")

                self.seconds = YLeaf(YType.int32, "seconds")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("nanoseconds",
                                "seconds") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(RsvpStandby.GracefulRestart.RecoveryTimeLeft, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(RsvpStandby.GracefulRestart.RecoveryTimeLeft, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.nanoseconds.is_set or
                    self.seconds.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.nanoseconds.yfilter != YFilter.not_set or
                    self.seconds.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "recovery-time-left" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/graceful-restart/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.nanoseconds.is_set or self.nanoseconds.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.nanoseconds.get_name_leafdata())
                if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.seconds.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "nanoseconds" or name == "seconds"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "nanoseconds"):
                    self.nanoseconds = value
                    self.nanoseconds.value_namespace = name_space
                    self.nanoseconds.value_namespace_prefix = name_space_prefix
                if(value_path == "seconds"):
                    self.seconds = value
                    self.seconds.value_namespace = name_space
                    self.seconds.value_namespace_prefix = name_space_prefix


        class RecoveryTimerExpTime(Entity):
            """
            Time at which recovery timer will expire
            
            .. attribute:: nanoseconds
            
            	Time Value in Nano\-seconds
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            	**units**\: nanosecond
            
            .. attribute:: seconds
            
            	Time Value in Seconds
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            	**units**\: second
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(RsvpStandby.GracefulRestart.RecoveryTimerExpTime, self).__init__()

                self.yang_name = "recovery-timer-exp-time"
                self.yang_parent_name = "graceful-restart"

                self.nanoseconds = YLeaf(YType.int32, "nanoseconds")

                self.seconds = YLeaf(YType.int32, "seconds")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("nanoseconds",
                                "seconds") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(RsvpStandby.GracefulRestart.RecoveryTimerExpTime, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(RsvpStandby.GracefulRestart.RecoveryTimerExpTime, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.nanoseconds.is_set or
                    self.seconds.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.nanoseconds.yfilter != YFilter.not_set or
                    self.seconds.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "recovery-timer-exp-time" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/graceful-restart/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.nanoseconds.is_set or self.nanoseconds.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.nanoseconds.get_name_leafdata())
                if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.seconds.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "nanoseconds" or name == "seconds"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "nanoseconds"):
                    self.nanoseconds = value
                    self.nanoseconds.value_namespace = name_space
                    self.nanoseconds.value_namespace_prefix = name_space_prefix
                if(value_path == "seconds"):
                    self.seconds = value
                    self.seconds.value_namespace = name_space
                    self.seconds.value_namespace_prefix = name_space_prefix


        class LocalNodeAddress(Entity):
            """
            Local node address
            
            .. attribute:: application_type
            
            	GR local node\-id app type
            	**type**\:   :py:class:`RsvpMgmtGrApp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtGrApp>`
            
            .. attribute:: local_node_ip_address
            
            	Local node address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(RsvpStandby.GracefulRestart.LocalNodeAddress, self).__init__()

                self.yang_name = "local-node-address"
                self.yang_parent_name = "graceful-restart"

                self.application_type = YLeaf(YType.enumeration, "application-type")

                self.local_node_ip_address = YLeaf(YType.str, "local-node-ip-address")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("application_type",
                                "local_node_ip_address") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(RsvpStandby.GracefulRestart.LocalNodeAddress, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(RsvpStandby.GracefulRestart.LocalNodeAddress, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.application_type.is_set or
                    self.local_node_ip_address.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.application_type.yfilter != YFilter.not_set or
                    self.local_node_ip_address.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "local-node-address" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/graceful-restart/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.application_type.is_set or self.application_type.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.application_type.get_name_leafdata())
                if (self.local_node_ip_address.is_set or self.local_node_ip_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.local_node_ip_address.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "application-type" or name == "local-node-ip-address"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "application-type"):
                    self.application_type = value
                    self.application_type.value_namespace = name_space
                    self.application_type.value_namespace_prefix = name_space_prefix
                if(value_path == "local-node-ip-address"):
                    self.local_node_ip_address = value
                    self.local_node_ip_address.value_namespace = name_space
                    self.local_node_ip_address.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.local_node_address:
                if (c.has_data()):
                    return True
            return (
                self.global_neighbors.is_set or
                self.hello_interval.is_set or
                self.is_gr_enabled.is_set or
                self.is_recovery_timer_running.is_set or
                self.missed_hellos.is_set or
                self.pending_states.is_set or
                self.recovery_time.is_set or
                self.restart_time.is_set or
                (self.recovery_time_left is not None and self.recovery_time_left.has_data()) or
                (self.recovery_timer_exp_time is not None and self.recovery_timer_exp_time.has_data()))

        def has_operation(self):
            for c in self.local_node_address:
                if (c.has_operation()):
                    return True
            return (
                self.yfilter != YFilter.not_set or
                self.global_neighbors.yfilter != YFilter.not_set or
                self.hello_interval.yfilter != YFilter.not_set or
                self.is_gr_enabled.yfilter != YFilter.not_set or
                self.is_recovery_timer_running.yfilter != YFilter.not_set or
                self.missed_hellos.yfilter != YFilter.not_set or
                self.pending_states.yfilter != YFilter.not_set or
                self.recovery_time.yfilter != YFilter.not_set or
                self.restart_time.yfilter != YFilter.not_set or
                (self.recovery_time_left is not None and self.recovery_time_left.has_operation()) or
                (self.recovery_timer_exp_time is not None and self.recovery_timer_exp_time.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "graceful-restart" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()
            if (self.global_neighbors.is_set or self.global_neighbors.yfilter != YFilter.not_set):
                leaf_name_data.append(self.global_neighbors.get_name_leafdata())
            if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                leaf_name_data.append(self.hello_interval.get_name_leafdata())
            if (self.is_gr_enabled.is_set or self.is_gr_enabled.yfilter != YFilter.not_set):
                leaf_name_data.append(self.is_gr_enabled.get_name_leafdata())
            if (self.is_recovery_timer_running.is_set or self.is_recovery_timer_running.yfilter != YFilter.not_set):
                leaf_name_data.append(self.is_recovery_timer_running.get_name_leafdata())
            if (self.missed_hellos.is_set or self.missed_hellos.yfilter != YFilter.not_set):
                leaf_name_data.append(self.missed_hellos.get_name_leafdata())
            if (self.pending_states.is_set or self.pending_states.yfilter != YFilter.not_set):
                leaf_name_data.append(self.pending_states.get_name_leafdata())
            if (self.recovery_time.is_set or self.recovery_time.yfilter != YFilter.not_set):
                leaf_name_data.append(self.recovery_time.get_name_leafdata())
            if (self.restart_time.is_set or self.restart_time.yfilter != YFilter.not_set):
                leaf_name_data.append(self.restart_time.get_name_leafdata())

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "local-node-address"):
                for c in self.local_node_address:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = RsvpStandby.GracefulRestart.LocalNodeAddress()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.local_node_address.append(c)
                return c

            if (child_yang_name == "recovery-time-left"):
                if (self.recovery_time_left is None):
                    self.recovery_time_left = RsvpStandby.GracefulRestart.RecoveryTimeLeft()
                    self.recovery_time_left.parent = self
                    self._children_name_map["recovery_time_left"] = "recovery-time-left"
                return self.recovery_time_left

            if (child_yang_name == "recovery-timer-exp-time"):
                if (self.recovery_timer_exp_time is None):
                    self.recovery_timer_exp_time = RsvpStandby.GracefulRestart.RecoveryTimerExpTime()
                    self.recovery_timer_exp_time.parent = self
                    self._children_name_map["recovery_timer_exp_time"] = "recovery-timer-exp-time"
                return self.recovery_timer_exp_time

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "local-node-address" or name == "recovery-time-left" or name == "recovery-timer-exp-time" or name == "global-neighbors" or name == "hello-interval" or name == "is-gr-enabled" or name == "is-recovery-timer-running" or name == "missed-hellos" or name == "pending-states" or name == "recovery-time" or name == "restart-time"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            if(value_path == "global-neighbors"):
                self.global_neighbors = value
                self.global_neighbors.value_namespace = name_space
                self.global_neighbors.value_namespace_prefix = name_space_prefix
            if(value_path == "hello-interval"):
                self.hello_interval = value
                self.hello_interval.value_namespace = name_space
                self.hello_interval.value_namespace_prefix = name_space_prefix
            if(value_path == "is-gr-enabled"):
                self.is_gr_enabled = value
                self.is_gr_enabled.value_namespace = name_space
                self.is_gr_enabled.value_namespace_prefix = name_space_prefix
            if(value_path == "is-recovery-timer-running"):
                self.is_recovery_timer_running = value
                self.is_recovery_timer_running.value_namespace = name_space
                self.is_recovery_timer_running.value_namespace_prefix = name_space_prefix
            if(value_path == "missed-hellos"):
                self.missed_hellos = value
                self.missed_hellos.value_namespace = name_space
                self.missed_hellos.value_namespace_prefix = name_space_prefix
            if(value_path == "pending-states"):
                self.pending_states = value
                self.pending_states.value_namespace = name_space
                self.pending_states.value_namespace_prefix = name_space_prefix
            if(value_path == "recovery-time"):
                self.recovery_time = value
                self.recovery_time.value_namespace = name_space
                self.recovery_time.value_namespace_prefix = name_space_prefix
            if(value_path == "restart-time"):
                self.restart_time = value
                self.restart_time.value_namespace = name_space
                self.restart_time.value_namespace_prefix = name_space_prefix


    class HelloInterfaceInstanceBriefs(Entity):
        """
        Table of brief info about i/f\-based hello
        instances
        
        .. attribute:: hello_interface_instance_brief
        
        	Brief info for a single interface\-based hello instance
        	**type**\: list of    :py:class:`HelloInterfaceInstanceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.HelloInterfaceInstanceBriefs.HelloInterfaceInstanceBrief>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(RsvpStandby.HelloInterfaceInstanceBriefs, self).__init__()

            self.yang_name = "hello-interface-instance-briefs"
            self.yang_parent_name = "rsvp-standby"

            self.hello_interface_instance_brief = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(RsvpStandby.HelloInterfaceInstanceBriefs, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(RsvpStandby.HelloInterfaceInstanceBriefs, self).__setattr__(name, value)


        class HelloInterfaceInstanceBrief(Entity):
            """
            Brief info for a single interface\-based hello
            instance
            
            .. attribute:: source_address  <key>
            
            	Source Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: destination_address  <key>
            
            	Destination Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: destination_address_xr
            
            	Destination address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: hello_interface
            
            	Interface to use
            	**type**\:  str
            
            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
            
            .. attribute:: instance_type
            
            	Hello instance type
            	**type**\:   :py:class:`RsvpMgmtHelloInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtHelloInstance>`
            
            .. attribute:: source_address_xr
            
            	Source address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(RsvpStandby.HelloInterfaceInstanceBriefs.HelloInterfaceInstanceBrief, self).__init__()

                self.yang_name = "hello-interface-instance-brief"
                self.yang_parent_name = "hello-interface-instance-briefs"

                self.source_address = YLeaf(YType.str, "source-address")

                self.destination_address = YLeaf(YType.str, "destination-address")

                self.destination_address_xr = YLeaf(YType.str, "destination-address-xr")

                self.hello_interface = YLeaf(YType.str, "hello-interface")

                self.instance_type = YLeaf(YType.enumeration, "instance-type")

                self.source_address_xr = YLeaf(YType.str, "source-address-xr")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("source_address",
                                "destination_address",
                                "destination_address_xr",
                                "hello_interface",
                                "instance_type",
                                "source_address_xr") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(RsvpStandby.HelloInterfaceInstanceBriefs.HelloInterfaceInstanceBrief, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(RsvpStandby.HelloInterfaceInstanceBriefs.HelloInterfaceInstanceBrief, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.source_address.is_set or
                    self.destination_address.is_set or
                    self.destination_address_xr.is_set or
                    self.hello_interface.is_set or
                    self.instance_type.is_set or
                    self.source_address_xr.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.source_address.yfilter != YFilter.not_set or
                    self.destination_address.yfilter != YFilter.not_set or
                    self.destination_address_xr.yfilter != YFilter.not_set or
                    self.hello_interface.yfilter != YFilter.not_set or
                    self.instance_type.yfilter != YFilter.not_set or
                    self.source_address_xr.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "hello-interface-instance-brief" + "[source-address='" + self.source_address.get() + "']" + "[destination-address='" + self.destination_address.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/hello-interface-instance-briefs/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_address.get_name_leafdata())
                if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_address.get_name_leafdata())
                if (self.destination_address_xr.is_set or self.destination_address_xr.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_address_xr.get_name_leafdata())
                if (self.hello_interface.is_set or self.hello_interface.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.hello_interface.get_name_leafdata())
                if (self.instance_type.is_set or self.instance_type.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.instance_type.get_name_leafdata())
                if (self.source_address_xr.is_set or self.source_address_xr.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_address_xr.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "source-address" or name == "destination-address" or name == "destination-address-xr" or name == "hello-interface" or name == "instance-type" or name == "source-address-xr"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "source-address"):
                    self.source_address = value
                    self.source_address.value_namespace = name_space
                    self.source_address.value_namespace_prefix = name_space_prefix
                if(value_path == "destination-address"):
                    self.destination_address = value
                    self.destination_address.value_namespace = name_space
                    self.destination_address.value_namespace_prefix = name_space_prefix
                if(value_path == "destination-address-xr"):
                    self.destination_address_xr = value
                    self.destination_address_xr.value_namespace = name_space
                    self.destination_address_xr.value_namespace_prefix = name_space_prefix
                if(value_path == "hello-interface"):
                    self.hello_interface = value
                    self.hello_interface.value_namespace = name_space
                    self.hello_interface.value_namespace_prefix = name_space_prefix
                if(value_path == "instance-type"):
                    self.instance_type = value
                    self.instance_type.value_namespace = name_space
                    self.instance_type.value_namespace_prefix = name_space_prefix
                if(value_path == "source-address-xr"):
                    self.source_address_xr = value
                    self.source_address_xr.value_namespace = name_space
                    self.source_address_xr.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.hello_interface_instance_brief:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.hello_interface_instance_brief:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "hello-interface-instance-briefs" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "hello-interface-instance-brief"):
                for c in self.hello_interface_instance_brief:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = RsvpStandby.HelloInterfaceInstanceBriefs.HelloInterfaceInstanceBrief()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.hello_interface_instance_brief.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "hello-interface-instance-brief"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class HelloInterfaceInstanceDetails(Entity):
        """
        Table of detailed info about i/f\-based hello
        instances
        
        .. attribute:: hello_interface_instance_detail
        
        	Detailed info for a single interface\-based hello instance
        	**type**\: list of    :py:class:`HelloInterfaceInstanceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.HelloInterfaceInstanceDetails.HelloInterfaceInstanceDetail>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(RsvpStandby.HelloInterfaceInstanceDetails, self).__init__()

            self.yang_name = "hello-interface-instance-details"
            self.yang_parent_name = "rsvp-standby"

            self.hello_interface_instance_detail = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(RsvpStandby.HelloInterfaceInstanceDetails, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(RsvpStandby.HelloInterfaceInstanceDetails, self).__setattr__(name, value)


        class HelloInterfaceInstanceDetail(Entity):
            """
            Detailed info for a single interface\-based
            hello instance
            
            .. attribute:: source_address  <key>
            
            	Source Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: destination_address  <key>
            
            	Destination Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: destination_address_xr
            
            	Destination address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: destination_instance
            
            	Destination Instance
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: hello_global_neighbor_id
            
            	Global Neighbor ID
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: hello_interface
            
            	Interface to use
            	**type**\:  str
            
            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
            
            .. attribute:: hello_messages_received
            
            	Number of hello messages received
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: hello_messages_sent
            
            	Number of hello messages sent
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: instance_type
            
            	Hello instance type
            	**type**\:   :py:class:`RsvpMgmtHelloInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtHelloInstance>`
            
            .. attribute:: last_message_sent_time
            
            	Last Ack/msg sent time
            	**type**\:   :py:class:`LastMessageSentTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.HelloInterfaceInstanceDetails.HelloInterfaceInstanceDetail.LastMessageSentTime>`
            
            .. attribute:: source_address_xr
            
            	Source address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: source_instance
            
            	Source Instance
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(RsvpStandby.HelloInterfaceInstanceDetails.HelloInterfaceInstanceDetail, self).__init__()

                self.yang_name = "hello-interface-instance-detail"
                self.yang_parent_name = "hello-interface-instance-details"

                self.source_address = YLeaf(YType.str, "source-address")

                self.destination_address = YLeaf(YType.str, "destination-address")

                self.destination_address_xr = YLeaf(YType.str, "destination-address-xr")

                self.destination_instance = YLeaf(YType.uint32, "destination-instance")

                self.hello_global_neighbor_id = YLeaf(YType.str, "hello-global-neighbor-id")

                self.hello_interface = YLeaf(YType.str, "hello-interface")

                self.hello_messages_received = YLeaf(YType.uint64, "hello-messages-received")

                self.hello_messages_sent = YLeaf(YType.uint64, "hello-messages-sent")

                self.instance_type = YLeaf(YType.enumeration, "instance-type")

                self.source_address_xr = YLeaf(YType.str, "source-address-xr")

                self.source_instance = YLeaf(YType.uint32, "source-instance")

                self.last_message_sent_time = RsvpStandby.HelloInterfaceInstanceDetails.HelloInterfaceInstanceDetail.LastMessageSentTime()
                self.last_message_sent_time.parent = self
                self._children_name_map["last_message_sent_time"] = "last-message-sent-time"
                self._children_yang_names.add("last-message-sent-time")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("source_address",
                                "destination_address",
                                "destination_address_xr",
                                "destination_instance",
                                "hello_global_neighbor_id",
                                "hello_interface",
                                "hello_messages_received",
                                "hello_messages_sent",
                                "instance_type",
                                "source_address_xr",
                                "source_instance") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(RsvpStandby.HelloInterfaceInstanceDetails.HelloInterfaceInstanceDetail, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(RsvpStandby.HelloInterfaceInstanceDetails.HelloInterfaceInstanceDetail, self).__setattr__(name, value)


            class LastMessageSentTime(Entity):
                """
                Last Ack/msg sent time
                
                .. attribute:: nanoseconds
                
                	Time Value in Nano\-seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: nanosecond
                
                .. attribute:: seconds
                
                	Time Value in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.HelloInterfaceInstanceDetails.HelloInterfaceInstanceDetail.LastMessageSentTime, self).__init__()

                    self.yang_name = "last-message-sent-time"
                    self.yang_parent_name = "hello-interface-instance-detail"

                    self.nanoseconds = YLeaf(YType.int32, "nanoseconds")

                    self.seconds = YLeaf(YType.int32, "seconds")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("nanoseconds",
                                    "seconds") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.HelloInterfaceInstanceDetails.HelloInterfaceInstanceDetail.LastMessageSentTime, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.HelloInterfaceInstanceDetails.HelloInterfaceInstanceDetail.LastMessageSentTime, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.nanoseconds.is_set or
                        self.seconds.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.nanoseconds.yfilter != YFilter.not_set or
                        self.seconds.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "last-message-sent-time" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.nanoseconds.is_set or self.nanoseconds.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.nanoseconds.get_name_leafdata())
                    if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.seconds.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "nanoseconds" or name == "seconds"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "nanoseconds"):
                        self.nanoseconds = value
                        self.nanoseconds.value_namespace = name_space
                        self.nanoseconds.value_namespace_prefix = name_space_prefix
                    if(value_path == "seconds"):
                        self.seconds = value
                        self.seconds.value_namespace = name_space
                        self.seconds.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.source_address.is_set or
                    self.destination_address.is_set or
                    self.destination_address_xr.is_set or
                    self.destination_instance.is_set or
                    self.hello_global_neighbor_id.is_set or
                    self.hello_interface.is_set or
                    self.hello_messages_received.is_set or
                    self.hello_messages_sent.is_set or
                    self.instance_type.is_set or
                    self.source_address_xr.is_set or
                    self.source_instance.is_set or
                    (self.last_message_sent_time is not None and self.last_message_sent_time.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.source_address.yfilter != YFilter.not_set or
                    self.destination_address.yfilter != YFilter.not_set or
                    self.destination_address_xr.yfilter != YFilter.not_set or
                    self.destination_instance.yfilter != YFilter.not_set or
                    self.hello_global_neighbor_id.yfilter != YFilter.not_set or
                    self.hello_interface.yfilter != YFilter.not_set or
                    self.hello_messages_received.yfilter != YFilter.not_set or
                    self.hello_messages_sent.yfilter != YFilter.not_set or
                    self.instance_type.yfilter != YFilter.not_set or
                    self.source_address_xr.yfilter != YFilter.not_set or
                    self.source_instance.yfilter != YFilter.not_set or
                    (self.last_message_sent_time is not None and self.last_message_sent_time.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "hello-interface-instance-detail" + "[source-address='" + self.source_address.get() + "']" + "[destination-address='" + self.destination_address.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/hello-interface-instance-details/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_address.get_name_leafdata())
                if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_address.get_name_leafdata())
                if (self.destination_address_xr.is_set or self.destination_address_xr.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_address_xr.get_name_leafdata())
                if (self.destination_instance.is_set or self.destination_instance.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_instance.get_name_leafdata())
                if (self.hello_global_neighbor_id.is_set or self.hello_global_neighbor_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.hello_global_neighbor_id.get_name_leafdata())
                if (self.hello_interface.is_set or self.hello_interface.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.hello_interface.get_name_leafdata())
                if (self.hello_messages_received.is_set or self.hello_messages_received.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.hello_messages_received.get_name_leafdata())
                if (self.hello_messages_sent.is_set or self.hello_messages_sent.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.hello_messages_sent.get_name_leafdata())
                if (self.instance_type.is_set or self.instance_type.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.instance_type.get_name_leafdata())
                if (self.source_address_xr.is_set or self.source_address_xr.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_address_xr.get_name_leafdata())
                if (self.source_instance.is_set or self.source_instance.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_instance.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "last-message-sent-time"):
                    if (self.last_message_sent_time is None):
                        self.last_message_sent_time = RsvpStandby.HelloInterfaceInstanceDetails.HelloInterfaceInstanceDetail.LastMessageSentTime()
                        self.last_message_sent_time.parent = self
                        self._children_name_map["last_message_sent_time"] = "last-message-sent-time"
                    return self.last_message_sent_time

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "last-message-sent-time" or name == "source-address" or name == "destination-address" or name == "destination-address-xr" or name == "destination-instance" or name == "hello-global-neighbor-id" or name == "hello-interface" or name == "hello-messages-received" or name == "hello-messages-sent" or name == "instance-type" or name == "source-address-xr" or name == "source-instance"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "source-address"):
                    self.source_address = value
                    self.source_address.value_namespace = name_space
                    self.source_address.value_namespace_prefix = name_space_prefix
                if(value_path == "destination-address"):
                    self.destination_address = value
                    self.destination_address.value_namespace = name_space
                    self.destination_address.value_namespace_prefix = name_space_prefix
                if(value_path == "destination-address-xr"):
                    self.destination_address_xr = value
                    self.destination_address_xr.value_namespace = name_space
                    self.destination_address_xr.value_namespace_prefix = name_space_prefix
                if(value_path == "destination-instance"):
                    self.destination_instance = value
                    self.destination_instance.value_namespace = name_space
                    self.destination_instance.value_namespace_prefix = name_space_prefix
                if(value_path == "hello-global-neighbor-id"):
                    self.hello_global_neighbor_id = value
                    self.hello_global_neighbor_id.value_namespace = name_space
                    self.hello_global_neighbor_id.value_namespace_prefix = name_space_prefix
                if(value_path == "hello-interface"):
                    self.hello_interface = value
                    self.hello_interface.value_namespace = name_space
                    self.hello_interface.value_namespace_prefix = name_space_prefix
                if(value_path == "hello-messages-received"):
                    self.hello_messages_received = value
                    self.hello_messages_received.value_namespace = name_space
                    self.hello_messages_received.value_namespace_prefix = name_space_prefix
                if(value_path == "hello-messages-sent"):
                    self.hello_messages_sent = value
                    self.hello_messages_sent.value_namespace = name_space
                    self.hello_messages_sent.value_namespace_prefix = name_space_prefix
                if(value_path == "instance-type"):
                    self.instance_type = value
                    self.instance_type.value_namespace = name_space
                    self.instance_type.value_namespace_prefix = name_space_prefix
                if(value_path == "source-address-xr"):
                    self.source_address_xr = value
                    self.source_address_xr.value_namespace = name_space
                    self.source_address_xr.value_namespace_prefix = name_space_prefix
                if(value_path == "source-instance"):
                    self.source_instance = value
                    self.source_instance.value_namespace = name_space
                    self.source_instance.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.hello_interface_instance_detail:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.hello_interface_instance_detail:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "hello-interface-instance-details" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "hello-interface-instance-detail"):
                for c in self.hello_interface_instance_detail:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = RsvpStandby.HelloInterfaceInstanceDetails.HelloInterfaceInstanceDetail()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.hello_interface_instance_detail.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "hello-interface-instance-detail"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class InterfaceNeighborDetails(Entity):
        """
        Table of detailed info about I/F neighbors
        
        .. attribute:: interface_neighbor_detail
        
        	Detailed info for a single interface neighbor
        	**type**\: list of    :py:class:`InterfaceNeighborDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.InterfaceNeighborDetails.InterfaceNeighborDetail>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(RsvpStandby.InterfaceNeighborDetails, self).__init__()

            self.yang_name = "interface-neighbor-details"
            self.yang_parent_name = "rsvp-standby"

            self.interface_neighbor_detail = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(RsvpStandby.InterfaceNeighborDetails, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(RsvpStandby.InterfaceNeighborDetails, self).__setattr__(name, value)


        class InterfaceNeighborDetail(Entity):
            """
            Detailed info for a single interface neighbor
            
            .. attribute:: neighbor_address  <key>
            
            	Address of global neighbor
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: interface_neighbor_list_detail
            
            	Detail list of I/F Neighbors
            	**type**\: list of    :py:class:`InterfaceNeighborListDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.InterfaceNeighborDetails.InterfaceNeighborDetail.InterfaceNeighborListDetail>`
            
            .. attribute:: node_address
            
            	Neighbor node address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(RsvpStandby.InterfaceNeighborDetails.InterfaceNeighborDetail, self).__init__()

                self.yang_name = "interface-neighbor-detail"
                self.yang_parent_name = "interface-neighbor-details"

                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                self.node_address = YLeaf(YType.str, "node-address")

                self.interface_neighbor_list_detail = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("neighbor_address",
                                "node_address") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(RsvpStandby.InterfaceNeighborDetails.InterfaceNeighborDetail, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(RsvpStandby.InterfaceNeighborDetails.InterfaceNeighborDetail, self).__setattr__(name, value)


            class InterfaceNeighborListDetail(Entity):
                """
                Detail list of I/F Neighbors
                
                .. attribute:: interface_neighbor_address
                
                	Interface Neighbor address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: is_rr_enabled
                
                	Is Neighbor's RR enable
                	**type**\:  bool
                
                .. attribute:: neighbor_epoch
                
                	Neighbor's epoch value
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: neighbor_interface_name
                
                	Neighbor's Interface handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: out_of_order_messages
                
                	Number of out of order msgs
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: retransmitted_messages
                
                	Number of retransmitted msgs
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.InterfaceNeighborDetails.InterfaceNeighborDetail.InterfaceNeighborListDetail, self).__init__()

                    self.yang_name = "interface-neighbor-list-detail"
                    self.yang_parent_name = "interface-neighbor-detail"

                    self.interface_neighbor_address = YLeaf(YType.str, "interface-neighbor-address")

                    self.is_rr_enabled = YLeaf(YType.boolean, "is-rr-enabled")

                    self.neighbor_epoch = YLeaf(YType.uint32, "neighbor-epoch")

                    self.neighbor_interface_name = YLeaf(YType.str, "neighbor-interface-name")

                    self.out_of_order_messages = YLeaf(YType.uint32, "out-of-order-messages")

                    self.retransmitted_messages = YLeaf(YType.uint32, "retransmitted-messages")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("interface_neighbor_address",
                                    "is_rr_enabled",
                                    "neighbor_epoch",
                                    "neighbor_interface_name",
                                    "out_of_order_messages",
                                    "retransmitted_messages") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.InterfaceNeighborDetails.InterfaceNeighborDetail.InterfaceNeighborListDetail, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.InterfaceNeighborDetails.InterfaceNeighborDetail.InterfaceNeighborListDetail, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.interface_neighbor_address.is_set or
                        self.is_rr_enabled.is_set or
                        self.neighbor_epoch.is_set or
                        self.neighbor_interface_name.is_set or
                        self.out_of_order_messages.is_set or
                        self.retransmitted_messages.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.interface_neighbor_address.yfilter != YFilter.not_set or
                        self.is_rr_enabled.yfilter != YFilter.not_set or
                        self.neighbor_epoch.yfilter != YFilter.not_set or
                        self.neighbor_interface_name.yfilter != YFilter.not_set or
                        self.out_of_order_messages.yfilter != YFilter.not_set or
                        self.retransmitted_messages.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "interface-neighbor-list-detail" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.interface_neighbor_address.is_set or self.interface_neighbor_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface_neighbor_address.get_name_leafdata())
                    if (self.is_rr_enabled.is_set or self.is_rr_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_rr_enabled.get_name_leafdata())
                    if (self.neighbor_epoch.is_set or self.neighbor_epoch.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.neighbor_epoch.get_name_leafdata())
                    if (self.neighbor_interface_name.is_set or self.neighbor_interface_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.neighbor_interface_name.get_name_leafdata())
                    if (self.out_of_order_messages.is_set or self.out_of_order_messages.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.out_of_order_messages.get_name_leafdata())
                    if (self.retransmitted_messages.is_set or self.retransmitted_messages.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.retransmitted_messages.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface-neighbor-address" or name == "is-rr-enabled" or name == "neighbor-epoch" or name == "neighbor-interface-name" or name == "out-of-order-messages" or name == "retransmitted-messages"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "interface-neighbor-address"):
                        self.interface_neighbor_address = value
                        self.interface_neighbor_address.value_namespace = name_space
                        self.interface_neighbor_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-rr-enabled"):
                        self.is_rr_enabled = value
                        self.is_rr_enabled.value_namespace = name_space
                        self.is_rr_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "neighbor-epoch"):
                        self.neighbor_epoch = value
                        self.neighbor_epoch.value_namespace = name_space
                        self.neighbor_epoch.value_namespace_prefix = name_space_prefix
                    if(value_path == "neighbor-interface-name"):
                        self.neighbor_interface_name = value
                        self.neighbor_interface_name.value_namespace = name_space
                        self.neighbor_interface_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "out-of-order-messages"):
                        self.out_of_order_messages = value
                        self.out_of_order_messages.value_namespace = name_space
                        self.out_of_order_messages.value_namespace_prefix = name_space_prefix
                    if(value_path == "retransmitted-messages"):
                        self.retransmitted_messages = value
                        self.retransmitted_messages.value_namespace = name_space
                        self.retransmitted_messages.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.interface_neighbor_list_detail:
                    if (c.has_data()):
                        return True
                return (
                    self.neighbor_address.is_set or
                    self.node_address.is_set)

            def has_operation(self):
                for c in self.interface_neighbor_list_detail:
                    if (c.has_operation()):
                        return True
                return (
                    self.yfilter != YFilter.not_set or
                    self.neighbor_address.yfilter != YFilter.not_set or
                    self.node_address.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "interface-neighbor-detail" + "[neighbor-address='" + self.neighbor_address.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/interface-neighbor-details/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                if (self.node_address.is_set or self.node_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.node_address.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "interface-neighbor-list-detail"):
                    for c in self.interface_neighbor_list_detail:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = RsvpStandby.InterfaceNeighborDetails.InterfaceNeighborDetail.InterfaceNeighborListDetail()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.interface_neighbor_list_detail.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "interface-neighbor-list-detail" or name == "neighbor-address" or name == "node-address"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "neighbor-address"):
                    self.neighbor_address = value
                    self.neighbor_address.value_namespace = name_space
                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                if(value_path == "node-address"):
                    self.node_address = value
                    self.node_address.value_namespace = name_space
                    self.node_address.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.interface_neighbor_detail:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.interface_neighbor_detail:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "interface-neighbor-details" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "interface-neighbor-detail"):
                for c in self.interface_neighbor_detail:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = RsvpStandby.InterfaceNeighborDetails.InterfaceNeighborDetail()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.interface_neighbor_detail.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "interface-neighbor-detail"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class Nsr(Entity):
        """
        RSVP NSR information
        
        .. attribute:: status
        
        	RSVP NSR status information
        	**type**\:   :py:class:`Status <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Nsr.Status>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(RsvpStandby.Nsr, self).__init__()

            self.yang_name = "nsr"
            self.yang_parent_name = "rsvp-standby"

            self.status = RsvpStandby.Nsr.Status()
            self.status.parent = self
            self._children_name_map["status"] = "status"
            self._children_yang_names.add("status")


        class Status(Entity):
            """
            RSVP NSR status information
            
            .. attribute:: idt_status
            
            	IDT status
            	**type**\:   :py:class:`IdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Nsr.Status.IdtStatus>`
            
            .. attribute:: previous_idt_status
            
            	Previous IDT status
            	**type**\:   :py:class:`PreviousIdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Nsr.Status.PreviousIdtStatus>`
            
            .. attribute:: role
            
            	Process role
            	**type**\:   :py:class:`RsvpProcRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpProcRole>`
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(RsvpStandby.Nsr.Status, self).__init__()

                self.yang_name = "status"
                self.yang_parent_name = "nsr"

                self.role = YLeaf(YType.enumeration, "role")

                self.idt_status = RsvpStandby.Nsr.Status.IdtStatus()
                self.idt_status.parent = self
                self._children_name_map["idt_status"] = "idt-status"
                self._children_yang_names.add("idt-status")

                self.previous_idt_status = RsvpStandby.Nsr.Status.PreviousIdtStatus()
                self.previous_idt_status.parent = self
                self._children_name_map["previous_idt_status"] = "previous-idt-status"
                self._children_yang_names.add("previous-idt-status")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("role") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(RsvpStandby.Nsr.Status, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(RsvpStandby.Nsr.Status, self).__setattr__(name, value)


            class IdtStatus(Entity):
                """
                IDT status
                
                .. attribute:: declare_time
                
                	Declare ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_end_time
                
                	IDT end timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_start_time
                
                	IDT start timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: not_ready_reason
                
                	Not ready reason
                	**type**\:   :py:class:`RsvpProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpProcNsrNotReadyReason>`
                
                .. attribute:: sync_status
                
                	Sync status
                	**type**\:   :py:class:`RsvpSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpSyncStatus>`
                
                .. attribute:: withdraw_time
                
                	Withdraw ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.Nsr.Status.IdtStatus, self).__init__()

                    self.yang_name = "idt-status"
                    self.yang_parent_name = "status"

                    self.declare_time = YLeaf(YType.uint32, "declare-time")

                    self.idt_end_time = YLeaf(YType.uint32, "idt-end-time")

                    self.idt_start_time = YLeaf(YType.uint32, "idt-start-time")

                    self.not_ready_reason = YLeaf(YType.enumeration, "not-ready-reason")

                    self.sync_status = YLeaf(YType.enumeration, "sync-status")

                    self.withdraw_time = YLeaf(YType.uint32, "withdraw-time")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("declare_time",
                                    "idt_end_time",
                                    "idt_start_time",
                                    "not_ready_reason",
                                    "sync_status",
                                    "withdraw_time") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.Nsr.Status.IdtStatus, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.Nsr.Status.IdtStatus, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.declare_time.is_set or
                        self.idt_end_time.is_set or
                        self.idt_start_time.is_set or
                        self.not_ready_reason.is_set or
                        self.sync_status.is_set or
                        self.withdraw_time.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.declare_time.yfilter != YFilter.not_set or
                        self.idt_end_time.yfilter != YFilter.not_set or
                        self.idt_start_time.yfilter != YFilter.not_set or
                        self.not_ready_reason.yfilter != YFilter.not_set or
                        self.sync_status.yfilter != YFilter.not_set or
                        self.withdraw_time.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "idt-status" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/nsr/status/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.declare_time.is_set or self.declare_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.declare_time.get_name_leafdata())
                    if (self.idt_end_time.is_set or self.idt_end_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.idt_end_time.get_name_leafdata())
                    if (self.idt_start_time.is_set or self.idt_start_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.idt_start_time.get_name_leafdata())
                    if (self.not_ready_reason.is_set or self.not_ready_reason.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.not_ready_reason.get_name_leafdata())
                    if (self.sync_status.is_set or self.sync_status.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sync_status.get_name_leafdata())
                    if (self.withdraw_time.is_set or self.withdraw_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.withdraw_time.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "declare-time" or name == "idt-end-time" or name == "idt-start-time" or name == "not-ready-reason" or name == "sync-status" or name == "withdraw-time"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "declare-time"):
                        self.declare_time = value
                        self.declare_time.value_namespace = name_space
                        self.declare_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "idt-end-time"):
                        self.idt_end_time = value
                        self.idt_end_time.value_namespace = name_space
                        self.idt_end_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "idt-start-time"):
                        self.idt_start_time = value
                        self.idt_start_time.value_namespace = name_space
                        self.idt_start_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "not-ready-reason"):
                        self.not_ready_reason = value
                        self.not_ready_reason.value_namespace = name_space
                        self.not_ready_reason.value_namespace_prefix = name_space_prefix
                    if(value_path == "sync-status"):
                        self.sync_status = value
                        self.sync_status.value_namespace = name_space
                        self.sync_status.value_namespace_prefix = name_space_prefix
                    if(value_path == "withdraw-time"):
                        self.withdraw_time = value
                        self.withdraw_time.value_namespace = name_space
                        self.withdraw_time.value_namespace_prefix = name_space_prefix


            class PreviousIdtStatus(Entity):
                """
                Previous IDT status
                
                .. attribute:: declare_time
                
                	Declare ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_end_time
                
                	IDT end timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_start_time
                
                	IDT start timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: not_ready_reason
                
                	Not ready reason
                	**type**\:   :py:class:`RsvpProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpProcNsrNotReadyReason>`
                
                .. attribute:: sync_status
                
                	Sync status
                	**type**\:   :py:class:`RsvpSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpSyncStatus>`
                
                .. attribute:: withdraw_time
                
                	Withdraw ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.Nsr.Status.PreviousIdtStatus, self).__init__()

                    self.yang_name = "previous-idt-status"
                    self.yang_parent_name = "status"

                    self.declare_time = YLeaf(YType.uint32, "declare-time")

                    self.idt_end_time = YLeaf(YType.uint32, "idt-end-time")

                    self.idt_start_time = YLeaf(YType.uint32, "idt-start-time")

                    self.not_ready_reason = YLeaf(YType.enumeration, "not-ready-reason")

                    self.sync_status = YLeaf(YType.enumeration, "sync-status")

                    self.withdraw_time = YLeaf(YType.uint32, "withdraw-time")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("declare_time",
                                    "idt_end_time",
                                    "idt_start_time",
                                    "not_ready_reason",
                                    "sync_status",
                                    "withdraw_time") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.Nsr.Status.PreviousIdtStatus, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.Nsr.Status.PreviousIdtStatus, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.declare_time.is_set or
                        self.idt_end_time.is_set or
                        self.idt_start_time.is_set or
                        self.not_ready_reason.is_set or
                        self.sync_status.is_set or
                        self.withdraw_time.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.declare_time.yfilter != YFilter.not_set or
                        self.idt_end_time.yfilter != YFilter.not_set or
                        self.idt_start_time.yfilter != YFilter.not_set or
                        self.not_ready_reason.yfilter != YFilter.not_set or
                        self.sync_status.yfilter != YFilter.not_set or
                        self.withdraw_time.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "previous-idt-status" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/nsr/status/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.declare_time.is_set or self.declare_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.declare_time.get_name_leafdata())
                    if (self.idt_end_time.is_set or self.idt_end_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.idt_end_time.get_name_leafdata())
                    if (self.idt_start_time.is_set or self.idt_start_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.idt_start_time.get_name_leafdata())
                    if (self.not_ready_reason.is_set or self.not_ready_reason.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.not_ready_reason.get_name_leafdata())
                    if (self.sync_status.is_set or self.sync_status.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sync_status.get_name_leafdata())
                    if (self.withdraw_time.is_set or self.withdraw_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.withdraw_time.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "declare-time" or name == "idt-end-time" or name == "idt-start-time" or name == "not-ready-reason" or name == "sync-status" or name == "withdraw-time"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "declare-time"):
                        self.declare_time = value
                        self.declare_time.value_namespace = name_space
                        self.declare_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "idt-end-time"):
                        self.idt_end_time = value
                        self.idt_end_time.value_namespace = name_space
                        self.idt_end_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "idt-start-time"):
                        self.idt_start_time = value
                        self.idt_start_time.value_namespace = name_space
                        self.idt_start_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "not-ready-reason"):
                        self.not_ready_reason = value
                        self.not_ready_reason.value_namespace = name_space
                        self.not_ready_reason.value_namespace_prefix = name_space_prefix
                    if(value_path == "sync-status"):
                        self.sync_status = value
                        self.sync_status.value_namespace = name_space
                        self.sync_status.value_namespace_prefix = name_space_prefix
                    if(value_path == "withdraw-time"):
                        self.withdraw_time = value
                        self.withdraw_time.value_namespace = name_space
                        self.withdraw_time.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.role.is_set or
                    (self.idt_status is not None and self.idt_status.has_data()) or
                    (self.previous_idt_status is not None and self.previous_idt_status.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.role.yfilter != YFilter.not_set or
                    (self.idt_status is not None and self.idt_status.has_operation()) or
                    (self.previous_idt_status is not None and self.previous_idt_status.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "status" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/nsr/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.role.is_set or self.role.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.role.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "idt-status"):
                    if (self.idt_status is None):
                        self.idt_status = RsvpStandby.Nsr.Status.IdtStatus()
                        self.idt_status.parent = self
                        self._children_name_map["idt_status"] = "idt-status"
                    return self.idt_status

                if (child_yang_name == "previous-idt-status"):
                    if (self.previous_idt_status is None):
                        self.previous_idt_status = RsvpStandby.Nsr.Status.PreviousIdtStatus()
                        self.previous_idt_status.parent = self
                        self._children_name_map["previous_idt_status"] = "previous-idt-status"
                    return self.previous_idt_status

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "idt-status" or name == "previous-idt-status" or name == "role"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "role"):
                    self.role = value
                    self.role.value_namespace = name_space
                    self.role.value_namespace_prefix = name_space_prefix

        def has_data(self):
            return (self.status is not None and self.status.has_data())

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.status is not None and self.status.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "nsr" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "status"):
                if (self.status is None):
                    self.status = RsvpStandby.Nsr.Status()
                    self.status.parent = self
                    self._children_name_map["status"] = "status"
                return self.status

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "status"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class Summary(Entity):
        """
        RSVP summary information
        
        .. attribute:: database_counters
        
        	All database counters
        	**type**\:   :py:class:`DatabaseCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Summary.DatabaseCounters>`
        
        .. attribute:: interfaces
        
        	Total interfaces
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: issu_status
        
        	Issu status
        	**type**\:   :py:class:`IssuStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Summary.IssuStatus>`
        
        .. attribute:: ls_ps
        
        	Total LSPs
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: nsr_status
        
        	NSR status
        	**type**\:   :py:class:`NsrStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Summary.NsrStatus>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(RsvpStandby.Summary, self).__init__()

            self.yang_name = "summary"
            self.yang_parent_name = "rsvp-standby"

            self.interfaces = YLeaf(YType.uint32, "interfaces")

            self.ls_ps = YLeaf(YType.uint32, "ls-ps")

            self.database_counters = RsvpStandby.Summary.DatabaseCounters()
            self.database_counters.parent = self
            self._children_name_map["database_counters"] = "database-counters"
            self._children_yang_names.add("database-counters")

            self.issu_status = RsvpStandby.Summary.IssuStatus()
            self.issu_status.parent = self
            self._children_name_map["issu_status"] = "issu-status"
            self._children_yang_names.add("issu-status")

            self.nsr_status = RsvpStandby.Summary.NsrStatus()
            self.nsr_status.parent = self
            self._children_name_map["nsr_status"] = "nsr-status"
            self._children_yang_names.add("nsr-status")

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in ("interfaces",
                            "ls_ps") and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(RsvpStandby.Summary, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(RsvpStandby.Summary, self).__setattr__(name, value)


        class IssuStatus(Entity):
            """
            Issu status
            
            .. attribute:: idt_status
            
            	IDT status
            	**type**\:   :py:class:`IdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Summary.IssuStatus.IdtStatus>`
            
            .. attribute:: previous_idt_status
            
            	Previous IDT status
            	**type**\:   :py:class:`PreviousIdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Summary.IssuStatus.PreviousIdtStatus>`
            
            .. attribute:: role
            
            	Process role
            	**type**\:   :py:class:`RsvpProcRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpProcRole>`
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(RsvpStandby.Summary.IssuStatus, self).__init__()

                self.yang_name = "issu-status"
                self.yang_parent_name = "summary"

                self.role = YLeaf(YType.enumeration, "role")

                self.idt_status = RsvpStandby.Summary.IssuStatus.IdtStatus()
                self.idt_status.parent = self
                self._children_name_map["idt_status"] = "idt-status"
                self._children_yang_names.add("idt-status")

                self.previous_idt_status = RsvpStandby.Summary.IssuStatus.PreviousIdtStatus()
                self.previous_idt_status.parent = self
                self._children_name_map["previous_idt_status"] = "previous-idt-status"
                self._children_yang_names.add("previous-idt-status")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("role") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(RsvpStandby.Summary.IssuStatus, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(RsvpStandby.Summary.IssuStatus, self).__setattr__(name, value)


            class IdtStatus(Entity):
                """
                IDT status
                
                .. attribute:: declare_time
                
                	Declare ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_end_time
                
                	IDT end timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_start_time
                
                	IDT start timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: not_ready_reason
                
                	Not ready reason
                	**type**\:   :py:class:`RsvpProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpProcNsrNotReadyReason>`
                
                .. attribute:: sync_status
                
                	Sync status
                	**type**\:   :py:class:`RsvpSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpSyncStatus>`
                
                .. attribute:: withdraw_time
                
                	Withdraw ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.Summary.IssuStatus.IdtStatus, self).__init__()

                    self.yang_name = "idt-status"
                    self.yang_parent_name = "issu-status"

                    self.declare_time = YLeaf(YType.uint32, "declare-time")

                    self.idt_end_time = YLeaf(YType.uint32, "idt-end-time")

                    self.idt_start_time = YLeaf(YType.uint32, "idt-start-time")

                    self.not_ready_reason = YLeaf(YType.enumeration, "not-ready-reason")

                    self.sync_status = YLeaf(YType.enumeration, "sync-status")

                    self.withdraw_time = YLeaf(YType.uint32, "withdraw-time")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("declare_time",
                                    "idt_end_time",
                                    "idt_start_time",
                                    "not_ready_reason",
                                    "sync_status",
                                    "withdraw_time") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.Summary.IssuStatus.IdtStatus, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.Summary.IssuStatus.IdtStatus, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.declare_time.is_set or
                        self.idt_end_time.is_set or
                        self.idt_start_time.is_set or
                        self.not_ready_reason.is_set or
                        self.sync_status.is_set or
                        self.withdraw_time.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.declare_time.yfilter != YFilter.not_set or
                        self.idt_end_time.yfilter != YFilter.not_set or
                        self.idt_start_time.yfilter != YFilter.not_set or
                        self.not_ready_reason.yfilter != YFilter.not_set or
                        self.sync_status.yfilter != YFilter.not_set or
                        self.withdraw_time.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "idt-status" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/summary/issu-status/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.declare_time.is_set or self.declare_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.declare_time.get_name_leafdata())
                    if (self.idt_end_time.is_set or self.idt_end_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.idt_end_time.get_name_leafdata())
                    if (self.idt_start_time.is_set or self.idt_start_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.idt_start_time.get_name_leafdata())
                    if (self.not_ready_reason.is_set or self.not_ready_reason.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.not_ready_reason.get_name_leafdata())
                    if (self.sync_status.is_set or self.sync_status.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sync_status.get_name_leafdata())
                    if (self.withdraw_time.is_set or self.withdraw_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.withdraw_time.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "declare-time" or name == "idt-end-time" or name == "idt-start-time" or name == "not-ready-reason" or name == "sync-status" or name == "withdraw-time"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "declare-time"):
                        self.declare_time = value
                        self.declare_time.value_namespace = name_space
                        self.declare_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "idt-end-time"):
                        self.idt_end_time = value
                        self.idt_end_time.value_namespace = name_space
                        self.idt_end_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "idt-start-time"):
                        self.idt_start_time = value
                        self.idt_start_time.value_namespace = name_space
                        self.idt_start_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "not-ready-reason"):
                        self.not_ready_reason = value
                        self.not_ready_reason.value_namespace = name_space
                        self.not_ready_reason.value_namespace_prefix = name_space_prefix
                    if(value_path == "sync-status"):
                        self.sync_status = value
                        self.sync_status.value_namespace = name_space
                        self.sync_status.value_namespace_prefix = name_space_prefix
                    if(value_path == "withdraw-time"):
                        self.withdraw_time = value
                        self.withdraw_time.value_namespace = name_space
                        self.withdraw_time.value_namespace_prefix = name_space_prefix


            class PreviousIdtStatus(Entity):
                """
                Previous IDT status
                
                .. attribute:: declare_time
                
                	Declare ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_end_time
                
                	IDT end timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_start_time
                
                	IDT start timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: not_ready_reason
                
                	Not ready reason
                	**type**\:   :py:class:`RsvpProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpProcNsrNotReadyReason>`
                
                .. attribute:: sync_status
                
                	Sync status
                	**type**\:   :py:class:`RsvpSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpSyncStatus>`
                
                .. attribute:: withdraw_time
                
                	Withdraw ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.Summary.IssuStatus.PreviousIdtStatus, self).__init__()

                    self.yang_name = "previous-idt-status"
                    self.yang_parent_name = "issu-status"

                    self.declare_time = YLeaf(YType.uint32, "declare-time")

                    self.idt_end_time = YLeaf(YType.uint32, "idt-end-time")

                    self.idt_start_time = YLeaf(YType.uint32, "idt-start-time")

                    self.not_ready_reason = YLeaf(YType.enumeration, "not-ready-reason")

                    self.sync_status = YLeaf(YType.enumeration, "sync-status")

                    self.withdraw_time = YLeaf(YType.uint32, "withdraw-time")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("declare_time",
                                    "idt_end_time",
                                    "idt_start_time",
                                    "not_ready_reason",
                                    "sync_status",
                                    "withdraw_time") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.Summary.IssuStatus.PreviousIdtStatus, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.Summary.IssuStatus.PreviousIdtStatus, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.declare_time.is_set or
                        self.idt_end_time.is_set or
                        self.idt_start_time.is_set or
                        self.not_ready_reason.is_set or
                        self.sync_status.is_set or
                        self.withdraw_time.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.declare_time.yfilter != YFilter.not_set or
                        self.idt_end_time.yfilter != YFilter.not_set or
                        self.idt_start_time.yfilter != YFilter.not_set or
                        self.not_ready_reason.yfilter != YFilter.not_set or
                        self.sync_status.yfilter != YFilter.not_set or
                        self.withdraw_time.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "previous-idt-status" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/summary/issu-status/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.declare_time.is_set or self.declare_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.declare_time.get_name_leafdata())
                    if (self.idt_end_time.is_set or self.idt_end_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.idt_end_time.get_name_leafdata())
                    if (self.idt_start_time.is_set or self.idt_start_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.idt_start_time.get_name_leafdata())
                    if (self.not_ready_reason.is_set or self.not_ready_reason.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.not_ready_reason.get_name_leafdata())
                    if (self.sync_status.is_set or self.sync_status.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sync_status.get_name_leafdata())
                    if (self.withdraw_time.is_set or self.withdraw_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.withdraw_time.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "declare-time" or name == "idt-end-time" or name == "idt-start-time" or name == "not-ready-reason" or name == "sync-status" or name == "withdraw-time"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "declare-time"):
                        self.declare_time = value
                        self.declare_time.value_namespace = name_space
                        self.declare_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "idt-end-time"):
                        self.idt_end_time = value
                        self.idt_end_time.value_namespace = name_space
                        self.idt_end_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "idt-start-time"):
                        self.idt_start_time = value
                        self.idt_start_time.value_namespace = name_space
                        self.idt_start_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "not-ready-reason"):
                        self.not_ready_reason = value
                        self.not_ready_reason.value_namespace = name_space
                        self.not_ready_reason.value_namespace_prefix = name_space_prefix
                    if(value_path == "sync-status"):
                        self.sync_status = value
                        self.sync_status.value_namespace = name_space
                        self.sync_status.value_namespace_prefix = name_space_prefix
                    if(value_path == "withdraw-time"):
                        self.withdraw_time = value
                        self.withdraw_time.value_namespace = name_space
                        self.withdraw_time.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.role.is_set or
                    (self.idt_status is not None and self.idt_status.has_data()) or
                    (self.previous_idt_status is not None and self.previous_idt_status.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.role.yfilter != YFilter.not_set or
                    (self.idt_status is not None and self.idt_status.has_operation()) or
                    (self.previous_idt_status is not None and self.previous_idt_status.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "issu-status" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/summary/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.role.is_set or self.role.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.role.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "idt-status"):
                    if (self.idt_status is None):
                        self.idt_status = RsvpStandby.Summary.IssuStatus.IdtStatus()
                        self.idt_status.parent = self
                        self._children_name_map["idt_status"] = "idt-status"
                    return self.idt_status

                if (child_yang_name == "previous-idt-status"):
                    if (self.previous_idt_status is None):
                        self.previous_idt_status = RsvpStandby.Summary.IssuStatus.PreviousIdtStatus()
                        self.previous_idt_status.parent = self
                        self._children_name_map["previous_idt_status"] = "previous-idt-status"
                    return self.previous_idt_status

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "idt-status" or name == "previous-idt-status" or name == "role"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "role"):
                    self.role = value
                    self.role.value_namespace = name_space
                    self.role.value_namespace_prefix = name_space_prefix


        class NsrStatus(Entity):
            """
            NSR status
            
            .. attribute:: idt_status
            
            	IDT status
            	**type**\:   :py:class:`IdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Summary.NsrStatus.IdtStatus>`
            
            .. attribute:: previous_idt_status
            
            	Previous IDT status
            	**type**\:   :py:class:`PreviousIdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Summary.NsrStatus.PreviousIdtStatus>`
            
            .. attribute:: role
            
            	Process role
            	**type**\:   :py:class:`RsvpProcRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpProcRole>`
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(RsvpStandby.Summary.NsrStatus, self).__init__()

                self.yang_name = "nsr-status"
                self.yang_parent_name = "summary"

                self.role = YLeaf(YType.enumeration, "role")

                self.idt_status = RsvpStandby.Summary.NsrStatus.IdtStatus()
                self.idt_status.parent = self
                self._children_name_map["idt_status"] = "idt-status"
                self._children_yang_names.add("idt-status")

                self.previous_idt_status = RsvpStandby.Summary.NsrStatus.PreviousIdtStatus()
                self.previous_idt_status.parent = self
                self._children_name_map["previous_idt_status"] = "previous-idt-status"
                self._children_yang_names.add("previous-idt-status")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("role") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(RsvpStandby.Summary.NsrStatus, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(RsvpStandby.Summary.NsrStatus, self).__setattr__(name, value)


            class IdtStatus(Entity):
                """
                IDT status
                
                .. attribute:: declare_time
                
                	Declare ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_end_time
                
                	IDT end timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_start_time
                
                	IDT start timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: not_ready_reason
                
                	Not ready reason
                	**type**\:   :py:class:`RsvpProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpProcNsrNotReadyReason>`
                
                .. attribute:: sync_status
                
                	Sync status
                	**type**\:   :py:class:`RsvpSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpSyncStatus>`
                
                .. attribute:: withdraw_time
                
                	Withdraw ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.Summary.NsrStatus.IdtStatus, self).__init__()

                    self.yang_name = "idt-status"
                    self.yang_parent_name = "nsr-status"

                    self.declare_time = YLeaf(YType.uint32, "declare-time")

                    self.idt_end_time = YLeaf(YType.uint32, "idt-end-time")

                    self.idt_start_time = YLeaf(YType.uint32, "idt-start-time")

                    self.not_ready_reason = YLeaf(YType.enumeration, "not-ready-reason")

                    self.sync_status = YLeaf(YType.enumeration, "sync-status")

                    self.withdraw_time = YLeaf(YType.uint32, "withdraw-time")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("declare_time",
                                    "idt_end_time",
                                    "idt_start_time",
                                    "not_ready_reason",
                                    "sync_status",
                                    "withdraw_time") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.Summary.NsrStatus.IdtStatus, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.Summary.NsrStatus.IdtStatus, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.declare_time.is_set or
                        self.idt_end_time.is_set or
                        self.idt_start_time.is_set or
                        self.not_ready_reason.is_set or
                        self.sync_status.is_set or
                        self.withdraw_time.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.declare_time.yfilter != YFilter.not_set or
                        self.idt_end_time.yfilter != YFilter.not_set or
                        self.idt_start_time.yfilter != YFilter.not_set or
                        self.not_ready_reason.yfilter != YFilter.not_set or
                        self.sync_status.yfilter != YFilter.not_set or
                        self.withdraw_time.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "idt-status" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/summary/nsr-status/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.declare_time.is_set or self.declare_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.declare_time.get_name_leafdata())
                    if (self.idt_end_time.is_set or self.idt_end_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.idt_end_time.get_name_leafdata())
                    if (self.idt_start_time.is_set or self.idt_start_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.idt_start_time.get_name_leafdata())
                    if (self.not_ready_reason.is_set or self.not_ready_reason.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.not_ready_reason.get_name_leafdata())
                    if (self.sync_status.is_set or self.sync_status.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sync_status.get_name_leafdata())
                    if (self.withdraw_time.is_set or self.withdraw_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.withdraw_time.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "declare-time" or name == "idt-end-time" or name == "idt-start-time" or name == "not-ready-reason" or name == "sync-status" or name == "withdraw-time"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "declare-time"):
                        self.declare_time = value
                        self.declare_time.value_namespace = name_space
                        self.declare_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "idt-end-time"):
                        self.idt_end_time = value
                        self.idt_end_time.value_namespace = name_space
                        self.idt_end_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "idt-start-time"):
                        self.idt_start_time = value
                        self.idt_start_time.value_namespace = name_space
                        self.idt_start_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "not-ready-reason"):
                        self.not_ready_reason = value
                        self.not_ready_reason.value_namespace = name_space
                        self.not_ready_reason.value_namespace_prefix = name_space_prefix
                    if(value_path == "sync-status"):
                        self.sync_status = value
                        self.sync_status.value_namespace = name_space
                        self.sync_status.value_namespace_prefix = name_space_prefix
                    if(value_path == "withdraw-time"):
                        self.withdraw_time = value
                        self.withdraw_time.value_namespace = name_space
                        self.withdraw_time.value_namespace_prefix = name_space_prefix


            class PreviousIdtStatus(Entity):
                """
                Previous IDT status
                
                .. attribute:: declare_time
                
                	Declare ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_end_time
                
                	IDT end timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_start_time
                
                	IDT start timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: not_ready_reason
                
                	Not ready reason
                	**type**\:   :py:class:`RsvpProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpProcNsrNotReadyReason>`
                
                .. attribute:: sync_status
                
                	Sync status
                	**type**\:   :py:class:`RsvpSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpSyncStatus>`
                
                .. attribute:: withdraw_time
                
                	Withdraw ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.Summary.NsrStatus.PreviousIdtStatus, self).__init__()

                    self.yang_name = "previous-idt-status"
                    self.yang_parent_name = "nsr-status"

                    self.declare_time = YLeaf(YType.uint32, "declare-time")

                    self.idt_end_time = YLeaf(YType.uint32, "idt-end-time")

                    self.idt_start_time = YLeaf(YType.uint32, "idt-start-time")

                    self.not_ready_reason = YLeaf(YType.enumeration, "not-ready-reason")

                    self.sync_status = YLeaf(YType.enumeration, "sync-status")

                    self.withdraw_time = YLeaf(YType.uint32, "withdraw-time")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("declare_time",
                                    "idt_end_time",
                                    "idt_start_time",
                                    "not_ready_reason",
                                    "sync_status",
                                    "withdraw_time") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.Summary.NsrStatus.PreviousIdtStatus, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.Summary.NsrStatus.PreviousIdtStatus, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.declare_time.is_set or
                        self.idt_end_time.is_set or
                        self.idt_start_time.is_set or
                        self.not_ready_reason.is_set or
                        self.sync_status.is_set or
                        self.withdraw_time.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.declare_time.yfilter != YFilter.not_set or
                        self.idt_end_time.yfilter != YFilter.not_set or
                        self.idt_start_time.yfilter != YFilter.not_set or
                        self.not_ready_reason.yfilter != YFilter.not_set or
                        self.sync_status.yfilter != YFilter.not_set or
                        self.withdraw_time.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "previous-idt-status" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/summary/nsr-status/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.declare_time.is_set or self.declare_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.declare_time.get_name_leafdata())
                    if (self.idt_end_time.is_set or self.idt_end_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.idt_end_time.get_name_leafdata())
                    if (self.idt_start_time.is_set or self.idt_start_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.idt_start_time.get_name_leafdata())
                    if (self.not_ready_reason.is_set or self.not_ready_reason.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.not_ready_reason.get_name_leafdata())
                    if (self.sync_status.is_set or self.sync_status.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sync_status.get_name_leafdata())
                    if (self.withdraw_time.is_set or self.withdraw_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.withdraw_time.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "declare-time" or name == "idt-end-time" or name == "idt-start-time" or name == "not-ready-reason" or name == "sync-status" or name == "withdraw-time"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "declare-time"):
                        self.declare_time = value
                        self.declare_time.value_namespace = name_space
                        self.declare_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "idt-end-time"):
                        self.idt_end_time = value
                        self.idt_end_time.value_namespace = name_space
                        self.idt_end_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "idt-start-time"):
                        self.idt_start_time = value
                        self.idt_start_time.value_namespace = name_space
                        self.idt_start_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "not-ready-reason"):
                        self.not_ready_reason = value
                        self.not_ready_reason.value_namespace = name_space
                        self.not_ready_reason.value_namespace_prefix = name_space_prefix
                    if(value_path == "sync-status"):
                        self.sync_status = value
                        self.sync_status.value_namespace = name_space
                        self.sync_status.value_namespace_prefix = name_space_prefix
                    if(value_path == "withdraw-time"):
                        self.withdraw_time = value
                        self.withdraw_time.value_namespace = name_space
                        self.withdraw_time.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.role.is_set or
                    (self.idt_status is not None and self.idt_status.has_data()) or
                    (self.previous_idt_status is not None and self.previous_idt_status.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.role.yfilter != YFilter.not_set or
                    (self.idt_status is not None and self.idt_status.has_operation()) or
                    (self.previous_idt_status is not None and self.previous_idt_status.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "nsr-status" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/summary/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.role.is_set or self.role.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.role.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "idt-status"):
                    if (self.idt_status is None):
                        self.idt_status = RsvpStandby.Summary.NsrStatus.IdtStatus()
                        self.idt_status.parent = self
                        self._children_name_map["idt_status"] = "idt-status"
                    return self.idt_status

                if (child_yang_name == "previous-idt-status"):
                    if (self.previous_idt_status is None):
                        self.previous_idt_status = RsvpStandby.Summary.NsrStatus.PreviousIdtStatus()
                        self.previous_idt_status.parent = self
                        self._children_name_map["previous_idt_status"] = "previous-idt-status"
                    return self.previous_idt_status

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "idt-status" or name == "previous-idt-status" or name == "role"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "role"):
                    self.role = value
                    self.role.value_namespace = name_space
                    self.role.value_namespace_prefix = name_space_prefix


        class DatabaseCounters(Entity):
            """
            All database counters
            
            .. attribute:: incoming_paths
            
            	Number of locally created and incoming path states
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: incoming_reservations
            
            	Number of locally created and incoming reservation states
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: interfaces
            
            	Number of Interfaces
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: outgoing_paths
            
            	Number of outgoing path states
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: outgoing_reservations
            
            	Number of outgoing reservation states
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: sessions
            
            	Number of sessions
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(RsvpStandby.Summary.DatabaseCounters, self).__init__()

                self.yang_name = "database-counters"
                self.yang_parent_name = "summary"

                self.incoming_paths = YLeaf(YType.uint32, "incoming-paths")

                self.incoming_reservations = YLeaf(YType.uint32, "incoming-reservations")

                self.interfaces = YLeaf(YType.uint32, "interfaces")

                self.outgoing_paths = YLeaf(YType.uint32, "outgoing-paths")

                self.outgoing_reservations = YLeaf(YType.uint32, "outgoing-reservations")

                self.sessions = YLeaf(YType.uint32, "sessions")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("incoming_paths",
                                "incoming_reservations",
                                "interfaces",
                                "outgoing_paths",
                                "outgoing_reservations",
                                "sessions") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(RsvpStandby.Summary.DatabaseCounters, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(RsvpStandby.Summary.DatabaseCounters, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.incoming_paths.is_set or
                    self.incoming_reservations.is_set or
                    self.interfaces.is_set or
                    self.outgoing_paths.is_set or
                    self.outgoing_reservations.is_set or
                    self.sessions.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.incoming_paths.yfilter != YFilter.not_set or
                    self.incoming_reservations.yfilter != YFilter.not_set or
                    self.interfaces.yfilter != YFilter.not_set or
                    self.outgoing_paths.yfilter != YFilter.not_set or
                    self.outgoing_reservations.yfilter != YFilter.not_set or
                    self.sessions.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "database-counters" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/summary/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.incoming_paths.is_set or self.incoming_paths.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.incoming_paths.get_name_leafdata())
                if (self.incoming_reservations.is_set or self.incoming_reservations.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.incoming_reservations.get_name_leafdata())
                if (self.interfaces.is_set or self.interfaces.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.interfaces.get_name_leafdata())
                if (self.outgoing_paths.is_set or self.outgoing_paths.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.outgoing_paths.get_name_leafdata())
                if (self.outgoing_reservations.is_set or self.outgoing_reservations.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.outgoing_reservations.get_name_leafdata())
                if (self.sessions.is_set or self.sessions.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.sessions.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "incoming-paths" or name == "incoming-reservations" or name == "interfaces" or name == "outgoing-paths" or name == "outgoing-reservations" or name == "sessions"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "incoming-paths"):
                    self.incoming_paths = value
                    self.incoming_paths.value_namespace = name_space
                    self.incoming_paths.value_namespace_prefix = name_space_prefix
                if(value_path == "incoming-reservations"):
                    self.incoming_reservations = value
                    self.incoming_reservations.value_namespace = name_space
                    self.incoming_reservations.value_namespace_prefix = name_space_prefix
                if(value_path == "interfaces"):
                    self.interfaces = value
                    self.interfaces.value_namespace = name_space
                    self.interfaces.value_namespace_prefix = name_space_prefix
                if(value_path == "outgoing-paths"):
                    self.outgoing_paths = value
                    self.outgoing_paths.value_namespace = name_space
                    self.outgoing_paths.value_namespace_prefix = name_space_prefix
                if(value_path == "outgoing-reservations"):
                    self.outgoing_reservations = value
                    self.outgoing_reservations.value_namespace = name_space
                    self.outgoing_reservations.value_namespace_prefix = name_space_prefix
                if(value_path == "sessions"):
                    self.sessions = value
                    self.sessions.value_namespace = name_space
                    self.sessions.value_namespace_prefix = name_space_prefix

        def has_data(self):
            return (
                self.interfaces.is_set or
                self.ls_ps.is_set or
                (self.database_counters is not None and self.database_counters.has_data()) or
                (self.issu_status is not None and self.issu_status.has_data()) or
                (self.nsr_status is not None and self.nsr_status.has_data()))

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                self.interfaces.yfilter != YFilter.not_set or
                self.ls_ps.yfilter != YFilter.not_set or
                (self.database_counters is not None and self.database_counters.has_operation()) or
                (self.issu_status is not None and self.issu_status.has_operation()) or
                (self.nsr_status is not None and self.nsr_status.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "summary" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()
            if (self.interfaces.is_set or self.interfaces.yfilter != YFilter.not_set):
                leaf_name_data.append(self.interfaces.get_name_leafdata())
            if (self.ls_ps.is_set or self.ls_ps.yfilter != YFilter.not_set):
                leaf_name_data.append(self.ls_ps.get_name_leafdata())

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "database-counters"):
                if (self.database_counters is None):
                    self.database_counters = RsvpStandby.Summary.DatabaseCounters()
                    self.database_counters.parent = self
                    self._children_name_map["database_counters"] = "database-counters"
                return self.database_counters

            if (child_yang_name == "issu-status"):
                if (self.issu_status is None):
                    self.issu_status = RsvpStandby.Summary.IssuStatus()
                    self.issu_status.parent = self
                    self._children_name_map["issu_status"] = "issu-status"
                return self.issu_status

            if (child_yang_name == "nsr-status"):
                if (self.nsr_status is None):
                    self.nsr_status = RsvpStandby.Summary.NsrStatus()
                    self.nsr_status.parent = self
                    self._children_name_map["nsr_status"] = "nsr-status"
                return self.nsr_status

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "database-counters" or name == "issu-status" or name == "nsr-status" or name == "interfaces" or name == "ls-ps"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            if(value_path == "interfaces"):
                self.interfaces = value
                self.interfaces.value_namespace = name_space
                self.interfaces.value_namespace_prefix = name_space_prefix
            if(value_path == "ls-ps"):
                self.ls_ps = value
                self.ls_ps.value_namespace = name_space
                self.ls_ps.value_namespace_prefix = name_space_prefix


    class Frrs(Entity):
        """
        Table of detailed info about Fast Re\-route
        states
        
        .. attribute:: frr
        
        	Detailed info for a single Fast Re\-route state
        	**type**\: list of    :py:class:`Frr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Frrs.Frr>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(RsvpStandby.Frrs, self).__init__()

            self.yang_name = "frrs"
            self.yang_parent_name = "rsvp-standby"

            self.frr = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(RsvpStandby.Frrs, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(RsvpStandby.Frrs, self).__setattr__(name, value)


        class Frr(Entity):
            """
            Detailed info for a single Fast Re\-route state
            
            .. attribute:: destination_address
            
            	Destination Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: destination_port
            
            	Destination Port
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: extended_tunnel_id
            
            	Extended Tunnel ID
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: p2mp_id
            
            	P2MP ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: path_status
            
            	RSVP FRR Path States
            	**type**\:   :py:class:`RsvpMgmtFrrStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtFrrStateEnum>`
            
            .. attribute:: protocol
            
            	Protocol
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: reservation_status
            
            	RSVP FRR Reservation States
            	**type**\:   :py:class:`RsvpMgmtFrrStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtFrrStateEnum>`
            
            .. attribute:: s2l_sub_lsp
            
            	RSVP S2L Sub\-LSP information
            	**type**\:   :py:class:`S2LSubLsp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Frrs.Frr.S2LSubLsp>`
            
            .. attribute:: session
            
            	RSVP Session Information
            	**type**\:   :py:class:`Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Frrs.Frr.Session>`
            
            .. attribute:: session_type
            
            	Session Type
            	**type**\:   :py:class:`RsvpSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpSession>`
            
            .. attribute:: source_address
            
            	Source Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: source_port
            
            	Source Port
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: sub_group_id
            
            	Subgroup ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: sub_group_origin
            
            	Subgroup Origin
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: vrf_name
            
            	VRF Name
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(RsvpStandby.Frrs.Frr, self).__init__()

                self.yang_name = "frr"
                self.yang_parent_name = "frrs"

                self.destination_address = YLeaf(YType.str, "destination-address")

                self.destination_port = YLeaf(YType.int32, "destination-port")

                self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                self.p2mp_id = YLeaf(YType.int32, "p2mp-id")

                self.path_status = YLeaf(YType.enumeration, "path-status")

                self.protocol = YLeaf(YType.int32, "protocol")

                self.reservation_status = YLeaf(YType.enumeration, "reservation-status")

                self.session_type = YLeaf(YType.enumeration, "session-type")

                self.source_address = YLeaf(YType.str, "source-address")

                self.source_port = YLeaf(YType.int32, "source-port")

                self.sub_group_id = YLeaf(YType.int32, "sub-group-id")

                self.sub_group_origin = YLeaf(YType.str, "sub-group-origin")

                self.vrf_name = YLeaf(YType.str, "vrf-name")

                self.s2l_sub_lsp = RsvpStandby.Frrs.Frr.S2LSubLsp()
                self.s2l_sub_lsp.parent = self
                self._children_name_map["s2l_sub_lsp"] = "s2l-sub-lsp"
                self._children_yang_names.add("s2l-sub-lsp")

                self.session = RsvpStandby.Frrs.Frr.Session()
                self.session.parent = self
                self._children_name_map["session"] = "session"
                self._children_yang_names.add("session")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("destination_address",
                                "destination_port",
                                "extended_tunnel_id",
                                "p2mp_id",
                                "path_status",
                                "protocol",
                                "reservation_status",
                                "session_type",
                                "source_address",
                                "source_port",
                                "sub_group_id",
                                "sub_group_origin",
                                "vrf_name") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(RsvpStandby.Frrs.Frr, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(RsvpStandby.Frrs.Frr, self).__setattr__(name, value)


            class Session(Entity):
                """
                RSVP Session Information
                
                .. attribute:: rsvp_session
                
                	RSVP Session
                	**type**\:   :py:class:`RsvpSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Frrs.Frr.Session.RsvpSession>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.Frrs.Frr.Session, self).__init__()

                    self.yang_name = "session"
                    self.yang_parent_name = "frr"

                    self.rsvp_session = RsvpStandby.Frrs.Frr.Session.RsvpSession()
                    self.rsvp_session.parent = self
                    self._children_name_map["rsvp_session"] = "rsvp-session"
                    self._children_yang_names.add("rsvp-session")


                class RsvpSession(Entity):
                    """
                    RSVP Session
                    
                    .. attribute:: ipv4
                    
                    	UDP IPv4 session
                    	**type**\:   :py:class:`Ipv4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Frrs.Frr.Session.RsvpSession.Ipv4>`
                    
                    .. attribute:: ipv4_lsp_session
                    
                    	IPv4 LSP session
                    	**type**\:   :py:class:`Ipv4LspSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Frrs.Frr.Session.RsvpSession.Ipv4LspSession>`
                    
                    .. attribute:: ipv4_p2mp_lsp_session
                    
                    	IPv4 P2MP LSP session
                    	**type**\:   :py:class:`Ipv4P2MpLspSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Frrs.Frr.Session.RsvpSession.Ipv4P2MpLspSession>`
                    
                    .. attribute:: ipv4_uni_session
                    
                    	IPv4 UNI session
                    	**type**\:   :py:class:`Ipv4UniSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.Frrs.Frr.Session.RsvpSession.Ipv4UniSession>`
                    
                    .. attribute:: session_type
                    
                    	SessionType
                    	**type**\:   :py:class:`RsvpMgmtSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtSession>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.Frrs.Frr.Session.RsvpSession, self).__init__()

                        self.yang_name = "rsvp-session"
                        self.yang_parent_name = "session"

                        self.session_type = YLeaf(YType.enumeration, "session-type")

                        self.ipv4 = RsvpStandby.Frrs.Frr.Session.RsvpSession.Ipv4()
                        self.ipv4.parent = self
                        self._children_name_map["ipv4"] = "ipv4"
                        self._children_yang_names.add("ipv4")

                        self.ipv4_lsp_session = RsvpStandby.Frrs.Frr.Session.RsvpSession.Ipv4LspSession()
                        self.ipv4_lsp_session.parent = self
                        self._children_name_map["ipv4_lsp_session"] = "ipv4-lsp-session"
                        self._children_yang_names.add("ipv4-lsp-session")

                        self.ipv4_p2mp_lsp_session = RsvpStandby.Frrs.Frr.Session.RsvpSession.Ipv4P2MpLspSession()
                        self.ipv4_p2mp_lsp_session.parent = self
                        self._children_name_map["ipv4_p2mp_lsp_session"] = "ipv4-p2mp-lsp-session"
                        self._children_yang_names.add("ipv4-p2mp-lsp-session")

                        self.ipv4_uni_session = RsvpStandby.Frrs.Frr.Session.RsvpSession.Ipv4UniSession()
                        self.ipv4_uni_session.parent = self
                        self._children_name_map["ipv4_uni_session"] = "ipv4-uni-session"
                        self._children_yang_names.add("ipv4-uni-session")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("session_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.Frrs.Frr.Session.RsvpSession, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.Frrs.Frr.Session.RsvpSession, self).__setattr__(name, value)


                    class Ipv4(Entity):
                        """
                        UDP IPv4 session
                        
                        .. attribute:: destination_address
                        
                        	Destination address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: destination_port
                        
                        	The Session Destination Port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: protocol
                        
                        	Protocol type (originally defined in RFC 790, further values in subsequent RFCs)
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.Frrs.Frr.Session.RsvpSession.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "rsvp-session"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.destination_port = YLeaf(YType.uint16, "destination-port")

                            self.protocol = YLeaf(YType.uint8, "protocol")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "destination_port",
                                            "protocol") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.Frrs.Frr.Session.RsvpSession.Ipv4, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.Frrs.Frr.Session.RsvpSession.Ipv4, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination_address.is_set or
                                self.destination_port.is_set or
                                self.protocol.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.destination_port.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/frrs/frr/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.destination_port.is_set or self.destination_port.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_port.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "destination-port" or name == "protocol"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "destination-port"):
                                self.destination_port = value
                                self.destination_port.value_namespace = name_space
                                self.destination_port.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix


                    class Ipv4LspSession(Entity):
                        """
                        IPv4 LSP session
                        
                        .. attribute:: destination_address
                        
                        	Destination address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: extended_tunnel_id
                        
                        	The Session Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: tunnel_id
                        
                        	The Session Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.Frrs.Frr.Session.RsvpSession.Ipv4LspSession, self).__init__()

                            self.yang_name = "ipv4-lsp-session"
                            self.yang_parent_name = "rsvp-session"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                            self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "extended_tunnel_id",
                                            "tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.Frrs.Frr.Session.RsvpSession.Ipv4LspSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.Frrs.Frr.Session.RsvpSession.Ipv4LspSession, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination_address.is_set or
                                self.extended_tunnel_id.is_set or
                                self.tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.extended_tunnel_id.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-lsp-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/frrs/frr/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "extended-tunnel-id" or name == "tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "extended-tunnel-id"):
                                self.extended_tunnel_id = value
                                self.extended_tunnel_id.value_namespace = name_space
                                self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix


                    class Ipv4UniSession(Entity):
                        """
                        IPv4 UNI session
                        
                        .. attribute:: destination_address
                        
                        	Destination address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: extended_address
                        
                        	The Session Extended Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: tunnel_id
                        
                        	The Session Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.Frrs.Frr.Session.RsvpSession.Ipv4UniSession, self).__init__()

                            self.yang_name = "ipv4-uni-session"
                            self.yang_parent_name = "rsvp-session"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.extended_address = YLeaf(YType.str, "extended-address")

                            self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "extended_address",
                                            "tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.Frrs.Frr.Session.RsvpSession.Ipv4UniSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.Frrs.Frr.Session.RsvpSession.Ipv4UniSession, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination_address.is_set or
                                self.extended_address.is_set or
                                self.tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.extended_address.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-uni-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/frrs/frr/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.extended_address.is_set or self.extended_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_address.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "extended-address" or name == "tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "extended-address"):
                                self.extended_address = value
                                self.extended_address.value_namespace = name_space
                                self.extended_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix


                    class Ipv4P2MpLspSession(Entity):
                        """
                        IPv4 P2MP LSP session
                        
                        .. attribute:: extended_tunnel_id
                        
                        	The Session Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: p2mp_id
                        
                        	The Point to Multipoint ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tunnel_id
                        
                        	The Session Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.Frrs.Frr.Session.RsvpSession.Ipv4P2MpLspSession, self).__init__()

                            self.yang_name = "ipv4-p2mp-lsp-session"
                            self.yang_parent_name = "rsvp-session"

                            self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                            self.p2mp_id = YLeaf(YType.uint32, "p2mp-id")

                            self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("extended_tunnel_id",
                                            "p2mp_id",
                                            "tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.Frrs.Frr.Session.RsvpSession.Ipv4P2MpLspSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.Frrs.Frr.Session.RsvpSession.Ipv4P2MpLspSession, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.extended_tunnel_id.is_set or
                                self.p2mp_id.is_set or
                                self.tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.extended_tunnel_id.yfilter != YFilter.not_set or
                                self.p2mp_id.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-p2mp-lsp-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/frrs/frr/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                            if (self.p2mp_id.is_set or self.p2mp_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.p2mp_id.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "extended-tunnel-id" or name == "p2mp-id" or name == "tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "extended-tunnel-id"):
                                self.extended_tunnel_id = value
                                self.extended_tunnel_id.value_namespace = name_space
                                self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "p2mp-id"):
                                self.p2mp_id = value
                                self.p2mp_id.value_namespace = name_space
                                self.p2mp_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.session_type.is_set or
                            (self.ipv4 is not None and self.ipv4.has_data()) or
                            (self.ipv4_lsp_session is not None and self.ipv4_lsp_session.has_data()) or
                            (self.ipv4_p2mp_lsp_session is not None and self.ipv4_p2mp_lsp_session.has_data()) or
                            (self.ipv4_uni_session is not None and self.ipv4_uni_session.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.session_type.yfilter != YFilter.not_set or
                            (self.ipv4 is not None and self.ipv4.has_operation()) or
                            (self.ipv4_lsp_session is not None and self.ipv4_lsp_session.has_operation()) or
                            (self.ipv4_p2mp_lsp_session is not None and self.ipv4_p2mp_lsp_session.has_operation()) or
                            (self.ipv4_uni_session is not None and self.ipv4_uni_session.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rsvp-session" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/frrs/frr/session/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.session_type.is_set or self.session_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.session_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "ipv4"):
                            if (self.ipv4 is None):
                                self.ipv4 = RsvpStandby.Frrs.Frr.Session.RsvpSession.Ipv4()
                                self.ipv4.parent = self
                                self._children_name_map["ipv4"] = "ipv4"
                            return self.ipv4

                        if (child_yang_name == "ipv4-lsp-session"):
                            if (self.ipv4_lsp_session is None):
                                self.ipv4_lsp_session = RsvpStandby.Frrs.Frr.Session.RsvpSession.Ipv4LspSession()
                                self.ipv4_lsp_session.parent = self
                                self._children_name_map["ipv4_lsp_session"] = "ipv4-lsp-session"
                            return self.ipv4_lsp_session

                        if (child_yang_name == "ipv4-p2mp-lsp-session"):
                            if (self.ipv4_p2mp_lsp_session is None):
                                self.ipv4_p2mp_lsp_session = RsvpStandby.Frrs.Frr.Session.RsvpSession.Ipv4P2MpLspSession()
                                self.ipv4_p2mp_lsp_session.parent = self
                                self._children_name_map["ipv4_p2mp_lsp_session"] = "ipv4-p2mp-lsp-session"
                            return self.ipv4_p2mp_lsp_session

                        if (child_yang_name == "ipv4-uni-session"):
                            if (self.ipv4_uni_session is None):
                                self.ipv4_uni_session = RsvpStandby.Frrs.Frr.Session.RsvpSession.Ipv4UniSession()
                                self.ipv4_uni_session.parent = self
                                self._children_name_map["ipv4_uni_session"] = "ipv4-uni-session"
                            return self.ipv4_uni_session

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ipv4" or name == "ipv4-lsp-session" or name == "ipv4-p2mp-lsp-session" or name == "ipv4-uni-session" or name == "session-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "session-type"):
                            self.session_type = value
                            self.session_type.value_namespace = name_space
                            self.session_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (self.rsvp_session is not None and self.rsvp_session.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.rsvp_session is not None and self.rsvp_session.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "session" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/frrs/frr/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "rsvp-session"):
                        if (self.rsvp_session is None):
                            self.rsvp_session = RsvpStandby.Frrs.Frr.Session.RsvpSession()
                            self.rsvp_session.parent = self
                            self._children_name_map["rsvp_session"] = "rsvp-session"
                        return self.rsvp_session

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "rsvp-session"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class S2LSubLsp(Entity):
                """
                RSVP S2L Sub\-LSP information
                
                .. attribute:: s2l_destination_address
                
                	S2L Sub\-LSP Destination Address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.Frrs.Frr.S2LSubLsp, self).__init__()

                    self.yang_name = "s2l-sub-lsp"
                    self.yang_parent_name = "frr"

                    self.s2l_destination_address = YLeaf(YType.str, "s2l-destination-address")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("s2l_destination_address") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.Frrs.Frr.S2LSubLsp, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.Frrs.Frr.S2LSubLsp, self).__setattr__(name, value)

                def has_data(self):
                    return self.s2l_destination_address.is_set

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.s2l_destination_address.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "s2l-sub-lsp" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/frrs/frr/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.s2l_destination_address.is_set or self.s2l_destination_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.s2l_destination_address.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "s2l-destination-address"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "s2l-destination-address"):
                        self.s2l_destination_address = value
                        self.s2l_destination_address.value_namespace = name_space
                        self.s2l_destination_address.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.destination_address.is_set or
                    self.destination_port.is_set or
                    self.extended_tunnel_id.is_set or
                    self.p2mp_id.is_set or
                    self.path_status.is_set or
                    self.protocol.is_set or
                    self.reservation_status.is_set or
                    self.session_type.is_set or
                    self.source_address.is_set or
                    self.source_port.is_set or
                    self.sub_group_id.is_set or
                    self.sub_group_origin.is_set or
                    self.vrf_name.is_set or
                    (self.s2l_sub_lsp is not None and self.s2l_sub_lsp.has_data()) or
                    (self.session is not None and self.session.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.destination_address.yfilter != YFilter.not_set or
                    self.destination_port.yfilter != YFilter.not_set or
                    self.extended_tunnel_id.yfilter != YFilter.not_set or
                    self.p2mp_id.yfilter != YFilter.not_set or
                    self.path_status.yfilter != YFilter.not_set or
                    self.protocol.yfilter != YFilter.not_set or
                    self.reservation_status.yfilter != YFilter.not_set or
                    self.session_type.yfilter != YFilter.not_set or
                    self.source_address.yfilter != YFilter.not_set or
                    self.source_port.yfilter != YFilter.not_set or
                    self.sub_group_id.yfilter != YFilter.not_set or
                    self.sub_group_origin.yfilter != YFilter.not_set or
                    self.vrf_name.yfilter != YFilter.not_set or
                    (self.s2l_sub_lsp is not None and self.s2l_sub_lsp.has_operation()) or
                    (self.session is not None and self.session.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "frr" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/frrs/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_address.get_name_leafdata())
                if (self.destination_port.is_set or self.destination_port.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_port.get_name_leafdata())
                if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                if (self.p2mp_id.is_set or self.p2mp_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.p2mp_id.get_name_leafdata())
                if (self.path_status.is_set or self.path_status.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.path_status.get_name_leafdata())
                if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.protocol.get_name_leafdata())
                if (self.reservation_status.is_set or self.reservation_status.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.reservation_status.get_name_leafdata())
                if (self.session_type.is_set or self.session_type.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.session_type.get_name_leafdata())
                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_address.get_name_leafdata())
                if (self.source_port.is_set or self.source_port.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_port.get_name_leafdata())
                if (self.sub_group_id.is_set or self.sub_group_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.sub_group_id.get_name_leafdata())
                if (self.sub_group_origin.is_set or self.sub_group_origin.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.sub_group_origin.get_name_leafdata())
                if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.vrf_name.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "s2l-sub-lsp"):
                    if (self.s2l_sub_lsp is None):
                        self.s2l_sub_lsp = RsvpStandby.Frrs.Frr.S2LSubLsp()
                        self.s2l_sub_lsp.parent = self
                        self._children_name_map["s2l_sub_lsp"] = "s2l-sub-lsp"
                    return self.s2l_sub_lsp

                if (child_yang_name == "session"):
                    if (self.session is None):
                        self.session = RsvpStandby.Frrs.Frr.Session()
                        self.session.parent = self
                        self._children_name_map["session"] = "session"
                    return self.session

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "s2l-sub-lsp" or name == "session" or name == "destination-address" or name == "destination-port" or name == "extended-tunnel-id" or name == "p2mp-id" or name == "path-status" or name == "protocol" or name == "reservation-status" or name == "session-type" or name == "source-address" or name == "source-port" or name == "sub-group-id" or name == "sub-group-origin" or name == "vrf-name"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "destination-address"):
                    self.destination_address = value
                    self.destination_address.value_namespace = name_space
                    self.destination_address.value_namespace_prefix = name_space_prefix
                if(value_path == "destination-port"):
                    self.destination_port = value
                    self.destination_port.value_namespace = name_space
                    self.destination_port.value_namespace_prefix = name_space_prefix
                if(value_path == "extended-tunnel-id"):
                    self.extended_tunnel_id = value
                    self.extended_tunnel_id.value_namespace = name_space
                    self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                if(value_path == "p2mp-id"):
                    self.p2mp_id = value
                    self.p2mp_id.value_namespace = name_space
                    self.p2mp_id.value_namespace_prefix = name_space_prefix
                if(value_path == "path-status"):
                    self.path_status = value
                    self.path_status.value_namespace = name_space
                    self.path_status.value_namespace_prefix = name_space_prefix
                if(value_path == "protocol"):
                    self.protocol = value
                    self.protocol.value_namespace = name_space
                    self.protocol.value_namespace_prefix = name_space_prefix
                if(value_path == "reservation-status"):
                    self.reservation_status = value
                    self.reservation_status.value_namespace = name_space
                    self.reservation_status.value_namespace_prefix = name_space_prefix
                if(value_path == "session-type"):
                    self.session_type = value
                    self.session_type.value_namespace = name_space
                    self.session_type.value_namespace_prefix = name_space_prefix
                if(value_path == "source-address"):
                    self.source_address = value
                    self.source_address.value_namespace = name_space
                    self.source_address.value_namespace_prefix = name_space_prefix
                if(value_path == "source-port"):
                    self.source_port = value
                    self.source_port.value_namespace = name_space
                    self.source_port.value_namespace_prefix = name_space_prefix
                if(value_path == "sub-group-id"):
                    self.sub_group_id = value
                    self.sub_group_id.value_namespace = name_space
                    self.sub_group_id.value_namespace_prefix = name_space_prefix
                if(value_path == "sub-group-origin"):
                    self.sub_group_origin = value
                    self.sub_group_origin.value_namespace = name_space
                    self.sub_group_origin.value_namespace_prefix = name_space_prefix
                if(value_path == "vrf-name"):
                    self.vrf_name = value
                    self.vrf_name.value_namespace = name_space
                    self.vrf_name.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.frr:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.frr:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "frrs" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "frr"):
                for c in self.frr:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = RsvpStandby.Frrs.Frr()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.frr.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "frr"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class RequestBriefs(Entity):
        """
        Table of brief info about requests
        
        .. attribute:: request_brief
        
        	Brief info for a request
        	**type**\: list of    :py:class:`RequestBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RequestBriefs.RequestBrief>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(RsvpStandby.RequestBriefs, self).__init__()

            self.yang_name = "request-briefs"
            self.yang_parent_name = "rsvp-standby"

            self.request_brief = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(RsvpStandby.RequestBriefs, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(RsvpStandby.RequestBriefs, self).__setattr__(name, value)


        class RequestBrief(Entity):
            """
            Brief info for a request
            
            .. attribute:: destination_address
            
            	Destination Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: destination_port
            
            	Destination Port
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: extended_tunnel_id
            
            	Extended Tunnel ID
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: filter
            
            	RSVP Filter
            	**type**\:   :py:class:`Filter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RequestBriefs.RequestBrief.Filter>`
            
            .. attribute:: flow_spec
            
            	Flow Spec Information
            	**type**\:   :py:class:`FlowSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RequestBriefs.RequestBrief.FlowSpec>`
            
            .. attribute:: generic_flow_spec
            
            	Generic Flow Spec Information
            	**type**\:   :py:class:`GenericFlowSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RequestBriefs.RequestBrief.GenericFlowSpec>`
            
            .. attribute:: output_interface
            
            	Output Interface
            	**type**\:  str
            
            .. attribute:: p2mp_id
            
            	P2MP ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: protocol
            
            	Protocol
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: s2l_sub_lsp
            
            	RSVP S2L Sub\-LSP information
            	**type**\:   :py:class:`S2LSubLsp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RequestBriefs.RequestBrief.S2LSubLsp>`
            
            .. attribute:: session
            
            	RSVP Session Information
            	**type**\:   :py:class:`Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RequestBriefs.RequestBrief.Session>`
            
            .. attribute:: session_type
            
            	Session Type
            	**type**\:   :py:class:`RsvpSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpSession>`
            
            .. attribute:: source_address
            
            	Source Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: source_port
            
            	Source Port
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: style
            
            	RSVP Style
            	**type**\:   :py:class:`Style <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RequestBriefs.RequestBrief.Style>`
            
            .. attribute:: sub_group_id
            
            	Subgroup ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: sub_group_origin
            
            	Subgroup Origin
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: vrf_name
            
            	VRF Name
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(RsvpStandby.RequestBriefs.RequestBrief, self).__init__()

                self.yang_name = "request-brief"
                self.yang_parent_name = "request-briefs"

                self.destination_address = YLeaf(YType.str, "destination-address")

                self.destination_port = YLeaf(YType.int32, "destination-port")

                self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                self.output_interface = YLeaf(YType.str, "output-interface")

                self.p2mp_id = YLeaf(YType.int32, "p2mp-id")

                self.protocol = YLeaf(YType.int32, "protocol")

                self.session_type = YLeaf(YType.enumeration, "session-type")

                self.source_address = YLeaf(YType.str, "source-address")

                self.source_port = YLeaf(YType.int32, "source-port")

                self.sub_group_id = YLeaf(YType.int32, "sub-group-id")

                self.sub_group_origin = YLeaf(YType.str, "sub-group-origin")

                self.vrf_name = YLeaf(YType.str, "vrf-name")

                self.filter = RsvpStandby.RequestBriefs.RequestBrief.Filter()
                self.filter.parent = self
                self._children_name_map["filter"] = "filter"
                self._children_yang_names.add("filter")

                self.flow_spec = RsvpStandby.RequestBriefs.RequestBrief.FlowSpec()
                self.flow_spec.parent = self
                self._children_name_map["flow_spec"] = "flow-spec"
                self._children_yang_names.add("flow-spec")

                self.generic_flow_spec = RsvpStandby.RequestBriefs.RequestBrief.GenericFlowSpec()
                self.generic_flow_spec.parent = self
                self._children_name_map["generic_flow_spec"] = "generic-flow-spec"
                self._children_yang_names.add("generic-flow-spec")

                self.s2l_sub_lsp = RsvpStandby.RequestBriefs.RequestBrief.S2LSubLsp()
                self.s2l_sub_lsp.parent = self
                self._children_name_map["s2l_sub_lsp"] = "s2l-sub-lsp"
                self._children_yang_names.add("s2l-sub-lsp")

                self.session = RsvpStandby.RequestBriefs.RequestBrief.Session()
                self.session.parent = self
                self._children_name_map["session"] = "session"
                self._children_yang_names.add("session")

                self.style = RsvpStandby.RequestBriefs.RequestBrief.Style()
                self.style.parent = self
                self._children_name_map["style"] = "style"
                self._children_yang_names.add("style")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("destination_address",
                                "destination_port",
                                "extended_tunnel_id",
                                "output_interface",
                                "p2mp_id",
                                "protocol",
                                "session_type",
                                "source_address",
                                "source_port",
                                "sub_group_id",
                                "sub_group_origin",
                                "vrf_name") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(RsvpStandby.RequestBriefs.RequestBrief, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(RsvpStandby.RequestBriefs.RequestBrief, self).__setattr__(name, value)


            class Session(Entity):
                """
                RSVP Session Information
                
                .. attribute:: rsvp_session
                
                	RSVP Session
                	**type**\:   :py:class:`RsvpSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RequestBriefs.RequestBrief.Session.RsvpSession>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.RequestBriefs.RequestBrief.Session, self).__init__()

                    self.yang_name = "session"
                    self.yang_parent_name = "request-brief"

                    self.rsvp_session = RsvpStandby.RequestBriefs.RequestBrief.Session.RsvpSession()
                    self.rsvp_session.parent = self
                    self._children_name_map["rsvp_session"] = "rsvp-session"
                    self._children_yang_names.add("rsvp-session")


                class RsvpSession(Entity):
                    """
                    RSVP Session
                    
                    .. attribute:: ipv4
                    
                    	UDP IPv4 session
                    	**type**\:   :py:class:`Ipv4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RequestBriefs.RequestBrief.Session.RsvpSession.Ipv4>`
                    
                    .. attribute:: ipv4_lsp_session
                    
                    	IPv4 LSP session
                    	**type**\:   :py:class:`Ipv4LspSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RequestBriefs.RequestBrief.Session.RsvpSession.Ipv4LspSession>`
                    
                    .. attribute:: ipv4_p2mp_lsp_session
                    
                    	IPv4 P2MP LSP session
                    	**type**\:   :py:class:`Ipv4P2MpLspSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RequestBriefs.RequestBrief.Session.RsvpSession.Ipv4P2MpLspSession>`
                    
                    .. attribute:: ipv4_uni_session
                    
                    	IPv4 UNI session
                    	**type**\:   :py:class:`Ipv4UniSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RequestBriefs.RequestBrief.Session.RsvpSession.Ipv4UniSession>`
                    
                    .. attribute:: session_type
                    
                    	SessionType
                    	**type**\:   :py:class:`RsvpMgmtSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtSession>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.RequestBriefs.RequestBrief.Session.RsvpSession, self).__init__()

                        self.yang_name = "rsvp-session"
                        self.yang_parent_name = "session"

                        self.session_type = YLeaf(YType.enumeration, "session-type")

                        self.ipv4 = RsvpStandby.RequestBriefs.RequestBrief.Session.RsvpSession.Ipv4()
                        self.ipv4.parent = self
                        self._children_name_map["ipv4"] = "ipv4"
                        self._children_yang_names.add("ipv4")

                        self.ipv4_lsp_session = RsvpStandby.RequestBriefs.RequestBrief.Session.RsvpSession.Ipv4LspSession()
                        self.ipv4_lsp_session.parent = self
                        self._children_name_map["ipv4_lsp_session"] = "ipv4-lsp-session"
                        self._children_yang_names.add("ipv4-lsp-session")

                        self.ipv4_p2mp_lsp_session = RsvpStandby.RequestBriefs.RequestBrief.Session.RsvpSession.Ipv4P2MpLspSession()
                        self.ipv4_p2mp_lsp_session.parent = self
                        self._children_name_map["ipv4_p2mp_lsp_session"] = "ipv4-p2mp-lsp-session"
                        self._children_yang_names.add("ipv4-p2mp-lsp-session")

                        self.ipv4_uni_session = RsvpStandby.RequestBriefs.RequestBrief.Session.RsvpSession.Ipv4UniSession()
                        self.ipv4_uni_session.parent = self
                        self._children_name_map["ipv4_uni_session"] = "ipv4-uni-session"
                        self._children_yang_names.add("ipv4-uni-session")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("session_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.RequestBriefs.RequestBrief.Session.RsvpSession, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.RequestBriefs.RequestBrief.Session.RsvpSession, self).__setattr__(name, value)


                    class Ipv4(Entity):
                        """
                        UDP IPv4 session
                        
                        .. attribute:: destination_address
                        
                        	Destination address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: destination_port
                        
                        	The Session Destination Port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: protocol
                        
                        	Protocol type (originally defined in RFC 790, further values in subsequent RFCs)
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.RequestBriefs.RequestBrief.Session.RsvpSession.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "rsvp-session"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.destination_port = YLeaf(YType.uint16, "destination-port")

                            self.protocol = YLeaf(YType.uint8, "protocol")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "destination_port",
                                            "protocol") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.RequestBriefs.RequestBrief.Session.RsvpSession.Ipv4, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.RequestBriefs.RequestBrief.Session.RsvpSession.Ipv4, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination_address.is_set or
                                self.destination_port.is_set or
                                self.protocol.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.destination_port.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/request-briefs/request-brief/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.destination_port.is_set or self.destination_port.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_port.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "destination-port" or name == "protocol"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "destination-port"):
                                self.destination_port = value
                                self.destination_port.value_namespace = name_space
                                self.destination_port.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix


                    class Ipv4LspSession(Entity):
                        """
                        IPv4 LSP session
                        
                        .. attribute:: destination_address
                        
                        	Destination address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: extended_tunnel_id
                        
                        	The Session Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: tunnel_id
                        
                        	The Session Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.RequestBriefs.RequestBrief.Session.RsvpSession.Ipv4LspSession, self).__init__()

                            self.yang_name = "ipv4-lsp-session"
                            self.yang_parent_name = "rsvp-session"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                            self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "extended_tunnel_id",
                                            "tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.RequestBriefs.RequestBrief.Session.RsvpSession.Ipv4LspSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.RequestBriefs.RequestBrief.Session.RsvpSession.Ipv4LspSession, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination_address.is_set or
                                self.extended_tunnel_id.is_set or
                                self.tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.extended_tunnel_id.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-lsp-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/request-briefs/request-brief/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "extended-tunnel-id" or name == "tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "extended-tunnel-id"):
                                self.extended_tunnel_id = value
                                self.extended_tunnel_id.value_namespace = name_space
                                self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix


                    class Ipv4UniSession(Entity):
                        """
                        IPv4 UNI session
                        
                        .. attribute:: destination_address
                        
                        	Destination address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: extended_address
                        
                        	The Session Extended Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: tunnel_id
                        
                        	The Session Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.RequestBriefs.RequestBrief.Session.RsvpSession.Ipv4UniSession, self).__init__()

                            self.yang_name = "ipv4-uni-session"
                            self.yang_parent_name = "rsvp-session"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.extended_address = YLeaf(YType.str, "extended-address")

                            self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "extended_address",
                                            "tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.RequestBriefs.RequestBrief.Session.RsvpSession.Ipv4UniSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.RequestBriefs.RequestBrief.Session.RsvpSession.Ipv4UniSession, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination_address.is_set or
                                self.extended_address.is_set or
                                self.tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.extended_address.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-uni-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/request-briefs/request-brief/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.extended_address.is_set or self.extended_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_address.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "extended-address" or name == "tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "extended-address"):
                                self.extended_address = value
                                self.extended_address.value_namespace = name_space
                                self.extended_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix


                    class Ipv4P2MpLspSession(Entity):
                        """
                        IPv4 P2MP LSP session
                        
                        .. attribute:: extended_tunnel_id
                        
                        	The Session Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: p2mp_id
                        
                        	The Point to Multipoint ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tunnel_id
                        
                        	The Session Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.RequestBriefs.RequestBrief.Session.RsvpSession.Ipv4P2MpLspSession, self).__init__()

                            self.yang_name = "ipv4-p2mp-lsp-session"
                            self.yang_parent_name = "rsvp-session"

                            self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                            self.p2mp_id = YLeaf(YType.uint32, "p2mp-id")

                            self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("extended_tunnel_id",
                                            "p2mp_id",
                                            "tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.RequestBriefs.RequestBrief.Session.RsvpSession.Ipv4P2MpLspSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.RequestBriefs.RequestBrief.Session.RsvpSession.Ipv4P2MpLspSession, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.extended_tunnel_id.is_set or
                                self.p2mp_id.is_set or
                                self.tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.extended_tunnel_id.yfilter != YFilter.not_set or
                                self.p2mp_id.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-p2mp-lsp-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/request-briefs/request-brief/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                            if (self.p2mp_id.is_set or self.p2mp_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.p2mp_id.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "extended-tunnel-id" or name == "p2mp-id" or name == "tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "extended-tunnel-id"):
                                self.extended_tunnel_id = value
                                self.extended_tunnel_id.value_namespace = name_space
                                self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "p2mp-id"):
                                self.p2mp_id = value
                                self.p2mp_id.value_namespace = name_space
                                self.p2mp_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.session_type.is_set or
                            (self.ipv4 is not None and self.ipv4.has_data()) or
                            (self.ipv4_lsp_session is not None and self.ipv4_lsp_session.has_data()) or
                            (self.ipv4_p2mp_lsp_session is not None and self.ipv4_p2mp_lsp_session.has_data()) or
                            (self.ipv4_uni_session is not None and self.ipv4_uni_session.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.session_type.yfilter != YFilter.not_set or
                            (self.ipv4 is not None and self.ipv4.has_operation()) or
                            (self.ipv4_lsp_session is not None and self.ipv4_lsp_session.has_operation()) or
                            (self.ipv4_p2mp_lsp_session is not None and self.ipv4_p2mp_lsp_session.has_operation()) or
                            (self.ipv4_uni_session is not None and self.ipv4_uni_session.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rsvp-session" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/request-briefs/request-brief/session/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.session_type.is_set or self.session_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.session_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "ipv4"):
                            if (self.ipv4 is None):
                                self.ipv4 = RsvpStandby.RequestBriefs.RequestBrief.Session.RsvpSession.Ipv4()
                                self.ipv4.parent = self
                                self._children_name_map["ipv4"] = "ipv4"
                            return self.ipv4

                        if (child_yang_name == "ipv4-lsp-session"):
                            if (self.ipv4_lsp_session is None):
                                self.ipv4_lsp_session = RsvpStandby.RequestBriefs.RequestBrief.Session.RsvpSession.Ipv4LspSession()
                                self.ipv4_lsp_session.parent = self
                                self._children_name_map["ipv4_lsp_session"] = "ipv4-lsp-session"
                            return self.ipv4_lsp_session

                        if (child_yang_name == "ipv4-p2mp-lsp-session"):
                            if (self.ipv4_p2mp_lsp_session is None):
                                self.ipv4_p2mp_lsp_session = RsvpStandby.RequestBriefs.RequestBrief.Session.RsvpSession.Ipv4P2MpLspSession()
                                self.ipv4_p2mp_lsp_session.parent = self
                                self._children_name_map["ipv4_p2mp_lsp_session"] = "ipv4-p2mp-lsp-session"
                            return self.ipv4_p2mp_lsp_session

                        if (child_yang_name == "ipv4-uni-session"):
                            if (self.ipv4_uni_session is None):
                                self.ipv4_uni_session = RsvpStandby.RequestBriefs.RequestBrief.Session.RsvpSession.Ipv4UniSession()
                                self.ipv4_uni_session.parent = self
                                self._children_name_map["ipv4_uni_session"] = "ipv4-uni-session"
                            return self.ipv4_uni_session

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ipv4" or name == "ipv4-lsp-session" or name == "ipv4-p2mp-lsp-session" or name == "ipv4-uni-session" or name == "session-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "session-type"):
                            self.session_type = value
                            self.session_type.value_namespace = name_space
                            self.session_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (self.rsvp_session is not None and self.rsvp_session.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.rsvp_session is not None and self.rsvp_session.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "session" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/request-briefs/request-brief/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "rsvp-session"):
                        if (self.rsvp_session is None):
                            self.rsvp_session = RsvpStandby.RequestBriefs.RequestBrief.Session.RsvpSession()
                            self.rsvp_session.parent = self
                            self._children_name_map["rsvp_session"] = "rsvp-session"
                        return self.rsvp_session

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "rsvp-session"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class S2LSubLsp(Entity):
                """
                RSVP S2L Sub\-LSP information
                
                .. attribute:: s2l_destination_address
                
                	S2L Sub\-LSP Destination Address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.RequestBriefs.RequestBrief.S2LSubLsp, self).__init__()

                    self.yang_name = "s2l-sub-lsp"
                    self.yang_parent_name = "request-brief"

                    self.s2l_destination_address = YLeaf(YType.str, "s2l-destination-address")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("s2l_destination_address") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.RequestBriefs.RequestBrief.S2LSubLsp, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.RequestBriefs.RequestBrief.S2LSubLsp, self).__setattr__(name, value)

                def has_data(self):
                    return self.s2l_destination_address.is_set

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.s2l_destination_address.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "s2l-sub-lsp" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/request-briefs/request-brief/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.s2l_destination_address.is_set or self.s2l_destination_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.s2l_destination_address.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "s2l-destination-address"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "s2l-destination-address"):
                        self.s2l_destination_address = value
                        self.s2l_destination_address.value_namespace = name_space
                        self.s2l_destination_address.value_namespace_prefix = name_space_prefix


            class FlowSpec(Entity):
                """
                Flow Spec Information
                
                .. attribute:: flow_average_rate
                
                	The Flow Average Rate in bytes per second
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: byte/s
                
                .. attribute:: flow_max_burst
                
                	The Flow Maximum Burst
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: flow_max_unit
                
                	The Flow Maximum Unit
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: flow_min_unit
                
                	The Flow Minimum Unit
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: flow_peak_rate
                
                	The Flow Peak Rate in bytes per second
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: byte/s
                
                .. attribute:: flow_qos
                
                	The Flow Quality of Service
                	**type**\:   :py:class:`RsvpMgmtQosServiceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtQosServiceEnum>`
                
                .. attribute:: flow_requested_rate
                
                	The Flow Requested Rate in bytes per second
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: byte/s
                
                .. attribute:: flow_slack
                
                	The Flow Slack
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.RequestBriefs.RequestBrief.FlowSpec, self).__init__()

                    self.yang_name = "flow-spec"
                    self.yang_parent_name = "request-brief"

                    self.flow_average_rate = YLeaf(YType.uint64, "flow-average-rate")

                    self.flow_max_burst = YLeaf(YType.uint64, "flow-max-burst")

                    self.flow_max_unit = YLeaf(YType.uint32, "flow-max-unit")

                    self.flow_min_unit = YLeaf(YType.uint32, "flow-min-unit")

                    self.flow_peak_rate = YLeaf(YType.uint64, "flow-peak-rate")

                    self.flow_qos = YLeaf(YType.enumeration, "flow-qos")

                    self.flow_requested_rate = YLeaf(YType.uint64, "flow-requested-rate")

                    self.flow_slack = YLeaf(YType.uint32, "flow-slack")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("flow_average_rate",
                                    "flow_max_burst",
                                    "flow_max_unit",
                                    "flow_min_unit",
                                    "flow_peak_rate",
                                    "flow_qos",
                                    "flow_requested_rate",
                                    "flow_slack") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.RequestBriefs.RequestBrief.FlowSpec, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.RequestBriefs.RequestBrief.FlowSpec, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.flow_average_rate.is_set or
                        self.flow_max_burst.is_set or
                        self.flow_max_unit.is_set or
                        self.flow_min_unit.is_set or
                        self.flow_peak_rate.is_set or
                        self.flow_qos.is_set or
                        self.flow_requested_rate.is_set or
                        self.flow_slack.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.flow_average_rate.yfilter != YFilter.not_set or
                        self.flow_max_burst.yfilter != YFilter.not_set or
                        self.flow_max_unit.yfilter != YFilter.not_set or
                        self.flow_min_unit.yfilter != YFilter.not_set or
                        self.flow_peak_rate.yfilter != YFilter.not_set or
                        self.flow_qos.yfilter != YFilter.not_set or
                        self.flow_requested_rate.yfilter != YFilter.not_set or
                        self.flow_slack.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "flow-spec" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/request-briefs/request-brief/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.flow_average_rate.is_set or self.flow_average_rate.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_average_rate.get_name_leafdata())
                    if (self.flow_max_burst.is_set or self.flow_max_burst.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_max_burst.get_name_leafdata())
                    if (self.flow_max_unit.is_set or self.flow_max_unit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_max_unit.get_name_leafdata())
                    if (self.flow_min_unit.is_set or self.flow_min_unit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_min_unit.get_name_leafdata())
                    if (self.flow_peak_rate.is_set or self.flow_peak_rate.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_peak_rate.get_name_leafdata())
                    if (self.flow_qos.is_set or self.flow_qos.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_qos.get_name_leafdata())
                    if (self.flow_requested_rate.is_set or self.flow_requested_rate.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_requested_rate.get_name_leafdata())
                    if (self.flow_slack.is_set or self.flow_slack.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_slack.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "flow-average-rate" or name == "flow-max-burst" or name == "flow-max-unit" or name == "flow-min-unit" or name == "flow-peak-rate" or name == "flow-qos" or name == "flow-requested-rate" or name == "flow-slack"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "flow-average-rate"):
                        self.flow_average_rate = value
                        self.flow_average_rate.value_namespace = name_space
                        self.flow_average_rate.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-max-burst"):
                        self.flow_max_burst = value
                        self.flow_max_burst.value_namespace = name_space
                        self.flow_max_burst.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-max-unit"):
                        self.flow_max_unit = value
                        self.flow_max_unit.value_namespace = name_space
                        self.flow_max_unit.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-min-unit"):
                        self.flow_min_unit = value
                        self.flow_min_unit.value_namespace = name_space
                        self.flow_min_unit.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-peak-rate"):
                        self.flow_peak_rate = value
                        self.flow_peak_rate.value_namespace = name_space
                        self.flow_peak_rate.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-qos"):
                        self.flow_qos = value
                        self.flow_qos.value_namespace = name_space
                        self.flow_qos.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-requested-rate"):
                        self.flow_requested_rate = value
                        self.flow_requested_rate.value_namespace = name_space
                        self.flow_requested_rate.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-slack"):
                        self.flow_slack = value
                        self.flow_slack.value_namespace = name_space
                        self.flow_slack.value_namespace_prefix = name_space_prefix


            class GenericFlowSpec(Entity):
                """
                Generic Flow Spec Information
                
                .. attribute:: flow_spec_type
                
                	FlowSpecType
                	**type**\:   :py:class:`RsvpMgmtFlowSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtFlowSpec>`
                
                .. attribute:: g709otn_flow_spec
                
                	G709 OTN FlowSpec
                	**type**\:   :py:class:`G709OtnFlowSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RequestBriefs.RequestBrief.GenericFlowSpec.G709OtnFlowSpec>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.RequestBriefs.RequestBrief.GenericFlowSpec, self).__init__()

                    self.yang_name = "generic-flow-spec"
                    self.yang_parent_name = "request-brief"

                    self.flow_spec_type = YLeaf(YType.enumeration, "flow-spec-type")

                    self.g709otn_flow_spec = RsvpStandby.RequestBriefs.RequestBrief.GenericFlowSpec.G709OtnFlowSpec()
                    self.g709otn_flow_spec.parent = self
                    self._children_name_map["g709otn_flow_spec"] = "g709otn-flow-spec"
                    self._children_yang_names.add("g709otn-flow-spec")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("flow_spec_type") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.RequestBriefs.RequestBrief.GenericFlowSpec, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.RequestBriefs.RequestBrief.GenericFlowSpec, self).__setattr__(name, value)


                class G709OtnFlowSpec(Entity):
                    """
                    G709 OTN FlowSpec
                    
                    .. attribute:: flow_bit_rate
                    
                    	G709 OTN Flow Bit Rate
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: flow_multiplier
                    
                    	G709 OTN Flow Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: flow_nvc
                    
                    	G709 OTN Flow NVC
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: flow_signal_type
                    
                    	G709 OTN Flow Signal Type (Refer G709 v3)
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.RequestBriefs.RequestBrief.GenericFlowSpec.G709OtnFlowSpec, self).__init__()

                        self.yang_name = "g709otn-flow-spec"
                        self.yang_parent_name = "generic-flow-spec"

                        self.flow_bit_rate = YLeaf(YType.uint64, "flow-bit-rate")

                        self.flow_multiplier = YLeaf(YType.uint16, "flow-multiplier")

                        self.flow_nvc = YLeaf(YType.uint16, "flow-nvc")

                        self.flow_signal_type = YLeaf(YType.uint8, "flow-signal-type")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("flow_bit_rate",
                                        "flow_multiplier",
                                        "flow_nvc",
                                        "flow_signal_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.RequestBriefs.RequestBrief.GenericFlowSpec.G709OtnFlowSpec, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.RequestBriefs.RequestBrief.GenericFlowSpec.G709OtnFlowSpec, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.flow_bit_rate.is_set or
                            self.flow_multiplier.is_set or
                            self.flow_nvc.is_set or
                            self.flow_signal_type.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.flow_bit_rate.yfilter != YFilter.not_set or
                            self.flow_multiplier.yfilter != YFilter.not_set or
                            self.flow_nvc.yfilter != YFilter.not_set or
                            self.flow_signal_type.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "g709otn-flow-spec" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/request-briefs/request-brief/generic-flow-spec/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.flow_bit_rate.is_set or self.flow_bit_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.flow_bit_rate.get_name_leafdata())
                        if (self.flow_multiplier.is_set or self.flow_multiplier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.flow_multiplier.get_name_leafdata())
                        if (self.flow_nvc.is_set or self.flow_nvc.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.flow_nvc.get_name_leafdata())
                        if (self.flow_signal_type.is_set or self.flow_signal_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.flow_signal_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "flow-bit-rate" or name == "flow-multiplier" or name == "flow-nvc" or name == "flow-signal-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "flow-bit-rate"):
                            self.flow_bit_rate = value
                            self.flow_bit_rate.value_namespace = name_space
                            self.flow_bit_rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "flow-multiplier"):
                            self.flow_multiplier = value
                            self.flow_multiplier.value_namespace = name_space
                            self.flow_multiplier.value_namespace_prefix = name_space_prefix
                        if(value_path == "flow-nvc"):
                            self.flow_nvc = value
                            self.flow_nvc.value_namespace = name_space
                            self.flow_nvc.value_namespace_prefix = name_space_prefix
                        if(value_path == "flow-signal-type"):
                            self.flow_signal_type = value
                            self.flow_signal_type.value_namespace = name_space
                            self.flow_signal_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.flow_spec_type.is_set or
                        (self.g709otn_flow_spec is not None and self.g709otn_flow_spec.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.flow_spec_type.yfilter != YFilter.not_set or
                        (self.g709otn_flow_spec is not None and self.g709otn_flow_spec.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "generic-flow-spec" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/request-briefs/request-brief/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.flow_spec_type.is_set or self.flow_spec_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_spec_type.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "g709otn-flow-spec"):
                        if (self.g709otn_flow_spec is None):
                            self.g709otn_flow_spec = RsvpStandby.RequestBriefs.RequestBrief.GenericFlowSpec.G709OtnFlowSpec()
                            self.g709otn_flow_spec.parent = self
                            self._children_name_map["g709otn_flow_spec"] = "g709otn-flow-spec"
                        return self.g709otn_flow_spec

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "g709otn-flow-spec" or name == "flow-spec-type"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "flow-spec-type"):
                        self.flow_spec_type = value
                        self.flow_spec_type.value_namespace = name_space
                        self.flow_spec_type.value_namespace_prefix = name_space_prefix


            class Filter(Entity):
                """
                RSVP Filter
                
                .. attribute:: rsvp_filter
                
                	RSVP Filter
                	**type**\:   :py:class:`RsvpFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RequestBriefs.RequestBrief.Filter.RsvpFilter>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.RequestBriefs.RequestBrief.Filter, self).__init__()

                    self.yang_name = "filter"
                    self.yang_parent_name = "request-brief"

                    self.rsvp_filter = RsvpStandby.RequestBriefs.RequestBrief.Filter.RsvpFilter()
                    self.rsvp_filter.parent = self
                    self._children_name_map["rsvp_filter"] = "rsvp-filter"
                    self._children_yang_names.add("rsvp-filter")


                class RsvpFilter(Entity):
                    """
                    RSVP Filter
                    
                    .. attribute:: filter_type
                    
                    	FilterType
                    	**type**\:   :py:class:`RsvpMgmtFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtFilter>`
                    
                    .. attribute:: p2mp_ipv4_session
                    
                    	IPv4 P2MP LSP FilterSpec
                    	**type**\:   :py:class:`P2MpIpv4Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RequestBriefs.RequestBrief.Filter.RsvpFilter.P2MpIpv4Session>`
                    
                    .. attribute:: udp_ipv4_session
                    
                    	UDP IPV4 FilterSpec
                    	**type**\:   :py:class:`UdpIpv4Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RequestBriefs.RequestBrief.Filter.RsvpFilter.UdpIpv4Session>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.RequestBriefs.RequestBrief.Filter.RsvpFilter, self).__init__()

                        self.yang_name = "rsvp-filter"
                        self.yang_parent_name = "filter"

                        self.filter_type = YLeaf(YType.enumeration, "filter-type")

                        self.p2mp_ipv4_session = RsvpStandby.RequestBriefs.RequestBrief.Filter.RsvpFilter.P2MpIpv4Session()
                        self.p2mp_ipv4_session.parent = self
                        self._children_name_map["p2mp_ipv4_session"] = "p2mp-ipv4-session"
                        self._children_yang_names.add("p2mp-ipv4-session")

                        self.udp_ipv4_session = RsvpStandby.RequestBriefs.RequestBrief.Filter.RsvpFilter.UdpIpv4Session()
                        self.udp_ipv4_session.parent = self
                        self._children_name_map["udp_ipv4_session"] = "udp-ipv4-session"
                        self._children_yang_names.add("udp-ipv4-session")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("filter_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.RequestBriefs.RequestBrief.Filter.RsvpFilter, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.RequestBriefs.RequestBrief.Filter.RsvpFilter, self).__setattr__(name, value)


                    class UdpIpv4Session(Entity):
                        """
                        UDP IPV4 FilterSpec
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source_port
                        
                        	Source Port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.RequestBriefs.RequestBrief.Filter.RsvpFilter.UdpIpv4Session, self).__init__()

                            self.yang_name = "udp-ipv4-session"
                            self.yang_parent_name = "rsvp-filter"

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.source_port = YLeaf(YType.uint16, "source-port")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("source_address",
                                            "source_port") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.RequestBriefs.RequestBrief.Filter.RsvpFilter.UdpIpv4Session, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.RequestBriefs.RequestBrief.Filter.RsvpFilter.UdpIpv4Session, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.source_address.is_set or
                                self.source_port.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                self.source_port.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "udp-ipv4-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/request-briefs/request-brief/filter/rsvp-filter/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())
                            if (self.source_port.is_set or self.source_port.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_port.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "source-address" or name == "source-port"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-port"):
                                self.source_port = value
                                self.source_port.value_namespace = name_space
                                self.source_port.value_namespace_prefix = name_space_prefix


                    class P2MpIpv4Session(Entity):
                        """
                        IPv4 P2MP LSP FilterSpec
                        
                        .. attribute:: p2mp_sub_group_origin
                        
                        	Point to Multipoint SubGroup Origin
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source_port
                        
                        	Source Port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: sub_group_id
                        
                        	Point to Multipoint Subgroup ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.RequestBriefs.RequestBrief.Filter.RsvpFilter.P2MpIpv4Session, self).__init__()

                            self.yang_name = "p2mp-ipv4-session"
                            self.yang_parent_name = "rsvp-filter"

                            self.p2mp_sub_group_origin = YLeaf(YType.str, "p2mp-sub-group-origin")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.source_port = YLeaf(YType.uint16, "source-port")

                            self.sub_group_id = YLeaf(YType.uint16, "sub-group-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("p2mp_sub_group_origin",
                                            "source_address",
                                            "source_port",
                                            "sub_group_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.RequestBriefs.RequestBrief.Filter.RsvpFilter.P2MpIpv4Session, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.RequestBriefs.RequestBrief.Filter.RsvpFilter.P2MpIpv4Session, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.p2mp_sub_group_origin.is_set or
                                self.source_address.is_set or
                                self.source_port.is_set or
                                self.sub_group_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.p2mp_sub_group_origin.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                self.source_port.yfilter != YFilter.not_set or
                                self.sub_group_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "p2mp-ipv4-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/request-briefs/request-brief/filter/rsvp-filter/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.p2mp_sub_group_origin.is_set or self.p2mp_sub_group_origin.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.p2mp_sub_group_origin.get_name_leafdata())
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())
                            if (self.source_port.is_set or self.source_port.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_port.get_name_leafdata())
                            if (self.sub_group_id.is_set or self.sub_group_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sub_group_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "p2mp-sub-group-origin" or name == "source-address" or name == "source-port" or name == "sub-group-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "p2mp-sub-group-origin"):
                                self.p2mp_sub_group_origin = value
                                self.p2mp_sub_group_origin.value_namespace = name_space
                                self.p2mp_sub_group_origin.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-port"):
                                self.source_port = value
                                self.source_port.value_namespace = name_space
                                self.source_port.value_namespace_prefix = name_space_prefix
                            if(value_path == "sub-group-id"):
                                self.sub_group_id = value
                                self.sub_group_id.value_namespace = name_space
                                self.sub_group_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.filter_type.is_set or
                            (self.p2mp_ipv4_session is not None and self.p2mp_ipv4_session.has_data()) or
                            (self.udp_ipv4_session is not None and self.udp_ipv4_session.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.filter_type.yfilter != YFilter.not_set or
                            (self.p2mp_ipv4_session is not None and self.p2mp_ipv4_session.has_operation()) or
                            (self.udp_ipv4_session is not None and self.udp_ipv4_session.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rsvp-filter" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/request-briefs/request-brief/filter/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.filter_type.is_set or self.filter_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.filter_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "p2mp-ipv4-session"):
                            if (self.p2mp_ipv4_session is None):
                                self.p2mp_ipv4_session = RsvpStandby.RequestBriefs.RequestBrief.Filter.RsvpFilter.P2MpIpv4Session()
                                self.p2mp_ipv4_session.parent = self
                                self._children_name_map["p2mp_ipv4_session"] = "p2mp-ipv4-session"
                            return self.p2mp_ipv4_session

                        if (child_yang_name == "udp-ipv4-session"):
                            if (self.udp_ipv4_session is None):
                                self.udp_ipv4_session = RsvpStandby.RequestBriefs.RequestBrief.Filter.RsvpFilter.UdpIpv4Session()
                                self.udp_ipv4_session.parent = self
                                self._children_name_map["udp_ipv4_session"] = "udp-ipv4-session"
                            return self.udp_ipv4_session

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "p2mp-ipv4-session" or name == "udp-ipv4-session" or name == "filter-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "filter-type"):
                            self.filter_type = value
                            self.filter_type.value_namespace = name_space
                            self.filter_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (self.rsvp_filter is not None and self.rsvp_filter.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.rsvp_filter is not None and self.rsvp_filter.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "filter" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/request-briefs/request-brief/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "rsvp-filter"):
                        if (self.rsvp_filter is None):
                            self.rsvp_filter = RsvpStandby.RequestBriefs.RequestBrief.Filter.RsvpFilter()
                            self.rsvp_filter.parent = self
                            self._children_name_map["rsvp_filter"] = "rsvp-filter"
                        return self.rsvp_filter

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "rsvp-filter"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Style(Entity):
                """
                RSVP Style
                
                .. attribute:: reservation_type
                
                	The Reservation Type\: WF, SE or FF
                	**type**\:   :py:class:`RsvpMgmtReservationTypeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtReservationTypeEnum>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.RequestBriefs.RequestBrief.Style, self).__init__()

                    self.yang_name = "style"
                    self.yang_parent_name = "request-brief"

                    self.reservation_type = YLeaf(YType.enumeration, "reservation-type")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("reservation_type") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.RequestBriefs.RequestBrief.Style, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.RequestBriefs.RequestBrief.Style, self).__setattr__(name, value)

                def has_data(self):
                    return self.reservation_type.is_set

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.reservation_type.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "style" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/request-briefs/request-brief/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.reservation_type.is_set or self.reservation_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reservation_type.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "reservation-type"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "reservation-type"):
                        self.reservation_type = value
                        self.reservation_type.value_namespace = name_space
                        self.reservation_type.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.destination_address.is_set or
                    self.destination_port.is_set or
                    self.extended_tunnel_id.is_set or
                    self.output_interface.is_set or
                    self.p2mp_id.is_set or
                    self.protocol.is_set or
                    self.session_type.is_set or
                    self.source_address.is_set or
                    self.source_port.is_set or
                    self.sub_group_id.is_set or
                    self.sub_group_origin.is_set or
                    self.vrf_name.is_set or
                    (self.filter is not None and self.filter.has_data()) or
                    (self.flow_spec is not None and self.flow_spec.has_data()) or
                    (self.generic_flow_spec is not None and self.generic_flow_spec.has_data()) or
                    (self.s2l_sub_lsp is not None and self.s2l_sub_lsp.has_data()) or
                    (self.session is not None and self.session.has_data()) or
                    (self.style is not None and self.style.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.destination_address.yfilter != YFilter.not_set or
                    self.destination_port.yfilter != YFilter.not_set or
                    self.extended_tunnel_id.yfilter != YFilter.not_set or
                    self.output_interface.yfilter != YFilter.not_set or
                    self.p2mp_id.yfilter != YFilter.not_set or
                    self.protocol.yfilter != YFilter.not_set or
                    self.session_type.yfilter != YFilter.not_set or
                    self.source_address.yfilter != YFilter.not_set or
                    self.source_port.yfilter != YFilter.not_set or
                    self.sub_group_id.yfilter != YFilter.not_set or
                    self.sub_group_origin.yfilter != YFilter.not_set or
                    self.vrf_name.yfilter != YFilter.not_set or
                    (self.filter is not None and self.filter.has_operation()) or
                    (self.flow_spec is not None and self.flow_spec.has_operation()) or
                    (self.generic_flow_spec is not None and self.generic_flow_spec.has_operation()) or
                    (self.s2l_sub_lsp is not None and self.s2l_sub_lsp.has_operation()) or
                    (self.session is not None and self.session.has_operation()) or
                    (self.style is not None and self.style.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "request-brief" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/request-briefs/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_address.get_name_leafdata())
                if (self.destination_port.is_set or self.destination_port.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_port.get_name_leafdata())
                if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                if (self.output_interface.is_set or self.output_interface.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.output_interface.get_name_leafdata())
                if (self.p2mp_id.is_set or self.p2mp_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.p2mp_id.get_name_leafdata())
                if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.protocol.get_name_leafdata())
                if (self.session_type.is_set or self.session_type.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.session_type.get_name_leafdata())
                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_address.get_name_leafdata())
                if (self.source_port.is_set or self.source_port.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_port.get_name_leafdata())
                if (self.sub_group_id.is_set or self.sub_group_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.sub_group_id.get_name_leafdata())
                if (self.sub_group_origin.is_set or self.sub_group_origin.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.sub_group_origin.get_name_leafdata())
                if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.vrf_name.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "filter"):
                    if (self.filter is None):
                        self.filter = RsvpStandby.RequestBriefs.RequestBrief.Filter()
                        self.filter.parent = self
                        self._children_name_map["filter"] = "filter"
                    return self.filter

                if (child_yang_name == "flow-spec"):
                    if (self.flow_spec is None):
                        self.flow_spec = RsvpStandby.RequestBriefs.RequestBrief.FlowSpec()
                        self.flow_spec.parent = self
                        self._children_name_map["flow_spec"] = "flow-spec"
                    return self.flow_spec

                if (child_yang_name == "generic-flow-spec"):
                    if (self.generic_flow_spec is None):
                        self.generic_flow_spec = RsvpStandby.RequestBriefs.RequestBrief.GenericFlowSpec()
                        self.generic_flow_spec.parent = self
                        self._children_name_map["generic_flow_spec"] = "generic-flow-spec"
                    return self.generic_flow_spec

                if (child_yang_name == "s2l-sub-lsp"):
                    if (self.s2l_sub_lsp is None):
                        self.s2l_sub_lsp = RsvpStandby.RequestBriefs.RequestBrief.S2LSubLsp()
                        self.s2l_sub_lsp.parent = self
                        self._children_name_map["s2l_sub_lsp"] = "s2l-sub-lsp"
                    return self.s2l_sub_lsp

                if (child_yang_name == "session"):
                    if (self.session is None):
                        self.session = RsvpStandby.RequestBriefs.RequestBrief.Session()
                        self.session.parent = self
                        self._children_name_map["session"] = "session"
                    return self.session

                if (child_yang_name == "style"):
                    if (self.style is None):
                        self.style = RsvpStandby.RequestBriefs.RequestBrief.Style()
                        self.style.parent = self
                        self._children_name_map["style"] = "style"
                    return self.style

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "filter" or name == "flow-spec" or name == "generic-flow-spec" or name == "s2l-sub-lsp" or name == "session" or name == "style" or name == "destination-address" or name == "destination-port" or name == "extended-tunnel-id" or name == "output-interface" or name == "p2mp-id" or name == "protocol" or name == "session-type" or name == "source-address" or name == "source-port" or name == "sub-group-id" or name == "sub-group-origin" or name == "vrf-name"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "destination-address"):
                    self.destination_address = value
                    self.destination_address.value_namespace = name_space
                    self.destination_address.value_namespace_prefix = name_space_prefix
                if(value_path == "destination-port"):
                    self.destination_port = value
                    self.destination_port.value_namespace = name_space
                    self.destination_port.value_namespace_prefix = name_space_prefix
                if(value_path == "extended-tunnel-id"):
                    self.extended_tunnel_id = value
                    self.extended_tunnel_id.value_namespace = name_space
                    self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                if(value_path == "output-interface"):
                    self.output_interface = value
                    self.output_interface.value_namespace = name_space
                    self.output_interface.value_namespace_prefix = name_space_prefix
                if(value_path == "p2mp-id"):
                    self.p2mp_id = value
                    self.p2mp_id.value_namespace = name_space
                    self.p2mp_id.value_namespace_prefix = name_space_prefix
                if(value_path == "protocol"):
                    self.protocol = value
                    self.protocol.value_namespace = name_space
                    self.protocol.value_namespace_prefix = name_space_prefix
                if(value_path == "session-type"):
                    self.session_type = value
                    self.session_type.value_namespace = name_space
                    self.session_type.value_namespace_prefix = name_space_prefix
                if(value_path == "source-address"):
                    self.source_address = value
                    self.source_address.value_namespace = name_space
                    self.source_address.value_namespace_prefix = name_space_prefix
                if(value_path == "source-port"):
                    self.source_port = value
                    self.source_port.value_namespace = name_space
                    self.source_port.value_namespace_prefix = name_space_prefix
                if(value_path == "sub-group-id"):
                    self.sub_group_id = value
                    self.sub_group_id.value_namespace = name_space
                    self.sub_group_id.value_namespace_prefix = name_space_prefix
                if(value_path == "sub-group-origin"):
                    self.sub_group_origin = value
                    self.sub_group_origin.value_namespace = name_space
                    self.sub_group_origin.value_namespace_prefix = name_space_prefix
                if(value_path == "vrf-name"):
                    self.vrf_name = value
                    self.vrf_name.value_namespace = name_space
                    self.vrf_name.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.request_brief:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.request_brief:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "request-briefs" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "request-brief"):
                for c in self.request_brief:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = RsvpStandby.RequestBriefs.RequestBrief()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.request_brief.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "request-brief"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class RequestDetails(Entity):
        """
        Table of detail info about requests
        
        .. attribute:: request_detail
        
        	Detail info for a request
        	**type**\: list of    :py:class:`RequestDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RequestDetails.RequestDetail>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(RsvpStandby.RequestDetails, self).__init__()

            self.yang_name = "request-details"
            self.yang_parent_name = "rsvp-standby"

            self.request_detail = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(RsvpStandby.RequestDetails, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(RsvpStandby.RequestDetails, self).__setattr__(name, value)


        class RequestDetail(Entity):
            """
            Detail info for a request
            
            .. attribute:: destination_address
            
            	Destination Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: destination_port
            
            	Destination Port
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: extended_tunnel_id
            
            	Extended Tunnel ID
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: filter
            
            	RSVP Filter
            	**type**\:   :py:class:`Filter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RequestDetails.RequestDetail.Filter>`
            
            .. attribute:: flow_spec
            
            	Flow Spec Information
            	**type**\:   :py:class:`FlowSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RequestDetails.RequestDetail.FlowSpec>`
            
            .. attribute:: generic_flow_spec
            
            	Generic Flow Spec Information
            	**type**\:   :py:class:`GenericFlowSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RequestDetails.RequestDetail.GenericFlowSpec>`
            
            .. attribute:: header
            
            	RSVP Header Information
            	**type**\:   :py:class:`Header <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RequestDetails.RequestDetail.Header>`
            
            .. attribute:: hop
            
            	Hop Infomation
            	**type**\:   :py:class:`Hop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RequestDetails.RequestDetail.Hop>`
            
            .. attribute:: output_interface
            
            	output Interface
            	**type**\:  str
            
            .. attribute:: p2mp_id
            
            	P2MP ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: policy_flags
            
            	RSVP Policy Flags
            	**type**\:   :py:class:`PolicyFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RequestDetails.RequestDetail.PolicyFlags>`
            
            .. attribute:: policy_query_flags
            
            	RSVP Query Flags
            	**type**\:   :py:class:`PolicyQueryFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RequestDetails.RequestDetail.PolicyQueryFlags>`
            
            .. attribute:: policy_sources
            
            	RSVP Policy Sources
            	**type**\:   :py:class:`PolicySources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RequestDetails.RequestDetail.PolicySources>`
            
            .. attribute:: protocol
            
            	Protocol
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: psb_key
            
            	List of RSB keys
            	**type**\: list of    :py:class:`PsbKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RequestDetails.RequestDetail.PsbKey>`
            
            .. attribute:: req_flags
            
            	Request flags
            	**type**\:   :py:class:`ReqFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RequestDetails.RequestDetail.ReqFlags>`
            
            .. attribute:: rsb_key
            
            	List of RSB keys
            	**type**\: list of    :py:class:`RsbKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RequestDetails.RequestDetail.RsbKey>`
            
            .. attribute:: s2l_sub_lsp
            
            	RSVP S2L Sub\-LSP information
            	**type**\:   :py:class:`S2LSubLsp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RequestDetails.RequestDetail.S2LSubLsp>`
            
            .. attribute:: session
            
            	RSVP Session Information
            	**type**\:   :py:class:`Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RequestDetails.RequestDetail.Session>`
            
            .. attribute:: session_type
            
            	Session Type
            	**type**\:   :py:class:`RsvpSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpSession>`
            
            .. attribute:: source_address
            
            	Source Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: source_port
            
            	Source Port
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: style
            
            	RSVP Style
            	**type**\:   :py:class:`Style <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RequestDetails.RequestDetail.Style>`
            
            .. attribute:: sub_group_id
            
            	Subgroup ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: sub_group_origin
            
            	Subgroup Origin
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: vrf_name
            
            	VRF Name
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(RsvpStandby.RequestDetails.RequestDetail, self).__init__()

                self.yang_name = "request-detail"
                self.yang_parent_name = "request-details"

                self.destination_address = YLeaf(YType.str, "destination-address")

                self.destination_port = YLeaf(YType.int32, "destination-port")

                self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                self.output_interface = YLeaf(YType.str, "output-interface")

                self.p2mp_id = YLeaf(YType.int32, "p2mp-id")

                self.protocol = YLeaf(YType.int32, "protocol")

                self.session_type = YLeaf(YType.enumeration, "session-type")

                self.source_address = YLeaf(YType.str, "source-address")

                self.source_port = YLeaf(YType.int32, "source-port")

                self.sub_group_id = YLeaf(YType.int32, "sub-group-id")

                self.sub_group_origin = YLeaf(YType.str, "sub-group-origin")

                self.vrf_name = YLeaf(YType.str, "vrf-name")

                self.filter = RsvpStandby.RequestDetails.RequestDetail.Filter()
                self.filter.parent = self
                self._children_name_map["filter"] = "filter"
                self._children_yang_names.add("filter")

                self.flow_spec = RsvpStandby.RequestDetails.RequestDetail.FlowSpec()
                self.flow_spec.parent = self
                self._children_name_map["flow_spec"] = "flow-spec"
                self._children_yang_names.add("flow-spec")

                self.generic_flow_spec = RsvpStandby.RequestDetails.RequestDetail.GenericFlowSpec()
                self.generic_flow_spec.parent = self
                self._children_name_map["generic_flow_spec"] = "generic-flow-spec"
                self._children_yang_names.add("generic-flow-spec")

                self.header = RsvpStandby.RequestDetails.RequestDetail.Header()
                self.header.parent = self
                self._children_name_map["header"] = "header"
                self._children_yang_names.add("header")

                self.hop = RsvpStandby.RequestDetails.RequestDetail.Hop()
                self.hop.parent = self
                self._children_name_map["hop"] = "hop"
                self._children_yang_names.add("hop")

                self.policy_flags = RsvpStandby.RequestDetails.RequestDetail.PolicyFlags()
                self.policy_flags.parent = self
                self._children_name_map["policy_flags"] = "policy-flags"
                self._children_yang_names.add("policy-flags")

                self.policy_query_flags = RsvpStandby.RequestDetails.RequestDetail.PolicyQueryFlags()
                self.policy_query_flags.parent = self
                self._children_name_map["policy_query_flags"] = "policy-query-flags"
                self._children_yang_names.add("policy-query-flags")

                self.policy_sources = RsvpStandby.RequestDetails.RequestDetail.PolicySources()
                self.policy_sources.parent = self
                self._children_name_map["policy_sources"] = "policy-sources"
                self._children_yang_names.add("policy-sources")

                self.req_flags = RsvpStandby.RequestDetails.RequestDetail.ReqFlags()
                self.req_flags.parent = self
                self._children_name_map["req_flags"] = "req-flags"
                self._children_yang_names.add("req-flags")

                self.s2l_sub_lsp = RsvpStandby.RequestDetails.RequestDetail.S2LSubLsp()
                self.s2l_sub_lsp.parent = self
                self._children_name_map["s2l_sub_lsp"] = "s2l-sub-lsp"
                self._children_yang_names.add("s2l-sub-lsp")

                self.session = RsvpStandby.RequestDetails.RequestDetail.Session()
                self.session.parent = self
                self._children_name_map["session"] = "session"
                self._children_yang_names.add("session")

                self.style = RsvpStandby.RequestDetails.RequestDetail.Style()
                self.style.parent = self
                self._children_name_map["style"] = "style"
                self._children_yang_names.add("style")

                self.psb_key = YList(self)
                self.rsb_key = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("destination_address",
                                "destination_port",
                                "extended_tunnel_id",
                                "output_interface",
                                "p2mp_id",
                                "protocol",
                                "session_type",
                                "source_address",
                                "source_port",
                                "sub_group_id",
                                "sub_group_origin",
                                "vrf_name") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(RsvpStandby.RequestDetails.RequestDetail, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(RsvpStandby.RequestDetails.RequestDetail, self).__setattr__(name, value)


            class Session(Entity):
                """
                RSVP Session Information
                
                .. attribute:: rsvp_session
                
                	RSVP Session
                	**type**\:   :py:class:`RsvpSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RequestDetails.RequestDetail.Session.RsvpSession>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.RequestDetails.RequestDetail.Session, self).__init__()

                    self.yang_name = "session"
                    self.yang_parent_name = "request-detail"

                    self.rsvp_session = RsvpStandby.RequestDetails.RequestDetail.Session.RsvpSession()
                    self.rsvp_session.parent = self
                    self._children_name_map["rsvp_session"] = "rsvp-session"
                    self._children_yang_names.add("rsvp-session")


                class RsvpSession(Entity):
                    """
                    RSVP Session
                    
                    .. attribute:: ipv4
                    
                    	UDP IPv4 session
                    	**type**\:   :py:class:`Ipv4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RequestDetails.RequestDetail.Session.RsvpSession.Ipv4>`
                    
                    .. attribute:: ipv4_lsp_session
                    
                    	IPv4 LSP session
                    	**type**\:   :py:class:`Ipv4LspSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RequestDetails.RequestDetail.Session.RsvpSession.Ipv4LspSession>`
                    
                    .. attribute:: ipv4_p2mp_lsp_session
                    
                    	IPv4 P2MP LSP session
                    	**type**\:   :py:class:`Ipv4P2MpLspSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RequestDetails.RequestDetail.Session.RsvpSession.Ipv4P2MpLspSession>`
                    
                    .. attribute:: ipv4_uni_session
                    
                    	IPv4 UNI session
                    	**type**\:   :py:class:`Ipv4UniSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RequestDetails.RequestDetail.Session.RsvpSession.Ipv4UniSession>`
                    
                    .. attribute:: session_type
                    
                    	SessionType
                    	**type**\:   :py:class:`RsvpMgmtSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtSession>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.RequestDetails.RequestDetail.Session.RsvpSession, self).__init__()

                        self.yang_name = "rsvp-session"
                        self.yang_parent_name = "session"

                        self.session_type = YLeaf(YType.enumeration, "session-type")

                        self.ipv4 = RsvpStandby.RequestDetails.RequestDetail.Session.RsvpSession.Ipv4()
                        self.ipv4.parent = self
                        self._children_name_map["ipv4"] = "ipv4"
                        self._children_yang_names.add("ipv4")

                        self.ipv4_lsp_session = RsvpStandby.RequestDetails.RequestDetail.Session.RsvpSession.Ipv4LspSession()
                        self.ipv4_lsp_session.parent = self
                        self._children_name_map["ipv4_lsp_session"] = "ipv4-lsp-session"
                        self._children_yang_names.add("ipv4-lsp-session")

                        self.ipv4_p2mp_lsp_session = RsvpStandby.RequestDetails.RequestDetail.Session.RsvpSession.Ipv4P2MpLspSession()
                        self.ipv4_p2mp_lsp_session.parent = self
                        self._children_name_map["ipv4_p2mp_lsp_session"] = "ipv4-p2mp-lsp-session"
                        self._children_yang_names.add("ipv4-p2mp-lsp-session")

                        self.ipv4_uni_session = RsvpStandby.RequestDetails.RequestDetail.Session.RsvpSession.Ipv4UniSession()
                        self.ipv4_uni_session.parent = self
                        self._children_name_map["ipv4_uni_session"] = "ipv4-uni-session"
                        self._children_yang_names.add("ipv4-uni-session")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("session_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.RequestDetails.RequestDetail.Session.RsvpSession, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.RequestDetails.RequestDetail.Session.RsvpSession, self).__setattr__(name, value)


                    class Ipv4(Entity):
                        """
                        UDP IPv4 session
                        
                        .. attribute:: destination_address
                        
                        	Destination address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: destination_port
                        
                        	The Session Destination Port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: protocol
                        
                        	Protocol type (originally defined in RFC 790, further values in subsequent RFCs)
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.RequestDetails.RequestDetail.Session.RsvpSession.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "rsvp-session"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.destination_port = YLeaf(YType.uint16, "destination-port")

                            self.protocol = YLeaf(YType.uint8, "protocol")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "destination_port",
                                            "protocol") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.RequestDetails.RequestDetail.Session.RsvpSession.Ipv4, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.RequestDetails.RequestDetail.Session.RsvpSession.Ipv4, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination_address.is_set or
                                self.destination_port.is_set or
                                self.protocol.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.destination_port.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/request-details/request-detail/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.destination_port.is_set or self.destination_port.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_port.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "destination-port" or name == "protocol"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "destination-port"):
                                self.destination_port = value
                                self.destination_port.value_namespace = name_space
                                self.destination_port.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix


                    class Ipv4LspSession(Entity):
                        """
                        IPv4 LSP session
                        
                        .. attribute:: destination_address
                        
                        	Destination address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: extended_tunnel_id
                        
                        	The Session Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: tunnel_id
                        
                        	The Session Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.RequestDetails.RequestDetail.Session.RsvpSession.Ipv4LspSession, self).__init__()

                            self.yang_name = "ipv4-lsp-session"
                            self.yang_parent_name = "rsvp-session"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                            self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "extended_tunnel_id",
                                            "tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.RequestDetails.RequestDetail.Session.RsvpSession.Ipv4LspSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.RequestDetails.RequestDetail.Session.RsvpSession.Ipv4LspSession, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination_address.is_set or
                                self.extended_tunnel_id.is_set or
                                self.tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.extended_tunnel_id.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-lsp-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/request-details/request-detail/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "extended-tunnel-id" or name == "tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "extended-tunnel-id"):
                                self.extended_tunnel_id = value
                                self.extended_tunnel_id.value_namespace = name_space
                                self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix


                    class Ipv4UniSession(Entity):
                        """
                        IPv4 UNI session
                        
                        .. attribute:: destination_address
                        
                        	Destination address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: extended_address
                        
                        	The Session Extended Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: tunnel_id
                        
                        	The Session Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.RequestDetails.RequestDetail.Session.RsvpSession.Ipv4UniSession, self).__init__()

                            self.yang_name = "ipv4-uni-session"
                            self.yang_parent_name = "rsvp-session"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.extended_address = YLeaf(YType.str, "extended-address")

                            self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "extended_address",
                                            "tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.RequestDetails.RequestDetail.Session.RsvpSession.Ipv4UniSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.RequestDetails.RequestDetail.Session.RsvpSession.Ipv4UniSession, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination_address.is_set or
                                self.extended_address.is_set or
                                self.tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.extended_address.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-uni-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/request-details/request-detail/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.extended_address.is_set or self.extended_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_address.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "extended-address" or name == "tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "extended-address"):
                                self.extended_address = value
                                self.extended_address.value_namespace = name_space
                                self.extended_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix


                    class Ipv4P2MpLspSession(Entity):
                        """
                        IPv4 P2MP LSP session
                        
                        .. attribute:: extended_tunnel_id
                        
                        	The Session Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: p2mp_id
                        
                        	The Point to Multipoint ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tunnel_id
                        
                        	The Session Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.RequestDetails.RequestDetail.Session.RsvpSession.Ipv4P2MpLspSession, self).__init__()

                            self.yang_name = "ipv4-p2mp-lsp-session"
                            self.yang_parent_name = "rsvp-session"

                            self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                            self.p2mp_id = YLeaf(YType.uint32, "p2mp-id")

                            self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("extended_tunnel_id",
                                            "p2mp_id",
                                            "tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.RequestDetails.RequestDetail.Session.RsvpSession.Ipv4P2MpLspSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.RequestDetails.RequestDetail.Session.RsvpSession.Ipv4P2MpLspSession, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.extended_tunnel_id.is_set or
                                self.p2mp_id.is_set or
                                self.tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.extended_tunnel_id.yfilter != YFilter.not_set or
                                self.p2mp_id.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-p2mp-lsp-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/request-details/request-detail/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                            if (self.p2mp_id.is_set or self.p2mp_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.p2mp_id.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "extended-tunnel-id" or name == "p2mp-id" or name == "tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "extended-tunnel-id"):
                                self.extended_tunnel_id = value
                                self.extended_tunnel_id.value_namespace = name_space
                                self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "p2mp-id"):
                                self.p2mp_id = value
                                self.p2mp_id.value_namespace = name_space
                                self.p2mp_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.session_type.is_set or
                            (self.ipv4 is not None and self.ipv4.has_data()) or
                            (self.ipv4_lsp_session is not None and self.ipv4_lsp_session.has_data()) or
                            (self.ipv4_p2mp_lsp_session is not None and self.ipv4_p2mp_lsp_session.has_data()) or
                            (self.ipv4_uni_session is not None and self.ipv4_uni_session.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.session_type.yfilter != YFilter.not_set or
                            (self.ipv4 is not None and self.ipv4.has_operation()) or
                            (self.ipv4_lsp_session is not None and self.ipv4_lsp_session.has_operation()) or
                            (self.ipv4_p2mp_lsp_session is not None and self.ipv4_p2mp_lsp_session.has_operation()) or
                            (self.ipv4_uni_session is not None and self.ipv4_uni_session.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rsvp-session" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/request-details/request-detail/session/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.session_type.is_set or self.session_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.session_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "ipv4"):
                            if (self.ipv4 is None):
                                self.ipv4 = RsvpStandby.RequestDetails.RequestDetail.Session.RsvpSession.Ipv4()
                                self.ipv4.parent = self
                                self._children_name_map["ipv4"] = "ipv4"
                            return self.ipv4

                        if (child_yang_name == "ipv4-lsp-session"):
                            if (self.ipv4_lsp_session is None):
                                self.ipv4_lsp_session = RsvpStandby.RequestDetails.RequestDetail.Session.RsvpSession.Ipv4LspSession()
                                self.ipv4_lsp_session.parent = self
                                self._children_name_map["ipv4_lsp_session"] = "ipv4-lsp-session"
                            return self.ipv4_lsp_session

                        if (child_yang_name == "ipv4-p2mp-lsp-session"):
                            if (self.ipv4_p2mp_lsp_session is None):
                                self.ipv4_p2mp_lsp_session = RsvpStandby.RequestDetails.RequestDetail.Session.RsvpSession.Ipv4P2MpLspSession()
                                self.ipv4_p2mp_lsp_session.parent = self
                                self._children_name_map["ipv4_p2mp_lsp_session"] = "ipv4-p2mp-lsp-session"
                            return self.ipv4_p2mp_lsp_session

                        if (child_yang_name == "ipv4-uni-session"):
                            if (self.ipv4_uni_session is None):
                                self.ipv4_uni_session = RsvpStandby.RequestDetails.RequestDetail.Session.RsvpSession.Ipv4UniSession()
                                self.ipv4_uni_session.parent = self
                                self._children_name_map["ipv4_uni_session"] = "ipv4-uni-session"
                            return self.ipv4_uni_session

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ipv4" or name == "ipv4-lsp-session" or name == "ipv4-p2mp-lsp-session" or name == "ipv4-uni-session" or name == "session-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "session-type"):
                            self.session_type = value
                            self.session_type.value_namespace = name_space
                            self.session_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (self.rsvp_session is not None and self.rsvp_session.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.rsvp_session is not None and self.rsvp_session.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "session" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/request-details/request-detail/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "rsvp-session"):
                        if (self.rsvp_session is None):
                            self.rsvp_session = RsvpStandby.RequestDetails.RequestDetail.Session.RsvpSession()
                            self.rsvp_session.parent = self
                            self._children_name_map["rsvp_session"] = "rsvp-session"
                        return self.rsvp_session

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "rsvp-session"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class S2LSubLsp(Entity):
                """
                RSVP S2L Sub\-LSP information
                
                .. attribute:: s2l_destination_address
                
                	S2L Sub\-LSP Destination Address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.RequestDetails.RequestDetail.S2LSubLsp, self).__init__()

                    self.yang_name = "s2l-sub-lsp"
                    self.yang_parent_name = "request-detail"

                    self.s2l_destination_address = YLeaf(YType.str, "s2l-destination-address")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("s2l_destination_address") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.RequestDetails.RequestDetail.S2LSubLsp, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.RequestDetails.RequestDetail.S2LSubLsp, self).__setattr__(name, value)

                def has_data(self):
                    return self.s2l_destination_address.is_set

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.s2l_destination_address.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "s2l-sub-lsp" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/request-details/request-detail/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.s2l_destination_address.is_set or self.s2l_destination_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.s2l_destination_address.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "s2l-destination-address"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "s2l-destination-address"):
                        self.s2l_destination_address = value
                        self.s2l_destination_address.value_namespace = name_space
                        self.s2l_destination_address.value_namespace_prefix = name_space_prefix


            class FlowSpec(Entity):
                """
                Flow Spec Information
                
                .. attribute:: flow_average_rate
                
                	The Flow Average Rate in bytes per second
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: byte/s
                
                .. attribute:: flow_max_burst
                
                	The Flow Maximum Burst
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: flow_max_unit
                
                	The Flow Maximum Unit
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: flow_min_unit
                
                	The Flow Minimum Unit
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: flow_peak_rate
                
                	The Flow Peak Rate in bytes per second
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: byte/s
                
                .. attribute:: flow_qos
                
                	The Flow Quality of Service
                	**type**\:   :py:class:`RsvpMgmtQosServiceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtQosServiceEnum>`
                
                .. attribute:: flow_requested_rate
                
                	The Flow Requested Rate in bytes per second
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: byte/s
                
                .. attribute:: flow_slack
                
                	The Flow Slack
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.RequestDetails.RequestDetail.FlowSpec, self).__init__()

                    self.yang_name = "flow-spec"
                    self.yang_parent_name = "request-detail"

                    self.flow_average_rate = YLeaf(YType.uint64, "flow-average-rate")

                    self.flow_max_burst = YLeaf(YType.uint64, "flow-max-burst")

                    self.flow_max_unit = YLeaf(YType.uint32, "flow-max-unit")

                    self.flow_min_unit = YLeaf(YType.uint32, "flow-min-unit")

                    self.flow_peak_rate = YLeaf(YType.uint64, "flow-peak-rate")

                    self.flow_qos = YLeaf(YType.enumeration, "flow-qos")

                    self.flow_requested_rate = YLeaf(YType.uint64, "flow-requested-rate")

                    self.flow_slack = YLeaf(YType.uint32, "flow-slack")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("flow_average_rate",
                                    "flow_max_burst",
                                    "flow_max_unit",
                                    "flow_min_unit",
                                    "flow_peak_rate",
                                    "flow_qos",
                                    "flow_requested_rate",
                                    "flow_slack") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.RequestDetails.RequestDetail.FlowSpec, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.RequestDetails.RequestDetail.FlowSpec, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.flow_average_rate.is_set or
                        self.flow_max_burst.is_set or
                        self.flow_max_unit.is_set or
                        self.flow_min_unit.is_set or
                        self.flow_peak_rate.is_set or
                        self.flow_qos.is_set or
                        self.flow_requested_rate.is_set or
                        self.flow_slack.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.flow_average_rate.yfilter != YFilter.not_set or
                        self.flow_max_burst.yfilter != YFilter.not_set or
                        self.flow_max_unit.yfilter != YFilter.not_set or
                        self.flow_min_unit.yfilter != YFilter.not_set or
                        self.flow_peak_rate.yfilter != YFilter.not_set or
                        self.flow_qos.yfilter != YFilter.not_set or
                        self.flow_requested_rate.yfilter != YFilter.not_set or
                        self.flow_slack.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "flow-spec" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/request-details/request-detail/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.flow_average_rate.is_set or self.flow_average_rate.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_average_rate.get_name_leafdata())
                    if (self.flow_max_burst.is_set or self.flow_max_burst.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_max_burst.get_name_leafdata())
                    if (self.flow_max_unit.is_set or self.flow_max_unit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_max_unit.get_name_leafdata())
                    if (self.flow_min_unit.is_set or self.flow_min_unit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_min_unit.get_name_leafdata())
                    if (self.flow_peak_rate.is_set or self.flow_peak_rate.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_peak_rate.get_name_leafdata())
                    if (self.flow_qos.is_set or self.flow_qos.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_qos.get_name_leafdata())
                    if (self.flow_requested_rate.is_set or self.flow_requested_rate.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_requested_rate.get_name_leafdata())
                    if (self.flow_slack.is_set or self.flow_slack.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_slack.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "flow-average-rate" or name == "flow-max-burst" or name == "flow-max-unit" or name == "flow-min-unit" or name == "flow-peak-rate" or name == "flow-qos" or name == "flow-requested-rate" or name == "flow-slack"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "flow-average-rate"):
                        self.flow_average_rate = value
                        self.flow_average_rate.value_namespace = name_space
                        self.flow_average_rate.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-max-burst"):
                        self.flow_max_burst = value
                        self.flow_max_burst.value_namespace = name_space
                        self.flow_max_burst.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-max-unit"):
                        self.flow_max_unit = value
                        self.flow_max_unit.value_namespace = name_space
                        self.flow_max_unit.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-min-unit"):
                        self.flow_min_unit = value
                        self.flow_min_unit.value_namespace = name_space
                        self.flow_min_unit.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-peak-rate"):
                        self.flow_peak_rate = value
                        self.flow_peak_rate.value_namespace = name_space
                        self.flow_peak_rate.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-qos"):
                        self.flow_qos = value
                        self.flow_qos.value_namespace = name_space
                        self.flow_qos.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-requested-rate"):
                        self.flow_requested_rate = value
                        self.flow_requested_rate.value_namespace = name_space
                        self.flow_requested_rate.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-slack"):
                        self.flow_slack = value
                        self.flow_slack.value_namespace = name_space
                        self.flow_slack.value_namespace_prefix = name_space_prefix


            class GenericFlowSpec(Entity):
                """
                Generic Flow Spec Information
                
                .. attribute:: flow_spec_type
                
                	FlowSpecType
                	**type**\:   :py:class:`RsvpMgmtFlowSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtFlowSpec>`
                
                .. attribute:: g709otn_flow_spec
                
                	G709 OTN FlowSpec
                	**type**\:   :py:class:`G709OtnFlowSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RequestDetails.RequestDetail.GenericFlowSpec.G709OtnFlowSpec>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.RequestDetails.RequestDetail.GenericFlowSpec, self).__init__()

                    self.yang_name = "generic-flow-spec"
                    self.yang_parent_name = "request-detail"

                    self.flow_spec_type = YLeaf(YType.enumeration, "flow-spec-type")

                    self.g709otn_flow_spec = RsvpStandby.RequestDetails.RequestDetail.GenericFlowSpec.G709OtnFlowSpec()
                    self.g709otn_flow_spec.parent = self
                    self._children_name_map["g709otn_flow_spec"] = "g709otn-flow-spec"
                    self._children_yang_names.add("g709otn-flow-spec")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("flow_spec_type") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.RequestDetails.RequestDetail.GenericFlowSpec, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.RequestDetails.RequestDetail.GenericFlowSpec, self).__setattr__(name, value)


                class G709OtnFlowSpec(Entity):
                    """
                    G709 OTN FlowSpec
                    
                    .. attribute:: flow_bit_rate
                    
                    	G709 OTN Flow Bit Rate
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: flow_multiplier
                    
                    	G709 OTN Flow Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: flow_nvc
                    
                    	G709 OTN Flow NVC
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: flow_signal_type
                    
                    	G709 OTN Flow Signal Type (Refer G709 v3)
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.RequestDetails.RequestDetail.GenericFlowSpec.G709OtnFlowSpec, self).__init__()

                        self.yang_name = "g709otn-flow-spec"
                        self.yang_parent_name = "generic-flow-spec"

                        self.flow_bit_rate = YLeaf(YType.uint64, "flow-bit-rate")

                        self.flow_multiplier = YLeaf(YType.uint16, "flow-multiplier")

                        self.flow_nvc = YLeaf(YType.uint16, "flow-nvc")

                        self.flow_signal_type = YLeaf(YType.uint8, "flow-signal-type")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("flow_bit_rate",
                                        "flow_multiplier",
                                        "flow_nvc",
                                        "flow_signal_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.RequestDetails.RequestDetail.GenericFlowSpec.G709OtnFlowSpec, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.RequestDetails.RequestDetail.GenericFlowSpec.G709OtnFlowSpec, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.flow_bit_rate.is_set or
                            self.flow_multiplier.is_set or
                            self.flow_nvc.is_set or
                            self.flow_signal_type.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.flow_bit_rate.yfilter != YFilter.not_set or
                            self.flow_multiplier.yfilter != YFilter.not_set or
                            self.flow_nvc.yfilter != YFilter.not_set or
                            self.flow_signal_type.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "g709otn-flow-spec" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/request-details/request-detail/generic-flow-spec/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.flow_bit_rate.is_set or self.flow_bit_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.flow_bit_rate.get_name_leafdata())
                        if (self.flow_multiplier.is_set or self.flow_multiplier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.flow_multiplier.get_name_leafdata())
                        if (self.flow_nvc.is_set or self.flow_nvc.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.flow_nvc.get_name_leafdata())
                        if (self.flow_signal_type.is_set or self.flow_signal_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.flow_signal_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "flow-bit-rate" or name == "flow-multiplier" or name == "flow-nvc" or name == "flow-signal-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "flow-bit-rate"):
                            self.flow_bit_rate = value
                            self.flow_bit_rate.value_namespace = name_space
                            self.flow_bit_rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "flow-multiplier"):
                            self.flow_multiplier = value
                            self.flow_multiplier.value_namespace = name_space
                            self.flow_multiplier.value_namespace_prefix = name_space_prefix
                        if(value_path == "flow-nvc"):
                            self.flow_nvc = value
                            self.flow_nvc.value_namespace = name_space
                            self.flow_nvc.value_namespace_prefix = name_space_prefix
                        if(value_path == "flow-signal-type"):
                            self.flow_signal_type = value
                            self.flow_signal_type.value_namespace = name_space
                            self.flow_signal_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.flow_spec_type.is_set or
                        (self.g709otn_flow_spec is not None and self.g709otn_flow_spec.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.flow_spec_type.yfilter != YFilter.not_set or
                        (self.g709otn_flow_spec is not None and self.g709otn_flow_spec.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "generic-flow-spec" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/request-details/request-detail/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.flow_spec_type.is_set or self.flow_spec_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_spec_type.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "g709otn-flow-spec"):
                        if (self.g709otn_flow_spec is None):
                            self.g709otn_flow_spec = RsvpStandby.RequestDetails.RequestDetail.GenericFlowSpec.G709OtnFlowSpec()
                            self.g709otn_flow_spec.parent = self
                            self._children_name_map["g709otn_flow_spec"] = "g709otn-flow-spec"
                        return self.g709otn_flow_spec

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "g709otn-flow-spec" or name == "flow-spec-type"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "flow-spec-type"):
                        self.flow_spec_type = value
                        self.flow_spec_type.value_namespace = name_space
                        self.flow_spec_type.value_namespace_prefix = name_space_prefix


            class Filter(Entity):
                """
                RSVP Filter
                
                .. attribute:: rsvp_filter
                
                	RSVP Filter
                	**type**\:   :py:class:`RsvpFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RequestDetails.RequestDetail.Filter.RsvpFilter>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.RequestDetails.RequestDetail.Filter, self).__init__()

                    self.yang_name = "filter"
                    self.yang_parent_name = "request-detail"

                    self.rsvp_filter = RsvpStandby.RequestDetails.RequestDetail.Filter.RsvpFilter()
                    self.rsvp_filter.parent = self
                    self._children_name_map["rsvp_filter"] = "rsvp-filter"
                    self._children_yang_names.add("rsvp-filter")


                class RsvpFilter(Entity):
                    """
                    RSVP Filter
                    
                    .. attribute:: filter_type
                    
                    	FilterType
                    	**type**\:   :py:class:`RsvpMgmtFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtFilter>`
                    
                    .. attribute:: p2mp_ipv4_session
                    
                    	IPv4 P2MP LSP FilterSpec
                    	**type**\:   :py:class:`P2MpIpv4Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RequestDetails.RequestDetail.Filter.RsvpFilter.P2MpIpv4Session>`
                    
                    .. attribute:: udp_ipv4_session
                    
                    	UDP IPV4 FilterSpec
                    	**type**\:   :py:class:`UdpIpv4Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.RequestDetails.RequestDetail.Filter.RsvpFilter.UdpIpv4Session>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.RequestDetails.RequestDetail.Filter.RsvpFilter, self).__init__()

                        self.yang_name = "rsvp-filter"
                        self.yang_parent_name = "filter"

                        self.filter_type = YLeaf(YType.enumeration, "filter-type")

                        self.p2mp_ipv4_session = RsvpStandby.RequestDetails.RequestDetail.Filter.RsvpFilter.P2MpIpv4Session()
                        self.p2mp_ipv4_session.parent = self
                        self._children_name_map["p2mp_ipv4_session"] = "p2mp-ipv4-session"
                        self._children_yang_names.add("p2mp-ipv4-session")

                        self.udp_ipv4_session = RsvpStandby.RequestDetails.RequestDetail.Filter.RsvpFilter.UdpIpv4Session()
                        self.udp_ipv4_session.parent = self
                        self._children_name_map["udp_ipv4_session"] = "udp-ipv4-session"
                        self._children_yang_names.add("udp-ipv4-session")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("filter_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.RequestDetails.RequestDetail.Filter.RsvpFilter, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.RequestDetails.RequestDetail.Filter.RsvpFilter, self).__setattr__(name, value)


                    class UdpIpv4Session(Entity):
                        """
                        UDP IPV4 FilterSpec
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source_port
                        
                        	Source Port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.RequestDetails.RequestDetail.Filter.RsvpFilter.UdpIpv4Session, self).__init__()

                            self.yang_name = "udp-ipv4-session"
                            self.yang_parent_name = "rsvp-filter"

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.source_port = YLeaf(YType.uint16, "source-port")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("source_address",
                                            "source_port") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.RequestDetails.RequestDetail.Filter.RsvpFilter.UdpIpv4Session, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.RequestDetails.RequestDetail.Filter.RsvpFilter.UdpIpv4Session, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.source_address.is_set or
                                self.source_port.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                self.source_port.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "udp-ipv4-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/request-details/request-detail/filter/rsvp-filter/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())
                            if (self.source_port.is_set or self.source_port.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_port.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "source-address" or name == "source-port"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-port"):
                                self.source_port = value
                                self.source_port.value_namespace = name_space
                                self.source_port.value_namespace_prefix = name_space_prefix


                    class P2MpIpv4Session(Entity):
                        """
                        IPv4 P2MP LSP FilterSpec
                        
                        .. attribute:: p2mp_sub_group_origin
                        
                        	Point to Multipoint SubGroup Origin
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source_port
                        
                        	Source Port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: sub_group_id
                        
                        	Point to Multipoint Subgroup ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.RequestDetails.RequestDetail.Filter.RsvpFilter.P2MpIpv4Session, self).__init__()

                            self.yang_name = "p2mp-ipv4-session"
                            self.yang_parent_name = "rsvp-filter"

                            self.p2mp_sub_group_origin = YLeaf(YType.str, "p2mp-sub-group-origin")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.source_port = YLeaf(YType.uint16, "source-port")

                            self.sub_group_id = YLeaf(YType.uint16, "sub-group-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("p2mp_sub_group_origin",
                                            "source_address",
                                            "source_port",
                                            "sub_group_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.RequestDetails.RequestDetail.Filter.RsvpFilter.P2MpIpv4Session, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.RequestDetails.RequestDetail.Filter.RsvpFilter.P2MpIpv4Session, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.p2mp_sub_group_origin.is_set or
                                self.source_address.is_set or
                                self.source_port.is_set or
                                self.sub_group_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.p2mp_sub_group_origin.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                self.source_port.yfilter != YFilter.not_set or
                                self.sub_group_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "p2mp-ipv4-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/request-details/request-detail/filter/rsvp-filter/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.p2mp_sub_group_origin.is_set or self.p2mp_sub_group_origin.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.p2mp_sub_group_origin.get_name_leafdata())
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())
                            if (self.source_port.is_set or self.source_port.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_port.get_name_leafdata())
                            if (self.sub_group_id.is_set or self.sub_group_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sub_group_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "p2mp-sub-group-origin" or name == "source-address" or name == "source-port" or name == "sub-group-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "p2mp-sub-group-origin"):
                                self.p2mp_sub_group_origin = value
                                self.p2mp_sub_group_origin.value_namespace = name_space
                                self.p2mp_sub_group_origin.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-port"):
                                self.source_port = value
                                self.source_port.value_namespace = name_space
                                self.source_port.value_namespace_prefix = name_space_prefix
                            if(value_path == "sub-group-id"):
                                self.sub_group_id = value
                                self.sub_group_id.value_namespace = name_space
                                self.sub_group_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.filter_type.is_set or
                            (self.p2mp_ipv4_session is not None and self.p2mp_ipv4_session.has_data()) or
                            (self.udp_ipv4_session is not None and self.udp_ipv4_session.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.filter_type.yfilter != YFilter.not_set or
                            (self.p2mp_ipv4_session is not None and self.p2mp_ipv4_session.has_operation()) or
                            (self.udp_ipv4_session is not None and self.udp_ipv4_session.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rsvp-filter" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/request-details/request-detail/filter/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.filter_type.is_set or self.filter_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.filter_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "p2mp-ipv4-session"):
                            if (self.p2mp_ipv4_session is None):
                                self.p2mp_ipv4_session = RsvpStandby.RequestDetails.RequestDetail.Filter.RsvpFilter.P2MpIpv4Session()
                                self.p2mp_ipv4_session.parent = self
                                self._children_name_map["p2mp_ipv4_session"] = "p2mp-ipv4-session"
                            return self.p2mp_ipv4_session

                        if (child_yang_name == "udp-ipv4-session"):
                            if (self.udp_ipv4_session is None):
                                self.udp_ipv4_session = RsvpStandby.RequestDetails.RequestDetail.Filter.RsvpFilter.UdpIpv4Session()
                                self.udp_ipv4_session.parent = self
                                self._children_name_map["udp_ipv4_session"] = "udp-ipv4-session"
                            return self.udp_ipv4_session

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "p2mp-ipv4-session" or name == "udp-ipv4-session" or name == "filter-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "filter-type"):
                            self.filter_type = value
                            self.filter_type.value_namespace = name_space
                            self.filter_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (self.rsvp_filter is not None and self.rsvp_filter.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.rsvp_filter is not None and self.rsvp_filter.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "filter" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/request-details/request-detail/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "rsvp-filter"):
                        if (self.rsvp_filter is None):
                            self.rsvp_filter = RsvpStandby.RequestDetails.RequestDetail.Filter.RsvpFilter()
                            self.rsvp_filter.parent = self
                            self._children_name_map["rsvp_filter"] = "rsvp-filter"
                        return self.rsvp_filter

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "rsvp-filter"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Style(Entity):
                """
                RSVP Style
                
                .. attribute:: reservation_type
                
                	The Reservation Type\: WF, SE or FF
                	**type**\:   :py:class:`RsvpMgmtReservationTypeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtReservationTypeEnum>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.RequestDetails.RequestDetail.Style, self).__init__()

                    self.yang_name = "style"
                    self.yang_parent_name = "request-detail"

                    self.reservation_type = YLeaf(YType.enumeration, "reservation-type")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("reservation_type") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.RequestDetails.RequestDetail.Style, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.RequestDetails.RequestDetail.Style, self).__setattr__(name, value)

                def has_data(self):
                    return self.reservation_type.is_set

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.reservation_type.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "style" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/request-details/request-detail/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.reservation_type.is_set or self.reservation_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reservation_type.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "reservation-type"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "reservation-type"):
                        self.reservation_type = value
                        self.reservation_type.value_namespace = name_space
                        self.reservation_type.value_namespace_prefix = name_space_prefix


            class ReqFlags(Entity):
                """
                Request flags
                
                .. attribute:: is_ack_outstanding
                
                	Is ACK message outstanding
                	**type**\:  bool
                
                .. attribute:: is_label_request_in_path
                
                	The Path message contains Label Request
                	**type**\:  bool
                
                .. attribute:: is_local_receiver
                
                	Local Receiver
                	**type**\:  bool
                
                .. attribute:: is_merge_point
                
                	Is node a Merge Point
                	**type**\:  bool
                
                .. attribute:: is_message_id_allocated
                
                	Is MessageID allocated
                	**type**\:  bool
                
                .. attribute:: is_nack_received
                
                	A NACK message was received
                	**type**\:  bool
                
                .. attribute:: is_paced
                
                	Message is paced
                	**type**\:  bool
                
                .. attribute:: is_record_label_in_path
                
                	Path has Session\-Attr object with Record Labels set
                	**type**\:  bool
                
                .. attribute:: is_refreshing
                
                	Is neighbor refreshing
                	**type**\:  bool
                
                .. attribute:: is_retransmit
                
                	Retransmit the message
                	**type**\:  bool
                
                .. attribute:: is_rro_in_path
                
                	The Path message contains RRO
                	**type**\:  bool
                
                .. attribute:: is_send_confirm
                
                	Send Confirm message
                	**type**\:  bool
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.RequestDetails.RequestDetail.ReqFlags, self).__init__()

                    self.yang_name = "req-flags"
                    self.yang_parent_name = "request-detail"

                    self.is_ack_outstanding = YLeaf(YType.boolean, "is-ack-outstanding")

                    self.is_label_request_in_path = YLeaf(YType.boolean, "is-label-request-in-path")

                    self.is_local_receiver = YLeaf(YType.boolean, "is-local-receiver")

                    self.is_merge_point = YLeaf(YType.boolean, "is-merge-point")

                    self.is_message_id_allocated = YLeaf(YType.boolean, "is-message-id-allocated")

                    self.is_nack_received = YLeaf(YType.boolean, "is-nack-received")

                    self.is_paced = YLeaf(YType.boolean, "is-paced")

                    self.is_record_label_in_path = YLeaf(YType.boolean, "is-record-label-in-path")

                    self.is_refreshing = YLeaf(YType.boolean, "is-refreshing")

                    self.is_retransmit = YLeaf(YType.boolean, "is-retransmit")

                    self.is_rro_in_path = YLeaf(YType.boolean, "is-rro-in-path")

                    self.is_send_confirm = YLeaf(YType.boolean, "is-send-confirm")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("is_ack_outstanding",
                                    "is_label_request_in_path",
                                    "is_local_receiver",
                                    "is_merge_point",
                                    "is_message_id_allocated",
                                    "is_nack_received",
                                    "is_paced",
                                    "is_record_label_in_path",
                                    "is_refreshing",
                                    "is_retransmit",
                                    "is_rro_in_path",
                                    "is_send_confirm") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.RequestDetails.RequestDetail.ReqFlags, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.RequestDetails.RequestDetail.ReqFlags, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.is_ack_outstanding.is_set or
                        self.is_label_request_in_path.is_set or
                        self.is_local_receiver.is_set or
                        self.is_merge_point.is_set or
                        self.is_message_id_allocated.is_set or
                        self.is_nack_received.is_set or
                        self.is_paced.is_set or
                        self.is_record_label_in_path.is_set or
                        self.is_refreshing.is_set or
                        self.is_retransmit.is_set or
                        self.is_rro_in_path.is_set or
                        self.is_send_confirm.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.is_ack_outstanding.yfilter != YFilter.not_set or
                        self.is_label_request_in_path.yfilter != YFilter.not_set or
                        self.is_local_receiver.yfilter != YFilter.not_set or
                        self.is_merge_point.yfilter != YFilter.not_set or
                        self.is_message_id_allocated.yfilter != YFilter.not_set or
                        self.is_nack_received.yfilter != YFilter.not_set or
                        self.is_paced.yfilter != YFilter.not_set or
                        self.is_record_label_in_path.yfilter != YFilter.not_set or
                        self.is_refreshing.yfilter != YFilter.not_set or
                        self.is_retransmit.yfilter != YFilter.not_set or
                        self.is_rro_in_path.yfilter != YFilter.not_set or
                        self.is_send_confirm.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "req-flags" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/request-details/request-detail/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.is_ack_outstanding.is_set or self.is_ack_outstanding.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_ack_outstanding.get_name_leafdata())
                    if (self.is_label_request_in_path.is_set or self.is_label_request_in_path.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_label_request_in_path.get_name_leafdata())
                    if (self.is_local_receiver.is_set or self.is_local_receiver.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_local_receiver.get_name_leafdata())
                    if (self.is_merge_point.is_set or self.is_merge_point.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_merge_point.get_name_leafdata())
                    if (self.is_message_id_allocated.is_set or self.is_message_id_allocated.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_message_id_allocated.get_name_leafdata())
                    if (self.is_nack_received.is_set or self.is_nack_received.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_nack_received.get_name_leafdata())
                    if (self.is_paced.is_set or self.is_paced.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_paced.get_name_leafdata())
                    if (self.is_record_label_in_path.is_set or self.is_record_label_in_path.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_record_label_in_path.get_name_leafdata())
                    if (self.is_refreshing.is_set or self.is_refreshing.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_refreshing.get_name_leafdata())
                    if (self.is_retransmit.is_set or self.is_retransmit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_retransmit.get_name_leafdata())
                    if (self.is_rro_in_path.is_set or self.is_rro_in_path.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_rro_in_path.get_name_leafdata())
                    if (self.is_send_confirm.is_set or self.is_send_confirm.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_send_confirm.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "is-ack-outstanding" or name == "is-label-request-in-path" or name == "is-local-receiver" or name == "is-merge-point" or name == "is-message-id-allocated" or name == "is-nack-received" or name == "is-paced" or name == "is-record-label-in-path" or name == "is-refreshing" or name == "is-retransmit" or name == "is-rro-in-path" or name == "is-send-confirm"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "is-ack-outstanding"):
                        self.is_ack_outstanding = value
                        self.is_ack_outstanding.value_namespace = name_space
                        self.is_ack_outstanding.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-label-request-in-path"):
                        self.is_label_request_in_path = value
                        self.is_label_request_in_path.value_namespace = name_space
                        self.is_label_request_in_path.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-local-receiver"):
                        self.is_local_receiver = value
                        self.is_local_receiver.value_namespace = name_space
                        self.is_local_receiver.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-merge-point"):
                        self.is_merge_point = value
                        self.is_merge_point.value_namespace = name_space
                        self.is_merge_point.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-message-id-allocated"):
                        self.is_message_id_allocated = value
                        self.is_message_id_allocated.value_namespace = name_space
                        self.is_message_id_allocated.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-nack-received"):
                        self.is_nack_received = value
                        self.is_nack_received.value_namespace = name_space
                        self.is_nack_received.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-paced"):
                        self.is_paced = value
                        self.is_paced.value_namespace = name_space
                        self.is_paced.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-record-label-in-path"):
                        self.is_record_label_in_path = value
                        self.is_record_label_in_path.value_namespace = name_space
                        self.is_record_label_in_path.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-refreshing"):
                        self.is_refreshing = value
                        self.is_refreshing.value_namespace = name_space
                        self.is_refreshing.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-retransmit"):
                        self.is_retransmit = value
                        self.is_retransmit.value_namespace = name_space
                        self.is_retransmit.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-rro-in-path"):
                        self.is_rro_in_path = value
                        self.is_rro_in_path.value_namespace = name_space
                        self.is_rro_in_path.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-send-confirm"):
                        self.is_send_confirm = value
                        self.is_send_confirm.value_namespace = name_space
                        self.is_send_confirm.value_namespace_prefix = name_space_prefix


            class Hop(Entity):
                """
                Hop Infomation
                
                .. attribute:: neighbor_address
                
                	IP address of the neighbor
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: neighbor_logical_interface_name
                
                	Neighbor Logical Interface Name
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.RequestDetails.RequestDetail.Hop, self).__init__()

                    self.yang_name = "hop"
                    self.yang_parent_name = "request-detail"

                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                    self.neighbor_logical_interface_name = YLeaf(YType.str, "neighbor-logical-interface-name")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("neighbor_address",
                                    "neighbor_logical_interface_name") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.RequestDetails.RequestDetail.Hop, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.RequestDetails.RequestDetail.Hop, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.neighbor_address.is_set or
                        self.neighbor_logical_interface_name.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.neighbor_address.yfilter != YFilter.not_set or
                        self.neighbor_logical_interface_name.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "hop" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/request-details/request-detail/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                    if (self.neighbor_logical_interface_name.is_set or self.neighbor_logical_interface_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.neighbor_logical_interface_name.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "neighbor-address" or name == "neighbor-logical-interface-name"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "neighbor-address"):
                        self.neighbor_address = value
                        self.neighbor_address.value_namespace = name_space
                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "neighbor-logical-interface-name"):
                        self.neighbor_logical_interface_name = value
                        self.neighbor_logical_interface_name.value_namespace = name_space
                        self.neighbor_logical_interface_name.value_namespace_prefix = name_space_prefix


            class Header(Entity):
                """
                RSVP Header Information
                
                .. attribute:: ip_source_address
                
                	IP Source Address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: ip_tos
                
                	IP Type of Service
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: ip_ttl
                
                	IP TTL
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: rsvp_header_flags
                
                	RSVP Header Flags (defined in RFC2205 Section 3 .1.1)
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: rsvp_message_type
                
                	RSVP Message Type
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: rsvp_ttl
                
                	RSVP TTL
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: rsvp_version
                
                	RSVP Version
                	**type**\:  int
                
                	**range:** 0..255
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.RequestDetails.RequestDetail.Header, self).__init__()

                    self.yang_name = "header"
                    self.yang_parent_name = "request-detail"

                    self.ip_source_address = YLeaf(YType.str, "ip-source-address")

                    self.ip_tos = YLeaf(YType.uint8, "ip-tos")

                    self.ip_ttl = YLeaf(YType.uint8, "ip-ttl")

                    self.rsvp_header_flags = YLeaf(YType.uint8, "rsvp-header-flags")

                    self.rsvp_message_type = YLeaf(YType.uint8, "rsvp-message-type")

                    self.rsvp_ttl = YLeaf(YType.uint8, "rsvp-ttl")

                    self.rsvp_version = YLeaf(YType.uint8, "rsvp-version")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("ip_source_address",
                                    "ip_tos",
                                    "ip_ttl",
                                    "rsvp_header_flags",
                                    "rsvp_message_type",
                                    "rsvp_ttl",
                                    "rsvp_version") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.RequestDetails.RequestDetail.Header, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.RequestDetails.RequestDetail.Header, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.ip_source_address.is_set or
                        self.ip_tos.is_set or
                        self.ip_ttl.is_set or
                        self.rsvp_header_flags.is_set or
                        self.rsvp_message_type.is_set or
                        self.rsvp_ttl.is_set or
                        self.rsvp_version.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.ip_source_address.yfilter != YFilter.not_set or
                        self.ip_tos.yfilter != YFilter.not_set or
                        self.ip_ttl.yfilter != YFilter.not_set or
                        self.rsvp_header_flags.yfilter != YFilter.not_set or
                        self.rsvp_message_type.yfilter != YFilter.not_set or
                        self.rsvp_ttl.yfilter != YFilter.not_set or
                        self.rsvp_version.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "header" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/request-details/request-detail/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.ip_source_address.is_set or self.ip_source_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ip_source_address.get_name_leafdata())
                    if (self.ip_tos.is_set or self.ip_tos.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ip_tos.get_name_leafdata())
                    if (self.ip_ttl.is_set or self.ip_ttl.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ip_ttl.get_name_leafdata())
                    if (self.rsvp_header_flags.is_set or self.rsvp_header_flags.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_header_flags.get_name_leafdata())
                    if (self.rsvp_message_type.is_set or self.rsvp_message_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_message_type.get_name_leafdata())
                    if (self.rsvp_ttl.is_set or self.rsvp_ttl.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_ttl.get_name_leafdata())
                    if (self.rsvp_version.is_set or self.rsvp_version.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_version.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ip-source-address" or name == "ip-tos" or name == "ip-ttl" or name == "rsvp-header-flags" or name == "rsvp-message-type" or name == "rsvp-ttl" or name == "rsvp-version"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "ip-source-address"):
                        self.ip_source_address = value
                        self.ip_source_address.value_namespace = name_space
                        self.ip_source_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "ip-tos"):
                        self.ip_tos = value
                        self.ip_tos.value_namespace = name_space
                        self.ip_tos.value_namespace_prefix = name_space_prefix
                    if(value_path == "ip-ttl"):
                        self.ip_ttl = value
                        self.ip_ttl.value_namespace = name_space
                        self.ip_ttl.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-header-flags"):
                        self.rsvp_header_flags = value
                        self.rsvp_header_flags.value_namespace = name_space
                        self.rsvp_header_flags.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-message-type"):
                        self.rsvp_message_type = value
                        self.rsvp_message_type.value_namespace = name_space
                        self.rsvp_message_type.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-ttl"):
                        self.rsvp_ttl = value
                        self.rsvp_ttl.value_namespace = name_space
                        self.rsvp_ttl.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-version"):
                        self.rsvp_version = value
                        self.rsvp_version.value_namespace = name_space
                        self.rsvp_version.value_namespace_prefix = name_space_prefix


            class PolicySources(Entity):
                """
                RSVP Policy Sources
                
                .. attribute:: is_cable
                
                	Policy Source is Cable
                	**type**\:  bool
                
                .. attribute:: is_cops
                
                	Policy Source is COPS
                	**type**\:  bool
                
                .. attribute:: is_default
                
                	Policy Source is Default
                	**type**\:  bool
                
                .. attribute:: is_local
                
                	Policy Source is Local
                	**type**\:  bool
                
                .. attribute:: is_te_link
                
                	Policy Source is TE Link
                	**type**\:  bool
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.RequestDetails.RequestDetail.PolicySources, self).__init__()

                    self.yang_name = "policy-sources"
                    self.yang_parent_name = "request-detail"

                    self.is_cable = YLeaf(YType.boolean, "is-cable")

                    self.is_cops = YLeaf(YType.boolean, "is-cops")

                    self.is_default = YLeaf(YType.boolean, "is-default")

                    self.is_local = YLeaf(YType.boolean, "is-local")

                    self.is_te_link = YLeaf(YType.boolean, "is-te-link")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("is_cable",
                                    "is_cops",
                                    "is_default",
                                    "is_local",
                                    "is_te_link") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.RequestDetails.RequestDetail.PolicySources, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.RequestDetails.RequestDetail.PolicySources, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.is_cable.is_set or
                        self.is_cops.is_set or
                        self.is_default.is_set or
                        self.is_local.is_set or
                        self.is_te_link.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.is_cable.yfilter != YFilter.not_set or
                        self.is_cops.yfilter != YFilter.not_set or
                        self.is_default.yfilter != YFilter.not_set or
                        self.is_local.yfilter != YFilter.not_set or
                        self.is_te_link.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "policy-sources" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/request-details/request-detail/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.is_cable.is_set or self.is_cable.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_cable.get_name_leafdata())
                    if (self.is_cops.is_set or self.is_cops.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_cops.get_name_leafdata())
                    if (self.is_default.is_set or self.is_default.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_default.get_name_leafdata())
                    if (self.is_local.is_set or self.is_local.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_local.get_name_leafdata())
                    if (self.is_te_link.is_set or self.is_te_link.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_te_link.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "is-cable" or name == "is-cops" or name == "is-default" or name == "is-local" or name == "is-te-link"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "is-cable"):
                        self.is_cable = value
                        self.is_cable.value_namespace = name_space
                        self.is_cable.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-cops"):
                        self.is_cops = value
                        self.is_cops.value_namespace = name_space
                        self.is_cops.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-default"):
                        self.is_default = value
                        self.is_default.value_namespace = name_space
                        self.is_default.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-local"):
                        self.is_local = value
                        self.is_local.value_namespace = name_space
                        self.is_local.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-te-link"):
                        self.is_te_link = value
                        self.is_te_link.value_namespace = name_space
                        self.is_te_link.value_namespace_prefix = name_space_prefix


            class PolicyFlags(Entity):
                """
                RSVP Policy Flags
                
                .. attribute:: is_accepted
                
                	Accepted
                	**type**\:  bool
                
                .. attribute:: is_forwarding
                
                	Forwarding
                	**type**\:  bool
                
                .. attribute:: is_installed
                
                	Installed
                	**type**\:  bool
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.RequestDetails.RequestDetail.PolicyFlags, self).__init__()

                    self.yang_name = "policy-flags"
                    self.yang_parent_name = "request-detail"

                    self.is_accepted = YLeaf(YType.boolean, "is-accepted")

                    self.is_forwarding = YLeaf(YType.boolean, "is-forwarding")

                    self.is_installed = YLeaf(YType.boolean, "is-installed")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("is_accepted",
                                    "is_forwarding",
                                    "is_installed") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.RequestDetails.RequestDetail.PolicyFlags, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.RequestDetails.RequestDetail.PolicyFlags, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.is_accepted.is_set or
                        self.is_forwarding.is_set or
                        self.is_installed.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.is_accepted.yfilter != YFilter.not_set or
                        self.is_forwarding.yfilter != YFilter.not_set or
                        self.is_installed.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "policy-flags" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/request-details/request-detail/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.is_accepted.is_set or self.is_accepted.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_accepted.get_name_leafdata())
                    if (self.is_forwarding.is_set or self.is_forwarding.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_forwarding.get_name_leafdata())
                    if (self.is_installed.is_set or self.is_installed.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_installed.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "is-accepted" or name == "is-forwarding" or name == "is-installed"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "is-accepted"):
                        self.is_accepted = value
                        self.is_accepted.value_namespace = name_space
                        self.is_accepted.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-forwarding"):
                        self.is_forwarding = value
                        self.is_forwarding.value_namespace = name_space
                        self.is_forwarding.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-installed"):
                        self.is_installed = value
                        self.is_installed.value_namespace = name_space
                        self.is_installed.value_namespace_prefix = name_space_prefix


            class PolicyQueryFlags(Entity):
                """
                RSVP Query Flags
                
                .. attribute:: is_bypass
                
                	Bypass
                	**type**\:  bool
                
                .. attribute:: is_needed
                
                	Needed
                	**type**\:  bool
                
                .. attribute:: is_report_required
                
                	Report Required
                	**type**\:  bool
                
                .. attribute:: is_resync
                
                	Resynchronization
                	**type**\:  bool
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.RequestDetails.RequestDetail.PolicyQueryFlags, self).__init__()

                    self.yang_name = "policy-query-flags"
                    self.yang_parent_name = "request-detail"

                    self.is_bypass = YLeaf(YType.boolean, "is-bypass")

                    self.is_needed = YLeaf(YType.boolean, "is-needed")

                    self.is_report_required = YLeaf(YType.boolean, "is-report-required")

                    self.is_resync = YLeaf(YType.boolean, "is-resync")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("is_bypass",
                                    "is_needed",
                                    "is_report_required",
                                    "is_resync") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.RequestDetails.RequestDetail.PolicyQueryFlags, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.RequestDetails.RequestDetail.PolicyQueryFlags, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.is_bypass.is_set or
                        self.is_needed.is_set or
                        self.is_report_required.is_set or
                        self.is_resync.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.is_bypass.yfilter != YFilter.not_set or
                        self.is_needed.yfilter != YFilter.not_set or
                        self.is_report_required.yfilter != YFilter.not_set or
                        self.is_resync.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "policy-query-flags" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/request-details/request-detail/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.is_bypass.is_set or self.is_bypass.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_bypass.get_name_leafdata())
                    if (self.is_needed.is_set or self.is_needed.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_needed.get_name_leafdata())
                    if (self.is_report_required.is_set or self.is_report_required.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_report_required.get_name_leafdata())
                    if (self.is_resync.is_set or self.is_resync.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_resync.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "is-bypass" or name == "is-needed" or name == "is-report-required" or name == "is-resync"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "is-bypass"):
                        self.is_bypass = value
                        self.is_bypass.value_namespace = name_space
                        self.is_bypass.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-needed"):
                        self.is_needed = value
                        self.is_needed.value_namespace = name_space
                        self.is_needed.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-report-required"):
                        self.is_report_required = value
                        self.is_report_required.value_namespace = name_space
                        self.is_report_required.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-resync"):
                        self.is_resync = value
                        self.is_resync.value_namespace = name_space
                        self.is_resync.value_namespace_prefix = name_space_prefix


            class PsbKey(Entity):
                """
                List of RSB keys
                
                .. attribute:: destination_address
                
                	Destination address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: destination_port_or_tunnel_id
                
                	Destination Port or Tunnel ID. For the LSP and OUNI session types this represents the Tunnel ID whereas for the UDP session type this represents the Destination Port
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: extended_tunnel_id
                
                	Protocol or Extended Tunnel ID. For the LSP and OUNI sesion types this represents the Extended Tunnel ID
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: p2mp_id
                
                	Point\-to\-multipoint ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: p2mp_sub_group_origin
                
                	Point to Multipoint SubGroup Origin
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: protocol
                
                	Protocol. UDP session type this represents the Protocol (UDP not supported at present)
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: session_type
                
                	Session Type (e.g. LSP, OUNI or UDP)
                	**type**\:   :py:class:`RsvpMgmtSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtSession>`
                
                .. attribute:: source_address
                
                	Source Address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: source_port_or_lsp_id
                
                	Source Port or LSP\_ID. For the LSP and OUNI session types this represents the LSP\_ID whereas for the UDP session type this represents the SourcePort
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: sub_group_id
                
                	Point to Multipoint Subgroup ID
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: vrfid
                
                	Signalling VRF ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.RequestDetails.RequestDetail.PsbKey, self).__init__()

                    self.yang_name = "psb-key"
                    self.yang_parent_name = "request-detail"

                    self.destination_address = YLeaf(YType.str, "destination-address")

                    self.destination_port_or_tunnel_id = YLeaf(YType.uint32, "destination-port-or-tunnel-id")

                    self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                    self.p2mp_id = YLeaf(YType.uint32, "p2mp-id")

                    self.p2mp_sub_group_origin = YLeaf(YType.str, "p2mp-sub-group-origin")

                    self.protocol = YLeaf(YType.uint32, "protocol")

                    self.session_type = YLeaf(YType.enumeration, "session-type")

                    self.source_address = YLeaf(YType.str, "source-address")

                    self.source_port_or_lsp_id = YLeaf(YType.uint32, "source-port-or-lsp-id")

                    self.sub_group_id = YLeaf(YType.uint16, "sub-group-id")

                    self.vrfid = YLeaf(YType.uint32, "vrfid")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("destination_address",
                                    "destination_port_or_tunnel_id",
                                    "extended_tunnel_id",
                                    "p2mp_id",
                                    "p2mp_sub_group_origin",
                                    "protocol",
                                    "session_type",
                                    "source_address",
                                    "source_port_or_lsp_id",
                                    "sub_group_id",
                                    "vrfid") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.RequestDetails.RequestDetail.PsbKey, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.RequestDetails.RequestDetail.PsbKey, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.destination_address.is_set or
                        self.destination_port_or_tunnel_id.is_set or
                        self.extended_tunnel_id.is_set or
                        self.p2mp_id.is_set or
                        self.p2mp_sub_group_origin.is_set or
                        self.protocol.is_set or
                        self.session_type.is_set or
                        self.source_address.is_set or
                        self.source_port_or_lsp_id.is_set or
                        self.sub_group_id.is_set or
                        self.vrfid.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.destination_address.yfilter != YFilter.not_set or
                        self.destination_port_or_tunnel_id.yfilter != YFilter.not_set or
                        self.extended_tunnel_id.yfilter != YFilter.not_set or
                        self.p2mp_id.yfilter != YFilter.not_set or
                        self.p2mp_sub_group_origin.yfilter != YFilter.not_set or
                        self.protocol.yfilter != YFilter.not_set or
                        self.session_type.yfilter != YFilter.not_set or
                        self.source_address.yfilter != YFilter.not_set or
                        self.source_port_or_lsp_id.yfilter != YFilter.not_set or
                        self.sub_group_id.yfilter != YFilter.not_set or
                        self.vrfid.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "psb-key" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/request-details/request-detail/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.destination_address.get_name_leafdata())
                    if (self.destination_port_or_tunnel_id.is_set or self.destination_port_or_tunnel_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.destination_port_or_tunnel_id.get_name_leafdata())
                    if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                    if (self.p2mp_id.is_set or self.p2mp_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.p2mp_id.get_name_leafdata())
                    if (self.p2mp_sub_group_origin.is_set or self.p2mp_sub_group_origin.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.p2mp_sub_group_origin.get_name_leafdata())
                    if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.protocol.get_name_leafdata())
                    if (self.session_type.is_set or self.session_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.session_type.get_name_leafdata())
                    if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.source_address.get_name_leafdata())
                    if (self.source_port_or_lsp_id.is_set or self.source_port_or_lsp_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.source_port_or_lsp_id.get_name_leafdata())
                    if (self.sub_group_id.is_set or self.sub_group_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sub_group_id.get_name_leafdata())
                    if (self.vrfid.is_set or self.vrfid.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.vrfid.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "destination-address" or name == "destination-port-or-tunnel-id" or name == "extended-tunnel-id" or name == "p2mp-id" or name == "p2mp-sub-group-origin" or name == "protocol" or name == "session-type" or name == "source-address" or name == "source-port-or-lsp-id" or name == "sub-group-id" or name == "vrfid"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "destination-address"):
                        self.destination_address = value
                        self.destination_address.value_namespace = name_space
                        self.destination_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "destination-port-or-tunnel-id"):
                        self.destination_port_or_tunnel_id = value
                        self.destination_port_or_tunnel_id.value_namespace = name_space
                        self.destination_port_or_tunnel_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "extended-tunnel-id"):
                        self.extended_tunnel_id = value
                        self.extended_tunnel_id.value_namespace = name_space
                        self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "p2mp-id"):
                        self.p2mp_id = value
                        self.p2mp_id.value_namespace = name_space
                        self.p2mp_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "p2mp-sub-group-origin"):
                        self.p2mp_sub_group_origin = value
                        self.p2mp_sub_group_origin.value_namespace = name_space
                        self.p2mp_sub_group_origin.value_namespace_prefix = name_space_prefix
                    if(value_path == "protocol"):
                        self.protocol = value
                        self.protocol.value_namespace = name_space
                        self.protocol.value_namespace_prefix = name_space_prefix
                    if(value_path == "session-type"):
                        self.session_type = value
                        self.session_type.value_namespace = name_space
                        self.session_type.value_namespace_prefix = name_space_prefix
                    if(value_path == "source-address"):
                        self.source_address = value
                        self.source_address.value_namespace = name_space
                        self.source_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "source-port-or-lsp-id"):
                        self.source_port_or_lsp_id = value
                        self.source_port_or_lsp_id.value_namespace = name_space
                        self.source_port_or_lsp_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "sub-group-id"):
                        self.sub_group_id = value
                        self.sub_group_id.value_namespace = name_space
                        self.sub_group_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "vrfid"):
                        self.vrfid = value
                        self.vrfid.value_namespace = name_space
                        self.vrfid.value_namespace_prefix = name_space_prefix


            class RsbKey(Entity):
                """
                List of RSB keys
                
                .. attribute:: destination_address
                
                	Destination address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: destination_port_or_tunnel_id
                
                	Destination Port or Tunnel ID. For the LSP and OUNI session types this represents the Tunnel ID whereas for the UDP session type this represents the Destination Port
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: extended_tunnel_id
                
                	Protocol or Extended Tunnel ID. For the LSP and OUNI sesion types this represents the Extended Tunnel ID
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: p2mp_id
                
                	Point\-to\-multipoint ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: p2mp_sub_group_origin
                
                	Point to Multipoint SubGroup Origin
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: protocol
                
                	Protocol. UDP session type this represents the Protocol (UDP not supported at present)
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: session_type
                
                	Session Type (e.g. LSP, OUNI or UDP)
                	**type**\:   :py:class:`RsvpMgmtSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtSession>`
                
                .. attribute:: source_address
                
                	Source Address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: source_port_or_lsp_id
                
                	Source Port or LSP\_ID. For the LSP and OUNI session types this represents the LSP\_ID whereas for the UDP session type this represents the SourcePort
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: sub_group_id
                
                	Point to Multipoint Subgroup ID
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: vrfid
                
                	Signalling VRF ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.RequestDetails.RequestDetail.RsbKey, self).__init__()

                    self.yang_name = "rsb-key"
                    self.yang_parent_name = "request-detail"

                    self.destination_address = YLeaf(YType.str, "destination-address")

                    self.destination_port_or_tunnel_id = YLeaf(YType.uint32, "destination-port-or-tunnel-id")

                    self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                    self.p2mp_id = YLeaf(YType.uint32, "p2mp-id")

                    self.p2mp_sub_group_origin = YLeaf(YType.str, "p2mp-sub-group-origin")

                    self.protocol = YLeaf(YType.uint32, "protocol")

                    self.session_type = YLeaf(YType.enumeration, "session-type")

                    self.source_address = YLeaf(YType.str, "source-address")

                    self.source_port_or_lsp_id = YLeaf(YType.uint32, "source-port-or-lsp-id")

                    self.sub_group_id = YLeaf(YType.uint16, "sub-group-id")

                    self.vrfid = YLeaf(YType.uint32, "vrfid")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("destination_address",
                                    "destination_port_or_tunnel_id",
                                    "extended_tunnel_id",
                                    "p2mp_id",
                                    "p2mp_sub_group_origin",
                                    "protocol",
                                    "session_type",
                                    "source_address",
                                    "source_port_or_lsp_id",
                                    "sub_group_id",
                                    "vrfid") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.RequestDetails.RequestDetail.RsbKey, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.RequestDetails.RequestDetail.RsbKey, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.destination_address.is_set or
                        self.destination_port_or_tunnel_id.is_set or
                        self.extended_tunnel_id.is_set or
                        self.p2mp_id.is_set or
                        self.p2mp_sub_group_origin.is_set or
                        self.protocol.is_set or
                        self.session_type.is_set or
                        self.source_address.is_set or
                        self.source_port_or_lsp_id.is_set or
                        self.sub_group_id.is_set or
                        self.vrfid.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.destination_address.yfilter != YFilter.not_set or
                        self.destination_port_or_tunnel_id.yfilter != YFilter.not_set or
                        self.extended_tunnel_id.yfilter != YFilter.not_set or
                        self.p2mp_id.yfilter != YFilter.not_set or
                        self.p2mp_sub_group_origin.yfilter != YFilter.not_set or
                        self.protocol.yfilter != YFilter.not_set or
                        self.session_type.yfilter != YFilter.not_set or
                        self.source_address.yfilter != YFilter.not_set or
                        self.source_port_or_lsp_id.yfilter != YFilter.not_set or
                        self.sub_group_id.yfilter != YFilter.not_set or
                        self.vrfid.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "rsb-key" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/request-details/request-detail/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.destination_address.get_name_leafdata())
                    if (self.destination_port_or_tunnel_id.is_set or self.destination_port_or_tunnel_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.destination_port_or_tunnel_id.get_name_leafdata())
                    if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                    if (self.p2mp_id.is_set or self.p2mp_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.p2mp_id.get_name_leafdata())
                    if (self.p2mp_sub_group_origin.is_set or self.p2mp_sub_group_origin.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.p2mp_sub_group_origin.get_name_leafdata())
                    if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.protocol.get_name_leafdata())
                    if (self.session_type.is_set or self.session_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.session_type.get_name_leafdata())
                    if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.source_address.get_name_leafdata())
                    if (self.source_port_or_lsp_id.is_set or self.source_port_or_lsp_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.source_port_or_lsp_id.get_name_leafdata())
                    if (self.sub_group_id.is_set or self.sub_group_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sub_group_id.get_name_leafdata())
                    if (self.vrfid.is_set or self.vrfid.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.vrfid.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "destination-address" or name == "destination-port-or-tunnel-id" or name == "extended-tunnel-id" or name == "p2mp-id" or name == "p2mp-sub-group-origin" or name == "protocol" or name == "session-type" or name == "source-address" or name == "source-port-or-lsp-id" or name == "sub-group-id" or name == "vrfid"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "destination-address"):
                        self.destination_address = value
                        self.destination_address.value_namespace = name_space
                        self.destination_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "destination-port-or-tunnel-id"):
                        self.destination_port_or_tunnel_id = value
                        self.destination_port_or_tunnel_id.value_namespace = name_space
                        self.destination_port_or_tunnel_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "extended-tunnel-id"):
                        self.extended_tunnel_id = value
                        self.extended_tunnel_id.value_namespace = name_space
                        self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "p2mp-id"):
                        self.p2mp_id = value
                        self.p2mp_id.value_namespace = name_space
                        self.p2mp_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "p2mp-sub-group-origin"):
                        self.p2mp_sub_group_origin = value
                        self.p2mp_sub_group_origin.value_namespace = name_space
                        self.p2mp_sub_group_origin.value_namespace_prefix = name_space_prefix
                    if(value_path == "protocol"):
                        self.protocol = value
                        self.protocol.value_namespace = name_space
                        self.protocol.value_namespace_prefix = name_space_prefix
                    if(value_path == "session-type"):
                        self.session_type = value
                        self.session_type.value_namespace = name_space
                        self.session_type.value_namespace_prefix = name_space_prefix
                    if(value_path == "source-address"):
                        self.source_address = value
                        self.source_address.value_namespace = name_space
                        self.source_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "source-port-or-lsp-id"):
                        self.source_port_or_lsp_id = value
                        self.source_port_or_lsp_id.value_namespace = name_space
                        self.source_port_or_lsp_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "sub-group-id"):
                        self.sub_group_id = value
                        self.sub_group_id.value_namespace = name_space
                        self.sub_group_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "vrfid"):
                        self.vrfid = value
                        self.vrfid.value_namespace = name_space
                        self.vrfid.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.psb_key:
                    if (c.has_data()):
                        return True
                for c in self.rsb_key:
                    if (c.has_data()):
                        return True
                return (
                    self.destination_address.is_set or
                    self.destination_port.is_set or
                    self.extended_tunnel_id.is_set or
                    self.output_interface.is_set or
                    self.p2mp_id.is_set or
                    self.protocol.is_set or
                    self.session_type.is_set or
                    self.source_address.is_set or
                    self.source_port.is_set or
                    self.sub_group_id.is_set or
                    self.sub_group_origin.is_set or
                    self.vrf_name.is_set or
                    (self.filter is not None and self.filter.has_data()) or
                    (self.flow_spec is not None and self.flow_spec.has_data()) or
                    (self.generic_flow_spec is not None and self.generic_flow_spec.has_data()) or
                    (self.header is not None and self.header.has_data()) or
                    (self.hop is not None and self.hop.has_data()) or
                    (self.policy_flags is not None and self.policy_flags.has_data()) or
                    (self.policy_query_flags is not None and self.policy_query_flags.has_data()) or
                    (self.policy_sources is not None and self.policy_sources.has_data()) or
                    (self.req_flags is not None and self.req_flags.has_data()) or
                    (self.s2l_sub_lsp is not None and self.s2l_sub_lsp.has_data()) or
                    (self.session is not None and self.session.has_data()) or
                    (self.style is not None and self.style.has_data()))

            def has_operation(self):
                for c in self.psb_key:
                    if (c.has_operation()):
                        return True
                for c in self.rsb_key:
                    if (c.has_operation()):
                        return True
                return (
                    self.yfilter != YFilter.not_set or
                    self.destination_address.yfilter != YFilter.not_set or
                    self.destination_port.yfilter != YFilter.not_set or
                    self.extended_tunnel_id.yfilter != YFilter.not_set or
                    self.output_interface.yfilter != YFilter.not_set or
                    self.p2mp_id.yfilter != YFilter.not_set or
                    self.protocol.yfilter != YFilter.not_set or
                    self.session_type.yfilter != YFilter.not_set or
                    self.source_address.yfilter != YFilter.not_set or
                    self.source_port.yfilter != YFilter.not_set or
                    self.sub_group_id.yfilter != YFilter.not_set or
                    self.sub_group_origin.yfilter != YFilter.not_set or
                    self.vrf_name.yfilter != YFilter.not_set or
                    (self.filter is not None and self.filter.has_operation()) or
                    (self.flow_spec is not None and self.flow_spec.has_operation()) or
                    (self.generic_flow_spec is not None and self.generic_flow_spec.has_operation()) or
                    (self.header is not None and self.header.has_operation()) or
                    (self.hop is not None and self.hop.has_operation()) or
                    (self.policy_flags is not None and self.policy_flags.has_operation()) or
                    (self.policy_query_flags is not None and self.policy_query_flags.has_operation()) or
                    (self.policy_sources is not None and self.policy_sources.has_operation()) or
                    (self.req_flags is not None and self.req_flags.has_operation()) or
                    (self.s2l_sub_lsp is not None and self.s2l_sub_lsp.has_operation()) or
                    (self.session is not None and self.session.has_operation()) or
                    (self.style is not None and self.style.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "request-detail" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/request-details/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_address.get_name_leafdata())
                if (self.destination_port.is_set or self.destination_port.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_port.get_name_leafdata())
                if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                if (self.output_interface.is_set or self.output_interface.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.output_interface.get_name_leafdata())
                if (self.p2mp_id.is_set or self.p2mp_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.p2mp_id.get_name_leafdata())
                if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.protocol.get_name_leafdata())
                if (self.session_type.is_set or self.session_type.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.session_type.get_name_leafdata())
                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_address.get_name_leafdata())
                if (self.source_port.is_set or self.source_port.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_port.get_name_leafdata())
                if (self.sub_group_id.is_set or self.sub_group_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.sub_group_id.get_name_leafdata())
                if (self.sub_group_origin.is_set or self.sub_group_origin.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.sub_group_origin.get_name_leafdata())
                if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.vrf_name.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "filter"):
                    if (self.filter is None):
                        self.filter = RsvpStandby.RequestDetails.RequestDetail.Filter()
                        self.filter.parent = self
                        self._children_name_map["filter"] = "filter"
                    return self.filter

                if (child_yang_name == "flow-spec"):
                    if (self.flow_spec is None):
                        self.flow_spec = RsvpStandby.RequestDetails.RequestDetail.FlowSpec()
                        self.flow_spec.parent = self
                        self._children_name_map["flow_spec"] = "flow-spec"
                    return self.flow_spec

                if (child_yang_name == "generic-flow-spec"):
                    if (self.generic_flow_spec is None):
                        self.generic_flow_spec = RsvpStandby.RequestDetails.RequestDetail.GenericFlowSpec()
                        self.generic_flow_spec.parent = self
                        self._children_name_map["generic_flow_spec"] = "generic-flow-spec"
                    return self.generic_flow_spec

                if (child_yang_name == "header"):
                    if (self.header is None):
                        self.header = RsvpStandby.RequestDetails.RequestDetail.Header()
                        self.header.parent = self
                        self._children_name_map["header"] = "header"
                    return self.header

                if (child_yang_name == "hop"):
                    if (self.hop is None):
                        self.hop = RsvpStandby.RequestDetails.RequestDetail.Hop()
                        self.hop.parent = self
                        self._children_name_map["hop"] = "hop"
                    return self.hop

                if (child_yang_name == "policy-flags"):
                    if (self.policy_flags is None):
                        self.policy_flags = RsvpStandby.RequestDetails.RequestDetail.PolicyFlags()
                        self.policy_flags.parent = self
                        self._children_name_map["policy_flags"] = "policy-flags"
                    return self.policy_flags

                if (child_yang_name == "policy-query-flags"):
                    if (self.policy_query_flags is None):
                        self.policy_query_flags = RsvpStandby.RequestDetails.RequestDetail.PolicyQueryFlags()
                        self.policy_query_flags.parent = self
                        self._children_name_map["policy_query_flags"] = "policy-query-flags"
                    return self.policy_query_flags

                if (child_yang_name == "policy-sources"):
                    if (self.policy_sources is None):
                        self.policy_sources = RsvpStandby.RequestDetails.RequestDetail.PolicySources()
                        self.policy_sources.parent = self
                        self._children_name_map["policy_sources"] = "policy-sources"
                    return self.policy_sources

                if (child_yang_name == "psb-key"):
                    for c in self.psb_key:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = RsvpStandby.RequestDetails.RequestDetail.PsbKey()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.psb_key.append(c)
                    return c

                if (child_yang_name == "req-flags"):
                    if (self.req_flags is None):
                        self.req_flags = RsvpStandby.RequestDetails.RequestDetail.ReqFlags()
                        self.req_flags.parent = self
                        self._children_name_map["req_flags"] = "req-flags"
                    return self.req_flags

                if (child_yang_name == "rsb-key"):
                    for c in self.rsb_key:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = RsvpStandby.RequestDetails.RequestDetail.RsbKey()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.rsb_key.append(c)
                    return c

                if (child_yang_name == "s2l-sub-lsp"):
                    if (self.s2l_sub_lsp is None):
                        self.s2l_sub_lsp = RsvpStandby.RequestDetails.RequestDetail.S2LSubLsp()
                        self.s2l_sub_lsp.parent = self
                        self._children_name_map["s2l_sub_lsp"] = "s2l-sub-lsp"
                    return self.s2l_sub_lsp

                if (child_yang_name == "session"):
                    if (self.session is None):
                        self.session = RsvpStandby.RequestDetails.RequestDetail.Session()
                        self.session.parent = self
                        self._children_name_map["session"] = "session"
                    return self.session

                if (child_yang_name == "style"):
                    if (self.style is None):
                        self.style = RsvpStandby.RequestDetails.RequestDetail.Style()
                        self.style.parent = self
                        self._children_name_map["style"] = "style"
                    return self.style

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "filter" or name == "flow-spec" or name == "generic-flow-spec" or name == "header" or name == "hop" or name == "policy-flags" or name == "policy-query-flags" or name == "policy-sources" or name == "psb-key" or name == "req-flags" or name == "rsb-key" or name == "s2l-sub-lsp" or name == "session" or name == "style" or name == "destination-address" or name == "destination-port" or name == "extended-tunnel-id" or name == "output-interface" or name == "p2mp-id" or name == "protocol" or name == "session-type" or name == "source-address" or name == "source-port" or name == "sub-group-id" or name == "sub-group-origin" or name == "vrf-name"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "destination-address"):
                    self.destination_address = value
                    self.destination_address.value_namespace = name_space
                    self.destination_address.value_namespace_prefix = name_space_prefix
                if(value_path == "destination-port"):
                    self.destination_port = value
                    self.destination_port.value_namespace = name_space
                    self.destination_port.value_namespace_prefix = name_space_prefix
                if(value_path == "extended-tunnel-id"):
                    self.extended_tunnel_id = value
                    self.extended_tunnel_id.value_namespace = name_space
                    self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                if(value_path == "output-interface"):
                    self.output_interface = value
                    self.output_interface.value_namespace = name_space
                    self.output_interface.value_namespace_prefix = name_space_prefix
                if(value_path == "p2mp-id"):
                    self.p2mp_id = value
                    self.p2mp_id.value_namespace = name_space
                    self.p2mp_id.value_namespace_prefix = name_space_prefix
                if(value_path == "protocol"):
                    self.protocol = value
                    self.protocol.value_namespace = name_space
                    self.protocol.value_namespace_prefix = name_space_prefix
                if(value_path == "session-type"):
                    self.session_type = value
                    self.session_type.value_namespace = name_space
                    self.session_type.value_namespace_prefix = name_space_prefix
                if(value_path == "source-address"):
                    self.source_address = value
                    self.source_address.value_namespace = name_space
                    self.source_address.value_namespace_prefix = name_space_prefix
                if(value_path == "source-port"):
                    self.source_port = value
                    self.source_port.value_namespace = name_space
                    self.source_port.value_namespace_prefix = name_space_prefix
                if(value_path == "sub-group-id"):
                    self.sub_group_id = value
                    self.sub_group_id.value_namespace = name_space
                    self.sub_group_id.value_namespace_prefix = name_space_prefix
                if(value_path == "sub-group-origin"):
                    self.sub_group_origin = value
                    self.sub_group_origin.value_namespace = name_space
                    self.sub_group_origin.value_namespace_prefix = name_space_prefix
                if(value_path == "vrf-name"):
                    self.vrf_name = value
                    self.vrf_name.value_namespace = name_space
                    self.vrf_name.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.request_detail:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.request_detail:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "request-details" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "request-detail"):
                for c in self.request_detail:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = RsvpStandby.RequestDetails.RequestDetail()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.request_detail.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "request-detail"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class InterfaceBriefs(Entity):
        """
        Table of brief info about RSVP\-enabled
        interfaces
        
        .. attribute:: interface_brief
        
        	Brief info about an RSVP\-enabled interface
        	**type**\: list of    :py:class:`InterfaceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.InterfaceBriefs.InterfaceBrief>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(RsvpStandby.InterfaceBriefs, self).__init__()

            self.yang_name = "interface-briefs"
            self.yang_parent_name = "rsvp-standby"

            self.interface_brief = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(RsvpStandby.InterfaceBriefs, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(RsvpStandby.InterfaceBriefs, self).__setattr__(name, value)


        class InterfaceBrief(Entity):
            """
            Brief info about an RSVP\-enabled interface
            
            .. attribute:: interface_name  <key>
            
            	Interface Name
            	**type**\:  str
            
            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
            
            .. attribute:: bandwidth_information
            
            	Interface bandwidth information
            	**type**\:   :py:class:`BandwidthInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.InterfaceBriefs.InterfaceBrief.BandwidthInformation>`
            
            .. attribute:: interface_name_xr
            
            	Interface Name
            	**type**\:  str
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(RsvpStandby.InterfaceBriefs.InterfaceBrief, self).__init__()

                self.yang_name = "interface-brief"
                self.yang_parent_name = "interface-briefs"

                self.interface_name = YLeaf(YType.str, "interface-name")

                self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                self.bandwidth_information = RsvpStandby.InterfaceBriefs.InterfaceBrief.BandwidthInformation()
                self.bandwidth_information.parent = self
                self._children_name_map["bandwidth_information"] = "bandwidth-information"
                self._children_yang_names.add("bandwidth-information")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("interface_name",
                                "interface_name_xr") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(RsvpStandby.InterfaceBriefs.InterfaceBrief, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(RsvpStandby.InterfaceBriefs.InterfaceBrief, self).__setattr__(name, value)


            class BandwidthInformation(Entity):
                """
                Interface bandwidth information
                
                .. attribute:: dste_mode
                
                	DSTEMode
                	**type**\:   :py:class:`RsvpMgmtDsteModes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtDsteModes>`
                
                .. attribute:: pre_standard_dste_interface
                
                	Prestandard DSTE interface information
                	**type**\:   :py:class:`PreStandardDsteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.InterfaceBriefs.InterfaceBrief.BandwidthInformation.PreStandardDsteInterface>`
                
                .. attribute:: standard_dste_interface
                
                	Standard DSTE interface information
                	**type**\:   :py:class:`StandardDsteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.InterfaceBriefs.InterfaceBrief.BandwidthInformation.StandardDsteInterface>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.InterfaceBriefs.InterfaceBrief.BandwidthInformation, self).__init__()

                    self.yang_name = "bandwidth-information"
                    self.yang_parent_name = "interface-brief"

                    self.dste_mode = YLeaf(YType.enumeration, "dste-mode")

                    self.pre_standard_dste_interface = RsvpStandby.InterfaceBriefs.InterfaceBrief.BandwidthInformation.PreStandardDsteInterface()
                    self.pre_standard_dste_interface.parent = self
                    self._children_name_map["pre_standard_dste_interface"] = "pre-standard-dste-interface"
                    self._children_yang_names.add("pre-standard-dste-interface")

                    self.standard_dste_interface = RsvpStandby.InterfaceBriefs.InterfaceBrief.BandwidthInformation.StandardDsteInterface()
                    self.standard_dste_interface.parent = self
                    self._children_name_map["standard_dste_interface"] = "standard-dste-interface"
                    self._children_yang_names.add("standard-dste-interface")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("dste_mode") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.InterfaceBriefs.InterfaceBrief.BandwidthInformation, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.InterfaceBriefs.InterfaceBrief.BandwidthInformation, self).__setattr__(name, value)


                class PreStandardDsteInterface(Entity):
                    """
                    Prestandard DSTE interface information
                    
                    .. attribute:: allocated_bit_rate
                    
                    	Bandwidth (bits per second) now allocated
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: is_max_bandwidth_absolute
                    
                    	True if the Max B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: is_max_subpool_bandwidth_absolute
                    
                    	True if the Max sub\-pool B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: max_bandwidth
                    
                    	Max bandwidth (bits per second) allowed
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_flow_bandwidth
                    
                    	Max bandwidth (bits per second) allowed per flow
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_subpool_bandwidth
                    
                    	Max bandwidth (bits per second) allowed in subpool
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.InterfaceBriefs.InterfaceBrief.BandwidthInformation.PreStandardDsteInterface, self).__init__()

                        self.yang_name = "pre-standard-dste-interface"
                        self.yang_parent_name = "bandwidth-information"

                        self.allocated_bit_rate = YLeaf(YType.uint64, "allocated-bit-rate")

                        self.is_max_bandwidth_absolute = YLeaf(YType.boolean, "is-max-bandwidth-absolute")

                        self.is_max_subpool_bandwidth_absolute = YLeaf(YType.boolean, "is-max-subpool-bandwidth-absolute")

                        self.max_bandwidth = YLeaf(YType.uint64, "max-bandwidth")

                        self.max_flow_bandwidth = YLeaf(YType.uint64, "max-flow-bandwidth")

                        self.max_subpool_bandwidth = YLeaf(YType.uint64, "max-subpool-bandwidth")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("allocated_bit_rate",
                                        "is_max_bandwidth_absolute",
                                        "is_max_subpool_bandwidth_absolute",
                                        "max_bandwidth",
                                        "max_flow_bandwidth",
                                        "max_subpool_bandwidth") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.InterfaceBriefs.InterfaceBrief.BandwidthInformation.PreStandardDsteInterface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.InterfaceBriefs.InterfaceBrief.BandwidthInformation.PreStandardDsteInterface, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.allocated_bit_rate.is_set or
                            self.is_max_bandwidth_absolute.is_set or
                            self.is_max_subpool_bandwidth_absolute.is_set or
                            self.max_bandwidth.is_set or
                            self.max_flow_bandwidth.is_set or
                            self.max_subpool_bandwidth.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.allocated_bit_rate.yfilter != YFilter.not_set or
                            self.is_max_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.is_max_subpool_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.max_bandwidth.yfilter != YFilter.not_set or
                            self.max_flow_bandwidth.yfilter != YFilter.not_set or
                            self.max_subpool_bandwidth.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "pre-standard-dste-interface" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.allocated_bit_rate.is_set or self.allocated_bit_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.allocated_bit_rate.get_name_leafdata())
                        if (self.is_max_bandwidth_absolute.is_set or self.is_max_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_bandwidth_absolute.get_name_leafdata())
                        if (self.is_max_subpool_bandwidth_absolute.is_set or self.is_max_subpool_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_subpool_bandwidth_absolute.get_name_leafdata())
                        if (self.max_bandwidth.is_set or self.max_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_bandwidth.get_name_leafdata())
                        if (self.max_flow_bandwidth.is_set or self.max_flow_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_flow_bandwidth.get_name_leafdata())
                        if (self.max_subpool_bandwidth.is_set or self.max_subpool_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_subpool_bandwidth.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "allocated-bit-rate" or name == "is-max-bandwidth-absolute" or name == "is-max-subpool-bandwidth-absolute" or name == "max-bandwidth" or name == "max-flow-bandwidth" or name == "max-subpool-bandwidth"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "allocated-bit-rate"):
                            self.allocated_bit_rate = value
                            self.allocated_bit_rate.value_namespace = name_space
                            self.allocated_bit_rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-bandwidth-absolute"):
                            self.is_max_bandwidth_absolute = value
                            self.is_max_bandwidth_absolute.value_namespace = name_space
                            self.is_max_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-subpool-bandwidth-absolute"):
                            self.is_max_subpool_bandwidth_absolute = value
                            self.is_max_subpool_bandwidth_absolute.value_namespace = name_space
                            self.is_max_subpool_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-bandwidth"):
                            self.max_bandwidth = value
                            self.max_bandwidth.value_namespace = name_space
                            self.max_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-flow-bandwidth"):
                            self.max_flow_bandwidth = value
                            self.max_flow_bandwidth.value_namespace = name_space
                            self.max_flow_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-subpool-bandwidth"):
                            self.max_subpool_bandwidth = value
                            self.max_subpool_bandwidth.value_namespace = name_space
                            self.max_subpool_bandwidth.value_namespace_prefix = name_space_prefix


                class StandardDsteInterface(Entity):
                    """
                    Standard DSTE interface information
                    
                    .. attribute:: allocated_bit_rate
                    
                    	Bandwidth (bits per second) now allocated
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: is_max_bandwidth_absolute
                    
                    	True if the Max B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: is_max_bc0_bandwidth_absolute
                    
                    	True if the Max BC0 B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: is_max_bc1_bandwidth_absolute
                    
                    	True if the Max BC1 sub\-pool B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: max_bandwidth
                    
                    	Max bandwidth (bits per second) allowed
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_flow_bandwidth
                    
                    	Max bandwidth (bits per second) allowed per flow
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_pool0_bandwidth
                    
                    	Max bandwidth (bits per second) allowed in BC0 pool
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_pool1_bandwidth
                    
                    	Max bandwidth (bits per second) allowed in BC1 pool
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.InterfaceBriefs.InterfaceBrief.BandwidthInformation.StandardDsteInterface, self).__init__()

                        self.yang_name = "standard-dste-interface"
                        self.yang_parent_name = "bandwidth-information"

                        self.allocated_bit_rate = YLeaf(YType.uint64, "allocated-bit-rate")

                        self.is_max_bandwidth_absolute = YLeaf(YType.boolean, "is-max-bandwidth-absolute")

                        self.is_max_bc0_bandwidth_absolute = YLeaf(YType.boolean, "is-max-bc0-bandwidth-absolute")

                        self.is_max_bc1_bandwidth_absolute = YLeaf(YType.boolean, "is-max-bc1-bandwidth-absolute")

                        self.max_bandwidth = YLeaf(YType.uint64, "max-bandwidth")

                        self.max_flow_bandwidth = YLeaf(YType.uint64, "max-flow-bandwidth")

                        self.max_pool0_bandwidth = YLeaf(YType.uint64, "max-pool0-bandwidth")

                        self.max_pool1_bandwidth = YLeaf(YType.uint64, "max-pool1-bandwidth")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("allocated_bit_rate",
                                        "is_max_bandwidth_absolute",
                                        "is_max_bc0_bandwidth_absolute",
                                        "is_max_bc1_bandwidth_absolute",
                                        "max_bandwidth",
                                        "max_flow_bandwidth",
                                        "max_pool0_bandwidth",
                                        "max_pool1_bandwidth") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.InterfaceBriefs.InterfaceBrief.BandwidthInformation.StandardDsteInterface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.InterfaceBriefs.InterfaceBrief.BandwidthInformation.StandardDsteInterface, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.allocated_bit_rate.is_set or
                            self.is_max_bandwidth_absolute.is_set or
                            self.is_max_bc0_bandwidth_absolute.is_set or
                            self.is_max_bc1_bandwidth_absolute.is_set or
                            self.max_bandwidth.is_set or
                            self.max_flow_bandwidth.is_set or
                            self.max_pool0_bandwidth.is_set or
                            self.max_pool1_bandwidth.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.allocated_bit_rate.yfilter != YFilter.not_set or
                            self.is_max_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.is_max_bc0_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.is_max_bc1_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.max_bandwidth.yfilter != YFilter.not_set or
                            self.max_flow_bandwidth.yfilter != YFilter.not_set or
                            self.max_pool0_bandwidth.yfilter != YFilter.not_set or
                            self.max_pool1_bandwidth.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "standard-dste-interface" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.allocated_bit_rate.is_set or self.allocated_bit_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.allocated_bit_rate.get_name_leafdata())
                        if (self.is_max_bandwidth_absolute.is_set or self.is_max_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_bandwidth_absolute.get_name_leafdata())
                        if (self.is_max_bc0_bandwidth_absolute.is_set or self.is_max_bc0_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_bc0_bandwidth_absolute.get_name_leafdata())
                        if (self.is_max_bc1_bandwidth_absolute.is_set or self.is_max_bc1_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_bc1_bandwidth_absolute.get_name_leafdata())
                        if (self.max_bandwidth.is_set or self.max_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_bandwidth.get_name_leafdata())
                        if (self.max_flow_bandwidth.is_set or self.max_flow_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_flow_bandwidth.get_name_leafdata())
                        if (self.max_pool0_bandwidth.is_set or self.max_pool0_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_pool0_bandwidth.get_name_leafdata())
                        if (self.max_pool1_bandwidth.is_set or self.max_pool1_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_pool1_bandwidth.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "allocated-bit-rate" or name == "is-max-bandwidth-absolute" or name == "is-max-bc0-bandwidth-absolute" or name == "is-max-bc1-bandwidth-absolute" or name == "max-bandwidth" or name == "max-flow-bandwidth" or name == "max-pool0-bandwidth" or name == "max-pool1-bandwidth"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "allocated-bit-rate"):
                            self.allocated_bit_rate = value
                            self.allocated_bit_rate.value_namespace = name_space
                            self.allocated_bit_rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-bandwidth-absolute"):
                            self.is_max_bandwidth_absolute = value
                            self.is_max_bandwidth_absolute.value_namespace = name_space
                            self.is_max_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-bc0-bandwidth-absolute"):
                            self.is_max_bc0_bandwidth_absolute = value
                            self.is_max_bc0_bandwidth_absolute.value_namespace = name_space
                            self.is_max_bc0_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-bc1-bandwidth-absolute"):
                            self.is_max_bc1_bandwidth_absolute = value
                            self.is_max_bc1_bandwidth_absolute.value_namespace = name_space
                            self.is_max_bc1_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-bandwidth"):
                            self.max_bandwidth = value
                            self.max_bandwidth.value_namespace = name_space
                            self.max_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-flow-bandwidth"):
                            self.max_flow_bandwidth = value
                            self.max_flow_bandwidth.value_namespace = name_space
                            self.max_flow_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-pool0-bandwidth"):
                            self.max_pool0_bandwidth = value
                            self.max_pool0_bandwidth.value_namespace = name_space
                            self.max_pool0_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-pool1-bandwidth"):
                            self.max_pool1_bandwidth = value
                            self.max_pool1_bandwidth.value_namespace = name_space
                            self.max_pool1_bandwidth.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.dste_mode.is_set or
                        (self.pre_standard_dste_interface is not None and self.pre_standard_dste_interface.has_data()) or
                        (self.standard_dste_interface is not None and self.standard_dste_interface.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.dste_mode.yfilter != YFilter.not_set or
                        (self.pre_standard_dste_interface is not None and self.pre_standard_dste_interface.has_operation()) or
                        (self.standard_dste_interface is not None and self.standard_dste_interface.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bandwidth-information" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.dste_mode.is_set or self.dste_mode.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.dste_mode.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "pre-standard-dste-interface"):
                        if (self.pre_standard_dste_interface is None):
                            self.pre_standard_dste_interface = RsvpStandby.InterfaceBriefs.InterfaceBrief.BandwidthInformation.PreStandardDsteInterface()
                            self.pre_standard_dste_interface.parent = self
                            self._children_name_map["pre_standard_dste_interface"] = "pre-standard-dste-interface"
                        return self.pre_standard_dste_interface

                    if (child_yang_name == "standard-dste-interface"):
                        if (self.standard_dste_interface is None):
                            self.standard_dste_interface = RsvpStandby.InterfaceBriefs.InterfaceBrief.BandwidthInformation.StandardDsteInterface()
                            self.standard_dste_interface.parent = self
                            self._children_name_map["standard_dste_interface"] = "standard-dste-interface"
                        return self.standard_dste_interface

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "pre-standard-dste-interface" or name == "standard-dste-interface" or name == "dste-mode"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "dste-mode"):
                        self.dste_mode = value
                        self.dste_mode.value_namespace = name_space
                        self.dste_mode.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.interface_name.is_set or
                    self.interface_name_xr.is_set or
                    (self.bandwidth_information is not None and self.bandwidth_information.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.interface_name.yfilter != YFilter.not_set or
                    self.interface_name_xr.yfilter != YFilter.not_set or
                    (self.bandwidth_information is not None and self.bandwidth_information.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "interface-brief" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/interface-briefs/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.interface_name_xr.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "bandwidth-information"):
                    if (self.bandwidth_information is None):
                        self.bandwidth_information = RsvpStandby.InterfaceBriefs.InterfaceBrief.BandwidthInformation()
                        self.bandwidth_information.parent = self
                        self._children_name_map["bandwidth_information"] = "bandwidth-information"
                    return self.bandwidth_information

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "bandwidth-information" or name == "interface-name" or name == "interface-name-xr"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "interface-name"):
                    self.interface_name = value
                    self.interface_name.value_namespace = name_space
                    self.interface_name.value_namespace_prefix = name_space_prefix
                if(value_path == "interface-name-xr"):
                    self.interface_name_xr = value
                    self.interface_name_xr.value_namespace = name_space
                    self.interface_name_xr.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.interface_brief:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.interface_brief:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "interface-briefs" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "interface-brief"):
                for c in self.interface_brief:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = RsvpStandby.InterfaceBriefs.InterfaceBrief()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.interface_brief.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "interface-brief"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class SessionDetaileds(Entity):
        """
        Table of detailed info about sessions
        
        .. attribute:: session_detailed
        
        	Detailed info about session
        	**type**\: list of    :py:class:`SessionDetailed <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(RsvpStandby.SessionDetaileds, self).__init__()

            self.yang_name = "session-detaileds"
            self.yang_parent_name = "rsvp-standby"

            self.session_detailed = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(RsvpStandby.SessionDetaileds, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(RsvpStandby.SessionDetaileds, self).__setattr__(name, value)


        class SessionDetailed(Entity):
            """
            Detailed info about session
            
            .. attribute:: compact
            
            	Compact session data
            	**type**\:   :py:class:`Compact <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.Compact>`
            
            .. attribute:: destination_address
            
            	Destination Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: destination_port
            
            	Destination Port
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: extended_tunnel_id
            
            	Extended Tunnel ID
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: p2mp_id
            
            	P2MP ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: protocol
            
            	Protocol
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: psb_rsb_info
            
            	Path and Reservation Info
            	**type**\: list of    :py:class:`PsbRsbInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo>`
            
            .. attribute:: s2l_sub_lsp
            
            	RSVP S2L Sub\-LSP information
            	**type**\:   :py:class:`S2LSubLsp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.S2LSubLsp>`
            
            .. attribute:: session_type
            
            	Session Type
            	**type**\:   :py:class:`RsvpSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpSession>`
            
            .. attribute:: vrf_name
            
            	VRF Name
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(RsvpStandby.SessionDetaileds.SessionDetailed, self).__init__()

                self.yang_name = "session-detailed"
                self.yang_parent_name = "session-detaileds"

                self.destination_address = YLeaf(YType.str, "destination-address")

                self.destination_port = YLeaf(YType.int32, "destination-port")

                self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                self.p2mp_id = YLeaf(YType.int32, "p2mp-id")

                self.protocol = YLeaf(YType.int32, "protocol")

                self.session_type = YLeaf(YType.enumeration, "session-type")

                self.vrf_name = YLeaf(YType.str, "vrf-name")

                self.compact = RsvpStandby.SessionDetaileds.SessionDetailed.Compact()
                self.compact.parent = self
                self._children_name_map["compact"] = "compact"
                self._children_yang_names.add("compact")

                self.s2l_sub_lsp = RsvpStandby.SessionDetaileds.SessionDetailed.S2LSubLsp()
                self.s2l_sub_lsp.parent = self
                self._children_name_map["s2l_sub_lsp"] = "s2l-sub-lsp"
                self._children_yang_names.add("s2l-sub-lsp")

                self.psb_rsb_info = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("destination_address",
                                "destination_port",
                                "extended_tunnel_id",
                                "p2mp_id",
                                "protocol",
                                "session_type",
                                "vrf_name") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(RsvpStandby.SessionDetaileds.SessionDetailed, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(RsvpStandby.SessionDetaileds.SessionDetailed, self).__setattr__(name, value)


            class Compact(Entity):
                """
                Compact session data
                
                .. attribute:: detail_list_size
                
                	Number of elements in detail list
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ps_bs
                
                	Number of path state block states
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: requests
                
                	Number of request states
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rs_bs
                
                	Number of reservation state block states
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: session
                
                	RSVP Session Information
                	**type**\:   :py:class:`Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.Compact.Session>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.SessionDetaileds.SessionDetailed.Compact, self).__init__()

                    self.yang_name = "compact"
                    self.yang_parent_name = "session-detailed"

                    self.detail_list_size = YLeaf(YType.uint32, "detail-list-size")

                    self.ps_bs = YLeaf(YType.uint32, "ps-bs")

                    self.requests = YLeaf(YType.uint32, "requests")

                    self.rs_bs = YLeaf(YType.uint32, "rs-bs")

                    self.session = RsvpStandby.SessionDetaileds.SessionDetailed.Compact.Session()
                    self.session.parent = self
                    self._children_name_map["session"] = "session"
                    self._children_yang_names.add("session")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("detail_list_size",
                                    "ps_bs",
                                    "requests",
                                    "rs_bs") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.SessionDetaileds.SessionDetailed.Compact, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.SessionDetaileds.SessionDetailed.Compact, self).__setattr__(name, value)


                class Session(Entity):
                    """
                    RSVP Session Information
                    
                    .. attribute:: rsvp_session
                    
                    	RSVP Session
                    	**type**\:   :py:class:`RsvpSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.SessionDetaileds.SessionDetailed.Compact.Session, self).__init__()

                        self.yang_name = "session"
                        self.yang_parent_name = "compact"

                        self.rsvp_session = RsvpStandby.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession()
                        self.rsvp_session.parent = self
                        self._children_name_map["rsvp_session"] = "rsvp-session"
                        self._children_yang_names.add("rsvp-session")


                    class RsvpSession(Entity):
                        """
                        RSVP Session
                        
                        .. attribute:: ipv4
                        
                        	UDP IPv4 session
                        	**type**\:   :py:class:`Ipv4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession.Ipv4>`
                        
                        .. attribute:: ipv4_lsp_session
                        
                        	IPv4 LSP session
                        	**type**\:   :py:class:`Ipv4LspSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession.Ipv4LspSession>`
                        
                        .. attribute:: ipv4_p2mp_lsp_session
                        
                        	IPv4 P2MP LSP session
                        	**type**\:   :py:class:`Ipv4P2MpLspSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession.Ipv4P2MpLspSession>`
                        
                        .. attribute:: ipv4_uni_session
                        
                        	IPv4 UNI session
                        	**type**\:   :py:class:`Ipv4UniSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession.Ipv4UniSession>`
                        
                        .. attribute:: session_type
                        
                        	SessionType
                        	**type**\:   :py:class:`RsvpMgmtSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtSession>`
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession, self).__init__()

                            self.yang_name = "rsvp-session"
                            self.yang_parent_name = "session"

                            self.session_type = YLeaf(YType.enumeration, "session-type")

                            self.ipv4 = RsvpStandby.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession.Ipv4()
                            self.ipv4.parent = self
                            self._children_name_map["ipv4"] = "ipv4"
                            self._children_yang_names.add("ipv4")

                            self.ipv4_lsp_session = RsvpStandby.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession.Ipv4LspSession()
                            self.ipv4_lsp_session.parent = self
                            self._children_name_map["ipv4_lsp_session"] = "ipv4-lsp-session"
                            self._children_yang_names.add("ipv4-lsp-session")

                            self.ipv4_p2mp_lsp_session = RsvpStandby.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession.Ipv4P2MpLspSession()
                            self.ipv4_p2mp_lsp_session.parent = self
                            self._children_name_map["ipv4_p2mp_lsp_session"] = "ipv4-p2mp-lsp-session"
                            self._children_yang_names.add("ipv4-p2mp-lsp-session")

                            self.ipv4_uni_session = RsvpStandby.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession.Ipv4UniSession()
                            self.ipv4_uni_session.parent = self
                            self._children_name_map["ipv4_uni_session"] = "ipv4-uni-session"
                            self._children_yang_names.add("ipv4-uni-session")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("session_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession, self).__setattr__(name, value)


                        class Ipv4(Entity):
                            """
                            UDP IPv4 session
                            
                            .. attribute:: destination_address
                            
                            	Destination address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: destination_port
                            
                            	The Session Destination Port
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: protocol
                            
                            	Protocol type (originally defined in RFC 790, further values in subsequent RFCs)
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(RsvpStandby.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession.Ipv4, self).__init__()

                                self.yang_name = "ipv4"
                                self.yang_parent_name = "rsvp-session"

                                self.destination_address = YLeaf(YType.str, "destination-address")

                                self.destination_port = YLeaf(YType.uint16, "destination-port")

                                self.protocol = YLeaf(YType.uint8, "protocol")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("destination_address",
                                                "destination_port",
                                                "protocol") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(RsvpStandby.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession.Ipv4, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(RsvpStandby.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession.Ipv4, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.destination_address.is_set or
                                    self.destination_port.is_set or
                                    self.protocol.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.destination_address.yfilter != YFilter.not_set or
                                    self.destination_port.yfilter != YFilter.not_set or
                                    self.protocol.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ipv4" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/compact/session/rsvp-session/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.destination_address.get_name_leafdata())
                                if (self.destination_port.is_set or self.destination_port.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.destination_port.get_name_leafdata())
                                if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protocol.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "destination-address" or name == "destination-port" or name == "protocol"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "destination-address"):
                                    self.destination_address = value
                                    self.destination_address.value_namespace = name_space
                                    self.destination_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "destination-port"):
                                    self.destination_port = value
                                    self.destination_port.value_namespace = name_space
                                    self.destination_port.value_namespace_prefix = name_space_prefix
                                if(value_path == "protocol"):
                                    self.protocol = value
                                    self.protocol.value_namespace = name_space
                                    self.protocol.value_namespace_prefix = name_space_prefix


                        class Ipv4LspSession(Entity):
                            """
                            IPv4 LSP session
                            
                            .. attribute:: destination_address
                            
                            	Destination address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: extended_tunnel_id
                            
                            	The Session Extended Tunnel ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: tunnel_id
                            
                            	The Session Tunnel ID
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(RsvpStandby.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession.Ipv4LspSession, self).__init__()

                                self.yang_name = "ipv4-lsp-session"
                                self.yang_parent_name = "rsvp-session"

                                self.destination_address = YLeaf(YType.str, "destination-address")

                                self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                                self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("destination_address",
                                                "extended_tunnel_id",
                                                "tunnel_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(RsvpStandby.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession.Ipv4LspSession, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(RsvpStandby.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession.Ipv4LspSession, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.destination_address.is_set or
                                    self.extended_tunnel_id.is_set or
                                    self.tunnel_id.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.destination_address.yfilter != YFilter.not_set or
                                    self.extended_tunnel_id.yfilter != YFilter.not_set or
                                    self.tunnel_id.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ipv4-lsp-session" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/compact/session/rsvp-session/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.destination_address.get_name_leafdata())
                                if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "destination-address" or name == "extended-tunnel-id" or name == "tunnel-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "destination-address"):
                                    self.destination_address = value
                                    self.destination_address.value_namespace = name_space
                                    self.destination_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "extended-tunnel-id"):
                                    self.extended_tunnel_id = value
                                    self.extended_tunnel_id.value_namespace = name_space
                                    self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "tunnel-id"):
                                    self.tunnel_id = value
                                    self.tunnel_id.value_namespace = name_space
                                    self.tunnel_id.value_namespace_prefix = name_space_prefix


                        class Ipv4UniSession(Entity):
                            """
                            IPv4 UNI session
                            
                            .. attribute:: destination_address
                            
                            	Destination address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: extended_address
                            
                            	The Session Extended Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: tunnel_id
                            
                            	The Session Tunnel ID
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(RsvpStandby.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession.Ipv4UniSession, self).__init__()

                                self.yang_name = "ipv4-uni-session"
                                self.yang_parent_name = "rsvp-session"

                                self.destination_address = YLeaf(YType.str, "destination-address")

                                self.extended_address = YLeaf(YType.str, "extended-address")

                                self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("destination_address",
                                                "extended_address",
                                                "tunnel_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(RsvpStandby.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession.Ipv4UniSession, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(RsvpStandby.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession.Ipv4UniSession, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.destination_address.is_set or
                                    self.extended_address.is_set or
                                    self.tunnel_id.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.destination_address.yfilter != YFilter.not_set or
                                    self.extended_address.yfilter != YFilter.not_set or
                                    self.tunnel_id.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ipv4-uni-session" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/compact/session/rsvp-session/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.destination_address.get_name_leafdata())
                                if (self.extended_address.is_set or self.extended_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.extended_address.get_name_leafdata())
                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "destination-address" or name == "extended-address" or name == "tunnel-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "destination-address"):
                                    self.destination_address = value
                                    self.destination_address.value_namespace = name_space
                                    self.destination_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "extended-address"):
                                    self.extended_address = value
                                    self.extended_address.value_namespace = name_space
                                    self.extended_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "tunnel-id"):
                                    self.tunnel_id = value
                                    self.tunnel_id.value_namespace = name_space
                                    self.tunnel_id.value_namespace_prefix = name_space_prefix


                        class Ipv4P2MpLspSession(Entity):
                            """
                            IPv4 P2MP LSP session
                            
                            .. attribute:: extended_tunnel_id
                            
                            	The Session Extended Tunnel ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: p2mp_id
                            
                            	The Point to Multipoint ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tunnel_id
                            
                            	The Session Tunnel ID
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(RsvpStandby.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession.Ipv4P2MpLspSession, self).__init__()

                                self.yang_name = "ipv4-p2mp-lsp-session"
                                self.yang_parent_name = "rsvp-session"

                                self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                                self.p2mp_id = YLeaf(YType.uint32, "p2mp-id")

                                self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("extended_tunnel_id",
                                                "p2mp_id",
                                                "tunnel_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(RsvpStandby.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession.Ipv4P2MpLspSession, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(RsvpStandby.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession.Ipv4P2MpLspSession, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.extended_tunnel_id.is_set or
                                    self.p2mp_id.is_set or
                                    self.tunnel_id.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.extended_tunnel_id.yfilter != YFilter.not_set or
                                    self.p2mp_id.yfilter != YFilter.not_set or
                                    self.tunnel_id.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ipv4-p2mp-lsp-session" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/compact/session/rsvp-session/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                                if (self.p2mp_id.is_set or self.p2mp_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.p2mp_id.get_name_leafdata())
                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "extended-tunnel-id" or name == "p2mp-id" or name == "tunnel-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "extended-tunnel-id"):
                                    self.extended_tunnel_id = value
                                    self.extended_tunnel_id.value_namespace = name_space
                                    self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "p2mp-id"):
                                    self.p2mp_id = value
                                    self.p2mp_id.value_namespace = name_space
                                    self.p2mp_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "tunnel-id"):
                                    self.tunnel_id = value
                                    self.tunnel_id.value_namespace = name_space
                                    self.tunnel_id.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.session_type.is_set or
                                (self.ipv4 is not None and self.ipv4.has_data()) or
                                (self.ipv4_lsp_session is not None and self.ipv4_lsp_session.has_data()) or
                                (self.ipv4_p2mp_lsp_session is not None and self.ipv4_p2mp_lsp_session.has_data()) or
                                (self.ipv4_uni_session is not None and self.ipv4_uni_session.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.session_type.yfilter != YFilter.not_set or
                                (self.ipv4 is not None and self.ipv4.has_operation()) or
                                (self.ipv4_lsp_session is not None and self.ipv4_lsp_session.has_operation()) or
                                (self.ipv4_p2mp_lsp_session is not None and self.ipv4_p2mp_lsp_session.has_operation()) or
                                (self.ipv4_uni_session is not None and self.ipv4_uni_session.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rsvp-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/compact/session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.session_type.is_set or self.session_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.session_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "ipv4"):
                                if (self.ipv4 is None):
                                    self.ipv4 = RsvpStandby.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession.Ipv4()
                                    self.ipv4.parent = self
                                    self._children_name_map["ipv4"] = "ipv4"
                                return self.ipv4

                            if (child_yang_name == "ipv4-lsp-session"):
                                if (self.ipv4_lsp_session is None):
                                    self.ipv4_lsp_session = RsvpStandby.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession.Ipv4LspSession()
                                    self.ipv4_lsp_session.parent = self
                                    self._children_name_map["ipv4_lsp_session"] = "ipv4-lsp-session"
                                return self.ipv4_lsp_session

                            if (child_yang_name == "ipv4-p2mp-lsp-session"):
                                if (self.ipv4_p2mp_lsp_session is None):
                                    self.ipv4_p2mp_lsp_session = RsvpStandby.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession.Ipv4P2MpLspSession()
                                    self.ipv4_p2mp_lsp_session.parent = self
                                    self._children_name_map["ipv4_p2mp_lsp_session"] = "ipv4-p2mp-lsp-session"
                                return self.ipv4_p2mp_lsp_session

                            if (child_yang_name == "ipv4-uni-session"):
                                if (self.ipv4_uni_session is None):
                                    self.ipv4_uni_session = RsvpStandby.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession.Ipv4UniSession()
                                    self.ipv4_uni_session.parent = self
                                    self._children_name_map["ipv4_uni_session"] = "ipv4-uni-session"
                                return self.ipv4_uni_session

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ipv4" or name == "ipv4-lsp-session" or name == "ipv4-p2mp-lsp-session" or name == "ipv4-uni-session" or name == "session-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "session-type"):
                                self.session_type = value
                                self.session_type.value_namespace = name_space
                                self.session_type.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (self.rsvp_session is not None and self.rsvp_session.has_data())

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.rsvp_session is not None and self.rsvp_session.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "session" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/compact/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "rsvp-session"):
                            if (self.rsvp_session is None):
                                self.rsvp_session = RsvpStandby.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession()
                                self.rsvp_session.parent = self
                                self._children_name_map["rsvp_session"] = "rsvp-session"
                            return self.rsvp_session

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "rsvp-session"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        self.detail_list_size.is_set or
                        self.ps_bs.is_set or
                        self.requests.is_set or
                        self.rs_bs.is_set or
                        (self.session is not None and self.session.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.detail_list_size.yfilter != YFilter.not_set or
                        self.ps_bs.yfilter != YFilter.not_set or
                        self.requests.yfilter != YFilter.not_set or
                        self.rs_bs.yfilter != YFilter.not_set or
                        (self.session is not None and self.session.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "compact" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.detail_list_size.is_set or self.detail_list_size.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.detail_list_size.get_name_leafdata())
                    if (self.ps_bs.is_set or self.ps_bs.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ps_bs.get_name_leafdata())
                    if (self.requests.is_set or self.requests.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.requests.get_name_leafdata())
                    if (self.rs_bs.is_set or self.rs_bs.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rs_bs.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "session"):
                        if (self.session is None):
                            self.session = RsvpStandby.SessionDetaileds.SessionDetailed.Compact.Session()
                            self.session.parent = self
                            self._children_name_map["session"] = "session"
                        return self.session

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "session" or name == "detail-list-size" or name == "ps-bs" or name == "requests" or name == "rs-bs"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "detail-list-size"):
                        self.detail_list_size = value
                        self.detail_list_size.value_namespace = name_space
                        self.detail_list_size.value_namespace_prefix = name_space_prefix
                    if(value_path == "ps-bs"):
                        self.ps_bs = value
                        self.ps_bs.value_namespace = name_space
                        self.ps_bs.value_namespace_prefix = name_space_prefix
                    if(value_path == "requests"):
                        self.requests = value
                        self.requests.value_namespace = name_space
                        self.requests.value_namespace_prefix = name_space_prefix
                    if(value_path == "rs-bs"):
                        self.rs_bs = value
                        self.rs_bs.value_namespace = name_space
                        self.rs_bs.value_namespace_prefix = name_space_prefix


            class S2LSubLsp(Entity):
                """
                RSVP S2L Sub\-LSP information
                
                .. attribute:: s2l_destination_address
                
                	S2L Sub\-LSP Destination Address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.SessionDetaileds.SessionDetailed.S2LSubLsp, self).__init__()

                    self.yang_name = "s2l-sub-lsp"
                    self.yang_parent_name = "session-detailed"

                    self.s2l_destination_address = YLeaf(YType.str, "s2l-destination-address")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("s2l_destination_address") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.SessionDetaileds.SessionDetailed.S2LSubLsp, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.SessionDetaileds.SessionDetailed.S2LSubLsp, self).__setattr__(name, value)

                def has_data(self):
                    return self.s2l_destination_address.is_set

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.s2l_destination_address.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "s2l-sub-lsp" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.s2l_destination_address.is_set or self.s2l_destination_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.s2l_destination_address.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "s2l-destination-address"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "s2l-destination-address"):
                        self.s2l_destination_address = value
                        self.s2l_destination_address.value_namespace = name_space
                        self.s2l_destination_address.value_namespace_prefix = name_space_prefix


            class PsbRsbInfo(Entity):
                """
                Path and Reservation Info
                
                .. attribute:: psb_info
                
                	Path Info
                	**type**\: list of    :py:class:`PsbInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo>`
                
                .. attribute:: rsb_info
                
                	Reservation Info
                	**type**\: list of    :py:class:`RsbInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo, self).__init__()

                    self.yang_name = "psb-rsb-info"
                    self.yang_parent_name = "session-detailed"

                    self.psb_info = YList(self)
                    self.rsb_info = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo, self).__setattr__(name, value)


                class PsbInfo(Entity):
                    """
                    Path Info
                    
                    .. attribute:: association
                    
                    	Association object
                    	**type**\:   :py:class:`Association <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association>`
                    
                    .. attribute:: destination_address
                    
                    	Destination address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: ero
                    
                    	Explicit Route Sub Objects
                    	**type**\: list of    :py:class:`Ero <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Ero>`
                    
                    .. attribute:: generic_in_label
                    
                    	Generic Label for inbound traffic
                    	**type**\:   :py:class:`GenericInLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericInLabel>`
                    
                    .. attribute:: generic_traffic_spec
                    
                    	Generic Traffic Spec object
                    	**type**\:   :py:class:`GenericTrafficSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericTrafficSpec>`
                    
                    .. attribute:: in_interface
                    
                    	Interface on which inbound message was received
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: in_label
                    
                    	Label for inbound traffic
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: incoming_interface_address
                    
                    	IP address of Path's incoming interface
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: is_bad_address
                    
                    	Address validity
                    	**type**\:  bool
                    
                    .. attribute:: is_ero_valid
                    
                    	ERO validity
                    	**type**\:  bool
                    
                    .. attribute:: is_rro_valid
                    
                    	RRO validity
                    	**type**\:  bool
                    
                    .. attribute:: is_traffic_spec_valid
                    
                    	Traffic Spec validity
                    	**type**\:  bool
                    
                    .. attribute:: is_valid
                    
                    	Entry validity
                    	**type**\:  bool
                    
                    .. attribute:: lsp_id
                    
                    	LSP ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: lsp_wrap_label
                    
                    	LSP Wrap Label
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: p2mp_sub_group_origin
                    
                    	Point to Multipoint SubGroup Origin
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: protection
                    
                    	Protection object
                    	**type**\:   :py:class:`Protection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Protection>`
                    
                    .. attribute:: reverse_lsp
                    
                    	Reverse LSP object
                    	**type**\:   :py:class:`ReverseLsp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp>`
                    
                    .. attribute:: rro
                    
                    	Record Route Sub Objects
                    	**type**\: list of    :py:class:`Rro <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro>`
                    
                    .. attribute:: sub_group_id
                    
                    	Point to Multipoint Subgroup ID
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: traffic_spec
                    
                    	Traffic Spec object
                    	**type**\:   :py:class:`TrafficSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.TrafficSpec>`
                    
                    .. attribute:: tunnel_name
                    
                    	Tunnel name
                    	**type**\:  str
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo, self).__init__()

                        self.yang_name = "psb-info"
                        self.yang_parent_name = "psb-rsb-info"

                        self.destination_address = YLeaf(YType.str, "destination-address")

                        self.in_interface = YLeaf(YType.str, "in-interface")

                        self.in_label = YLeaf(YType.uint32, "in-label")

                        self.incoming_interface_address = YLeaf(YType.str, "incoming-interface-address")

                        self.is_bad_address = YLeaf(YType.boolean, "is-bad-address")

                        self.is_ero_valid = YLeaf(YType.boolean, "is-ero-valid")

                        self.is_rro_valid = YLeaf(YType.boolean, "is-rro-valid")

                        self.is_traffic_spec_valid = YLeaf(YType.boolean, "is-traffic-spec-valid")

                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                        self.lsp_id = YLeaf(YType.uint32, "lsp-id")

                        self.lsp_wrap_label = YLeaf(YType.uint32, "lsp-wrap-label")

                        self.p2mp_sub_group_origin = YLeaf(YType.str, "p2mp-sub-group-origin")

                        self.sub_group_id = YLeaf(YType.uint16, "sub-group-id")

                        self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                        self.association = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association()
                        self.association.parent = self
                        self._children_name_map["association"] = "association"
                        self._children_yang_names.add("association")

                        self.generic_in_label = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericInLabel()
                        self.generic_in_label.parent = self
                        self._children_name_map["generic_in_label"] = "generic-in-label"
                        self._children_yang_names.add("generic-in-label")

                        self.generic_traffic_spec = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericTrafficSpec()
                        self.generic_traffic_spec.parent = self
                        self._children_name_map["generic_traffic_spec"] = "generic-traffic-spec"
                        self._children_yang_names.add("generic-traffic-spec")

                        self.protection = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Protection()
                        self.protection.parent = self
                        self._children_name_map["protection"] = "protection"
                        self._children_yang_names.add("protection")

                        self.reverse_lsp = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp()
                        self.reverse_lsp.parent = self
                        self._children_name_map["reverse_lsp"] = "reverse-lsp"
                        self._children_yang_names.add("reverse-lsp")

                        self.traffic_spec = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.TrafficSpec()
                        self.traffic_spec.parent = self
                        self._children_name_map["traffic_spec"] = "traffic-spec"
                        self._children_yang_names.add("traffic-spec")

                        self.ero = YList(self)
                        self.rro = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("destination_address",
                                        "in_interface",
                                        "in_label",
                                        "incoming_interface_address",
                                        "is_bad_address",
                                        "is_ero_valid",
                                        "is_rro_valid",
                                        "is_traffic_spec_valid",
                                        "is_valid",
                                        "lsp_id",
                                        "lsp_wrap_label",
                                        "p2mp_sub_group_origin",
                                        "sub_group_id",
                                        "tunnel_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo, self).__setattr__(name, value)


                    class GenericInLabel(Entity):
                        """
                        Generic Label for inbound traffic
                        
                        .. attribute:: generalized_label
                        
                        	Generalized Label
                        	**type**\:   :py:class:`GeneralizedLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericInLabel.GeneralizedLabel>`
                        
                        .. attribute:: generic_label_type
                        
                        	GenericLabelType
                        	**type**\:   :py:class:`RsvpMgmtGenericLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtGenericLabel>`
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericInLabel, self).__init__()

                            self.yang_name = "generic-in-label"
                            self.yang_parent_name = "psb-info"

                            self.generic_label_type = YLeaf(YType.enumeration, "generic-label-type")

                            self.generalized_label = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericInLabel.GeneralizedLabel()
                            self.generalized_label.parent = self
                            self._children_name_map["generalized_label"] = "generalized-label"
                            self._children_yang_names.add("generalized-label")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("generic_label_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericInLabel, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericInLabel, self).__setattr__(name, value)


                        class GeneralizedLabel(Entity):
                            """
                            Generalized Label
                            
                            .. attribute:: value
                            
                            	Generalized Label Value
                            	**type**\:  list of int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericInLabel.GeneralizedLabel, self).__init__()

                                self.yang_name = "generalized-label"
                                self.yang_parent_name = "generic-in-label"

                                self.value = YLeafList(YType.uint32, "value")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("value") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericInLabel.GeneralizedLabel, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericInLabel.GeneralizedLabel, self).__setattr__(name, value)

                            def has_data(self):
                                for leaf in self.value.getYLeafs():
                                    if (leaf.yfilter != YFilter.not_set):
                                        return True
                                return False

                            def has_operation(self):
                                for leaf in self.value.getYLeafs():
                                    if (leaf.is_set):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.value.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "generalized-label" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/psb-rsb-info/psb-info/generic-in-label/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                leaf_name_data.extend(self.value.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "value"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "value"):
                                    self.value.append(value)

                        def has_data(self):
                            return (
                                self.generic_label_type.is_set or
                                (self.generalized_label is not None and self.generalized_label.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.generic_label_type.yfilter != YFilter.not_set or
                                (self.generalized_label is not None and self.generalized_label.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "generic-in-label" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/psb-rsb-info/psb-info/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.generic_label_type.is_set or self.generic_label_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.generic_label_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "generalized-label"):
                                if (self.generalized_label is None):
                                    self.generalized_label = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericInLabel.GeneralizedLabel()
                                    self.generalized_label.parent = self
                                    self._children_name_map["generalized_label"] = "generalized-label"
                                return self.generalized_label

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "generalized-label" or name == "generic-label-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "generic-label-type"):
                                self.generic_label_type = value
                                self.generic_label_type.value_namespace = name_space
                                self.generic_label_type.value_namespace_prefix = name_space_prefix


                    class TrafficSpec(Entity):
                        """
                        Traffic Spec object
                        
                        .. attribute:: traffic_average_rate
                        
                        	Traffic Average Rate in bytes per second
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: byte/s
                        
                        .. attribute:: traffic_max_burst
                        
                        	Traffic Maximum Burst
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: traffic_max_unit
                        
                        	Traffic Maximum Unit
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: traffic_min_unit
                        
                        	Traffic Minimum Unit
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: traffic_peak_rate
                        
                        	Traffic Peak Rate in bytes per second
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: byte/s
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.TrafficSpec, self).__init__()

                            self.yang_name = "traffic-spec"
                            self.yang_parent_name = "psb-info"

                            self.traffic_average_rate = YLeaf(YType.uint64, "traffic-average-rate")

                            self.traffic_max_burst = YLeaf(YType.uint64, "traffic-max-burst")

                            self.traffic_max_unit = YLeaf(YType.uint32, "traffic-max-unit")

                            self.traffic_min_unit = YLeaf(YType.uint32, "traffic-min-unit")

                            self.traffic_peak_rate = YLeaf(YType.uint64, "traffic-peak-rate")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("traffic_average_rate",
                                            "traffic_max_burst",
                                            "traffic_max_unit",
                                            "traffic_min_unit",
                                            "traffic_peak_rate") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.TrafficSpec, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.TrafficSpec, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.traffic_average_rate.is_set or
                                self.traffic_max_burst.is_set or
                                self.traffic_max_unit.is_set or
                                self.traffic_min_unit.is_set or
                                self.traffic_peak_rate.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.traffic_average_rate.yfilter != YFilter.not_set or
                                self.traffic_max_burst.yfilter != YFilter.not_set or
                                self.traffic_max_unit.yfilter != YFilter.not_set or
                                self.traffic_min_unit.yfilter != YFilter.not_set or
                                self.traffic_peak_rate.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "traffic-spec" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/psb-rsb-info/psb-info/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.traffic_average_rate.is_set or self.traffic_average_rate.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.traffic_average_rate.get_name_leafdata())
                            if (self.traffic_max_burst.is_set or self.traffic_max_burst.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.traffic_max_burst.get_name_leafdata())
                            if (self.traffic_max_unit.is_set or self.traffic_max_unit.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.traffic_max_unit.get_name_leafdata())
                            if (self.traffic_min_unit.is_set or self.traffic_min_unit.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.traffic_min_unit.get_name_leafdata())
                            if (self.traffic_peak_rate.is_set or self.traffic_peak_rate.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.traffic_peak_rate.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "traffic-average-rate" or name == "traffic-max-burst" or name == "traffic-max-unit" or name == "traffic-min-unit" or name == "traffic-peak-rate"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "traffic-average-rate"):
                                self.traffic_average_rate = value
                                self.traffic_average_rate.value_namespace = name_space
                                self.traffic_average_rate.value_namespace_prefix = name_space_prefix
                            if(value_path == "traffic-max-burst"):
                                self.traffic_max_burst = value
                                self.traffic_max_burst.value_namespace = name_space
                                self.traffic_max_burst.value_namespace_prefix = name_space_prefix
                            if(value_path == "traffic-max-unit"):
                                self.traffic_max_unit = value
                                self.traffic_max_unit.value_namespace = name_space
                                self.traffic_max_unit.value_namespace_prefix = name_space_prefix
                            if(value_path == "traffic-min-unit"):
                                self.traffic_min_unit = value
                                self.traffic_min_unit.value_namespace = name_space
                                self.traffic_min_unit.value_namespace_prefix = name_space_prefix
                            if(value_path == "traffic-peak-rate"):
                                self.traffic_peak_rate = value
                                self.traffic_peak_rate.value_namespace = name_space
                                self.traffic_peak_rate.value_namespace_prefix = name_space_prefix


                    class GenericTrafficSpec(Entity):
                        """
                        Generic Traffic Spec object
                        
                        .. attribute:: g709otn_tspec
                        
                        	G709 OTN Sender Tspec
                        	**type**\:   :py:class:`G709OtnTspec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericTrafficSpec.G709OtnTspec>`
                        
                        .. attribute:: intsrv_tspec
                        
                        	Integrated Services Sender Tspec
                        	**type**\:   :py:class:`IntsrvTspec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericTrafficSpec.IntsrvTspec>`
                        
                        .. attribute:: tspec_type
                        
                        	TspecType
                        	**type**\:   :py:class:`RsvpMgmtTspec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtTspec>`
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericTrafficSpec, self).__init__()

                            self.yang_name = "generic-traffic-spec"
                            self.yang_parent_name = "psb-info"

                            self.tspec_type = YLeaf(YType.enumeration, "tspec-type")

                            self.g709otn_tspec = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericTrafficSpec.G709OtnTspec()
                            self.g709otn_tspec.parent = self
                            self._children_name_map["g709otn_tspec"] = "g709otn-tspec"
                            self._children_yang_names.add("g709otn-tspec")

                            self.intsrv_tspec = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericTrafficSpec.IntsrvTspec()
                            self.intsrv_tspec.parent = self
                            self._children_name_map["intsrv_tspec"] = "intsrv-tspec"
                            self._children_yang_names.add("intsrv-tspec")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("tspec_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericTrafficSpec, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericTrafficSpec, self).__setattr__(name, value)


                        class G709OtnTspec(Entity):
                            """
                            G709 OTN Sender Tspec
                            
                            .. attribute:: traffic_bit_rate
                            
                            	G709 OTN Traffic Bit Rate
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: traffic_multiplier
                            
                            	G709 OTN Traffic Multiplier
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: traffic_nvc
                            
                            	G709 OTN Traffic NVC
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: traffic_signal_type
                            
                            	G709 OTN Traffic Signal Type (Refer G709 v3)
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericTrafficSpec.G709OtnTspec, self).__init__()

                                self.yang_name = "g709otn-tspec"
                                self.yang_parent_name = "generic-traffic-spec"

                                self.traffic_bit_rate = YLeaf(YType.uint64, "traffic-bit-rate")

                                self.traffic_multiplier = YLeaf(YType.uint16, "traffic-multiplier")

                                self.traffic_nvc = YLeaf(YType.uint16, "traffic-nvc")

                                self.traffic_signal_type = YLeaf(YType.uint8, "traffic-signal-type")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("traffic_bit_rate",
                                                "traffic_multiplier",
                                                "traffic_nvc",
                                                "traffic_signal_type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericTrafficSpec.G709OtnTspec, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericTrafficSpec.G709OtnTspec, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.traffic_bit_rate.is_set or
                                    self.traffic_multiplier.is_set or
                                    self.traffic_nvc.is_set or
                                    self.traffic_signal_type.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.traffic_bit_rate.yfilter != YFilter.not_set or
                                    self.traffic_multiplier.yfilter != YFilter.not_set or
                                    self.traffic_nvc.yfilter != YFilter.not_set or
                                    self.traffic_signal_type.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "g709otn-tspec" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/psb-rsb-info/psb-info/generic-traffic-spec/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.traffic_bit_rate.is_set or self.traffic_bit_rate.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.traffic_bit_rate.get_name_leafdata())
                                if (self.traffic_multiplier.is_set or self.traffic_multiplier.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.traffic_multiplier.get_name_leafdata())
                                if (self.traffic_nvc.is_set or self.traffic_nvc.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.traffic_nvc.get_name_leafdata())
                                if (self.traffic_signal_type.is_set or self.traffic_signal_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.traffic_signal_type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "traffic-bit-rate" or name == "traffic-multiplier" or name == "traffic-nvc" or name == "traffic-signal-type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "traffic-bit-rate"):
                                    self.traffic_bit_rate = value
                                    self.traffic_bit_rate.value_namespace = name_space
                                    self.traffic_bit_rate.value_namespace_prefix = name_space_prefix
                                if(value_path == "traffic-multiplier"):
                                    self.traffic_multiplier = value
                                    self.traffic_multiplier.value_namespace = name_space
                                    self.traffic_multiplier.value_namespace_prefix = name_space_prefix
                                if(value_path == "traffic-nvc"):
                                    self.traffic_nvc = value
                                    self.traffic_nvc.value_namespace = name_space
                                    self.traffic_nvc.value_namespace_prefix = name_space_prefix
                                if(value_path == "traffic-signal-type"):
                                    self.traffic_signal_type = value
                                    self.traffic_signal_type.value_namespace = name_space
                                    self.traffic_signal_type.value_namespace_prefix = name_space_prefix


                        class IntsrvTspec(Entity):
                            """
                            Integrated Services Sender Tspec
                            
                            .. attribute:: traffic_average_rate
                            
                            	Traffic Average Rate in bytes per second
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: byte/s
                            
                            .. attribute:: traffic_max_burst
                            
                            	Traffic Maximum Burst
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: traffic_max_unit
                            
                            	Traffic Maximum Unit
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: traffic_min_unit
                            
                            	Traffic Minimum Unit
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: traffic_peak_rate
                            
                            	Traffic Peak Rate in bytes per second
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: byte/s
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericTrafficSpec.IntsrvTspec, self).__init__()

                                self.yang_name = "intsrv-tspec"
                                self.yang_parent_name = "generic-traffic-spec"

                                self.traffic_average_rate = YLeaf(YType.uint64, "traffic-average-rate")

                                self.traffic_max_burst = YLeaf(YType.uint64, "traffic-max-burst")

                                self.traffic_max_unit = YLeaf(YType.uint32, "traffic-max-unit")

                                self.traffic_min_unit = YLeaf(YType.uint32, "traffic-min-unit")

                                self.traffic_peak_rate = YLeaf(YType.uint64, "traffic-peak-rate")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("traffic_average_rate",
                                                "traffic_max_burst",
                                                "traffic_max_unit",
                                                "traffic_min_unit",
                                                "traffic_peak_rate") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericTrafficSpec.IntsrvTspec, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericTrafficSpec.IntsrvTspec, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.traffic_average_rate.is_set or
                                    self.traffic_max_burst.is_set or
                                    self.traffic_max_unit.is_set or
                                    self.traffic_min_unit.is_set or
                                    self.traffic_peak_rate.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.traffic_average_rate.yfilter != YFilter.not_set or
                                    self.traffic_max_burst.yfilter != YFilter.not_set or
                                    self.traffic_max_unit.yfilter != YFilter.not_set or
                                    self.traffic_min_unit.yfilter != YFilter.not_set or
                                    self.traffic_peak_rate.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "intsrv-tspec" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/psb-rsb-info/psb-info/generic-traffic-spec/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.traffic_average_rate.is_set or self.traffic_average_rate.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.traffic_average_rate.get_name_leafdata())
                                if (self.traffic_max_burst.is_set or self.traffic_max_burst.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.traffic_max_burst.get_name_leafdata())
                                if (self.traffic_max_unit.is_set or self.traffic_max_unit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.traffic_max_unit.get_name_leafdata())
                                if (self.traffic_min_unit.is_set or self.traffic_min_unit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.traffic_min_unit.get_name_leafdata())
                                if (self.traffic_peak_rate.is_set or self.traffic_peak_rate.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.traffic_peak_rate.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "traffic-average-rate" or name == "traffic-max-burst" or name == "traffic-max-unit" or name == "traffic-min-unit" or name == "traffic-peak-rate"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "traffic-average-rate"):
                                    self.traffic_average_rate = value
                                    self.traffic_average_rate.value_namespace = name_space
                                    self.traffic_average_rate.value_namespace_prefix = name_space_prefix
                                if(value_path == "traffic-max-burst"):
                                    self.traffic_max_burst = value
                                    self.traffic_max_burst.value_namespace = name_space
                                    self.traffic_max_burst.value_namespace_prefix = name_space_prefix
                                if(value_path == "traffic-max-unit"):
                                    self.traffic_max_unit = value
                                    self.traffic_max_unit.value_namespace = name_space
                                    self.traffic_max_unit.value_namespace_prefix = name_space_prefix
                                if(value_path == "traffic-min-unit"):
                                    self.traffic_min_unit = value
                                    self.traffic_min_unit.value_namespace = name_space
                                    self.traffic_min_unit.value_namespace_prefix = name_space_prefix
                                if(value_path == "traffic-peak-rate"):
                                    self.traffic_peak_rate = value
                                    self.traffic_peak_rate.value_namespace = name_space
                                    self.traffic_peak_rate.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.tspec_type.is_set or
                                (self.g709otn_tspec is not None and self.g709otn_tspec.has_data()) or
                                (self.intsrv_tspec is not None and self.intsrv_tspec.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.tspec_type.yfilter != YFilter.not_set or
                                (self.g709otn_tspec is not None and self.g709otn_tspec.has_operation()) or
                                (self.intsrv_tspec is not None and self.intsrv_tspec.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "generic-traffic-spec" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/psb-rsb-info/psb-info/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.tspec_type.is_set or self.tspec_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tspec_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "g709otn-tspec"):
                                if (self.g709otn_tspec is None):
                                    self.g709otn_tspec = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericTrafficSpec.G709OtnTspec()
                                    self.g709otn_tspec.parent = self
                                    self._children_name_map["g709otn_tspec"] = "g709otn-tspec"
                                return self.g709otn_tspec

                            if (child_yang_name == "intsrv-tspec"):
                                if (self.intsrv_tspec is None):
                                    self.intsrv_tspec = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericTrafficSpec.IntsrvTspec()
                                    self.intsrv_tspec.parent = self
                                    self._children_name_map["intsrv_tspec"] = "intsrv-tspec"
                                return self.intsrv_tspec

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "g709otn-tspec" or name == "intsrv-tspec" or name == "tspec-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "tspec-type"):
                                self.tspec_type = value
                                self.tspec_type.value_namespace = name_space
                                self.tspec_type.value_namespace_prefix = name_space_prefix


                    class Association(Entity):
                        """
                        Association object
                        
                        .. attribute:: association_type
                        
                        	AssociationType
                        	**type**\:   :py:class:`RsvpMgmtAssociation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtAssociation>`
                        
                        .. attribute:: extended_ipv4
                        
                        	EXTENDED IPV4 ASSOCIATION Object
                        	**type**\:   :py:class:`ExtendedIpv4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association.ExtendedIpv4>`
                        
                        .. attribute:: extended_ipv6
                        
                        	EXTENDED IPV6 ASSOCIATION Object
                        	**type**\:   :py:class:`ExtendedIpv6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association.ExtendedIpv6>`
                        
                        .. attribute:: ipv4
                        
                        	IPV4 ASSOCIATION Object
                        	**type**\:   :py:class:`Ipv4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association.Ipv4>`
                        
                        .. attribute:: ipv6
                        
                        	IPV6 ASSOCIATION Object
                        	**type**\:   :py:class:`Ipv6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association.Ipv6>`
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association, self).__init__()

                            self.yang_name = "association"
                            self.yang_parent_name = "psb-info"

                            self.association_type = YLeaf(YType.enumeration, "association-type")

                            self.extended_ipv4 = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association.ExtendedIpv4()
                            self.extended_ipv4.parent = self
                            self._children_name_map["extended_ipv4"] = "extended-ipv4"
                            self._children_yang_names.add("extended-ipv4")

                            self.extended_ipv6 = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association.ExtendedIpv6()
                            self.extended_ipv6.parent = self
                            self._children_name_map["extended_ipv6"] = "extended-ipv6"
                            self._children_yang_names.add("extended-ipv6")

                            self.ipv4 = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association.Ipv4()
                            self.ipv4.parent = self
                            self._children_name_map["ipv4"] = "ipv4"
                            self._children_yang_names.add("ipv4")

                            self.ipv6 = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association.Ipv6()
                            self.ipv6.parent = self
                            self._children_name_map["ipv6"] = "ipv6"
                            self._children_yang_names.add("ipv6")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("association_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association, self).__setattr__(name, value)


                        class Ipv4(Entity):
                            """
                            IPV4 ASSOCIATION Object
                            
                            .. attribute:: id
                            
                            	Association ID
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: source
                            
                            	Association IPV4 Source Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: type
                            
                            	Association Type (RFC 4872)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association.Ipv4, self).__init__()

                                self.yang_name = "ipv4"
                                self.yang_parent_name = "association"

                                self.id = YLeaf(YType.uint16, "id")

                                self.source = YLeaf(YType.str, "source")

                                self.type = YLeaf(YType.uint16, "type")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("id",
                                                "source",
                                                "type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association.Ipv4, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association.Ipv4, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.id.is_set or
                                    self.source.is_set or
                                    self.type.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.id.yfilter != YFilter.not_set or
                                    self.source.yfilter != YFilter.not_set or
                                    self.type.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ipv4" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/psb-rsb-info/psb-info/association/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.id.is_set or self.id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.id.get_name_leafdata())
                                if (self.source.is_set or self.source.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.source.get_name_leafdata())
                                if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "id" or name == "source" or name == "type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "id"):
                                    self.id = value
                                    self.id.value_namespace = name_space
                                    self.id.value_namespace_prefix = name_space_prefix
                                if(value_path == "source"):
                                    self.source = value
                                    self.source.value_namespace = name_space
                                    self.source.value_namespace_prefix = name_space_prefix
                                if(value_path == "type"):
                                    self.type = value
                                    self.type.value_namespace = name_space
                                    self.type.value_namespace_prefix = name_space_prefix


                        class Ipv6(Entity):
                            """
                            IPV6 ASSOCIATION Object
                            
                            .. attribute:: id
                            
                            	Association ID
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: source
                            
                            	Association IPV6 Source Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: type
                            
                            	Association Type (RFC 4872)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association.Ipv6, self).__init__()

                                self.yang_name = "ipv6"
                                self.yang_parent_name = "association"

                                self.id = YLeaf(YType.uint16, "id")

                                self.source = YLeaf(YType.str, "source")

                                self.type = YLeaf(YType.uint16, "type")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("id",
                                                "source",
                                                "type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association.Ipv6, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association.Ipv6, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.id.is_set or
                                    self.source.is_set or
                                    self.type.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.id.yfilter != YFilter.not_set or
                                    self.source.yfilter != YFilter.not_set or
                                    self.type.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ipv6" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/psb-rsb-info/psb-info/association/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.id.is_set or self.id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.id.get_name_leafdata())
                                if (self.source.is_set or self.source.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.source.get_name_leafdata())
                                if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "id" or name == "source" or name == "type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "id"):
                                    self.id = value
                                    self.id.value_namespace = name_space
                                    self.id.value_namespace_prefix = name_space_prefix
                                if(value_path == "source"):
                                    self.source = value
                                    self.source.value_namespace = name_space
                                    self.source.value_namespace_prefix = name_space_prefix
                                if(value_path == "type"):
                                    self.type = value
                                    self.type.value_namespace = name_space
                                    self.type.value_namespace_prefix = name_space_prefix


                        class ExtendedIpv4(Entity):
                            """
                            EXTENDED IPV4 ASSOCIATION Object
                            
                            .. attribute:: extended_id
                            
                            	Extended Association ID
                            	**type**\:  list of int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: global_source
                            
                            	Global Association Source
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: id
                            
                            	Association ID
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: source
                            
                            	Association IPV4 Source Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: type
                            
                            	Association Type (RFC 4872)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association.ExtendedIpv4, self).__init__()

                                self.yang_name = "extended-ipv4"
                                self.yang_parent_name = "association"

                                self.extended_id = YLeafList(YType.uint32, "extended-id")

                                self.global_source = YLeaf(YType.uint32, "global-source")

                                self.id = YLeaf(YType.uint16, "id")

                                self.source = YLeaf(YType.str, "source")

                                self.type = YLeaf(YType.uint16, "type")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("extended_id",
                                                "global_source",
                                                "id",
                                                "source",
                                                "type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association.ExtendedIpv4, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association.ExtendedIpv4, self).__setattr__(name, value)

                            def has_data(self):
                                for leaf in self.extended_id.getYLeafs():
                                    if (leaf.yfilter != YFilter.not_set):
                                        return True
                                return (
                                    self.global_source.is_set or
                                    self.id.is_set or
                                    self.source.is_set or
                                    self.type.is_set)

                            def has_operation(self):
                                for leaf in self.extended_id.getYLeafs():
                                    if (leaf.is_set):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.extended_id.yfilter != YFilter.not_set or
                                    self.global_source.yfilter != YFilter.not_set or
                                    self.id.yfilter != YFilter.not_set or
                                    self.source.yfilter != YFilter.not_set or
                                    self.type.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "extended-ipv4" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/psb-rsb-info/psb-info/association/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.global_source.is_set or self.global_source.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.global_source.get_name_leafdata())
                                if (self.id.is_set or self.id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.id.get_name_leafdata())
                                if (self.source.is_set or self.source.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.source.get_name_leafdata())
                                if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.type.get_name_leafdata())

                                leaf_name_data.extend(self.extended_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "extended-id" or name == "global-source" or name == "id" or name == "source" or name == "type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "extended-id"):
                                    self.extended_id.append(value)
                                if(value_path == "global-source"):
                                    self.global_source = value
                                    self.global_source.value_namespace = name_space
                                    self.global_source.value_namespace_prefix = name_space_prefix
                                if(value_path == "id"):
                                    self.id = value
                                    self.id.value_namespace = name_space
                                    self.id.value_namespace_prefix = name_space_prefix
                                if(value_path == "source"):
                                    self.source = value
                                    self.source.value_namespace = name_space
                                    self.source.value_namespace_prefix = name_space_prefix
                                if(value_path == "type"):
                                    self.type = value
                                    self.type.value_namespace = name_space
                                    self.type.value_namespace_prefix = name_space_prefix


                        class ExtendedIpv6(Entity):
                            """
                            EXTENDED IPV6 ASSOCIATION Object
                            
                            .. attribute:: extended_id
                            
                            	Extended Association ID
                            	**type**\:  list of int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: global_source
                            
                            	Global Association Source
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: id
                            
                            	Association ID
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: source
                            
                            	Association IPV6 Source Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: type
                            
                            	Association Type (RFC 4872)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association.ExtendedIpv6, self).__init__()

                                self.yang_name = "extended-ipv6"
                                self.yang_parent_name = "association"

                                self.extended_id = YLeafList(YType.uint32, "extended-id")

                                self.global_source = YLeaf(YType.uint32, "global-source")

                                self.id = YLeaf(YType.uint16, "id")

                                self.source = YLeaf(YType.str, "source")

                                self.type = YLeaf(YType.uint16, "type")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("extended_id",
                                                "global_source",
                                                "id",
                                                "source",
                                                "type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association.ExtendedIpv6, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association.ExtendedIpv6, self).__setattr__(name, value)

                            def has_data(self):
                                for leaf in self.extended_id.getYLeafs():
                                    if (leaf.yfilter != YFilter.not_set):
                                        return True
                                return (
                                    self.global_source.is_set or
                                    self.id.is_set or
                                    self.source.is_set or
                                    self.type.is_set)

                            def has_operation(self):
                                for leaf in self.extended_id.getYLeafs():
                                    if (leaf.is_set):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.extended_id.yfilter != YFilter.not_set or
                                    self.global_source.yfilter != YFilter.not_set or
                                    self.id.yfilter != YFilter.not_set or
                                    self.source.yfilter != YFilter.not_set or
                                    self.type.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "extended-ipv6" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/psb-rsb-info/psb-info/association/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.global_source.is_set or self.global_source.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.global_source.get_name_leafdata())
                                if (self.id.is_set or self.id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.id.get_name_leafdata())
                                if (self.source.is_set or self.source.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.source.get_name_leafdata())
                                if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.type.get_name_leafdata())

                                leaf_name_data.extend(self.extended_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "extended-id" or name == "global-source" or name == "id" or name == "source" or name == "type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "extended-id"):
                                    self.extended_id.append(value)
                                if(value_path == "global-source"):
                                    self.global_source = value
                                    self.global_source.value_namespace = name_space
                                    self.global_source.value_namespace_prefix = name_space_prefix
                                if(value_path == "id"):
                                    self.id = value
                                    self.id.value_namespace = name_space
                                    self.id.value_namespace_prefix = name_space_prefix
                                if(value_path == "source"):
                                    self.source = value
                                    self.source.value_namespace = name_space
                                    self.source.value_namespace_prefix = name_space_prefix
                                if(value_path == "type"):
                                    self.type = value
                                    self.type.value_namespace = name_space
                                    self.type.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.association_type.is_set or
                                (self.extended_ipv4 is not None and self.extended_ipv4.has_data()) or
                                (self.extended_ipv6 is not None and self.extended_ipv6.has_data()) or
                                (self.ipv4 is not None and self.ipv4.has_data()) or
                                (self.ipv6 is not None and self.ipv6.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.association_type.yfilter != YFilter.not_set or
                                (self.extended_ipv4 is not None and self.extended_ipv4.has_operation()) or
                                (self.extended_ipv6 is not None and self.extended_ipv6.has_operation()) or
                                (self.ipv4 is not None and self.ipv4.has_operation()) or
                                (self.ipv6 is not None and self.ipv6.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "association" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/psb-rsb-info/psb-info/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.association_type.is_set or self.association_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.association_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "extended-ipv4"):
                                if (self.extended_ipv4 is None):
                                    self.extended_ipv4 = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association.ExtendedIpv4()
                                    self.extended_ipv4.parent = self
                                    self._children_name_map["extended_ipv4"] = "extended-ipv4"
                                return self.extended_ipv4

                            if (child_yang_name == "extended-ipv6"):
                                if (self.extended_ipv6 is None):
                                    self.extended_ipv6 = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association.ExtendedIpv6()
                                    self.extended_ipv6.parent = self
                                    self._children_name_map["extended_ipv6"] = "extended-ipv6"
                                return self.extended_ipv6

                            if (child_yang_name == "ipv4"):
                                if (self.ipv4 is None):
                                    self.ipv4 = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association.Ipv4()
                                    self.ipv4.parent = self
                                    self._children_name_map["ipv4"] = "ipv4"
                                return self.ipv4

                            if (child_yang_name == "ipv6"):
                                if (self.ipv6 is None):
                                    self.ipv6 = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association.Ipv6()
                                    self.ipv6.parent = self
                                    self._children_name_map["ipv6"] = "ipv6"
                                return self.ipv6

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "extended-ipv4" or name == "extended-ipv6" or name == "ipv4" or name == "ipv6" or name == "association-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "association-type"):
                                self.association_type = value
                                self.association_type.value_namespace = name_space
                                self.association_type.value_namespace_prefix = name_space_prefix


                    class Protection(Entity):
                        """
                        Protection object
                        
                        .. attribute:: link_flags
                        
                        	PROTECTION Object Link Flags
                        	**type**\:   :py:class:`LinkFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Protection.LinkFlags>`
                        
                        .. attribute:: lsp_flags
                        
                        	PROTECTION Object LSP Flags
                        	**type**\:   :py:class:`LspFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Protection.LspFlags>`
                        
                        .. attribute:: n
                        
                        	Notification Bit
                        	**type**\:  bool
                        
                        .. attribute:: o
                        
                        	Operational Bit
                        	**type**\:  bool
                        
                        .. attribute:: p
                        
                        	Protecting Bit
                        	**type**\:  bool
                        
                        .. attribute:: s
                        
                        	Secondary Bit
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Protection, self).__init__()

                            self.yang_name = "protection"
                            self.yang_parent_name = "psb-info"

                            self.n = YLeaf(YType.boolean, "n")

                            self.o = YLeaf(YType.boolean, "o")

                            self.p = YLeaf(YType.boolean, "p")

                            self.s = YLeaf(YType.boolean, "s")

                            self.link_flags = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Protection.LinkFlags()
                            self.link_flags.parent = self
                            self._children_name_map["link_flags"] = "link-flags"
                            self._children_yang_names.add("link-flags")

                            self.lsp_flags = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Protection.LspFlags()
                            self.lsp_flags.parent = self
                            self._children_name_map["lsp_flags"] = "lsp-flags"
                            self._children_yang_names.add("lsp-flags")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("n",
                                            "o",
                                            "p",
                                            "s") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Protection, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Protection, self).__setattr__(name, value)


                        class LspFlags(Entity):
                            """
                            PROTECTION Object LSP Flags
                            
                            .. attribute:: one_plus_one_bi
                            
                            	1+1 Bidirectional Protection
                            	**type**\:  bool
                            
                            .. attribute:: one_plus_one_uni
                            
                            	1+1 Unidirectional Protection
                            	**type**\:  bool
                            
                            .. attribute:: one_to_n_protection_et
                            
                            	1\:N Protection with Extra\-Traffic
                            	**type**\:  bool
                            
                            .. attribute:: rerouting
                            
                            	Full Rerouting
                            	**type**\:  bool
                            
                            .. attribute:: rerouting_no_et
                            
                            	Rerouting Without Extra\-Traffic
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Protection.LspFlags, self).__init__()

                                self.yang_name = "lsp-flags"
                                self.yang_parent_name = "protection"

                                self.one_plus_one_bi = YLeaf(YType.boolean, "one-plus-one-bi")

                                self.one_plus_one_uni = YLeaf(YType.boolean, "one-plus-one-uni")

                                self.one_to_n_protection_et = YLeaf(YType.boolean, "one-to-n-protection-et")

                                self.rerouting = YLeaf(YType.boolean, "rerouting")

                                self.rerouting_no_et = YLeaf(YType.boolean, "rerouting-no-et")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("one_plus_one_bi",
                                                "one_plus_one_uni",
                                                "one_to_n_protection_et",
                                                "rerouting",
                                                "rerouting_no_et") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Protection.LspFlags, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Protection.LspFlags, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.one_plus_one_bi.is_set or
                                    self.one_plus_one_uni.is_set or
                                    self.one_to_n_protection_et.is_set or
                                    self.rerouting.is_set or
                                    self.rerouting_no_et.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.one_plus_one_bi.yfilter != YFilter.not_set or
                                    self.one_plus_one_uni.yfilter != YFilter.not_set or
                                    self.one_to_n_protection_et.yfilter != YFilter.not_set or
                                    self.rerouting.yfilter != YFilter.not_set or
                                    self.rerouting_no_et.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "lsp-flags" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/psb-rsb-info/psb-info/protection/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.one_plus_one_bi.is_set or self.one_plus_one_bi.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.one_plus_one_bi.get_name_leafdata())
                                if (self.one_plus_one_uni.is_set or self.one_plus_one_uni.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.one_plus_one_uni.get_name_leafdata())
                                if (self.one_to_n_protection_et.is_set or self.one_to_n_protection_et.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.one_to_n_protection_et.get_name_leafdata())
                                if (self.rerouting.is_set or self.rerouting.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rerouting.get_name_leafdata())
                                if (self.rerouting_no_et.is_set or self.rerouting_no_et.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rerouting_no_et.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "one-plus-one-bi" or name == "one-plus-one-uni" or name == "one-to-n-protection-et" or name == "rerouting" or name == "rerouting-no-et"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "one-plus-one-bi"):
                                    self.one_plus_one_bi = value
                                    self.one_plus_one_bi.value_namespace = name_space
                                    self.one_plus_one_bi.value_namespace_prefix = name_space_prefix
                                if(value_path == "one-plus-one-uni"):
                                    self.one_plus_one_uni = value
                                    self.one_plus_one_uni.value_namespace = name_space
                                    self.one_plus_one_uni.value_namespace_prefix = name_space_prefix
                                if(value_path == "one-to-n-protection-et"):
                                    self.one_to_n_protection_et = value
                                    self.one_to_n_protection_et.value_namespace = name_space
                                    self.one_to_n_protection_et.value_namespace_prefix = name_space_prefix
                                if(value_path == "rerouting"):
                                    self.rerouting = value
                                    self.rerouting.value_namespace = name_space
                                    self.rerouting.value_namespace_prefix = name_space_prefix
                                if(value_path == "rerouting-no-et"):
                                    self.rerouting_no_et = value
                                    self.rerouting_no_et.value_namespace = name_space
                                    self.rerouting_no_et.value_namespace_prefix = name_space_prefix


                        class LinkFlags(Entity):
                            """
                            PROTECTION Object Link Flags
                            
                            .. attribute:: ded1_plus1
                            
                            	Dedicated 1+1 Protection
                            	**type**\:  bool
                            
                            .. attribute:: ded1_to1
                            
                            	Dedicated 1\:1 Protection
                            	**type**\:  bool
                            
                            .. attribute:: enhanced
                            
                            	Indicates Enhanced Protection Scheme
                            	**type**\:  bool
                            
                            .. attribute:: extra_traffic
                            
                            	LSP should use Links that are protecting other (primary) traffic
                            	**type**\:  bool
                            
                            .. attribute:: reserved_bit1
                            
                            	Reserved Bit 1
                            	**type**\:  bool
                            
                            .. attribute:: reserved_bit2
                            
                            	Reserved Bit 2
                            	**type**\:  bool
                            
                            .. attribute:: shared
                            
                            	Shared Link Layer Protection
                            	**type**\:  bool
                            
                            .. attribute:: unprotected
                            
                            	LSP should not use any Link Layer Protection
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Protection.LinkFlags, self).__init__()

                                self.yang_name = "link-flags"
                                self.yang_parent_name = "protection"

                                self.ded1_plus1 = YLeaf(YType.boolean, "ded1-plus1")

                                self.ded1_to1 = YLeaf(YType.boolean, "ded1-to1")

                                self.enhanced = YLeaf(YType.boolean, "enhanced")

                                self.extra_traffic = YLeaf(YType.boolean, "extra-traffic")

                                self.reserved_bit1 = YLeaf(YType.boolean, "reserved-bit1")

                                self.reserved_bit2 = YLeaf(YType.boolean, "reserved-bit2")

                                self.shared = YLeaf(YType.boolean, "shared")

                                self.unprotected = YLeaf(YType.boolean, "unprotected")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ded1_plus1",
                                                "ded1_to1",
                                                "enhanced",
                                                "extra_traffic",
                                                "reserved_bit1",
                                                "reserved_bit2",
                                                "shared",
                                                "unprotected") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Protection.LinkFlags, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Protection.LinkFlags, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.ded1_plus1.is_set or
                                    self.ded1_to1.is_set or
                                    self.enhanced.is_set or
                                    self.extra_traffic.is_set or
                                    self.reserved_bit1.is_set or
                                    self.reserved_bit2.is_set or
                                    self.shared.is_set or
                                    self.unprotected.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ded1_plus1.yfilter != YFilter.not_set or
                                    self.ded1_to1.yfilter != YFilter.not_set or
                                    self.enhanced.yfilter != YFilter.not_set or
                                    self.extra_traffic.yfilter != YFilter.not_set or
                                    self.reserved_bit1.yfilter != YFilter.not_set or
                                    self.reserved_bit2.yfilter != YFilter.not_set or
                                    self.shared.yfilter != YFilter.not_set or
                                    self.unprotected.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "link-flags" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/psb-rsb-info/psb-info/protection/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ded1_plus1.is_set or self.ded1_plus1.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ded1_plus1.get_name_leafdata())
                                if (self.ded1_to1.is_set or self.ded1_to1.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ded1_to1.get_name_leafdata())
                                if (self.enhanced.is_set or self.enhanced.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.enhanced.get_name_leafdata())
                                if (self.extra_traffic.is_set or self.extra_traffic.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.extra_traffic.get_name_leafdata())
                                if (self.reserved_bit1.is_set or self.reserved_bit1.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.reserved_bit1.get_name_leafdata())
                                if (self.reserved_bit2.is_set or self.reserved_bit2.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.reserved_bit2.get_name_leafdata())
                                if (self.shared.is_set or self.shared.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.shared.get_name_leafdata())
                                if (self.unprotected.is_set or self.unprotected.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unprotected.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ded1-plus1" or name == "ded1-to1" or name == "enhanced" or name == "extra-traffic" or name == "reserved-bit1" or name == "reserved-bit2" or name == "shared" or name == "unprotected"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ded1-plus1"):
                                    self.ded1_plus1 = value
                                    self.ded1_plus1.value_namespace = name_space
                                    self.ded1_plus1.value_namespace_prefix = name_space_prefix
                                if(value_path == "ded1-to1"):
                                    self.ded1_to1 = value
                                    self.ded1_to1.value_namespace = name_space
                                    self.ded1_to1.value_namespace_prefix = name_space_prefix
                                if(value_path == "enhanced"):
                                    self.enhanced = value
                                    self.enhanced.value_namespace = name_space
                                    self.enhanced.value_namespace_prefix = name_space_prefix
                                if(value_path == "extra-traffic"):
                                    self.extra_traffic = value
                                    self.extra_traffic.value_namespace = name_space
                                    self.extra_traffic.value_namespace_prefix = name_space_prefix
                                if(value_path == "reserved-bit1"):
                                    self.reserved_bit1 = value
                                    self.reserved_bit1.value_namespace = name_space
                                    self.reserved_bit1.value_namespace_prefix = name_space_prefix
                                if(value_path == "reserved-bit2"):
                                    self.reserved_bit2 = value
                                    self.reserved_bit2.value_namespace = name_space
                                    self.reserved_bit2.value_namespace_prefix = name_space_prefix
                                if(value_path == "shared"):
                                    self.shared = value
                                    self.shared.value_namespace = name_space
                                    self.shared.value_namespace_prefix = name_space_prefix
                                if(value_path == "unprotected"):
                                    self.unprotected = value
                                    self.unprotected.value_namespace = name_space
                                    self.unprotected.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.n.is_set or
                                self.o.is_set or
                                self.p.is_set or
                                self.s.is_set or
                                (self.link_flags is not None and self.link_flags.has_data()) or
                                (self.lsp_flags is not None and self.lsp_flags.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.n.yfilter != YFilter.not_set or
                                self.o.yfilter != YFilter.not_set or
                                self.p.yfilter != YFilter.not_set or
                                self.s.yfilter != YFilter.not_set or
                                (self.link_flags is not None and self.link_flags.has_operation()) or
                                (self.lsp_flags is not None and self.lsp_flags.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "protection" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/psb-rsb-info/psb-info/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.n.is_set or self.n.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.n.get_name_leafdata())
                            if (self.o.is_set or self.o.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.o.get_name_leafdata())
                            if (self.p.is_set or self.p.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.p.get_name_leafdata())
                            if (self.s.is_set or self.s.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.s.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "link-flags"):
                                if (self.link_flags is None):
                                    self.link_flags = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Protection.LinkFlags()
                                    self.link_flags.parent = self
                                    self._children_name_map["link_flags"] = "link-flags"
                                return self.link_flags

                            if (child_yang_name == "lsp-flags"):
                                if (self.lsp_flags is None):
                                    self.lsp_flags = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Protection.LspFlags()
                                    self.lsp_flags.parent = self
                                    self._children_name_map["lsp_flags"] = "lsp-flags"
                                return self.lsp_flags

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "link-flags" or name == "lsp-flags" or name == "n" or name == "o" or name == "p" or name == "s"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "n"):
                                self.n = value
                                self.n.value_namespace = name_space
                                self.n.value_namespace_prefix = name_space_prefix
                            if(value_path == "o"):
                                self.o = value
                                self.o.value_namespace = name_space
                                self.o.value_namespace_prefix = name_space_prefix
                            if(value_path == "p"):
                                self.p = value
                                self.p.value_namespace = name_space
                                self.p.value_namespace_prefix = name_space_prefix
                            if(value_path == "s"):
                                self.s = value
                                self.s.value_namespace = name_space
                                self.s.value_namespace_prefix = name_space_prefix


                    class ReverseLsp(Entity):
                        """
                        Reverse LSP object
                        
                        .. attribute:: ero
                        
                        	Explicit Route Sub Objects
                        	**type**\: list of    :py:class:`Ero <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.Ero>`
                        
                        .. attribute:: generic_traffic_spec
                        
                        	Generic Traffic Spec object
                        	**type**\:   :py:class:`GenericTrafficSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.GenericTrafficSpec>`
                        
                        .. attribute:: unsup_sub_object
                        
                        	Unsupported REVERSE\_LSP Sub Objects
                        	**type**\: list of    :py:class:`UnsupSubObject <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.UnsupSubObject>`
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp, self).__init__()

                            self.yang_name = "reverse-lsp"
                            self.yang_parent_name = "psb-info"

                            self.generic_traffic_spec = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.GenericTrafficSpec()
                            self.generic_traffic_spec.parent = self
                            self._children_name_map["generic_traffic_spec"] = "generic-traffic-spec"
                            self._children_yang_names.add("generic-traffic-spec")

                            self.ero = YList(self)
                            self.unsup_sub_object = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp, self).__setattr__(name, value)


                        class GenericTrafficSpec(Entity):
                            """
                            Generic Traffic Spec object
                            
                            .. attribute:: g709otn_tspec
                            
                            	G709 OTN Sender Tspec
                            	**type**\:   :py:class:`G709OtnTspec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.GenericTrafficSpec.G709OtnTspec>`
                            
                            .. attribute:: intsrv_tspec
                            
                            	Integrated Services Sender Tspec
                            	**type**\:   :py:class:`IntsrvTspec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.GenericTrafficSpec.IntsrvTspec>`
                            
                            .. attribute:: tspec_type
                            
                            	TspecType
                            	**type**\:   :py:class:`RsvpMgmtTspec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtTspec>`
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.GenericTrafficSpec, self).__init__()

                                self.yang_name = "generic-traffic-spec"
                                self.yang_parent_name = "reverse-lsp"

                                self.tspec_type = YLeaf(YType.enumeration, "tspec-type")

                                self.g709otn_tspec = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.GenericTrafficSpec.G709OtnTspec()
                                self.g709otn_tspec.parent = self
                                self._children_name_map["g709otn_tspec"] = "g709otn-tspec"
                                self._children_yang_names.add("g709otn-tspec")

                                self.intsrv_tspec = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.GenericTrafficSpec.IntsrvTspec()
                                self.intsrv_tspec.parent = self
                                self._children_name_map["intsrv_tspec"] = "intsrv-tspec"
                                self._children_yang_names.add("intsrv-tspec")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("tspec_type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.GenericTrafficSpec, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.GenericTrafficSpec, self).__setattr__(name, value)


                            class G709OtnTspec(Entity):
                                """
                                G709 OTN Sender Tspec
                                
                                .. attribute:: traffic_bit_rate
                                
                                	G709 OTN Traffic Bit Rate
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: traffic_multiplier
                                
                                	G709 OTN Traffic Multiplier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: traffic_nvc
                                
                                	G709 OTN Traffic NVC
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: traffic_signal_type
                                
                                	G709 OTN Traffic Signal Type (Refer G709 v3)
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ip-rsvp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.GenericTrafficSpec.G709OtnTspec, self).__init__()

                                    self.yang_name = "g709otn-tspec"
                                    self.yang_parent_name = "generic-traffic-spec"

                                    self.traffic_bit_rate = YLeaf(YType.uint64, "traffic-bit-rate")

                                    self.traffic_multiplier = YLeaf(YType.uint16, "traffic-multiplier")

                                    self.traffic_nvc = YLeaf(YType.uint16, "traffic-nvc")

                                    self.traffic_signal_type = YLeaf(YType.uint8, "traffic-signal-type")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("traffic_bit_rate",
                                                    "traffic_multiplier",
                                                    "traffic_nvc",
                                                    "traffic_signal_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.GenericTrafficSpec.G709OtnTspec, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.GenericTrafficSpec.G709OtnTspec, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.traffic_bit_rate.is_set or
                                        self.traffic_multiplier.is_set or
                                        self.traffic_nvc.is_set or
                                        self.traffic_signal_type.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.traffic_bit_rate.yfilter != YFilter.not_set or
                                        self.traffic_multiplier.yfilter != YFilter.not_set or
                                        self.traffic_nvc.yfilter != YFilter.not_set or
                                        self.traffic_signal_type.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "g709otn-tspec" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/psb-rsb-info/psb-info/reverse-lsp/generic-traffic-spec/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.traffic_bit_rate.is_set or self.traffic_bit_rate.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.traffic_bit_rate.get_name_leafdata())
                                    if (self.traffic_multiplier.is_set or self.traffic_multiplier.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.traffic_multiplier.get_name_leafdata())
                                    if (self.traffic_nvc.is_set or self.traffic_nvc.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.traffic_nvc.get_name_leafdata())
                                    if (self.traffic_signal_type.is_set or self.traffic_signal_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.traffic_signal_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "traffic-bit-rate" or name == "traffic-multiplier" or name == "traffic-nvc" or name == "traffic-signal-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "traffic-bit-rate"):
                                        self.traffic_bit_rate = value
                                        self.traffic_bit_rate.value_namespace = name_space
                                        self.traffic_bit_rate.value_namespace_prefix = name_space_prefix
                                    if(value_path == "traffic-multiplier"):
                                        self.traffic_multiplier = value
                                        self.traffic_multiplier.value_namespace = name_space
                                        self.traffic_multiplier.value_namespace_prefix = name_space_prefix
                                    if(value_path == "traffic-nvc"):
                                        self.traffic_nvc = value
                                        self.traffic_nvc.value_namespace = name_space
                                        self.traffic_nvc.value_namespace_prefix = name_space_prefix
                                    if(value_path == "traffic-signal-type"):
                                        self.traffic_signal_type = value
                                        self.traffic_signal_type.value_namespace = name_space
                                        self.traffic_signal_type.value_namespace_prefix = name_space_prefix


                            class IntsrvTspec(Entity):
                                """
                                Integrated Services Sender Tspec
                                
                                .. attribute:: traffic_average_rate
                                
                                	Traffic Average Rate in bytes per second
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte/s
                                
                                .. attribute:: traffic_max_burst
                                
                                	Traffic Maximum Burst
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: traffic_max_unit
                                
                                	Traffic Maximum Unit
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: traffic_min_unit
                                
                                	Traffic Minimum Unit
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: traffic_peak_rate
                                
                                	Traffic Peak Rate in bytes per second
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte/s
                                
                                

                                """

                                _prefix = 'ip-rsvp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.GenericTrafficSpec.IntsrvTspec, self).__init__()

                                    self.yang_name = "intsrv-tspec"
                                    self.yang_parent_name = "generic-traffic-spec"

                                    self.traffic_average_rate = YLeaf(YType.uint64, "traffic-average-rate")

                                    self.traffic_max_burst = YLeaf(YType.uint64, "traffic-max-burst")

                                    self.traffic_max_unit = YLeaf(YType.uint32, "traffic-max-unit")

                                    self.traffic_min_unit = YLeaf(YType.uint32, "traffic-min-unit")

                                    self.traffic_peak_rate = YLeaf(YType.uint64, "traffic-peak-rate")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("traffic_average_rate",
                                                    "traffic_max_burst",
                                                    "traffic_max_unit",
                                                    "traffic_min_unit",
                                                    "traffic_peak_rate") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.GenericTrafficSpec.IntsrvTspec, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.GenericTrafficSpec.IntsrvTspec, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.traffic_average_rate.is_set or
                                        self.traffic_max_burst.is_set or
                                        self.traffic_max_unit.is_set or
                                        self.traffic_min_unit.is_set or
                                        self.traffic_peak_rate.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.traffic_average_rate.yfilter != YFilter.not_set or
                                        self.traffic_max_burst.yfilter != YFilter.not_set or
                                        self.traffic_max_unit.yfilter != YFilter.not_set or
                                        self.traffic_min_unit.yfilter != YFilter.not_set or
                                        self.traffic_peak_rate.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "intsrv-tspec" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/psb-rsb-info/psb-info/reverse-lsp/generic-traffic-spec/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.traffic_average_rate.is_set or self.traffic_average_rate.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.traffic_average_rate.get_name_leafdata())
                                    if (self.traffic_max_burst.is_set or self.traffic_max_burst.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.traffic_max_burst.get_name_leafdata())
                                    if (self.traffic_max_unit.is_set or self.traffic_max_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.traffic_max_unit.get_name_leafdata())
                                    if (self.traffic_min_unit.is_set or self.traffic_min_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.traffic_min_unit.get_name_leafdata())
                                    if (self.traffic_peak_rate.is_set or self.traffic_peak_rate.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.traffic_peak_rate.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "traffic-average-rate" or name == "traffic-max-burst" or name == "traffic-max-unit" or name == "traffic-min-unit" or name == "traffic-peak-rate"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "traffic-average-rate"):
                                        self.traffic_average_rate = value
                                        self.traffic_average_rate.value_namespace = name_space
                                        self.traffic_average_rate.value_namespace_prefix = name_space_prefix
                                    if(value_path == "traffic-max-burst"):
                                        self.traffic_max_burst = value
                                        self.traffic_max_burst.value_namespace = name_space
                                        self.traffic_max_burst.value_namespace_prefix = name_space_prefix
                                    if(value_path == "traffic-max-unit"):
                                        self.traffic_max_unit = value
                                        self.traffic_max_unit.value_namespace = name_space
                                        self.traffic_max_unit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "traffic-min-unit"):
                                        self.traffic_min_unit = value
                                        self.traffic_min_unit.value_namespace = name_space
                                        self.traffic_min_unit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "traffic-peak-rate"):
                                        self.traffic_peak_rate = value
                                        self.traffic_peak_rate.value_namespace = name_space
                                        self.traffic_peak_rate.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.tspec_type.is_set or
                                    (self.g709otn_tspec is not None and self.g709otn_tspec.has_data()) or
                                    (self.intsrv_tspec is not None and self.intsrv_tspec.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.tspec_type.yfilter != YFilter.not_set or
                                    (self.g709otn_tspec is not None and self.g709otn_tspec.has_operation()) or
                                    (self.intsrv_tspec is not None and self.intsrv_tspec.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "generic-traffic-spec" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/psb-rsb-info/psb-info/reverse-lsp/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.tspec_type.is_set or self.tspec_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tspec_type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "g709otn-tspec"):
                                    if (self.g709otn_tspec is None):
                                        self.g709otn_tspec = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.GenericTrafficSpec.G709OtnTspec()
                                        self.g709otn_tspec.parent = self
                                        self._children_name_map["g709otn_tspec"] = "g709otn-tspec"
                                    return self.g709otn_tspec

                                if (child_yang_name == "intsrv-tspec"):
                                    if (self.intsrv_tspec is None):
                                        self.intsrv_tspec = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.GenericTrafficSpec.IntsrvTspec()
                                        self.intsrv_tspec.parent = self
                                        self._children_name_map["intsrv_tspec"] = "intsrv-tspec"
                                    return self.intsrv_tspec

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "g709otn-tspec" or name == "intsrv-tspec" or name == "tspec-type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "tspec-type"):
                                    self.tspec_type = value
                                    self.tspec_type.value_namespace = name_space
                                    self.tspec_type.value_namespace_prefix = name_space_prefix


                        class Ero(Entity):
                            """
                            Explicit Route Sub Objects
                            
                            .. attribute:: ero_type
                            
                            	EROType
                            	**type**\:   :py:class:`RsvpMgmtEroSubobj <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtEroSubobj>`
                            
                            .. attribute:: ipv4ero_sub_object
                            
                            	IPV4 ERO Sub Object
                            	**type**\:   :py:class:`Ipv4EroSubObject <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.Ero.Ipv4EroSubObject>`
                            
                            .. attribute:: unnumbered_ero_sub_object
                            
                            	Unnumbered ERO Sub Object
                            	**type**\:   :py:class:`UnnumberedEroSubObject <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.Ero.UnnumberedEroSubObject>`
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.Ero, self).__init__()

                                self.yang_name = "ero"
                                self.yang_parent_name = "reverse-lsp"

                                self.ero_type = YLeaf(YType.enumeration, "ero-type")

                                self.ipv4ero_sub_object = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.Ero.Ipv4EroSubObject()
                                self.ipv4ero_sub_object.parent = self
                                self._children_name_map["ipv4ero_sub_object"] = "ipv4ero-sub-object"
                                self._children_yang_names.add("ipv4ero-sub-object")

                                self.unnumbered_ero_sub_object = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.Ero.UnnumberedEroSubObject()
                                self.unnumbered_ero_sub_object.parent = self
                                self._children_name_map["unnumbered_ero_sub_object"] = "unnumbered-ero-sub-object"
                                self._children_yang_names.add("unnumbered-ero-sub-object")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ero_type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.Ero, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.Ero, self).__setattr__(name, value)


                            class Ipv4EroSubObject(Entity):
                                """
                                IPV4 ERO Sub Object
                                
                                .. attribute:: ero_address
                                
                                	The ERO IPV4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: is_strict_route
                                
                                	ERO Entry Is Strict
                                	**type**\:  bool
                                
                                .. attribute:: prefix_length
                                
                                	ERO Prefix Length
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ip-rsvp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.Ero.Ipv4EroSubObject, self).__init__()

                                    self.yang_name = "ipv4ero-sub-object"
                                    self.yang_parent_name = "ero"

                                    self.ero_address = YLeaf(YType.str, "ero-address")

                                    self.is_strict_route = YLeaf(YType.boolean, "is-strict-route")

                                    self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("ero_address",
                                                    "is_strict_route",
                                                    "prefix_length") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.Ero.Ipv4EroSubObject, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.Ero.Ipv4EroSubObject, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.ero_address.is_set or
                                        self.is_strict_route.is_set or
                                        self.prefix_length.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.ero_address.yfilter != YFilter.not_set or
                                        self.is_strict_route.yfilter != YFilter.not_set or
                                        self.prefix_length.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "ipv4ero-sub-object" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/psb-rsb-info/psb-info/reverse-lsp/ero/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.ero_address.is_set or self.ero_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ero_address.get_name_leafdata())
                                    if (self.is_strict_route.is_set or self.is_strict_route.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_strict_route.get_name_leafdata())
                                    if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.prefix_length.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "ero-address" or name == "is-strict-route" or name == "prefix-length"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "ero-address"):
                                        self.ero_address = value
                                        self.ero_address.value_namespace = name_space
                                        self.ero_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-strict-route"):
                                        self.is_strict_route = value
                                        self.is_strict_route.value_namespace = name_space
                                        self.is_strict_route.value_namespace_prefix = name_space_prefix
                                    if(value_path == "prefix-length"):
                                        self.prefix_length = value
                                        self.prefix_length.value_namespace = name_space
                                        self.prefix_length.value_namespace_prefix = name_space_prefix


                            class UnnumberedEroSubObject(Entity):
                                """
                                Unnumbered ERO Sub Object
                                
                                .. attribute:: ero_interface_id
                                
                                	The Interface ID in ERO
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ero_router_id
                                
                                	The Router ID in ERO
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: is_strict_route
                                
                                	ERO Entry Is Strict
                                	**type**\:  bool
                                
                                .. attribute:: status
                                
                                	Status of ERO
                                	**type**\:   :py:class:`RsvpMgmtEroSubobjStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtEroSubobjStatus>`
                                
                                

                                """

                                _prefix = 'ip-rsvp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.Ero.UnnumberedEroSubObject, self).__init__()

                                    self.yang_name = "unnumbered-ero-sub-object"
                                    self.yang_parent_name = "ero"

                                    self.ero_interface_id = YLeaf(YType.uint32, "ero-interface-id")

                                    self.ero_router_id = YLeaf(YType.str, "ero-router-id")

                                    self.is_strict_route = YLeaf(YType.boolean, "is-strict-route")

                                    self.status = YLeaf(YType.enumeration, "status")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("ero_interface_id",
                                                    "ero_router_id",
                                                    "is_strict_route",
                                                    "status") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.Ero.UnnumberedEroSubObject, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.Ero.UnnumberedEroSubObject, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.ero_interface_id.is_set or
                                        self.ero_router_id.is_set or
                                        self.is_strict_route.is_set or
                                        self.status.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.ero_interface_id.yfilter != YFilter.not_set or
                                        self.ero_router_id.yfilter != YFilter.not_set or
                                        self.is_strict_route.yfilter != YFilter.not_set or
                                        self.status.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "unnumbered-ero-sub-object" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/psb-rsb-info/psb-info/reverse-lsp/ero/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.ero_interface_id.is_set or self.ero_interface_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ero_interface_id.get_name_leafdata())
                                    if (self.ero_router_id.is_set or self.ero_router_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ero_router_id.get_name_leafdata())
                                    if (self.is_strict_route.is_set or self.is_strict_route.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_strict_route.get_name_leafdata())
                                    if (self.status.is_set or self.status.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.status.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "ero-interface-id" or name == "ero-router-id" or name == "is-strict-route" or name == "status"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "ero-interface-id"):
                                        self.ero_interface_id = value
                                        self.ero_interface_id.value_namespace = name_space
                                        self.ero_interface_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ero-router-id"):
                                        self.ero_router_id = value
                                        self.ero_router_id.value_namespace = name_space
                                        self.ero_router_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-strict-route"):
                                        self.is_strict_route = value
                                        self.is_strict_route.value_namespace = name_space
                                        self.is_strict_route.value_namespace_prefix = name_space_prefix
                                    if(value_path == "status"):
                                        self.status = value
                                        self.status.value_namespace = name_space
                                        self.status.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.ero_type.is_set or
                                    (self.ipv4ero_sub_object is not None and self.ipv4ero_sub_object.has_data()) or
                                    (self.unnumbered_ero_sub_object is not None and self.unnumbered_ero_sub_object.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ero_type.yfilter != YFilter.not_set or
                                    (self.ipv4ero_sub_object is not None and self.ipv4ero_sub_object.has_operation()) or
                                    (self.unnumbered_ero_sub_object is not None and self.unnumbered_ero_sub_object.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ero" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/psb-rsb-info/psb-info/reverse-lsp/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ero_type.is_set or self.ero_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ero_type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "ipv4ero-sub-object"):
                                    if (self.ipv4ero_sub_object is None):
                                        self.ipv4ero_sub_object = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.Ero.Ipv4EroSubObject()
                                        self.ipv4ero_sub_object.parent = self
                                        self._children_name_map["ipv4ero_sub_object"] = "ipv4ero-sub-object"
                                    return self.ipv4ero_sub_object

                                if (child_yang_name == "unnumbered-ero-sub-object"):
                                    if (self.unnumbered_ero_sub_object is None):
                                        self.unnumbered_ero_sub_object = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.Ero.UnnumberedEroSubObject()
                                        self.unnumbered_ero_sub_object.parent = self
                                        self._children_name_map["unnumbered_ero_sub_object"] = "unnumbered-ero-sub-object"
                                    return self.unnumbered_ero_sub_object

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ipv4ero-sub-object" or name == "unnumbered-ero-sub-object" or name == "ero-type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ero-type"):
                                    self.ero_type = value
                                    self.ero_type.value_namespace = name_space
                                    self.ero_type.value_namespace_prefix = name_space_prefix


                        class UnsupSubObject(Entity):
                            """
                            Unsupported REVERSE\_LSP Sub Objects
                            
                            .. attribute:: rsvp_mgmt_rev_lsp_unsupported_subobj
                            
                            	rsvp mgmt rev lsp unsupported subobj
                            	**type**\:  list of int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.UnsupSubObject, self).__init__()

                                self.yang_name = "unsup-sub-object"
                                self.yang_parent_name = "reverse-lsp"

                                self.rsvp_mgmt_rev_lsp_unsupported_subobj = YLeafList(YType.uint8, "rsvp-mgmt-rev-lsp-unsupported-subobj")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("rsvp_mgmt_rev_lsp_unsupported_subobj") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.UnsupSubObject, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.UnsupSubObject, self).__setattr__(name, value)

                            def has_data(self):
                                for leaf in self.rsvp_mgmt_rev_lsp_unsupported_subobj.getYLeafs():
                                    if (leaf.yfilter != YFilter.not_set):
                                        return True
                                return False

                            def has_operation(self):
                                for leaf in self.rsvp_mgmt_rev_lsp_unsupported_subobj.getYLeafs():
                                    if (leaf.is_set):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.rsvp_mgmt_rev_lsp_unsupported_subobj.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "unsup-sub-object" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/psb-rsb-info/psb-info/reverse-lsp/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                leaf_name_data.extend(self.rsvp_mgmt_rev_lsp_unsupported_subobj.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "rsvp-mgmt-rev-lsp-unsupported-subobj"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "rsvp-mgmt-rev-lsp-unsupported-subobj"):
                                    self.rsvp_mgmt_rev_lsp_unsupported_subobj.append(value)

                        def has_data(self):
                            for c in self.ero:
                                if (c.has_data()):
                                    return True
                            for c in self.unsup_sub_object:
                                if (c.has_data()):
                                    return True
                            return (self.generic_traffic_spec is not None and self.generic_traffic_spec.has_data())

                        def has_operation(self):
                            for c in self.ero:
                                if (c.has_operation()):
                                    return True
                            for c in self.unsup_sub_object:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.generic_traffic_spec is not None and self.generic_traffic_spec.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "reverse-lsp" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/psb-rsb-info/psb-info/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "ero"):
                                for c in self.ero:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.Ero()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.ero.append(c)
                                return c

                            if (child_yang_name == "generic-traffic-spec"):
                                if (self.generic_traffic_spec is None):
                                    self.generic_traffic_spec = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.GenericTrafficSpec()
                                    self.generic_traffic_spec.parent = self
                                    self._children_name_map["generic_traffic_spec"] = "generic-traffic-spec"
                                return self.generic_traffic_spec

                            if (child_yang_name == "unsup-sub-object"):
                                for c in self.unsup_sub_object:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.UnsupSubObject()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.unsup_sub_object.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ero" or name == "generic-traffic-spec" or name == "unsup-sub-object"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Ero(Entity):
                        """
                        Explicit Route Sub Objects
                        
                        .. attribute:: ero_type
                        
                        	EROType
                        	**type**\:   :py:class:`RsvpMgmtEroSubobj <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtEroSubobj>`
                        
                        .. attribute:: ipv4ero_sub_object
                        
                        	IPV4 ERO Sub Object
                        	**type**\:   :py:class:`Ipv4EroSubObject <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Ero.Ipv4EroSubObject>`
                        
                        .. attribute:: unnumbered_ero_sub_object
                        
                        	Unnumbered ERO Sub Object
                        	**type**\:   :py:class:`UnnumberedEroSubObject <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Ero.UnnumberedEroSubObject>`
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Ero, self).__init__()

                            self.yang_name = "ero"
                            self.yang_parent_name = "psb-info"

                            self.ero_type = YLeaf(YType.enumeration, "ero-type")

                            self.ipv4ero_sub_object = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Ero.Ipv4EroSubObject()
                            self.ipv4ero_sub_object.parent = self
                            self._children_name_map["ipv4ero_sub_object"] = "ipv4ero-sub-object"
                            self._children_yang_names.add("ipv4ero-sub-object")

                            self.unnumbered_ero_sub_object = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Ero.UnnumberedEroSubObject()
                            self.unnumbered_ero_sub_object.parent = self
                            self._children_name_map["unnumbered_ero_sub_object"] = "unnumbered-ero-sub-object"
                            self._children_yang_names.add("unnumbered-ero-sub-object")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("ero_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Ero, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Ero, self).__setattr__(name, value)


                        class Ipv4EroSubObject(Entity):
                            """
                            IPV4 ERO Sub Object
                            
                            .. attribute:: ero_address
                            
                            	The ERO IPV4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: is_strict_route
                            
                            	ERO Entry Is Strict
                            	**type**\:  bool
                            
                            .. attribute:: prefix_length
                            
                            	ERO Prefix Length
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Ero.Ipv4EroSubObject, self).__init__()

                                self.yang_name = "ipv4ero-sub-object"
                                self.yang_parent_name = "ero"

                                self.ero_address = YLeaf(YType.str, "ero-address")

                                self.is_strict_route = YLeaf(YType.boolean, "is-strict-route")

                                self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ero_address",
                                                "is_strict_route",
                                                "prefix_length") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Ero.Ipv4EroSubObject, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Ero.Ipv4EroSubObject, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.ero_address.is_set or
                                    self.is_strict_route.is_set or
                                    self.prefix_length.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ero_address.yfilter != YFilter.not_set or
                                    self.is_strict_route.yfilter != YFilter.not_set or
                                    self.prefix_length.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ipv4ero-sub-object" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/psb-rsb-info/psb-info/ero/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ero_address.is_set or self.ero_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ero_address.get_name_leafdata())
                                if (self.is_strict_route.is_set or self.is_strict_route.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_strict_route.get_name_leafdata())
                                if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix_length.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ero-address" or name == "is-strict-route" or name == "prefix-length"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ero-address"):
                                    self.ero_address = value
                                    self.ero_address.value_namespace = name_space
                                    self.ero_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-strict-route"):
                                    self.is_strict_route = value
                                    self.is_strict_route.value_namespace = name_space
                                    self.is_strict_route.value_namespace_prefix = name_space_prefix
                                if(value_path == "prefix-length"):
                                    self.prefix_length = value
                                    self.prefix_length.value_namespace = name_space
                                    self.prefix_length.value_namespace_prefix = name_space_prefix


                        class UnnumberedEroSubObject(Entity):
                            """
                            Unnumbered ERO Sub Object
                            
                            .. attribute:: ero_interface_id
                            
                            	The Interface ID in ERO
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ero_router_id
                            
                            	The Router ID in ERO
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: is_strict_route
                            
                            	ERO Entry Is Strict
                            	**type**\:  bool
                            
                            .. attribute:: status
                            
                            	Status of ERO
                            	**type**\:   :py:class:`RsvpMgmtEroSubobjStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtEroSubobjStatus>`
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Ero.UnnumberedEroSubObject, self).__init__()

                                self.yang_name = "unnumbered-ero-sub-object"
                                self.yang_parent_name = "ero"

                                self.ero_interface_id = YLeaf(YType.uint32, "ero-interface-id")

                                self.ero_router_id = YLeaf(YType.str, "ero-router-id")

                                self.is_strict_route = YLeaf(YType.boolean, "is-strict-route")

                                self.status = YLeaf(YType.enumeration, "status")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ero_interface_id",
                                                "ero_router_id",
                                                "is_strict_route",
                                                "status") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Ero.UnnumberedEroSubObject, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Ero.UnnumberedEroSubObject, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.ero_interface_id.is_set or
                                    self.ero_router_id.is_set or
                                    self.is_strict_route.is_set or
                                    self.status.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ero_interface_id.yfilter != YFilter.not_set or
                                    self.ero_router_id.yfilter != YFilter.not_set or
                                    self.is_strict_route.yfilter != YFilter.not_set or
                                    self.status.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "unnumbered-ero-sub-object" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/psb-rsb-info/psb-info/ero/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ero_interface_id.is_set or self.ero_interface_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ero_interface_id.get_name_leafdata())
                                if (self.ero_router_id.is_set or self.ero_router_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ero_router_id.get_name_leafdata())
                                if (self.is_strict_route.is_set or self.is_strict_route.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_strict_route.get_name_leafdata())
                                if (self.status.is_set or self.status.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.status.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ero-interface-id" or name == "ero-router-id" or name == "is-strict-route" or name == "status"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ero-interface-id"):
                                    self.ero_interface_id = value
                                    self.ero_interface_id.value_namespace = name_space
                                    self.ero_interface_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "ero-router-id"):
                                    self.ero_router_id = value
                                    self.ero_router_id.value_namespace = name_space
                                    self.ero_router_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-strict-route"):
                                    self.is_strict_route = value
                                    self.is_strict_route.value_namespace = name_space
                                    self.is_strict_route.value_namespace_prefix = name_space_prefix
                                if(value_path == "status"):
                                    self.status = value
                                    self.status.value_namespace = name_space
                                    self.status.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.ero_type.is_set or
                                (self.ipv4ero_sub_object is not None and self.ipv4ero_sub_object.has_data()) or
                                (self.unnumbered_ero_sub_object is not None and self.unnumbered_ero_sub_object.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.ero_type.yfilter != YFilter.not_set or
                                (self.ipv4ero_sub_object is not None and self.ipv4ero_sub_object.has_operation()) or
                                (self.unnumbered_ero_sub_object is not None and self.unnumbered_ero_sub_object.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ero" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/psb-rsb-info/psb-info/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.ero_type.is_set or self.ero_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ero_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "ipv4ero-sub-object"):
                                if (self.ipv4ero_sub_object is None):
                                    self.ipv4ero_sub_object = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Ero.Ipv4EroSubObject()
                                    self.ipv4ero_sub_object.parent = self
                                    self._children_name_map["ipv4ero_sub_object"] = "ipv4ero-sub-object"
                                return self.ipv4ero_sub_object

                            if (child_yang_name == "unnumbered-ero-sub-object"):
                                if (self.unnumbered_ero_sub_object is None):
                                    self.unnumbered_ero_sub_object = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Ero.UnnumberedEroSubObject()
                                    self.unnumbered_ero_sub_object.parent = self
                                    self._children_name_map["unnumbered_ero_sub_object"] = "unnumbered-ero-sub-object"
                                return self.unnumbered_ero_sub_object

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ipv4ero-sub-object" or name == "unnumbered-ero-sub-object" or name == "ero-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "ero-type"):
                                self.ero_type = value
                                self.ero_type.value_namespace = name_space
                                self.ero_type.value_namespace_prefix = name_space_prefix


                    class Rro(Entity):
                        """
                        Record Route Sub Objects
                        
                        .. attribute:: ipv4rro_sub_object
                        
                        	IPV4 RRO Sub Object
                        	**type**\:   :py:class:`Ipv4RroSubObject <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.Ipv4RroSubObject>`
                        
                        .. attribute:: label_rro_sub_object
                        
                        	Label RRO Sub Object
                        	**type**\:   :py:class:`LabelRroSubObject <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.LabelRroSubObject>`
                        
                        .. attribute:: rro_type
                        
                        	RROType
                        	**type**\:   :py:class:`RsvpMgmtRroSubobj <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtRroSubobj>`
                        
                        .. attribute:: srlg_rro_sub_object
                        
                        	SRLG RRO Sub Object
                        	**type**\:   :py:class:`SrlgRroSubObject <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.SrlgRroSubObject>`
                        
                        .. attribute:: unnumbered_rro_sub_object
                        
                        	Unnumbered RRO Sub Object
                        	**type**\:   :py:class:`UnnumberedRroSubObject <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.UnnumberedRroSubObject>`
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro, self).__init__()

                            self.yang_name = "rro"
                            self.yang_parent_name = "psb-info"

                            self.rro_type = YLeaf(YType.enumeration, "rro-type")

                            self.ipv4rro_sub_object = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.Ipv4RroSubObject()
                            self.ipv4rro_sub_object.parent = self
                            self._children_name_map["ipv4rro_sub_object"] = "ipv4rro-sub-object"
                            self._children_yang_names.add("ipv4rro-sub-object")

                            self.label_rro_sub_object = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.LabelRroSubObject()
                            self.label_rro_sub_object.parent = self
                            self._children_name_map["label_rro_sub_object"] = "label-rro-sub-object"
                            self._children_yang_names.add("label-rro-sub-object")

                            self.srlg_rro_sub_object = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.SrlgRroSubObject()
                            self.srlg_rro_sub_object.parent = self
                            self._children_name_map["srlg_rro_sub_object"] = "srlg-rro-sub-object"
                            self._children_yang_names.add("srlg-rro-sub-object")

                            self.unnumbered_rro_sub_object = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.UnnumberedRroSubObject()
                            self.unnumbered_rro_sub_object.parent = self
                            self._children_name_map["unnumbered_rro_sub_object"] = "unnumbered-rro-sub-object"
                            self._children_yang_names.add("unnumbered-rro-sub-object")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("rro_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro, self).__setattr__(name, value)


                        class Ipv4RroSubObject(Entity):
                            """
                            IPV4 RRO Sub Object
                            
                            .. attribute:: flags
                            
                            	The RRO IPV4 Subobject Flags
                            	**type**\:   :py:class:`Flags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.Ipv4RroSubObject.Flags>`
                            
                            .. attribute:: rro_address
                            
                            	The RRO IPV4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.Ipv4RroSubObject, self).__init__()

                                self.yang_name = "ipv4rro-sub-object"
                                self.yang_parent_name = "rro"

                                self.rro_address = YLeaf(YType.str, "rro-address")

                                self.flags = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.Ipv4RroSubObject.Flags()
                                self.flags.parent = self
                                self._children_name_map["flags"] = "flags"
                                self._children_yang_names.add("flags")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("rro_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.Ipv4RroSubObject, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.Ipv4RroSubObject, self).__setattr__(name, value)


                            class Flags(Entity):
                                """
                                The RRO IPV4 Subobject Flags
                                
                                .. attribute:: is_bandwidth_protected
                                
                                	Bandwidth Protection Available
                                	**type**\:  bool
                                
                                .. attribute:: is_node_id
                                
                                	Node ID In Use
                                	**type**\:  bool
                                
                                .. attribute:: is_node_protection_available
                                
                                	Node Protection Available
                                	**type**\:  bool
                                
                                .. attribute:: is_protection_available
                                
                                	Local Protection Available
                                	**type**\:  bool
                                
                                .. attribute:: is_protection_in_use
                                
                                	Local Protection In Use
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ip-rsvp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.Ipv4RroSubObject.Flags, self).__init__()

                                    self.yang_name = "flags"
                                    self.yang_parent_name = "ipv4rro-sub-object"

                                    self.is_bandwidth_protected = YLeaf(YType.boolean, "is-bandwidth-protected")

                                    self.is_node_id = YLeaf(YType.boolean, "is-node-id")

                                    self.is_node_protection_available = YLeaf(YType.boolean, "is-node-protection-available")

                                    self.is_protection_available = YLeaf(YType.boolean, "is-protection-available")

                                    self.is_protection_in_use = YLeaf(YType.boolean, "is-protection-in-use")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("is_bandwidth_protected",
                                                    "is_node_id",
                                                    "is_node_protection_available",
                                                    "is_protection_available",
                                                    "is_protection_in_use") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.Ipv4RroSubObject.Flags, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.Ipv4RroSubObject.Flags, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.is_bandwidth_protected.is_set or
                                        self.is_node_id.is_set or
                                        self.is_node_protection_available.is_set or
                                        self.is_protection_available.is_set or
                                        self.is_protection_in_use.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.is_bandwidth_protected.yfilter != YFilter.not_set or
                                        self.is_node_id.yfilter != YFilter.not_set or
                                        self.is_node_protection_available.yfilter != YFilter.not_set or
                                        self.is_protection_available.yfilter != YFilter.not_set or
                                        self.is_protection_in_use.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "flags" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/psb-rsb-info/psb-info/rro/ipv4rro-sub-object/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.is_bandwidth_protected.is_set or self.is_bandwidth_protected.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_bandwidth_protected.get_name_leafdata())
                                    if (self.is_node_id.is_set or self.is_node_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_node_id.get_name_leafdata())
                                    if (self.is_node_protection_available.is_set or self.is_node_protection_available.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_node_protection_available.get_name_leafdata())
                                    if (self.is_protection_available.is_set or self.is_protection_available.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_protection_available.get_name_leafdata())
                                    if (self.is_protection_in_use.is_set or self.is_protection_in_use.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_protection_in_use.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "is-bandwidth-protected" or name == "is-node-id" or name == "is-node-protection-available" or name == "is-protection-available" or name == "is-protection-in-use"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "is-bandwidth-protected"):
                                        self.is_bandwidth_protected = value
                                        self.is_bandwidth_protected.value_namespace = name_space
                                        self.is_bandwidth_protected.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-node-id"):
                                        self.is_node_id = value
                                        self.is_node_id.value_namespace = name_space
                                        self.is_node_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-node-protection-available"):
                                        self.is_node_protection_available = value
                                        self.is_node_protection_available.value_namespace = name_space
                                        self.is_node_protection_available.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-protection-available"):
                                        self.is_protection_available = value
                                        self.is_protection_available.value_namespace = name_space
                                        self.is_protection_available.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-protection-in-use"):
                                        self.is_protection_in_use = value
                                        self.is_protection_in_use.value_namespace = name_space
                                        self.is_protection_in_use.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.rro_address.is_set or
                                    (self.flags is not None and self.flags.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.rro_address.yfilter != YFilter.not_set or
                                    (self.flags is not None and self.flags.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ipv4rro-sub-object" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/psb-rsb-info/psb-info/rro/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.rro_address.is_set or self.rro_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rro_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "flags"):
                                    if (self.flags is None):
                                        self.flags = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.Ipv4RroSubObject.Flags()
                                        self.flags.parent = self
                                        self._children_name_map["flags"] = "flags"
                                    return self.flags

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "flags" or name == "rro-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "rro-address"):
                                    self.rro_address = value
                                    self.rro_address.value_namespace = name_space
                                    self.rro_address.value_namespace_prefix = name_space_prefix


                        class LabelRroSubObject(Entity):
                            """
                            Label RRO Sub Object
                            
                            .. attribute:: flags
                            
                            	The RRO Subobject Label Flags
                            	**type**\:   :py:class:`Flags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.LabelRroSubObject.Flags>`
                            
                            .. attribute:: is_label_variable_length
                            
                            	Is the RRO Subobject Label Variable Length
                            	**type**\:  bool
                            
                            .. attribute:: label
                            
                            	The RRO Subobject Label Value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: variable_length_label
                            
                            	The RRO Subobject Variable Length Label
                            	**type**\:  list of int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.LabelRroSubObject, self).__init__()

                                self.yang_name = "label-rro-sub-object"
                                self.yang_parent_name = "rro"

                                self.is_label_variable_length = YLeaf(YType.boolean, "is-label-variable-length")

                                self.label = YLeaf(YType.uint32, "label")

                                self.variable_length_label = YLeafList(YType.uint32, "variable-length-label")

                                self.flags = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.LabelRroSubObject.Flags()
                                self.flags.parent = self
                                self._children_name_map["flags"] = "flags"
                                self._children_yang_names.add("flags")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("is_label_variable_length",
                                                "label",
                                                "variable_length_label") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.LabelRroSubObject, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.LabelRroSubObject, self).__setattr__(name, value)


                            class Flags(Entity):
                                """
                                The RRO Subobject Label Flags
                                
                                .. attribute:: is_global_label
                                
                                	Label is Global across all interfaces
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ip-rsvp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.LabelRroSubObject.Flags, self).__init__()

                                    self.yang_name = "flags"
                                    self.yang_parent_name = "label-rro-sub-object"

                                    self.is_global_label = YLeaf(YType.boolean, "is-global-label")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("is_global_label") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.LabelRroSubObject.Flags, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.LabelRroSubObject.Flags, self).__setattr__(name, value)

                                def has_data(self):
                                    return self.is_global_label.is_set

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.is_global_label.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "flags" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/psb-rsb-info/psb-info/rro/label-rro-sub-object/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.is_global_label.is_set or self.is_global_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_global_label.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "is-global-label"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "is-global-label"):
                                        self.is_global_label = value
                                        self.is_global_label.value_namespace = name_space
                                        self.is_global_label.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for leaf in self.variable_length_label.getYLeafs():
                                    if (leaf.yfilter != YFilter.not_set):
                                        return True
                                return (
                                    self.is_label_variable_length.is_set or
                                    self.label.is_set or
                                    (self.flags is not None and self.flags.has_data()))

                            def has_operation(self):
                                for leaf in self.variable_length_label.getYLeafs():
                                    if (leaf.is_set):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.is_label_variable_length.yfilter != YFilter.not_set or
                                    self.label.yfilter != YFilter.not_set or
                                    self.variable_length_label.yfilter != YFilter.not_set or
                                    (self.flags is not None and self.flags.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "label-rro-sub-object" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/psb-rsb-info/psb-info/rro/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.is_label_variable_length.is_set or self.is_label_variable_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_label_variable_length.get_name_leafdata())
                                if (self.label.is_set or self.label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.label.get_name_leafdata())

                                leaf_name_data.extend(self.variable_length_label.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "flags"):
                                    if (self.flags is None):
                                        self.flags = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.LabelRroSubObject.Flags()
                                        self.flags.parent = self
                                        self._children_name_map["flags"] = "flags"
                                    return self.flags

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "flags" or name == "is-label-variable-length" or name == "label" or name == "variable-length-label"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "is-label-variable-length"):
                                    self.is_label_variable_length = value
                                    self.is_label_variable_length.value_namespace = name_space
                                    self.is_label_variable_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "label"):
                                    self.label = value
                                    self.label.value_namespace = name_space
                                    self.label.value_namespace_prefix = name_space_prefix
                                if(value_path == "variable-length-label"):
                                    self.variable_length_label.append(value)


                        class UnnumberedRroSubObject(Entity):
                            """
                            Unnumbered RRO Sub Object
                            
                            .. attribute:: flags
                            
                            	The RRO Subobject Unnumbered Flags
                            	**type**\:   :py:class:`Flags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.UnnumberedRroSubObject.Flags>`
                            
                            .. attribute:: interface_address
                            
                            	The RRO Interface Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: interface_id
                            
                            	The RRO Interface ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.UnnumberedRroSubObject, self).__init__()

                                self.yang_name = "unnumbered-rro-sub-object"
                                self.yang_parent_name = "rro"

                                self.interface_address = YLeaf(YType.str, "interface-address")

                                self.interface_id = YLeaf(YType.uint32, "interface-id")

                                self.flags = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.UnnumberedRroSubObject.Flags()
                                self.flags.parent = self
                                self._children_name_map["flags"] = "flags"
                                self._children_yang_names.add("flags")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("interface_address",
                                                "interface_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.UnnumberedRroSubObject, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.UnnumberedRroSubObject, self).__setattr__(name, value)


                            class Flags(Entity):
                                """
                                The RRO Subobject Unnumbered Flags
                                
                                .. attribute:: is_bandwidth_protected
                                
                                	Bandwidth Protection Available
                                	**type**\:  bool
                                
                                .. attribute:: is_node_id
                                
                                	Node ID In Use
                                	**type**\:  bool
                                
                                .. attribute:: is_node_protection_available
                                
                                	Node Protection Available
                                	**type**\:  bool
                                
                                .. attribute:: is_protection_available
                                
                                	Local Protection Available
                                	**type**\:  bool
                                
                                .. attribute:: is_protection_in_use
                                
                                	Local Protection In Use
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ip-rsvp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.UnnumberedRroSubObject.Flags, self).__init__()

                                    self.yang_name = "flags"
                                    self.yang_parent_name = "unnumbered-rro-sub-object"

                                    self.is_bandwidth_protected = YLeaf(YType.boolean, "is-bandwidth-protected")

                                    self.is_node_id = YLeaf(YType.boolean, "is-node-id")

                                    self.is_node_protection_available = YLeaf(YType.boolean, "is-node-protection-available")

                                    self.is_protection_available = YLeaf(YType.boolean, "is-protection-available")

                                    self.is_protection_in_use = YLeaf(YType.boolean, "is-protection-in-use")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("is_bandwidth_protected",
                                                    "is_node_id",
                                                    "is_node_protection_available",
                                                    "is_protection_available",
                                                    "is_protection_in_use") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.UnnumberedRroSubObject.Flags, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.UnnumberedRroSubObject.Flags, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.is_bandwidth_protected.is_set or
                                        self.is_node_id.is_set or
                                        self.is_node_protection_available.is_set or
                                        self.is_protection_available.is_set or
                                        self.is_protection_in_use.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.is_bandwidth_protected.yfilter != YFilter.not_set or
                                        self.is_node_id.yfilter != YFilter.not_set or
                                        self.is_node_protection_available.yfilter != YFilter.not_set or
                                        self.is_protection_available.yfilter != YFilter.not_set or
                                        self.is_protection_in_use.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "flags" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/psb-rsb-info/psb-info/rro/unnumbered-rro-sub-object/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.is_bandwidth_protected.is_set or self.is_bandwidth_protected.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_bandwidth_protected.get_name_leafdata())
                                    if (self.is_node_id.is_set or self.is_node_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_node_id.get_name_leafdata())
                                    if (self.is_node_protection_available.is_set or self.is_node_protection_available.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_node_protection_available.get_name_leafdata())
                                    if (self.is_protection_available.is_set or self.is_protection_available.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_protection_available.get_name_leafdata())
                                    if (self.is_protection_in_use.is_set or self.is_protection_in_use.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_protection_in_use.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "is-bandwidth-protected" or name == "is-node-id" or name == "is-node-protection-available" or name == "is-protection-available" or name == "is-protection-in-use"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "is-bandwidth-protected"):
                                        self.is_bandwidth_protected = value
                                        self.is_bandwidth_protected.value_namespace = name_space
                                        self.is_bandwidth_protected.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-node-id"):
                                        self.is_node_id = value
                                        self.is_node_id.value_namespace = name_space
                                        self.is_node_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-node-protection-available"):
                                        self.is_node_protection_available = value
                                        self.is_node_protection_available.value_namespace = name_space
                                        self.is_node_protection_available.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-protection-available"):
                                        self.is_protection_available = value
                                        self.is_protection_available.value_namespace = name_space
                                        self.is_protection_available.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-protection-in-use"):
                                        self.is_protection_in_use = value
                                        self.is_protection_in_use.value_namespace = name_space
                                        self.is_protection_in_use.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.interface_address.is_set or
                                    self.interface_id.is_set or
                                    (self.flags is not None and self.flags.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.interface_address.yfilter != YFilter.not_set or
                                    self.interface_id.yfilter != YFilter.not_set or
                                    (self.flags is not None and self.flags.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "unnumbered-rro-sub-object" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/psb-rsb-info/psb-info/rro/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.interface_address.is_set or self.interface_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_address.get_name_leafdata())
                                if (self.interface_id.is_set or self.interface_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "flags"):
                                    if (self.flags is None):
                                        self.flags = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.UnnumberedRroSubObject.Flags()
                                        self.flags.parent = self
                                        self._children_name_map["flags"] = "flags"
                                    return self.flags

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "flags" or name == "interface-address" or name == "interface-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "interface-address"):
                                    self.interface_address = value
                                    self.interface_address.value_namespace = name_space
                                    self.interface_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-id"):
                                    self.interface_id = value
                                    self.interface_id.value_namespace = name_space
                                    self.interface_id.value_namespace_prefix = name_space_prefix


                        class SrlgRroSubObject(Entity):
                            """
                            SRLG RRO Sub Object
                            
                            .. attribute:: srl_gs
                            
                            	The RRO Subobject SRLGs
                            	**type**\:  list of int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.SrlgRroSubObject, self).__init__()

                                self.yang_name = "srlg-rro-sub-object"
                                self.yang_parent_name = "rro"

                                self.srl_gs = YLeafList(YType.uint32, "srl-gs")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("srl_gs") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.SrlgRroSubObject, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.SrlgRroSubObject, self).__setattr__(name, value)

                            def has_data(self):
                                for leaf in self.srl_gs.getYLeafs():
                                    if (leaf.yfilter != YFilter.not_set):
                                        return True
                                return False

                            def has_operation(self):
                                for leaf in self.srl_gs.getYLeafs():
                                    if (leaf.is_set):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.srl_gs.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "srlg-rro-sub-object" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/psb-rsb-info/psb-info/rro/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                leaf_name_data.extend(self.srl_gs.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "srl-gs"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "srl-gs"):
                                    self.srl_gs.append(value)

                        def has_data(self):
                            return (
                                self.rro_type.is_set or
                                (self.ipv4rro_sub_object is not None and self.ipv4rro_sub_object.has_data()) or
                                (self.label_rro_sub_object is not None and self.label_rro_sub_object.has_data()) or
                                (self.srlg_rro_sub_object is not None and self.srlg_rro_sub_object.has_data()) or
                                (self.unnumbered_rro_sub_object is not None and self.unnumbered_rro_sub_object.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.rro_type.yfilter != YFilter.not_set or
                                (self.ipv4rro_sub_object is not None and self.ipv4rro_sub_object.has_operation()) or
                                (self.label_rro_sub_object is not None and self.label_rro_sub_object.has_operation()) or
                                (self.srlg_rro_sub_object is not None and self.srlg_rro_sub_object.has_operation()) or
                                (self.unnumbered_rro_sub_object is not None and self.unnumbered_rro_sub_object.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rro" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/psb-rsb-info/psb-info/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.rro_type.is_set or self.rro_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rro_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "ipv4rro-sub-object"):
                                if (self.ipv4rro_sub_object is None):
                                    self.ipv4rro_sub_object = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.Ipv4RroSubObject()
                                    self.ipv4rro_sub_object.parent = self
                                    self._children_name_map["ipv4rro_sub_object"] = "ipv4rro-sub-object"
                                return self.ipv4rro_sub_object

                            if (child_yang_name == "label-rro-sub-object"):
                                if (self.label_rro_sub_object is None):
                                    self.label_rro_sub_object = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.LabelRroSubObject()
                                    self.label_rro_sub_object.parent = self
                                    self._children_name_map["label_rro_sub_object"] = "label-rro-sub-object"
                                return self.label_rro_sub_object

                            if (child_yang_name == "srlg-rro-sub-object"):
                                if (self.srlg_rro_sub_object is None):
                                    self.srlg_rro_sub_object = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.SrlgRroSubObject()
                                    self.srlg_rro_sub_object.parent = self
                                    self._children_name_map["srlg_rro_sub_object"] = "srlg-rro-sub-object"
                                return self.srlg_rro_sub_object

                            if (child_yang_name == "unnumbered-rro-sub-object"):
                                if (self.unnumbered_rro_sub_object is None):
                                    self.unnumbered_rro_sub_object = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.UnnumberedRroSubObject()
                                    self.unnumbered_rro_sub_object.parent = self
                                    self._children_name_map["unnumbered_rro_sub_object"] = "unnumbered-rro-sub-object"
                                return self.unnumbered_rro_sub_object

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ipv4rro-sub-object" or name == "label-rro-sub-object" or name == "srlg-rro-sub-object" or name == "unnumbered-rro-sub-object" or name == "rro-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "rro-type"):
                                self.rro_type = value
                                self.rro_type.value_namespace = name_space
                                self.rro_type.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.ero:
                            if (c.has_data()):
                                return True
                        for c in self.rro:
                            if (c.has_data()):
                                return True
                        return (
                            self.destination_address.is_set or
                            self.in_interface.is_set or
                            self.in_label.is_set or
                            self.incoming_interface_address.is_set or
                            self.is_bad_address.is_set or
                            self.is_ero_valid.is_set or
                            self.is_rro_valid.is_set or
                            self.is_traffic_spec_valid.is_set or
                            self.is_valid.is_set or
                            self.lsp_id.is_set or
                            self.lsp_wrap_label.is_set or
                            self.p2mp_sub_group_origin.is_set or
                            self.sub_group_id.is_set or
                            self.tunnel_name.is_set or
                            (self.association is not None and self.association.has_data()) or
                            (self.generic_in_label is not None and self.generic_in_label.has_data()) or
                            (self.generic_traffic_spec is not None and self.generic_traffic_spec.has_data()) or
                            (self.protection is not None and self.protection.has_data()) or
                            (self.reverse_lsp is not None and self.reverse_lsp.has_data()) or
                            (self.traffic_spec is not None and self.traffic_spec.has_data()))

                    def has_operation(self):
                        for c in self.ero:
                            if (c.has_operation()):
                                return True
                        for c in self.rro:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.destination_address.yfilter != YFilter.not_set or
                            self.in_interface.yfilter != YFilter.not_set or
                            self.in_label.yfilter != YFilter.not_set or
                            self.incoming_interface_address.yfilter != YFilter.not_set or
                            self.is_bad_address.yfilter != YFilter.not_set or
                            self.is_ero_valid.yfilter != YFilter.not_set or
                            self.is_rro_valid.yfilter != YFilter.not_set or
                            self.is_traffic_spec_valid.yfilter != YFilter.not_set or
                            self.is_valid.yfilter != YFilter.not_set or
                            self.lsp_id.yfilter != YFilter.not_set or
                            self.lsp_wrap_label.yfilter != YFilter.not_set or
                            self.p2mp_sub_group_origin.yfilter != YFilter.not_set or
                            self.sub_group_id.yfilter != YFilter.not_set or
                            self.tunnel_name.yfilter != YFilter.not_set or
                            (self.association is not None and self.association.has_operation()) or
                            (self.generic_in_label is not None and self.generic_in_label.has_operation()) or
                            (self.generic_traffic_spec is not None and self.generic_traffic_spec.has_operation()) or
                            (self.protection is not None and self.protection.has_operation()) or
                            (self.reverse_lsp is not None and self.reverse_lsp.has_operation()) or
                            (self.traffic_spec is not None and self.traffic_spec.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "psb-info" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/psb-rsb-info/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.destination_address.get_name_leafdata())
                        if (self.in_interface.is_set or self.in_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.in_interface.get_name_leafdata())
                        if (self.in_label.is_set or self.in_label.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.in_label.get_name_leafdata())
                        if (self.incoming_interface_address.is_set or self.incoming_interface_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.incoming_interface_address.get_name_leafdata())
                        if (self.is_bad_address.is_set or self.is_bad_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_bad_address.get_name_leafdata())
                        if (self.is_ero_valid.is_set or self.is_ero_valid.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_ero_valid.get_name_leafdata())
                        if (self.is_rro_valid.is_set or self.is_rro_valid.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_rro_valid.get_name_leafdata())
                        if (self.is_traffic_spec_valid.is_set or self.is_traffic_spec_valid.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_traffic_spec_valid.get_name_leafdata())
                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_valid.get_name_leafdata())
                        if (self.lsp_id.is_set or self.lsp_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.lsp_id.get_name_leafdata())
                        if (self.lsp_wrap_label.is_set or self.lsp_wrap_label.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.lsp_wrap_label.get_name_leafdata())
                        if (self.p2mp_sub_group_origin.is_set or self.p2mp_sub_group_origin.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.p2mp_sub_group_origin.get_name_leafdata())
                        if (self.sub_group_id.is_set or self.sub_group_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sub_group_id.get_name_leafdata())
                        if (self.tunnel_name.is_set or self.tunnel_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.tunnel_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "association"):
                            if (self.association is None):
                                self.association = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association()
                                self.association.parent = self
                                self._children_name_map["association"] = "association"
                            return self.association

                        if (child_yang_name == "ero"):
                            for c in self.ero:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Ero()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.ero.append(c)
                            return c

                        if (child_yang_name == "generic-in-label"):
                            if (self.generic_in_label is None):
                                self.generic_in_label = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericInLabel()
                                self.generic_in_label.parent = self
                                self._children_name_map["generic_in_label"] = "generic-in-label"
                            return self.generic_in_label

                        if (child_yang_name == "generic-traffic-spec"):
                            if (self.generic_traffic_spec is None):
                                self.generic_traffic_spec = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericTrafficSpec()
                                self.generic_traffic_spec.parent = self
                                self._children_name_map["generic_traffic_spec"] = "generic-traffic-spec"
                            return self.generic_traffic_spec

                        if (child_yang_name == "protection"):
                            if (self.protection is None):
                                self.protection = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Protection()
                                self.protection.parent = self
                                self._children_name_map["protection"] = "protection"
                            return self.protection

                        if (child_yang_name == "reverse-lsp"):
                            if (self.reverse_lsp is None):
                                self.reverse_lsp = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp()
                                self.reverse_lsp.parent = self
                                self._children_name_map["reverse_lsp"] = "reverse-lsp"
                            return self.reverse_lsp

                        if (child_yang_name == "rro"):
                            for c in self.rro:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.rro.append(c)
                            return c

                        if (child_yang_name == "traffic-spec"):
                            if (self.traffic_spec is None):
                                self.traffic_spec = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.TrafficSpec()
                                self.traffic_spec.parent = self
                                self._children_name_map["traffic_spec"] = "traffic-spec"
                            return self.traffic_spec

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "association" or name == "ero" or name == "generic-in-label" or name == "generic-traffic-spec" or name == "protection" or name == "reverse-lsp" or name == "rro" or name == "traffic-spec" or name == "destination-address" or name == "in-interface" or name == "in-label" or name == "incoming-interface-address" or name == "is-bad-address" or name == "is-ero-valid" or name == "is-rro-valid" or name == "is-traffic-spec-valid" or name == "is-valid" or name == "lsp-id" or name == "lsp-wrap-label" or name == "p2mp-sub-group-origin" or name == "sub-group-id" or name == "tunnel-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "destination-address"):
                            self.destination_address = value
                            self.destination_address.value_namespace = name_space
                            self.destination_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "in-interface"):
                            self.in_interface = value
                            self.in_interface.value_namespace = name_space
                            self.in_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "in-label"):
                            self.in_label = value
                            self.in_label.value_namespace = name_space
                            self.in_label.value_namespace_prefix = name_space_prefix
                        if(value_path == "incoming-interface-address"):
                            self.incoming_interface_address = value
                            self.incoming_interface_address.value_namespace = name_space
                            self.incoming_interface_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-bad-address"):
                            self.is_bad_address = value
                            self.is_bad_address.value_namespace = name_space
                            self.is_bad_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-ero-valid"):
                            self.is_ero_valid = value
                            self.is_ero_valid.value_namespace = name_space
                            self.is_ero_valid.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-rro-valid"):
                            self.is_rro_valid = value
                            self.is_rro_valid.value_namespace = name_space
                            self.is_rro_valid.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-traffic-spec-valid"):
                            self.is_traffic_spec_valid = value
                            self.is_traffic_spec_valid.value_namespace = name_space
                            self.is_traffic_spec_valid.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-valid"):
                            self.is_valid = value
                            self.is_valid.value_namespace = name_space
                            self.is_valid.value_namespace_prefix = name_space_prefix
                        if(value_path == "lsp-id"):
                            self.lsp_id = value
                            self.lsp_id.value_namespace = name_space
                            self.lsp_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "lsp-wrap-label"):
                            self.lsp_wrap_label = value
                            self.lsp_wrap_label.value_namespace = name_space
                            self.lsp_wrap_label.value_namespace_prefix = name_space_prefix
                        if(value_path == "p2mp-sub-group-origin"):
                            self.p2mp_sub_group_origin = value
                            self.p2mp_sub_group_origin.value_namespace = name_space
                            self.p2mp_sub_group_origin.value_namespace_prefix = name_space_prefix
                        if(value_path == "sub-group-id"):
                            self.sub_group_id = value
                            self.sub_group_id.value_namespace = name_space
                            self.sub_group_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "tunnel-name"):
                            self.tunnel_name = value
                            self.tunnel_name.value_namespace = name_space
                            self.tunnel_name.value_namespace_prefix = name_space_prefix


                class RsbInfo(Entity):
                    """
                    Reservation Info
                    
                    .. attribute:: backup_interface
                    
                    	Backup tunnel interface
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: backup_label
                    
                    	Backup label
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: destination_address
                    
                    	Destination address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: flow_spec
                    
                    	Flow spec object
                    	**type**\:   :py:class:`FlowSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.FlowSpec>`
                    
                    .. attribute:: generic_flow_spec
                    
                    	Generic Flow Spec object
                    	**type**\:   :py:class:`GenericFlowSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.GenericFlowSpec>`
                    
                    .. attribute:: generic_out_label
                    
                    	Generic Label for outbound traffic
                    	**type**\:   :py:class:`GenericOutLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.GenericOutLabel>`
                    
                    .. attribute:: is_flow_spec_valid
                    
                    	FlowSpec validity
                    	**type**\:  bool
                    
                    .. attribute:: is_rro_valid
                    
                    	RRO validity
                    	**type**\:  bool
                    
                    .. attribute:: is_valid
                    
                    	Entry validity
                    	**type**\:  bool
                    
                    .. attribute:: out_interface
                    
                    	Interface on which outbound message was sent
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: out_label
                    
                    	Label for outbound traffic
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rro
                    
                    	Record route object
                    	**type**\: list of    :py:class:`Rro <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo, self).__init__()

                        self.yang_name = "rsb-info"
                        self.yang_parent_name = "psb-rsb-info"

                        self.backup_interface = YLeaf(YType.str, "backup-interface")

                        self.backup_label = YLeaf(YType.uint32, "backup-label")

                        self.destination_address = YLeaf(YType.str, "destination-address")

                        self.is_flow_spec_valid = YLeaf(YType.boolean, "is-flow-spec-valid")

                        self.is_rro_valid = YLeaf(YType.boolean, "is-rro-valid")

                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                        self.out_interface = YLeaf(YType.str, "out-interface")

                        self.out_label = YLeaf(YType.uint32, "out-label")

                        self.flow_spec = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.FlowSpec()
                        self.flow_spec.parent = self
                        self._children_name_map["flow_spec"] = "flow-spec"
                        self._children_yang_names.add("flow-spec")

                        self.generic_flow_spec = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.GenericFlowSpec()
                        self.generic_flow_spec.parent = self
                        self._children_name_map["generic_flow_spec"] = "generic-flow-spec"
                        self._children_yang_names.add("generic-flow-spec")

                        self.generic_out_label = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.GenericOutLabel()
                        self.generic_out_label.parent = self
                        self._children_name_map["generic_out_label"] = "generic-out-label"
                        self._children_yang_names.add("generic-out-label")

                        self.rro = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("backup_interface",
                                        "backup_label",
                                        "destination_address",
                                        "is_flow_spec_valid",
                                        "is_rro_valid",
                                        "is_valid",
                                        "out_interface",
                                        "out_label") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo, self).__setattr__(name, value)


                    class GenericOutLabel(Entity):
                        """
                        Generic Label for outbound traffic
                        
                        .. attribute:: generalized_label
                        
                        	Generalized Label
                        	**type**\:   :py:class:`GeneralizedLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.GenericOutLabel.GeneralizedLabel>`
                        
                        .. attribute:: generic_label_type
                        
                        	GenericLabelType
                        	**type**\:   :py:class:`RsvpMgmtGenericLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtGenericLabel>`
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.GenericOutLabel, self).__init__()

                            self.yang_name = "generic-out-label"
                            self.yang_parent_name = "rsb-info"

                            self.generic_label_type = YLeaf(YType.enumeration, "generic-label-type")

                            self.generalized_label = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.GenericOutLabel.GeneralizedLabel()
                            self.generalized_label.parent = self
                            self._children_name_map["generalized_label"] = "generalized-label"
                            self._children_yang_names.add("generalized-label")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("generic_label_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.GenericOutLabel, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.GenericOutLabel, self).__setattr__(name, value)


                        class GeneralizedLabel(Entity):
                            """
                            Generalized Label
                            
                            .. attribute:: value
                            
                            	Generalized Label Value
                            	**type**\:  list of int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.GenericOutLabel.GeneralizedLabel, self).__init__()

                                self.yang_name = "generalized-label"
                                self.yang_parent_name = "generic-out-label"

                                self.value = YLeafList(YType.uint32, "value")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("value") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.GenericOutLabel.GeneralizedLabel, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.GenericOutLabel.GeneralizedLabel, self).__setattr__(name, value)

                            def has_data(self):
                                for leaf in self.value.getYLeafs():
                                    if (leaf.yfilter != YFilter.not_set):
                                        return True
                                return False

                            def has_operation(self):
                                for leaf in self.value.getYLeafs():
                                    if (leaf.is_set):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.value.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "generalized-label" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/psb-rsb-info/rsb-info/generic-out-label/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                leaf_name_data.extend(self.value.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "value"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "value"):
                                    self.value.append(value)

                        def has_data(self):
                            return (
                                self.generic_label_type.is_set or
                                (self.generalized_label is not None and self.generalized_label.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.generic_label_type.yfilter != YFilter.not_set or
                                (self.generalized_label is not None and self.generalized_label.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "generic-out-label" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/psb-rsb-info/rsb-info/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.generic_label_type.is_set or self.generic_label_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.generic_label_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "generalized-label"):
                                if (self.generalized_label is None):
                                    self.generalized_label = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.GenericOutLabel.GeneralizedLabel()
                                    self.generalized_label.parent = self
                                    self._children_name_map["generalized_label"] = "generalized-label"
                                return self.generalized_label

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "generalized-label" or name == "generic-label-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "generic-label-type"):
                                self.generic_label_type = value
                                self.generic_label_type.value_namespace = name_space
                                self.generic_label_type.value_namespace_prefix = name_space_prefix


                    class FlowSpec(Entity):
                        """
                        Flow spec object
                        
                        .. attribute:: flow_average_rate
                        
                        	The Flow Average Rate in bytes per second
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: byte/s
                        
                        .. attribute:: flow_max_burst
                        
                        	The Flow Maximum Burst
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: flow_max_unit
                        
                        	The Flow Maximum Unit
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: flow_min_unit
                        
                        	The Flow Minimum Unit
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: flow_peak_rate
                        
                        	The Flow Peak Rate in bytes per second
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: byte/s
                        
                        .. attribute:: flow_qos
                        
                        	The Flow Quality of Service
                        	**type**\:   :py:class:`RsvpMgmtQosServiceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtQosServiceEnum>`
                        
                        .. attribute:: flow_requested_rate
                        
                        	The Flow Requested Rate in bytes per second
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: byte/s
                        
                        .. attribute:: flow_slack
                        
                        	The Flow Slack
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.FlowSpec, self).__init__()

                            self.yang_name = "flow-spec"
                            self.yang_parent_name = "rsb-info"

                            self.flow_average_rate = YLeaf(YType.uint64, "flow-average-rate")

                            self.flow_max_burst = YLeaf(YType.uint64, "flow-max-burst")

                            self.flow_max_unit = YLeaf(YType.uint32, "flow-max-unit")

                            self.flow_min_unit = YLeaf(YType.uint32, "flow-min-unit")

                            self.flow_peak_rate = YLeaf(YType.uint64, "flow-peak-rate")

                            self.flow_qos = YLeaf(YType.enumeration, "flow-qos")

                            self.flow_requested_rate = YLeaf(YType.uint64, "flow-requested-rate")

                            self.flow_slack = YLeaf(YType.uint32, "flow-slack")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("flow_average_rate",
                                            "flow_max_burst",
                                            "flow_max_unit",
                                            "flow_min_unit",
                                            "flow_peak_rate",
                                            "flow_qos",
                                            "flow_requested_rate",
                                            "flow_slack") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.FlowSpec, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.FlowSpec, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.flow_average_rate.is_set or
                                self.flow_max_burst.is_set or
                                self.flow_max_unit.is_set or
                                self.flow_min_unit.is_set or
                                self.flow_peak_rate.is_set or
                                self.flow_qos.is_set or
                                self.flow_requested_rate.is_set or
                                self.flow_slack.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.flow_average_rate.yfilter != YFilter.not_set or
                                self.flow_max_burst.yfilter != YFilter.not_set or
                                self.flow_max_unit.yfilter != YFilter.not_set or
                                self.flow_min_unit.yfilter != YFilter.not_set or
                                self.flow_peak_rate.yfilter != YFilter.not_set or
                                self.flow_qos.yfilter != YFilter.not_set or
                                self.flow_requested_rate.yfilter != YFilter.not_set or
                                self.flow_slack.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "flow-spec" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/psb-rsb-info/rsb-info/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.flow_average_rate.is_set or self.flow_average_rate.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.flow_average_rate.get_name_leafdata())
                            if (self.flow_max_burst.is_set or self.flow_max_burst.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.flow_max_burst.get_name_leafdata())
                            if (self.flow_max_unit.is_set or self.flow_max_unit.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.flow_max_unit.get_name_leafdata())
                            if (self.flow_min_unit.is_set or self.flow_min_unit.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.flow_min_unit.get_name_leafdata())
                            if (self.flow_peak_rate.is_set or self.flow_peak_rate.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.flow_peak_rate.get_name_leafdata())
                            if (self.flow_qos.is_set or self.flow_qos.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.flow_qos.get_name_leafdata())
                            if (self.flow_requested_rate.is_set or self.flow_requested_rate.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.flow_requested_rate.get_name_leafdata())
                            if (self.flow_slack.is_set or self.flow_slack.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.flow_slack.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "flow-average-rate" or name == "flow-max-burst" or name == "flow-max-unit" or name == "flow-min-unit" or name == "flow-peak-rate" or name == "flow-qos" or name == "flow-requested-rate" or name == "flow-slack"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "flow-average-rate"):
                                self.flow_average_rate = value
                                self.flow_average_rate.value_namespace = name_space
                                self.flow_average_rate.value_namespace_prefix = name_space_prefix
                            if(value_path == "flow-max-burst"):
                                self.flow_max_burst = value
                                self.flow_max_burst.value_namespace = name_space
                                self.flow_max_burst.value_namespace_prefix = name_space_prefix
                            if(value_path == "flow-max-unit"):
                                self.flow_max_unit = value
                                self.flow_max_unit.value_namespace = name_space
                                self.flow_max_unit.value_namespace_prefix = name_space_prefix
                            if(value_path == "flow-min-unit"):
                                self.flow_min_unit = value
                                self.flow_min_unit.value_namespace = name_space
                                self.flow_min_unit.value_namespace_prefix = name_space_prefix
                            if(value_path == "flow-peak-rate"):
                                self.flow_peak_rate = value
                                self.flow_peak_rate.value_namespace = name_space
                                self.flow_peak_rate.value_namespace_prefix = name_space_prefix
                            if(value_path == "flow-qos"):
                                self.flow_qos = value
                                self.flow_qos.value_namespace = name_space
                                self.flow_qos.value_namespace_prefix = name_space_prefix
                            if(value_path == "flow-requested-rate"):
                                self.flow_requested_rate = value
                                self.flow_requested_rate.value_namespace = name_space
                                self.flow_requested_rate.value_namespace_prefix = name_space_prefix
                            if(value_path == "flow-slack"):
                                self.flow_slack = value
                                self.flow_slack.value_namespace = name_space
                                self.flow_slack.value_namespace_prefix = name_space_prefix


                    class GenericFlowSpec(Entity):
                        """
                        Generic Flow Spec object
                        
                        .. attribute:: flow_spec_type
                        
                        	FlowSpecType
                        	**type**\:   :py:class:`RsvpMgmtFlowSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtFlowSpec>`
                        
                        .. attribute:: g709otn_flow_spec
                        
                        	G709 OTN FlowSpec
                        	**type**\:   :py:class:`G709OtnFlowSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.GenericFlowSpec.G709OtnFlowSpec>`
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.GenericFlowSpec, self).__init__()

                            self.yang_name = "generic-flow-spec"
                            self.yang_parent_name = "rsb-info"

                            self.flow_spec_type = YLeaf(YType.enumeration, "flow-spec-type")

                            self.g709otn_flow_spec = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.GenericFlowSpec.G709OtnFlowSpec()
                            self.g709otn_flow_spec.parent = self
                            self._children_name_map["g709otn_flow_spec"] = "g709otn-flow-spec"
                            self._children_yang_names.add("g709otn-flow-spec")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("flow_spec_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.GenericFlowSpec, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.GenericFlowSpec, self).__setattr__(name, value)


                        class G709OtnFlowSpec(Entity):
                            """
                            G709 OTN FlowSpec
                            
                            .. attribute:: flow_bit_rate
                            
                            	G709 OTN Flow Bit Rate
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: flow_multiplier
                            
                            	G709 OTN Flow Multiplier
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: flow_nvc
                            
                            	G709 OTN Flow NVC
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: flow_signal_type
                            
                            	G709 OTN Flow Signal Type (Refer G709 v3)
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.GenericFlowSpec.G709OtnFlowSpec, self).__init__()

                                self.yang_name = "g709otn-flow-spec"
                                self.yang_parent_name = "generic-flow-spec"

                                self.flow_bit_rate = YLeaf(YType.uint64, "flow-bit-rate")

                                self.flow_multiplier = YLeaf(YType.uint16, "flow-multiplier")

                                self.flow_nvc = YLeaf(YType.uint16, "flow-nvc")

                                self.flow_signal_type = YLeaf(YType.uint8, "flow-signal-type")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("flow_bit_rate",
                                                "flow_multiplier",
                                                "flow_nvc",
                                                "flow_signal_type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.GenericFlowSpec.G709OtnFlowSpec, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.GenericFlowSpec.G709OtnFlowSpec, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.flow_bit_rate.is_set or
                                    self.flow_multiplier.is_set or
                                    self.flow_nvc.is_set or
                                    self.flow_signal_type.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.flow_bit_rate.yfilter != YFilter.not_set or
                                    self.flow_multiplier.yfilter != YFilter.not_set or
                                    self.flow_nvc.yfilter != YFilter.not_set or
                                    self.flow_signal_type.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "g709otn-flow-spec" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/psb-rsb-info/rsb-info/generic-flow-spec/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.flow_bit_rate.is_set or self.flow_bit_rate.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.flow_bit_rate.get_name_leafdata())
                                if (self.flow_multiplier.is_set or self.flow_multiplier.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.flow_multiplier.get_name_leafdata())
                                if (self.flow_nvc.is_set or self.flow_nvc.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.flow_nvc.get_name_leafdata())
                                if (self.flow_signal_type.is_set or self.flow_signal_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.flow_signal_type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "flow-bit-rate" or name == "flow-multiplier" or name == "flow-nvc" or name == "flow-signal-type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "flow-bit-rate"):
                                    self.flow_bit_rate = value
                                    self.flow_bit_rate.value_namespace = name_space
                                    self.flow_bit_rate.value_namespace_prefix = name_space_prefix
                                if(value_path == "flow-multiplier"):
                                    self.flow_multiplier = value
                                    self.flow_multiplier.value_namespace = name_space
                                    self.flow_multiplier.value_namespace_prefix = name_space_prefix
                                if(value_path == "flow-nvc"):
                                    self.flow_nvc = value
                                    self.flow_nvc.value_namespace = name_space
                                    self.flow_nvc.value_namespace_prefix = name_space_prefix
                                if(value_path == "flow-signal-type"):
                                    self.flow_signal_type = value
                                    self.flow_signal_type.value_namespace = name_space
                                    self.flow_signal_type.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.flow_spec_type.is_set or
                                (self.g709otn_flow_spec is not None and self.g709otn_flow_spec.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.flow_spec_type.yfilter != YFilter.not_set or
                                (self.g709otn_flow_spec is not None and self.g709otn_flow_spec.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "generic-flow-spec" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/psb-rsb-info/rsb-info/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.flow_spec_type.is_set or self.flow_spec_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.flow_spec_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "g709otn-flow-spec"):
                                if (self.g709otn_flow_spec is None):
                                    self.g709otn_flow_spec = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.GenericFlowSpec.G709OtnFlowSpec()
                                    self.g709otn_flow_spec.parent = self
                                    self._children_name_map["g709otn_flow_spec"] = "g709otn-flow-spec"
                                return self.g709otn_flow_spec

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "g709otn-flow-spec" or name == "flow-spec-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "flow-spec-type"):
                                self.flow_spec_type = value
                                self.flow_spec_type.value_namespace = name_space
                                self.flow_spec_type.value_namespace_prefix = name_space_prefix


                    class Rro(Entity):
                        """
                        Record route object
                        
                        .. attribute:: ipv4rro_sub_object
                        
                        	IPV4 RRO Sub Object
                        	**type**\:   :py:class:`Ipv4RroSubObject <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.Ipv4RroSubObject>`
                        
                        .. attribute:: label_rro_sub_object
                        
                        	Label RRO Sub Object
                        	**type**\:   :py:class:`LabelRroSubObject <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.LabelRroSubObject>`
                        
                        .. attribute:: rro_type
                        
                        	RROType
                        	**type**\:   :py:class:`RsvpMgmtRroSubobj <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtRroSubobj>`
                        
                        .. attribute:: srlg_rro_sub_object
                        
                        	SRLG RRO Sub Object
                        	**type**\:   :py:class:`SrlgRroSubObject <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.SrlgRroSubObject>`
                        
                        .. attribute:: unnumbered_rro_sub_object
                        
                        	Unnumbered RRO Sub Object
                        	**type**\:   :py:class:`UnnumberedRroSubObject <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.UnnumberedRroSubObject>`
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro, self).__init__()

                            self.yang_name = "rro"
                            self.yang_parent_name = "rsb-info"

                            self.rro_type = YLeaf(YType.enumeration, "rro-type")

                            self.ipv4rro_sub_object = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.Ipv4RroSubObject()
                            self.ipv4rro_sub_object.parent = self
                            self._children_name_map["ipv4rro_sub_object"] = "ipv4rro-sub-object"
                            self._children_yang_names.add("ipv4rro-sub-object")

                            self.label_rro_sub_object = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.LabelRroSubObject()
                            self.label_rro_sub_object.parent = self
                            self._children_name_map["label_rro_sub_object"] = "label-rro-sub-object"
                            self._children_yang_names.add("label-rro-sub-object")

                            self.srlg_rro_sub_object = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.SrlgRroSubObject()
                            self.srlg_rro_sub_object.parent = self
                            self._children_name_map["srlg_rro_sub_object"] = "srlg-rro-sub-object"
                            self._children_yang_names.add("srlg-rro-sub-object")

                            self.unnumbered_rro_sub_object = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.UnnumberedRroSubObject()
                            self.unnumbered_rro_sub_object.parent = self
                            self._children_name_map["unnumbered_rro_sub_object"] = "unnumbered-rro-sub-object"
                            self._children_yang_names.add("unnumbered-rro-sub-object")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("rro_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro, self).__setattr__(name, value)


                        class Ipv4RroSubObject(Entity):
                            """
                            IPV4 RRO Sub Object
                            
                            .. attribute:: flags
                            
                            	The RRO IPV4 Subobject Flags
                            	**type**\:   :py:class:`Flags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.Ipv4RroSubObject.Flags>`
                            
                            .. attribute:: rro_address
                            
                            	The RRO IPV4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.Ipv4RroSubObject, self).__init__()

                                self.yang_name = "ipv4rro-sub-object"
                                self.yang_parent_name = "rro"

                                self.rro_address = YLeaf(YType.str, "rro-address")

                                self.flags = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.Ipv4RroSubObject.Flags()
                                self.flags.parent = self
                                self._children_name_map["flags"] = "flags"
                                self._children_yang_names.add("flags")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("rro_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.Ipv4RroSubObject, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.Ipv4RroSubObject, self).__setattr__(name, value)


                            class Flags(Entity):
                                """
                                The RRO IPV4 Subobject Flags
                                
                                .. attribute:: is_bandwidth_protected
                                
                                	Bandwidth Protection Available
                                	**type**\:  bool
                                
                                .. attribute:: is_node_id
                                
                                	Node ID In Use
                                	**type**\:  bool
                                
                                .. attribute:: is_node_protection_available
                                
                                	Node Protection Available
                                	**type**\:  bool
                                
                                .. attribute:: is_protection_available
                                
                                	Local Protection Available
                                	**type**\:  bool
                                
                                .. attribute:: is_protection_in_use
                                
                                	Local Protection In Use
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ip-rsvp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.Ipv4RroSubObject.Flags, self).__init__()

                                    self.yang_name = "flags"
                                    self.yang_parent_name = "ipv4rro-sub-object"

                                    self.is_bandwidth_protected = YLeaf(YType.boolean, "is-bandwidth-protected")

                                    self.is_node_id = YLeaf(YType.boolean, "is-node-id")

                                    self.is_node_protection_available = YLeaf(YType.boolean, "is-node-protection-available")

                                    self.is_protection_available = YLeaf(YType.boolean, "is-protection-available")

                                    self.is_protection_in_use = YLeaf(YType.boolean, "is-protection-in-use")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("is_bandwidth_protected",
                                                    "is_node_id",
                                                    "is_node_protection_available",
                                                    "is_protection_available",
                                                    "is_protection_in_use") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.Ipv4RroSubObject.Flags, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.Ipv4RroSubObject.Flags, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.is_bandwidth_protected.is_set or
                                        self.is_node_id.is_set or
                                        self.is_node_protection_available.is_set or
                                        self.is_protection_available.is_set or
                                        self.is_protection_in_use.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.is_bandwidth_protected.yfilter != YFilter.not_set or
                                        self.is_node_id.yfilter != YFilter.not_set or
                                        self.is_node_protection_available.yfilter != YFilter.not_set or
                                        self.is_protection_available.yfilter != YFilter.not_set or
                                        self.is_protection_in_use.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "flags" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/psb-rsb-info/rsb-info/rro/ipv4rro-sub-object/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.is_bandwidth_protected.is_set or self.is_bandwidth_protected.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_bandwidth_protected.get_name_leafdata())
                                    if (self.is_node_id.is_set or self.is_node_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_node_id.get_name_leafdata())
                                    if (self.is_node_protection_available.is_set or self.is_node_protection_available.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_node_protection_available.get_name_leafdata())
                                    if (self.is_protection_available.is_set or self.is_protection_available.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_protection_available.get_name_leafdata())
                                    if (self.is_protection_in_use.is_set or self.is_protection_in_use.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_protection_in_use.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "is-bandwidth-protected" or name == "is-node-id" or name == "is-node-protection-available" or name == "is-protection-available" or name == "is-protection-in-use"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "is-bandwidth-protected"):
                                        self.is_bandwidth_protected = value
                                        self.is_bandwidth_protected.value_namespace = name_space
                                        self.is_bandwidth_protected.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-node-id"):
                                        self.is_node_id = value
                                        self.is_node_id.value_namespace = name_space
                                        self.is_node_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-node-protection-available"):
                                        self.is_node_protection_available = value
                                        self.is_node_protection_available.value_namespace = name_space
                                        self.is_node_protection_available.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-protection-available"):
                                        self.is_protection_available = value
                                        self.is_protection_available.value_namespace = name_space
                                        self.is_protection_available.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-protection-in-use"):
                                        self.is_protection_in_use = value
                                        self.is_protection_in_use.value_namespace = name_space
                                        self.is_protection_in_use.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.rro_address.is_set or
                                    (self.flags is not None and self.flags.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.rro_address.yfilter != YFilter.not_set or
                                    (self.flags is not None and self.flags.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ipv4rro-sub-object" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/psb-rsb-info/rsb-info/rro/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.rro_address.is_set or self.rro_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rro_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "flags"):
                                    if (self.flags is None):
                                        self.flags = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.Ipv4RroSubObject.Flags()
                                        self.flags.parent = self
                                        self._children_name_map["flags"] = "flags"
                                    return self.flags

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "flags" or name == "rro-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "rro-address"):
                                    self.rro_address = value
                                    self.rro_address.value_namespace = name_space
                                    self.rro_address.value_namespace_prefix = name_space_prefix


                        class LabelRroSubObject(Entity):
                            """
                            Label RRO Sub Object
                            
                            .. attribute:: flags
                            
                            	The RRO Subobject Label Flags
                            	**type**\:   :py:class:`Flags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.LabelRroSubObject.Flags>`
                            
                            .. attribute:: is_label_variable_length
                            
                            	Is the RRO Subobject Label Variable Length
                            	**type**\:  bool
                            
                            .. attribute:: label
                            
                            	The RRO Subobject Label Value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: variable_length_label
                            
                            	The RRO Subobject Variable Length Label
                            	**type**\:  list of int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.LabelRroSubObject, self).__init__()

                                self.yang_name = "label-rro-sub-object"
                                self.yang_parent_name = "rro"

                                self.is_label_variable_length = YLeaf(YType.boolean, "is-label-variable-length")

                                self.label = YLeaf(YType.uint32, "label")

                                self.variable_length_label = YLeafList(YType.uint32, "variable-length-label")

                                self.flags = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.LabelRroSubObject.Flags()
                                self.flags.parent = self
                                self._children_name_map["flags"] = "flags"
                                self._children_yang_names.add("flags")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("is_label_variable_length",
                                                "label",
                                                "variable_length_label") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.LabelRroSubObject, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.LabelRroSubObject, self).__setattr__(name, value)


                            class Flags(Entity):
                                """
                                The RRO Subobject Label Flags
                                
                                .. attribute:: is_global_label
                                
                                	Label is Global across all interfaces
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ip-rsvp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.LabelRroSubObject.Flags, self).__init__()

                                    self.yang_name = "flags"
                                    self.yang_parent_name = "label-rro-sub-object"

                                    self.is_global_label = YLeaf(YType.boolean, "is-global-label")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("is_global_label") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.LabelRroSubObject.Flags, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.LabelRroSubObject.Flags, self).__setattr__(name, value)

                                def has_data(self):
                                    return self.is_global_label.is_set

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.is_global_label.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "flags" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/psb-rsb-info/rsb-info/rro/label-rro-sub-object/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.is_global_label.is_set or self.is_global_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_global_label.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "is-global-label"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "is-global-label"):
                                        self.is_global_label = value
                                        self.is_global_label.value_namespace = name_space
                                        self.is_global_label.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for leaf in self.variable_length_label.getYLeafs():
                                    if (leaf.yfilter != YFilter.not_set):
                                        return True
                                return (
                                    self.is_label_variable_length.is_set or
                                    self.label.is_set or
                                    (self.flags is not None and self.flags.has_data()))

                            def has_operation(self):
                                for leaf in self.variable_length_label.getYLeafs():
                                    if (leaf.is_set):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.is_label_variable_length.yfilter != YFilter.not_set or
                                    self.label.yfilter != YFilter.not_set or
                                    self.variable_length_label.yfilter != YFilter.not_set or
                                    (self.flags is not None and self.flags.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "label-rro-sub-object" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/psb-rsb-info/rsb-info/rro/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.is_label_variable_length.is_set or self.is_label_variable_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_label_variable_length.get_name_leafdata())
                                if (self.label.is_set or self.label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.label.get_name_leafdata())

                                leaf_name_data.extend(self.variable_length_label.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "flags"):
                                    if (self.flags is None):
                                        self.flags = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.LabelRroSubObject.Flags()
                                        self.flags.parent = self
                                        self._children_name_map["flags"] = "flags"
                                    return self.flags

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "flags" or name == "is-label-variable-length" or name == "label" or name == "variable-length-label"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "is-label-variable-length"):
                                    self.is_label_variable_length = value
                                    self.is_label_variable_length.value_namespace = name_space
                                    self.is_label_variable_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "label"):
                                    self.label = value
                                    self.label.value_namespace = name_space
                                    self.label.value_namespace_prefix = name_space_prefix
                                if(value_path == "variable-length-label"):
                                    self.variable_length_label.append(value)


                        class UnnumberedRroSubObject(Entity):
                            """
                            Unnumbered RRO Sub Object
                            
                            .. attribute:: flags
                            
                            	The RRO Subobject Unnumbered Flags
                            	**type**\:   :py:class:`Flags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.UnnumberedRroSubObject.Flags>`
                            
                            .. attribute:: interface_address
                            
                            	The RRO Interface Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: interface_id
                            
                            	The RRO Interface ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.UnnumberedRroSubObject, self).__init__()

                                self.yang_name = "unnumbered-rro-sub-object"
                                self.yang_parent_name = "rro"

                                self.interface_address = YLeaf(YType.str, "interface-address")

                                self.interface_id = YLeaf(YType.uint32, "interface-id")

                                self.flags = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.UnnumberedRroSubObject.Flags()
                                self.flags.parent = self
                                self._children_name_map["flags"] = "flags"
                                self._children_yang_names.add("flags")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("interface_address",
                                                "interface_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.UnnumberedRroSubObject, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.UnnumberedRroSubObject, self).__setattr__(name, value)


                            class Flags(Entity):
                                """
                                The RRO Subobject Unnumbered Flags
                                
                                .. attribute:: is_bandwidth_protected
                                
                                	Bandwidth Protection Available
                                	**type**\:  bool
                                
                                .. attribute:: is_node_id
                                
                                	Node ID In Use
                                	**type**\:  bool
                                
                                .. attribute:: is_node_protection_available
                                
                                	Node Protection Available
                                	**type**\:  bool
                                
                                .. attribute:: is_protection_available
                                
                                	Local Protection Available
                                	**type**\:  bool
                                
                                .. attribute:: is_protection_in_use
                                
                                	Local Protection In Use
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ip-rsvp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.UnnumberedRroSubObject.Flags, self).__init__()

                                    self.yang_name = "flags"
                                    self.yang_parent_name = "unnumbered-rro-sub-object"

                                    self.is_bandwidth_protected = YLeaf(YType.boolean, "is-bandwidth-protected")

                                    self.is_node_id = YLeaf(YType.boolean, "is-node-id")

                                    self.is_node_protection_available = YLeaf(YType.boolean, "is-node-protection-available")

                                    self.is_protection_available = YLeaf(YType.boolean, "is-protection-available")

                                    self.is_protection_in_use = YLeaf(YType.boolean, "is-protection-in-use")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("is_bandwidth_protected",
                                                    "is_node_id",
                                                    "is_node_protection_available",
                                                    "is_protection_available",
                                                    "is_protection_in_use") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.UnnumberedRroSubObject.Flags, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.UnnumberedRroSubObject.Flags, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.is_bandwidth_protected.is_set or
                                        self.is_node_id.is_set or
                                        self.is_node_protection_available.is_set or
                                        self.is_protection_available.is_set or
                                        self.is_protection_in_use.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.is_bandwidth_protected.yfilter != YFilter.not_set or
                                        self.is_node_id.yfilter != YFilter.not_set or
                                        self.is_node_protection_available.yfilter != YFilter.not_set or
                                        self.is_protection_available.yfilter != YFilter.not_set or
                                        self.is_protection_in_use.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "flags" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/psb-rsb-info/rsb-info/rro/unnumbered-rro-sub-object/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.is_bandwidth_protected.is_set or self.is_bandwidth_protected.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_bandwidth_protected.get_name_leafdata())
                                    if (self.is_node_id.is_set or self.is_node_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_node_id.get_name_leafdata())
                                    if (self.is_node_protection_available.is_set or self.is_node_protection_available.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_node_protection_available.get_name_leafdata())
                                    if (self.is_protection_available.is_set or self.is_protection_available.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_protection_available.get_name_leafdata())
                                    if (self.is_protection_in_use.is_set or self.is_protection_in_use.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_protection_in_use.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "is-bandwidth-protected" or name == "is-node-id" or name == "is-node-protection-available" or name == "is-protection-available" or name == "is-protection-in-use"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "is-bandwidth-protected"):
                                        self.is_bandwidth_protected = value
                                        self.is_bandwidth_protected.value_namespace = name_space
                                        self.is_bandwidth_protected.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-node-id"):
                                        self.is_node_id = value
                                        self.is_node_id.value_namespace = name_space
                                        self.is_node_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-node-protection-available"):
                                        self.is_node_protection_available = value
                                        self.is_node_protection_available.value_namespace = name_space
                                        self.is_node_protection_available.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-protection-available"):
                                        self.is_protection_available = value
                                        self.is_protection_available.value_namespace = name_space
                                        self.is_protection_available.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-protection-in-use"):
                                        self.is_protection_in_use = value
                                        self.is_protection_in_use.value_namespace = name_space
                                        self.is_protection_in_use.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.interface_address.is_set or
                                    self.interface_id.is_set or
                                    (self.flags is not None and self.flags.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.interface_address.yfilter != YFilter.not_set or
                                    self.interface_id.yfilter != YFilter.not_set or
                                    (self.flags is not None and self.flags.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "unnumbered-rro-sub-object" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/psb-rsb-info/rsb-info/rro/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.interface_address.is_set or self.interface_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_address.get_name_leafdata())
                                if (self.interface_id.is_set or self.interface_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "flags"):
                                    if (self.flags is None):
                                        self.flags = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.UnnumberedRroSubObject.Flags()
                                        self.flags.parent = self
                                        self._children_name_map["flags"] = "flags"
                                    return self.flags

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "flags" or name == "interface-address" or name == "interface-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "interface-address"):
                                    self.interface_address = value
                                    self.interface_address.value_namespace = name_space
                                    self.interface_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-id"):
                                    self.interface_id = value
                                    self.interface_id.value_namespace = name_space
                                    self.interface_id.value_namespace_prefix = name_space_prefix


                        class SrlgRroSubObject(Entity):
                            """
                            SRLG RRO Sub Object
                            
                            .. attribute:: srl_gs
                            
                            	The RRO Subobject SRLGs
                            	**type**\:  list of int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.SrlgRroSubObject, self).__init__()

                                self.yang_name = "srlg-rro-sub-object"
                                self.yang_parent_name = "rro"

                                self.srl_gs = YLeafList(YType.uint32, "srl-gs")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("srl_gs") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.SrlgRroSubObject, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.SrlgRroSubObject, self).__setattr__(name, value)

                            def has_data(self):
                                for leaf in self.srl_gs.getYLeafs():
                                    if (leaf.yfilter != YFilter.not_set):
                                        return True
                                return False

                            def has_operation(self):
                                for leaf in self.srl_gs.getYLeafs():
                                    if (leaf.is_set):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.srl_gs.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "srlg-rro-sub-object" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/psb-rsb-info/rsb-info/rro/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                leaf_name_data.extend(self.srl_gs.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "srl-gs"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "srl-gs"):
                                    self.srl_gs.append(value)

                        def has_data(self):
                            return (
                                self.rro_type.is_set or
                                (self.ipv4rro_sub_object is not None and self.ipv4rro_sub_object.has_data()) or
                                (self.label_rro_sub_object is not None and self.label_rro_sub_object.has_data()) or
                                (self.srlg_rro_sub_object is not None and self.srlg_rro_sub_object.has_data()) or
                                (self.unnumbered_rro_sub_object is not None and self.unnumbered_rro_sub_object.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.rro_type.yfilter != YFilter.not_set or
                                (self.ipv4rro_sub_object is not None and self.ipv4rro_sub_object.has_operation()) or
                                (self.label_rro_sub_object is not None and self.label_rro_sub_object.has_operation()) or
                                (self.srlg_rro_sub_object is not None and self.srlg_rro_sub_object.has_operation()) or
                                (self.unnumbered_rro_sub_object is not None and self.unnumbered_rro_sub_object.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rro" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/psb-rsb-info/rsb-info/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.rro_type.is_set or self.rro_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rro_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "ipv4rro-sub-object"):
                                if (self.ipv4rro_sub_object is None):
                                    self.ipv4rro_sub_object = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.Ipv4RroSubObject()
                                    self.ipv4rro_sub_object.parent = self
                                    self._children_name_map["ipv4rro_sub_object"] = "ipv4rro-sub-object"
                                return self.ipv4rro_sub_object

                            if (child_yang_name == "label-rro-sub-object"):
                                if (self.label_rro_sub_object is None):
                                    self.label_rro_sub_object = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.LabelRroSubObject()
                                    self.label_rro_sub_object.parent = self
                                    self._children_name_map["label_rro_sub_object"] = "label-rro-sub-object"
                                return self.label_rro_sub_object

                            if (child_yang_name == "srlg-rro-sub-object"):
                                if (self.srlg_rro_sub_object is None):
                                    self.srlg_rro_sub_object = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.SrlgRroSubObject()
                                    self.srlg_rro_sub_object.parent = self
                                    self._children_name_map["srlg_rro_sub_object"] = "srlg-rro-sub-object"
                                return self.srlg_rro_sub_object

                            if (child_yang_name == "unnumbered-rro-sub-object"):
                                if (self.unnumbered_rro_sub_object is None):
                                    self.unnumbered_rro_sub_object = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.UnnumberedRroSubObject()
                                    self.unnumbered_rro_sub_object.parent = self
                                    self._children_name_map["unnumbered_rro_sub_object"] = "unnumbered-rro-sub-object"
                                return self.unnumbered_rro_sub_object

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ipv4rro-sub-object" or name == "label-rro-sub-object" or name == "srlg-rro-sub-object" or name == "unnumbered-rro-sub-object" or name == "rro-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "rro-type"):
                                self.rro_type = value
                                self.rro_type.value_namespace = name_space
                                self.rro_type.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.rro:
                            if (c.has_data()):
                                return True
                        return (
                            self.backup_interface.is_set or
                            self.backup_label.is_set or
                            self.destination_address.is_set or
                            self.is_flow_spec_valid.is_set or
                            self.is_rro_valid.is_set or
                            self.is_valid.is_set or
                            self.out_interface.is_set or
                            self.out_label.is_set or
                            (self.flow_spec is not None and self.flow_spec.has_data()) or
                            (self.generic_flow_spec is not None and self.generic_flow_spec.has_data()) or
                            (self.generic_out_label is not None and self.generic_out_label.has_data()))

                    def has_operation(self):
                        for c in self.rro:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.backup_interface.yfilter != YFilter.not_set or
                            self.backup_label.yfilter != YFilter.not_set or
                            self.destination_address.yfilter != YFilter.not_set or
                            self.is_flow_spec_valid.yfilter != YFilter.not_set or
                            self.is_rro_valid.yfilter != YFilter.not_set or
                            self.is_valid.yfilter != YFilter.not_set or
                            self.out_interface.yfilter != YFilter.not_set or
                            self.out_label.yfilter != YFilter.not_set or
                            (self.flow_spec is not None and self.flow_spec.has_operation()) or
                            (self.generic_flow_spec is not None and self.generic_flow_spec.has_operation()) or
                            (self.generic_out_label is not None and self.generic_out_label.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rsb-info" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/psb-rsb-info/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.backup_interface.is_set or self.backup_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.backup_interface.get_name_leafdata())
                        if (self.backup_label.is_set or self.backup_label.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.backup_label.get_name_leafdata())
                        if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.destination_address.get_name_leafdata())
                        if (self.is_flow_spec_valid.is_set or self.is_flow_spec_valid.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_flow_spec_valid.get_name_leafdata())
                        if (self.is_rro_valid.is_set or self.is_rro_valid.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_rro_valid.get_name_leafdata())
                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_valid.get_name_leafdata())
                        if (self.out_interface.is_set or self.out_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.out_interface.get_name_leafdata())
                        if (self.out_label.is_set or self.out_label.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.out_label.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "flow-spec"):
                            if (self.flow_spec is None):
                                self.flow_spec = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.FlowSpec()
                                self.flow_spec.parent = self
                                self._children_name_map["flow_spec"] = "flow-spec"
                            return self.flow_spec

                        if (child_yang_name == "generic-flow-spec"):
                            if (self.generic_flow_spec is None):
                                self.generic_flow_spec = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.GenericFlowSpec()
                                self.generic_flow_spec.parent = self
                                self._children_name_map["generic_flow_spec"] = "generic-flow-spec"
                            return self.generic_flow_spec

                        if (child_yang_name == "generic-out-label"):
                            if (self.generic_out_label is None):
                                self.generic_out_label = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.GenericOutLabel()
                                self.generic_out_label.parent = self
                                self._children_name_map["generic_out_label"] = "generic-out-label"
                            return self.generic_out_label

                        if (child_yang_name == "rro"):
                            for c in self.rro:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.rro.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "flow-spec" or name == "generic-flow-spec" or name == "generic-out-label" or name == "rro" or name == "backup-interface" or name == "backup-label" or name == "destination-address" or name == "is-flow-spec-valid" or name == "is-rro-valid" or name == "is-valid" or name == "out-interface" or name == "out-label"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "backup-interface"):
                            self.backup_interface = value
                            self.backup_interface.value_namespace = name_space
                            self.backup_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "backup-label"):
                            self.backup_label = value
                            self.backup_label.value_namespace = name_space
                            self.backup_label.value_namespace_prefix = name_space_prefix
                        if(value_path == "destination-address"):
                            self.destination_address = value
                            self.destination_address.value_namespace = name_space
                            self.destination_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-flow-spec-valid"):
                            self.is_flow_spec_valid = value
                            self.is_flow_spec_valid.value_namespace = name_space
                            self.is_flow_spec_valid.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-rro-valid"):
                            self.is_rro_valid = value
                            self.is_rro_valid.value_namespace = name_space
                            self.is_rro_valid.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-valid"):
                            self.is_valid = value
                            self.is_valid.value_namespace = name_space
                            self.is_valid.value_namespace_prefix = name_space_prefix
                        if(value_path == "out-interface"):
                            self.out_interface = value
                            self.out_interface.value_namespace = name_space
                            self.out_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "out-label"):
                            self.out_label = value
                            self.out_label.value_namespace = name_space
                            self.out_label.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.psb_info:
                        if (c.has_data()):
                            return True
                    for c in self.rsb_info:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.psb_info:
                        if (c.has_operation()):
                            return True
                    for c in self.rsb_info:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "psb-rsb-info" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/session-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "psb-info"):
                        for c in self.psb_info:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.psb_info.append(c)
                        return c

                    if (child_yang_name == "rsb-info"):
                        for c in self.rsb_info:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.rsb_info.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "psb-info" or name == "rsb-info"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                for c in self.psb_rsb_info:
                    if (c.has_data()):
                        return True
                return (
                    self.destination_address.is_set or
                    self.destination_port.is_set or
                    self.extended_tunnel_id.is_set or
                    self.p2mp_id.is_set or
                    self.protocol.is_set or
                    self.session_type.is_set or
                    self.vrf_name.is_set or
                    (self.compact is not None and self.compact.has_data()) or
                    (self.s2l_sub_lsp is not None and self.s2l_sub_lsp.has_data()))

            def has_operation(self):
                for c in self.psb_rsb_info:
                    if (c.has_operation()):
                        return True
                return (
                    self.yfilter != YFilter.not_set or
                    self.destination_address.yfilter != YFilter.not_set or
                    self.destination_port.yfilter != YFilter.not_set or
                    self.extended_tunnel_id.yfilter != YFilter.not_set or
                    self.p2mp_id.yfilter != YFilter.not_set or
                    self.protocol.yfilter != YFilter.not_set or
                    self.session_type.yfilter != YFilter.not_set or
                    self.vrf_name.yfilter != YFilter.not_set or
                    (self.compact is not None and self.compact.has_operation()) or
                    (self.s2l_sub_lsp is not None and self.s2l_sub_lsp.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "session-detailed" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/session-detaileds/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_address.get_name_leafdata())
                if (self.destination_port.is_set or self.destination_port.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_port.get_name_leafdata())
                if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                if (self.p2mp_id.is_set or self.p2mp_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.p2mp_id.get_name_leafdata())
                if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.protocol.get_name_leafdata())
                if (self.session_type.is_set or self.session_type.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.session_type.get_name_leafdata())
                if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.vrf_name.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "compact"):
                    if (self.compact is None):
                        self.compact = RsvpStandby.SessionDetaileds.SessionDetailed.Compact()
                        self.compact.parent = self
                        self._children_name_map["compact"] = "compact"
                    return self.compact

                if (child_yang_name == "psb-rsb-info"):
                    for c in self.psb_rsb_info:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = RsvpStandby.SessionDetaileds.SessionDetailed.PsbRsbInfo()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.psb_rsb_info.append(c)
                    return c

                if (child_yang_name == "s2l-sub-lsp"):
                    if (self.s2l_sub_lsp is None):
                        self.s2l_sub_lsp = RsvpStandby.SessionDetaileds.SessionDetailed.S2LSubLsp()
                        self.s2l_sub_lsp.parent = self
                        self._children_name_map["s2l_sub_lsp"] = "s2l-sub-lsp"
                    return self.s2l_sub_lsp

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "compact" or name == "psb-rsb-info" or name == "s2l-sub-lsp" or name == "destination-address" or name == "destination-port" or name == "extended-tunnel-id" or name == "p2mp-id" or name == "protocol" or name == "session-type" or name == "vrf-name"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "destination-address"):
                    self.destination_address = value
                    self.destination_address.value_namespace = name_space
                    self.destination_address.value_namespace_prefix = name_space_prefix
                if(value_path == "destination-port"):
                    self.destination_port = value
                    self.destination_port.value_namespace = name_space
                    self.destination_port.value_namespace_prefix = name_space_prefix
                if(value_path == "extended-tunnel-id"):
                    self.extended_tunnel_id = value
                    self.extended_tunnel_id.value_namespace = name_space
                    self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                if(value_path == "p2mp-id"):
                    self.p2mp_id = value
                    self.p2mp_id.value_namespace = name_space
                    self.p2mp_id.value_namespace_prefix = name_space_prefix
                if(value_path == "protocol"):
                    self.protocol = value
                    self.protocol.value_namespace = name_space
                    self.protocol.value_namespace_prefix = name_space_prefix
                if(value_path == "session-type"):
                    self.session_type = value
                    self.session_type.value_namespace = name_space
                    self.session_type.value_namespace_prefix = name_space_prefix
                if(value_path == "vrf-name"):
                    self.vrf_name = value
                    self.vrf_name.value_namespace = name_space
                    self.vrf_name.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.session_detailed:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.session_detailed:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "session-detaileds" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "session-detailed"):
                for c in self.session_detailed:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = RsvpStandby.SessionDetaileds.SessionDetailed()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.session_detailed.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "session-detailed"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class HelloInstanceDetails(Entity):
        """
        Table of detailed info about hello instances
        
        .. attribute:: hello_instance_detail
        
        	Detailed info for a single hello instance
        	**type**\: list of    :py:class:`HelloInstanceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.HelloInstanceDetails.HelloInstanceDetail>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(RsvpStandby.HelloInstanceDetails, self).__init__()

            self.yang_name = "hello-instance-details"
            self.yang_parent_name = "rsvp-standby"

            self.hello_instance_detail = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(RsvpStandby.HelloInstanceDetails, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(RsvpStandby.HelloInstanceDetails, self).__setattr__(name, value)


        class HelloInstanceDetail(Entity):
            """
            Detailed info for a single hello instance
            
            .. attribute:: source_address  <key>
            
            	Source Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: destination_address  <key>
            
            	Destination Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: communication_lost_hello_missed
            
            	Lost Comm. Hello missed count
            	**type**\:  int
            
            	**range:** 0..65535
            
            .. attribute:: communication_lost_interface_down
            
            	Count of lost comm. due to interface down
            	**type**\:  int
            
            	**range:** 0..65535
            
            .. attribute:: communication_lost_neighbor_disabled_hello
            
            	Count of lost comm. due to nbor disabling Hellos
            	**type**\:  int
            
            	**range:** 0..65535
            
            .. attribute:: communication_lost_reason
            
            	Reason why communication was lost
            	**type**\:   :py:class:`RsvpMgmtHelloDownReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtHelloDownReason>`
            
            .. attribute:: communication_lost_time
            
            	Time when communication was lost
            	**type**\:   :py:class:`CommunicationLostTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.HelloInstanceDetails.HelloInstanceDetail.CommunicationLostTime>`
            
            .. attribute:: communication_lost_wrong_destination_inst
            
            	Count of lost comm. due to wrong Destination Inst
            	**type**\:  int
            
            	**range:** 0..65535
            
            .. attribute:: communication_lost_wrong_source_inst
            
            	Count of lost comm. due to wrong Source Inst
            	**type**\:  int
            
            	**range:** 0..65535
            
            .. attribute:: destination_address_xr
            
            	Destination address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: destination_instance
            
            	Destination Instance
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: hello_instance_owner
            
            	Hello instance owner
            	**type**\:   :py:class:`RsvpMgmtHelloInstanceOwner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtHelloInstanceOwner>`
            
            .. attribute:: hello_interface
            
            	Interface to use
            	**type**\:  str
            
            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
            
            .. attribute:: hello_interval
            
            	Hello Interval
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: hello_messages_received
            
            	Number of hello messages received
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: hello_messages_sent
            
            	Number of hello messages sent
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: hello_request_suppressed
            
            	Count of Hello Requests suppessed
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: instance_type
            
            	Hello instance type
            	**type**\:   :py:class:`RsvpMgmtHelloInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtHelloInstance>`
            
            .. attribute:: missed_acks_allowed
            
            	Number of missed Hello allowed
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: neighbor_hello_state
            
            	Neighbor Hello state
            	**type**\:   :py:class:`RsvpMgmtHelloState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtHelloState>`
            
            .. attribute:: source_address_xr
            
            	Source address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: source_instance
            
            	Source Instance
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: total_communication_lost
            
            	Total number of times communication got lost
            	**type**\:  int
            
            	**range:** 0..65535
            
            .. attribute:: up_time
            
            	Hello up time
            	**type**\:   :py:class:`UpTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.HelloInstanceDetails.HelloInstanceDetail.UpTime>`
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(RsvpStandby.HelloInstanceDetails.HelloInstanceDetail, self).__init__()

                self.yang_name = "hello-instance-detail"
                self.yang_parent_name = "hello-instance-details"

                self.source_address = YLeaf(YType.str, "source-address")

                self.destination_address = YLeaf(YType.str, "destination-address")

                self.communication_lost_hello_missed = YLeaf(YType.uint16, "communication-lost-hello-missed")

                self.communication_lost_interface_down = YLeaf(YType.uint16, "communication-lost-interface-down")

                self.communication_lost_neighbor_disabled_hello = YLeaf(YType.uint16, "communication-lost-neighbor-disabled-hello")

                self.communication_lost_reason = YLeaf(YType.enumeration, "communication-lost-reason")

                self.communication_lost_wrong_destination_inst = YLeaf(YType.uint16, "communication-lost-wrong-destination-inst")

                self.communication_lost_wrong_source_inst = YLeaf(YType.uint16, "communication-lost-wrong-source-inst")

                self.destination_address_xr = YLeaf(YType.str, "destination-address-xr")

                self.destination_instance = YLeaf(YType.uint32, "destination-instance")

                self.hello_instance_owner = YLeaf(YType.enumeration, "hello-instance-owner")

                self.hello_interface = YLeaf(YType.str, "hello-interface")

                self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                self.hello_messages_received = YLeaf(YType.uint64, "hello-messages-received")

                self.hello_messages_sent = YLeaf(YType.uint64, "hello-messages-sent")

                self.hello_request_suppressed = YLeaf(YType.uint64, "hello-request-suppressed")

                self.instance_type = YLeaf(YType.enumeration, "instance-type")

                self.missed_acks_allowed = YLeaf(YType.uint32, "missed-acks-allowed")

                self.neighbor_hello_state = YLeaf(YType.enumeration, "neighbor-hello-state")

                self.source_address_xr = YLeaf(YType.str, "source-address-xr")

                self.source_instance = YLeaf(YType.uint32, "source-instance")

                self.total_communication_lost = YLeaf(YType.uint16, "total-communication-lost")

                self.communication_lost_time = RsvpStandby.HelloInstanceDetails.HelloInstanceDetail.CommunicationLostTime()
                self.communication_lost_time.parent = self
                self._children_name_map["communication_lost_time"] = "communication-lost-time"
                self._children_yang_names.add("communication-lost-time")

                self.up_time = RsvpStandby.HelloInstanceDetails.HelloInstanceDetail.UpTime()
                self.up_time.parent = self
                self._children_name_map["up_time"] = "up-time"
                self._children_yang_names.add("up-time")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("source_address",
                                "destination_address",
                                "communication_lost_hello_missed",
                                "communication_lost_interface_down",
                                "communication_lost_neighbor_disabled_hello",
                                "communication_lost_reason",
                                "communication_lost_wrong_destination_inst",
                                "communication_lost_wrong_source_inst",
                                "destination_address_xr",
                                "destination_instance",
                                "hello_instance_owner",
                                "hello_interface",
                                "hello_interval",
                                "hello_messages_received",
                                "hello_messages_sent",
                                "hello_request_suppressed",
                                "instance_type",
                                "missed_acks_allowed",
                                "neighbor_hello_state",
                                "source_address_xr",
                                "source_instance",
                                "total_communication_lost") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(RsvpStandby.HelloInstanceDetails.HelloInstanceDetail, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(RsvpStandby.HelloInstanceDetails.HelloInstanceDetail, self).__setattr__(name, value)


            class UpTime(Entity):
                """
                Hello up time
                
                .. attribute:: nanoseconds
                
                	Time Value in Nano\-seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: nanosecond
                
                .. attribute:: seconds
                
                	Time Value in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.HelloInstanceDetails.HelloInstanceDetail.UpTime, self).__init__()

                    self.yang_name = "up-time"
                    self.yang_parent_name = "hello-instance-detail"

                    self.nanoseconds = YLeaf(YType.int32, "nanoseconds")

                    self.seconds = YLeaf(YType.int32, "seconds")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("nanoseconds",
                                    "seconds") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.HelloInstanceDetails.HelloInstanceDetail.UpTime, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.HelloInstanceDetails.HelloInstanceDetail.UpTime, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.nanoseconds.is_set or
                        self.seconds.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.nanoseconds.yfilter != YFilter.not_set or
                        self.seconds.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "up-time" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.nanoseconds.is_set or self.nanoseconds.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.nanoseconds.get_name_leafdata())
                    if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.seconds.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "nanoseconds" or name == "seconds"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "nanoseconds"):
                        self.nanoseconds = value
                        self.nanoseconds.value_namespace = name_space
                        self.nanoseconds.value_namespace_prefix = name_space_prefix
                    if(value_path == "seconds"):
                        self.seconds = value
                        self.seconds.value_namespace = name_space
                        self.seconds.value_namespace_prefix = name_space_prefix


            class CommunicationLostTime(Entity):
                """
                Time when communication was lost
                
                .. attribute:: nanoseconds
                
                	Time Value in Nano\-seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: nanosecond
                
                .. attribute:: seconds
                
                	Time Value in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.HelloInstanceDetails.HelloInstanceDetail.CommunicationLostTime, self).__init__()

                    self.yang_name = "communication-lost-time"
                    self.yang_parent_name = "hello-instance-detail"

                    self.nanoseconds = YLeaf(YType.int32, "nanoseconds")

                    self.seconds = YLeaf(YType.int32, "seconds")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("nanoseconds",
                                    "seconds") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.HelloInstanceDetails.HelloInstanceDetail.CommunicationLostTime, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.HelloInstanceDetails.HelloInstanceDetail.CommunicationLostTime, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.nanoseconds.is_set or
                        self.seconds.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.nanoseconds.yfilter != YFilter.not_set or
                        self.seconds.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "communication-lost-time" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.nanoseconds.is_set or self.nanoseconds.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.nanoseconds.get_name_leafdata())
                    if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.seconds.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "nanoseconds" or name == "seconds"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "nanoseconds"):
                        self.nanoseconds = value
                        self.nanoseconds.value_namespace = name_space
                        self.nanoseconds.value_namespace_prefix = name_space_prefix
                    if(value_path == "seconds"):
                        self.seconds = value
                        self.seconds.value_namespace = name_space
                        self.seconds.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.source_address.is_set or
                    self.destination_address.is_set or
                    self.communication_lost_hello_missed.is_set or
                    self.communication_lost_interface_down.is_set or
                    self.communication_lost_neighbor_disabled_hello.is_set or
                    self.communication_lost_reason.is_set or
                    self.communication_lost_wrong_destination_inst.is_set or
                    self.communication_lost_wrong_source_inst.is_set or
                    self.destination_address_xr.is_set or
                    self.destination_instance.is_set or
                    self.hello_instance_owner.is_set or
                    self.hello_interface.is_set or
                    self.hello_interval.is_set or
                    self.hello_messages_received.is_set or
                    self.hello_messages_sent.is_set or
                    self.hello_request_suppressed.is_set or
                    self.instance_type.is_set or
                    self.missed_acks_allowed.is_set or
                    self.neighbor_hello_state.is_set or
                    self.source_address_xr.is_set or
                    self.source_instance.is_set or
                    self.total_communication_lost.is_set or
                    (self.communication_lost_time is not None and self.communication_lost_time.has_data()) or
                    (self.up_time is not None and self.up_time.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.source_address.yfilter != YFilter.not_set or
                    self.destination_address.yfilter != YFilter.not_set or
                    self.communication_lost_hello_missed.yfilter != YFilter.not_set or
                    self.communication_lost_interface_down.yfilter != YFilter.not_set or
                    self.communication_lost_neighbor_disabled_hello.yfilter != YFilter.not_set or
                    self.communication_lost_reason.yfilter != YFilter.not_set or
                    self.communication_lost_wrong_destination_inst.yfilter != YFilter.not_set or
                    self.communication_lost_wrong_source_inst.yfilter != YFilter.not_set or
                    self.destination_address_xr.yfilter != YFilter.not_set or
                    self.destination_instance.yfilter != YFilter.not_set or
                    self.hello_instance_owner.yfilter != YFilter.not_set or
                    self.hello_interface.yfilter != YFilter.not_set or
                    self.hello_interval.yfilter != YFilter.not_set or
                    self.hello_messages_received.yfilter != YFilter.not_set or
                    self.hello_messages_sent.yfilter != YFilter.not_set or
                    self.hello_request_suppressed.yfilter != YFilter.not_set or
                    self.instance_type.yfilter != YFilter.not_set or
                    self.missed_acks_allowed.yfilter != YFilter.not_set or
                    self.neighbor_hello_state.yfilter != YFilter.not_set or
                    self.source_address_xr.yfilter != YFilter.not_set or
                    self.source_instance.yfilter != YFilter.not_set or
                    self.total_communication_lost.yfilter != YFilter.not_set or
                    (self.communication_lost_time is not None and self.communication_lost_time.has_operation()) or
                    (self.up_time is not None and self.up_time.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "hello-instance-detail" + "[source-address='" + self.source_address.get() + "']" + "[destination-address='" + self.destination_address.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/hello-instance-details/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_address.get_name_leafdata())
                if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_address.get_name_leafdata())
                if (self.communication_lost_hello_missed.is_set or self.communication_lost_hello_missed.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.communication_lost_hello_missed.get_name_leafdata())
                if (self.communication_lost_interface_down.is_set or self.communication_lost_interface_down.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.communication_lost_interface_down.get_name_leafdata())
                if (self.communication_lost_neighbor_disabled_hello.is_set or self.communication_lost_neighbor_disabled_hello.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.communication_lost_neighbor_disabled_hello.get_name_leafdata())
                if (self.communication_lost_reason.is_set or self.communication_lost_reason.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.communication_lost_reason.get_name_leafdata())
                if (self.communication_lost_wrong_destination_inst.is_set or self.communication_lost_wrong_destination_inst.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.communication_lost_wrong_destination_inst.get_name_leafdata())
                if (self.communication_lost_wrong_source_inst.is_set or self.communication_lost_wrong_source_inst.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.communication_lost_wrong_source_inst.get_name_leafdata())
                if (self.destination_address_xr.is_set or self.destination_address_xr.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_address_xr.get_name_leafdata())
                if (self.destination_instance.is_set or self.destination_instance.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_instance.get_name_leafdata())
                if (self.hello_instance_owner.is_set or self.hello_instance_owner.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.hello_instance_owner.get_name_leafdata())
                if (self.hello_interface.is_set or self.hello_interface.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.hello_interface.get_name_leafdata())
                if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.hello_interval.get_name_leafdata())
                if (self.hello_messages_received.is_set or self.hello_messages_received.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.hello_messages_received.get_name_leafdata())
                if (self.hello_messages_sent.is_set or self.hello_messages_sent.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.hello_messages_sent.get_name_leafdata())
                if (self.hello_request_suppressed.is_set or self.hello_request_suppressed.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.hello_request_suppressed.get_name_leafdata())
                if (self.instance_type.is_set or self.instance_type.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.instance_type.get_name_leafdata())
                if (self.missed_acks_allowed.is_set or self.missed_acks_allowed.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.missed_acks_allowed.get_name_leafdata())
                if (self.neighbor_hello_state.is_set or self.neighbor_hello_state.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.neighbor_hello_state.get_name_leafdata())
                if (self.source_address_xr.is_set or self.source_address_xr.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_address_xr.get_name_leafdata())
                if (self.source_instance.is_set or self.source_instance.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_instance.get_name_leafdata())
                if (self.total_communication_lost.is_set or self.total_communication_lost.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.total_communication_lost.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "communication-lost-time"):
                    if (self.communication_lost_time is None):
                        self.communication_lost_time = RsvpStandby.HelloInstanceDetails.HelloInstanceDetail.CommunicationLostTime()
                        self.communication_lost_time.parent = self
                        self._children_name_map["communication_lost_time"] = "communication-lost-time"
                    return self.communication_lost_time

                if (child_yang_name == "up-time"):
                    if (self.up_time is None):
                        self.up_time = RsvpStandby.HelloInstanceDetails.HelloInstanceDetail.UpTime()
                        self.up_time.parent = self
                        self._children_name_map["up_time"] = "up-time"
                    return self.up_time

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "communication-lost-time" or name == "up-time" or name == "source-address" or name == "destination-address" or name == "communication-lost-hello-missed" or name == "communication-lost-interface-down" or name == "communication-lost-neighbor-disabled-hello" or name == "communication-lost-reason" or name == "communication-lost-wrong-destination-inst" or name == "communication-lost-wrong-source-inst" or name == "destination-address-xr" or name == "destination-instance" or name == "hello-instance-owner" or name == "hello-interface" or name == "hello-interval" or name == "hello-messages-received" or name == "hello-messages-sent" or name == "hello-request-suppressed" or name == "instance-type" or name == "missed-acks-allowed" or name == "neighbor-hello-state" or name == "source-address-xr" or name == "source-instance" or name == "total-communication-lost"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "source-address"):
                    self.source_address = value
                    self.source_address.value_namespace = name_space
                    self.source_address.value_namespace_prefix = name_space_prefix
                if(value_path == "destination-address"):
                    self.destination_address = value
                    self.destination_address.value_namespace = name_space
                    self.destination_address.value_namespace_prefix = name_space_prefix
                if(value_path == "communication-lost-hello-missed"):
                    self.communication_lost_hello_missed = value
                    self.communication_lost_hello_missed.value_namespace = name_space
                    self.communication_lost_hello_missed.value_namespace_prefix = name_space_prefix
                if(value_path == "communication-lost-interface-down"):
                    self.communication_lost_interface_down = value
                    self.communication_lost_interface_down.value_namespace = name_space
                    self.communication_lost_interface_down.value_namespace_prefix = name_space_prefix
                if(value_path == "communication-lost-neighbor-disabled-hello"):
                    self.communication_lost_neighbor_disabled_hello = value
                    self.communication_lost_neighbor_disabled_hello.value_namespace = name_space
                    self.communication_lost_neighbor_disabled_hello.value_namespace_prefix = name_space_prefix
                if(value_path == "communication-lost-reason"):
                    self.communication_lost_reason = value
                    self.communication_lost_reason.value_namespace = name_space
                    self.communication_lost_reason.value_namespace_prefix = name_space_prefix
                if(value_path == "communication-lost-wrong-destination-inst"):
                    self.communication_lost_wrong_destination_inst = value
                    self.communication_lost_wrong_destination_inst.value_namespace = name_space
                    self.communication_lost_wrong_destination_inst.value_namespace_prefix = name_space_prefix
                if(value_path == "communication-lost-wrong-source-inst"):
                    self.communication_lost_wrong_source_inst = value
                    self.communication_lost_wrong_source_inst.value_namespace = name_space
                    self.communication_lost_wrong_source_inst.value_namespace_prefix = name_space_prefix
                if(value_path == "destination-address-xr"):
                    self.destination_address_xr = value
                    self.destination_address_xr.value_namespace = name_space
                    self.destination_address_xr.value_namespace_prefix = name_space_prefix
                if(value_path == "destination-instance"):
                    self.destination_instance = value
                    self.destination_instance.value_namespace = name_space
                    self.destination_instance.value_namespace_prefix = name_space_prefix
                if(value_path == "hello-instance-owner"):
                    self.hello_instance_owner = value
                    self.hello_instance_owner.value_namespace = name_space
                    self.hello_instance_owner.value_namespace_prefix = name_space_prefix
                if(value_path == "hello-interface"):
                    self.hello_interface = value
                    self.hello_interface.value_namespace = name_space
                    self.hello_interface.value_namespace_prefix = name_space_prefix
                if(value_path == "hello-interval"):
                    self.hello_interval = value
                    self.hello_interval.value_namespace = name_space
                    self.hello_interval.value_namespace_prefix = name_space_prefix
                if(value_path == "hello-messages-received"):
                    self.hello_messages_received = value
                    self.hello_messages_received.value_namespace = name_space
                    self.hello_messages_received.value_namespace_prefix = name_space_prefix
                if(value_path == "hello-messages-sent"):
                    self.hello_messages_sent = value
                    self.hello_messages_sent.value_namespace = name_space
                    self.hello_messages_sent.value_namespace_prefix = name_space_prefix
                if(value_path == "hello-request-suppressed"):
                    self.hello_request_suppressed = value
                    self.hello_request_suppressed.value_namespace = name_space
                    self.hello_request_suppressed.value_namespace_prefix = name_space_prefix
                if(value_path == "instance-type"):
                    self.instance_type = value
                    self.instance_type.value_namespace = name_space
                    self.instance_type.value_namespace_prefix = name_space_prefix
                if(value_path == "missed-acks-allowed"):
                    self.missed_acks_allowed = value
                    self.missed_acks_allowed.value_namespace = name_space
                    self.missed_acks_allowed.value_namespace_prefix = name_space_prefix
                if(value_path == "neighbor-hello-state"):
                    self.neighbor_hello_state = value
                    self.neighbor_hello_state.value_namespace = name_space
                    self.neighbor_hello_state.value_namespace_prefix = name_space_prefix
                if(value_path == "source-address-xr"):
                    self.source_address_xr = value
                    self.source_address_xr.value_namespace = name_space
                    self.source_address_xr.value_namespace_prefix = name_space_prefix
                if(value_path == "source-instance"):
                    self.source_instance = value
                    self.source_instance.value_namespace = name_space
                    self.source_instance.value_namespace_prefix = name_space_prefix
                if(value_path == "total-communication-lost"):
                    self.total_communication_lost = value
                    self.total_communication_lost.value_namespace = name_space
                    self.total_communication_lost.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.hello_instance_detail:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.hello_instance_detail:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "hello-instance-details" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "hello-instance-detail"):
                for c in self.hello_instance_detail:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = RsvpStandby.HelloInstanceDetails.HelloInstanceDetail()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.hello_instance_detail.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "hello-instance-detail"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class GlobalNeighborDetails(Entity):
        """
        Table of detailed info about global neighbors
        
        .. attribute:: global_neighbor_detail
        
        	Detail info for a single global neighbor
        	**type**\: list of    :py:class:`GlobalNeighborDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.GlobalNeighborDetails.GlobalNeighborDetail>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(RsvpStandby.GlobalNeighborDetails, self).__init__()

            self.yang_name = "global-neighbor-details"
            self.yang_parent_name = "rsvp-standby"

            self.global_neighbor_detail = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(RsvpStandby.GlobalNeighborDetails, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(RsvpStandby.GlobalNeighborDetails, self).__setattr__(name, value)


        class GlobalNeighborDetail(Entity):
            """
            Detail info for a single global neighbor
            
            .. attribute:: neighbor_address  <key>
            
            	Address of global neighbor
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: global_neighbor_flags
            
            	Global Neighbor Flags
            	**type**\:   :py:class:`GlobalNeighborFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.GlobalNeighborDetails.GlobalNeighborDetail.GlobalNeighborFlags>`
            
            .. attribute:: hello_interval
            
            	Hello Interval (milliseconds)
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            	**units**\: millisecond
            
            .. attribute:: interface_neighbor
            
            	Interface Neighbor List
            	**type**\:  list of str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: is_gr_enabled
            
            	Is GR enabled
            	**type**\:  bool
            
            .. attribute:: is_recovery_timer_running
            
            	Is RSVP recovery timer running
            	**type**\:  bool
            
            .. attribute:: is_restart_timer_running
            
            	Is GR restart timer running
            	**type**\:  bool
            
            .. attribute:: local_node_address
            
            	Local node address
            	**type**\:  list of str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: lost_communication_reason
            
            	Reason why communication was lost
            	**type**\:  list of   :py:class:`RsvpMgmtHelloDownReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtHelloDownReason>`
            
            .. attribute:: lost_communication_time
            
            	Time when communication was lost
            	**type**\: list of    :py:class:`LostCommunicationTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.GlobalNeighborDetails.GlobalNeighborDetail.LostCommunicationTime>`
            
            .. attribute:: lost_communication_total
            
            	Total number of times communication got lost
            	**type**\:  list of int
            
            	**range:** 0..65535
            
            .. attribute:: missed_hellos
            
            	Hello missed count
            	**type**\:  int
            
            	**range:** 0..255
            
            .. attribute:: neighbor_hello_state
            
            	Neighbor's hello state
            	**type**\:  list of   :py:class:`RsvpMgmtHelloState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtHelloState>`
            
            .. attribute:: node_address
            
            	Neighbor node address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: pending_states
            
            	Number of pending states for this neighbor
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: recovery_time
            
            	GR Recovery Time (milliseconds)
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            	**units**\: millisecond
            
            .. attribute:: recovery_time_left
            
            	How much recovery timer remains
            	**type**\:   :py:class:`RecoveryTimeLeft <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.GlobalNeighborDetails.GlobalNeighborDetail.RecoveryTimeLeft>`
            
            .. attribute:: recovery_timer_exp_time
            
            	Time at which recovery timer will expire
            	**type**\:   :py:class:`RecoveryTimerExpTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.GlobalNeighborDetails.GlobalNeighborDetail.RecoveryTimerExpTime>`
            
            .. attribute:: restart_state
            
            	Current restart state
            	**type**\:   :py:class:`RsvpMgmtRestartState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtRestartState>`
            
            .. attribute:: restart_time
            
            	GR Restart Time (milliseconds)
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            	**units**\: millisecond
            
            .. attribute:: restart_time_left
            
            	How much restart time remains
            	**type**\:   :py:class:`RestartTimeLeft <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.GlobalNeighborDetails.GlobalNeighborDetail.RestartTimeLeft>`
            
            .. attribute:: restart_timer_expiry_time
            
            	When will restart timer expire
            	**type**\:   :py:class:`RestartTimerExpiryTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.GlobalNeighborDetails.GlobalNeighborDetail.RestartTimerExpiryTime>`
            
            .. attribute:: up_time
            
            	Hello up time
            	**type**\: list of    :py:class:`UpTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.GlobalNeighborDetails.GlobalNeighborDetail.UpTime>`
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(RsvpStandby.GlobalNeighborDetails.GlobalNeighborDetail, self).__init__()

                self.yang_name = "global-neighbor-detail"
                self.yang_parent_name = "global-neighbor-details"

                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                self.interface_neighbor = YLeafList(YType.str, "interface-neighbor")

                self.is_gr_enabled = YLeaf(YType.boolean, "is-gr-enabled")

                self.is_recovery_timer_running = YLeaf(YType.boolean, "is-recovery-timer-running")

                self.is_restart_timer_running = YLeaf(YType.boolean, "is-restart-timer-running")

                self.local_node_address = YLeafList(YType.str, "local-node-address")

                self.lost_communication_reason = YLeafList(YType.enumeration, "lost-communication-reason")

                self.lost_communication_total = YLeafList(YType.uint16, "lost-communication-total")

                self.missed_hellos = YLeaf(YType.uint8, "missed-hellos")

                self.neighbor_hello_state = YLeafList(YType.enumeration, "neighbor-hello-state")

                self.node_address = YLeaf(YType.str, "node-address")

                self.pending_states = YLeaf(YType.uint32, "pending-states")

                self.recovery_time = YLeaf(YType.uint32, "recovery-time")

                self.restart_state = YLeaf(YType.enumeration, "restart-state")

                self.restart_time = YLeaf(YType.uint32, "restart-time")

                self.global_neighbor_flags = RsvpStandby.GlobalNeighborDetails.GlobalNeighborDetail.GlobalNeighborFlags()
                self.global_neighbor_flags.parent = self
                self._children_name_map["global_neighbor_flags"] = "global-neighbor-flags"
                self._children_yang_names.add("global-neighbor-flags")

                self.recovery_time_left = RsvpStandby.GlobalNeighborDetails.GlobalNeighborDetail.RecoveryTimeLeft()
                self.recovery_time_left.parent = self
                self._children_name_map["recovery_time_left"] = "recovery-time-left"
                self._children_yang_names.add("recovery-time-left")

                self.recovery_timer_exp_time = RsvpStandby.GlobalNeighborDetails.GlobalNeighborDetail.RecoveryTimerExpTime()
                self.recovery_timer_exp_time.parent = self
                self._children_name_map["recovery_timer_exp_time"] = "recovery-timer-exp-time"
                self._children_yang_names.add("recovery-timer-exp-time")

                self.restart_time_left = RsvpStandby.GlobalNeighborDetails.GlobalNeighborDetail.RestartTimeLeft()
                self.restart_time_left.parent = self
                self._children_name_map["restart_time_left"] = "restart-time-left"
                self._children_yang_names.add("restart-time-left")

                self.restart_timer_expiry_time = RsvpStandby.GlobalNeighborDetails.GlobalNeighborDetail.RestartTimerExpiryTime()
                self.restart_timer_expiry_time.parent = self
                self._children_name_map["restart_timer_expiry_time"] = "restart-timer-expiry-time"
                self._children_yang_names.add("restart-timer-expiry-time")

                self.lost_communication_time = YList(self)
                self.up_time = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("neighbor_address",
                                "hello_interval",
                                "interface_neighbor",
                                "is_gr_enabled",
                                "is_recovery_timer_running",
                                "is_restart_timer_running",
                                "local_node_address",
                                "lost_communication_reason",
                                "lost_communication_total",
                                "missed_hellos",
                                "neighbor_hello_state",
                                "node_address",
                                "pending_states",
                                "recovery_time",
                                "restart_state",
                                "restart_time") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(RsvpStandby.GlobalNeighborDetails.GlobalNeighborDetail, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(RsvpStandby.GlobalNeighborDetails.GlobalNeighborDetail, self).__setattr__(name, value)


            class GlobalNeighborFlags(Entity):
                """
                Global Neighbor Flags
                
                .. attribute:: is_application_mpls
                
                	MPLS Application
                	**type**\:  bool
                
                .. attribute:: is_application_ouni
                
                	OUNI Application
                	**type**\:  bool
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.GlobalNeighborDetails.GlobalNeighborDetail.GlobalNeighborFlags, self).__init__()

                    self.yang_name = "global-neighbor-flags"
                    self.yang_parent_name = "global-neighbor-detail"

                    self.is_application_mpls = YLeaf(YType.boolean, "is-application-mpls")

                    self.is_application_ouni = YLeaf(YType.boolean, "is-application-ouni")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("is_application_mpls",
                                    "is_application_ouni") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.GlobalNeighborDetails.GlobalNeighborDetail.GlobalNeighborFlags, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.GlobalNeighborDetails.GlobalNeighborDetail.GlobalNeighborFlags, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.is_application_mpls.is_set or
                        self.is_application_ouni.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.is_application_mpls.yfilter != YFilter.not_set or
                        self.is_application_ouni.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "global-neighbor-flags" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.is_application_mpls.is_set or self.is_application_mpls.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_application_mpls.get_name_leafdata())
                    if (self.is_application_ouni.is_set or self.is_application_ouni.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_application_ouni.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "is-application-mpls" or name == "is-application-ouni"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "is-application-mpls"):
                        self.is_application_mpls = value
                        self.is_application_mpls.value_namespace = name_space
                        self.is_application_mpls.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-application-ouni"):
                        self.is_application_ouni = value
                        self.is_application_ouni.value_namespace = name_space
                        self.is_application_ouni.value_namespace_prefix = name_space_prefix


            class RestartTimeLeft(Entity):
                """
                How much restart time remains
                
                .. attribute:: nanoseconds
                
                	Time Value in Nano\-seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: nanosecond
                
                .. attribute:: seconds
                
                	Time Value in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.GlobalNeighborDetails.GlobalNeighborDetail.RestartTimeLeft, self).__init__()

                    self.yang_name = "restart-time-left"
                    self.yang_parent_name = "global-neighbor-detail"

                    self.nanoseconds = YLeaf(YType.int32, "nanoseconds")

                    self.seconds = YLeaf(YType.int32, "seconds")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("nanoseconds",
                                    "seconds") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.GlobalNeighborDetails.GlobalNeighborDetail.RestartTimeLeft, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.GlobalNeighborDetails.GlobalNeighborDetail.RestartTimeLeft, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.nanoseconds.is_set or
                        self.seconds.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.nanoseconds.yfilter != YFilter.not_set or
                        self.seconds.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "restart-time-left" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.nanoseconds.is_set or self.nanoseconds.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.nanoseconds.get_name_leafdata())
                    if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.seconds.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "nanoseconds" or name == "seconds"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "nanoseconds"):
                        self.nanoseconds = value
                        self.nanoseconds.value_namespace = name_space
                        self.nanoseconds.value_namespace_prefix = name_space_prefix
                    if(value_path == "seconds"):
                        self.seconds = value
                        self.seconds.value_namespace = name_space
                        self.seconds.value_namespace_prefix = name_space_prefix


            class RestartTimerExpiryTime(Entity):
                """
                When will restart timer expire
                
                .. attribute:: nanoseconds
                
                	Time Value in Nano\-seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: nanosecond
                
                .. attribute:: seconds
                
                	Time Value in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.GlobalNeighborDetails.GlobalNeighborDetail.RestartTimerExpiryTime, self).__init__()

                    self.yang_name = "restart-timer-expiry-time"
                    self.yang_parent_name = "global-neighbor-detail"

                    self.nanoseconds = YLeaf(YType.int32, "nanoseconds")

                    self.seconds = YLeaf(YType.int32, "seconds")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("nanoseconds",
                                    "seconds") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.GlobalNeighborDetails.GlobalNeighborDetail.RestartTimerExpiryTime, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.GlobalNeighborDetails.GlobalNeighborDetail.RestartTimerExpiryTime, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.nanoseconds.is_set or
                        self.seconds.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.nanoseconds.yfilter != YFilter.not_set or
                        self.seconds.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "restart-timer-expiry-time" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.nanoseconds.is_set or self.nanoseconds.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.nanoseconds.get_name_leafdata())
                    if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.seconds.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "nanoseconds" or name == "seconds"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "nanoseconds"):
                        self.nanoseconds = value
                        self.nanoseconds.value_namespace = name_space
                        self.nanoseconds.value_namespace_prefix = name_space_prefix
                    if(value_path == "seconds"):
                        self.seconds = value
                        self.seconds.value_namespace = name_space
                        self.seconds.value_namespace_prefix = name_space_prefix


            class RecoveryTimeLeft(Entity):
                """
                How much recovery timer remains
                
                .. attribute:: nanoseconds
                
                	Time Value in Nano\-seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: nanosecond
                
                .. attribute:: seconds
                
                	Time Value in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.GlobalNeighborDetails.GlobalNeighborDetail.RecoveryTimeLeft, self).__init__()

                    self.yang_name = "recovery-time-left"
                    self.yang_parent_name = "global-neighbor-detail"

                    self.nanoseconds = YLeaf(YType.int32, "nanoseconds")

                    self.seconds = YLeaf(YType.int32, "seconds")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("nanoseconds",
                                    "seconds") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.GlobalNeighborDetails.GlobalNeighborDetail.RecoveryTimeLeft, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.GlobalNeighborDetails.GlobalNeighborDetail.RecoveryTimeLeft, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.nanoseconds.is_set or
                        self.seconds.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.nanoseconds.yfilter != YFilter.not_set or
                        self.seconds.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "recovery-time-left" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.nanoseconds.is_set or self.nanoseconds.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.nanoseconds.get_name_leafdata())
                    if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.seconds.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "nanoseconds" or name == "seconds"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "nanoseconds"):
                        self.nanoseconds = value
                        self.nanoseconds.value_namespace = name_space
                        self.nanoseconds.value_namespace_prefix = name_space_prefix
                    if(value_path == "seconds"):
                        self.seconds = value
                        self.seconds.value_namespace = name_space
                        self.seconds.value_namespace_prefix = name_space_prefix


            class RecoveryTimerExpTime(Entity):
                """
                Time at which recovery timer will expire
                
                .. attribute:: nanoseconds
                
                	Time Value in Nano\-seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: nanosecond
                
                .. attribute:: seconds
                
                	Time Value in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.GlobalNeighborDetails.GlobalNeighborDetail.RecoveryTimerExpTime, self).__init__()

                    self.yang_name = "recovery-timer-exp-time"
                    self.yang_parent_name = "global-neighbor-detail"

                    self.nanoseconds = YLeaf(YType.int32, "nanoseconds")

                    self.seconds = YLeaf(YType.int32, "seconds")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("nanoseconds",
                                    "seconds") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.GlobalNeighborDetails.GlobalNeighborDetail.RecoveryTimerExpTime, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.GlobalNeighborDetails.GlobalNeighborDetail.RecoveryTimerExpTime, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.nanoseconds.is_set or
                        self.seconds.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.nanoseconds.yfilter != YFilter.not_set or
                        self.seconds.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "recovery-timer-exp-time" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.nanoseconds.is_set or self.nanoseconds.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.nanoseconds.get_name_leafdata())
                    if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.seconds.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "nanoseconds" or name == "seconds"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "nanoseconds"):
                        self.nanoseconds = value
                        self.nanoseconds.value_namespace = name_space
                        self.nanoseconds.value_namespace_prefix = name_space_prefix
                    if(value_path == "seconds"):
                        self.seconds = value
                        self.seconds.value_namespace = name_space
                        self.seconds.value_namespace_prefix = name_space_prefix


            class UpTime(Entity):
                """
                Hello up time
                
                .. attribute:: nanoseconds
                
                	Time Value in Nano\-seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: nanosecond
                
                .. attribute:: seconds
                
                	Time Value in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.GlobalNeighborDetails.GlobalNeighborDetail.UpTime, self).__init__()

                    self.yang_name = "up-time"
                    self.yang_parent_name = "global-neighbor-detail"

                    self.nanoseconds = YLeaf(YType.int32, "nanoseconds")

                    self.seconds = YLeaf(YType.int32, "seconds")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("nanoseconds",
                                    "seconds") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.GlobalNeighborDetails.GlobalNeighborDetail.UpTime, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.GlobalNeighborDetails.GlobalNeighborDetail.UpTime, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.nanoseconds.is_set or
                        self.seconds.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.nanoseconds.yfilter != YFilter.not_set or
                        self.seconds.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "up-time" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.nanoseconds.is_set or self.nanoseconds.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.nanoseconds.get_name_leafdata())
                    if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.seconds.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "nanoseconds" or name == "seconds"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "nanoseconds"):
                        self.nanoseconds = value
                        self.nanoseconds.value_namespace = name_space
                        self.nanoseconds.value_namespace_prefix = name_space_prefix
                    if(value_path == "seconds"):
                        self.seconds = value
                        self.seconds.value_namespace = name_space
                        self.seconds.value_namespace_prefix = name_space_prefix


            class LostCommunicationTime(Entity):
                """
                Time when communication was lost
                
                .. attribute:: nanoseconds
                
                	Time Value in Nano\-seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: nanosecond
                
                .. attribute:: seconds
                
                	Time Value in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.GlobalNeighborDetails.GlobalNeighborDetail.LostCommunicationTime, self).__init__()

                    self.yang_name = "lost-communication-time"
                    self.yang_parent_name = "global-neighbor-detail"

                    self.nanoseconds = YLeaf(YType.int32, "nanoseconds")

                    self.seconds = YLeaf(YType.int32, "seconds")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("nanoseconds",
                                    "seconds") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.GlobalNeighborDetails.GlobalNeighborDetail.LostCommunicationTime, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.GlobalNeighborDetails.GlobalNeighborDetail.LostCommunicationTime, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.nanoseconds.is_set or
                        self.seconds.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.nanoseconds.yfilter != YFilter.not_set or
                        self.seconds.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "lost-communication-time" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.nanoseconds.is_set or self.nanoseconds.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.nanoseconds.get_name_leafdata())
                    if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.seconds.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "nanoseconds" or name == "seconds"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "nanoseconds"):
                        self.nanoseconds = value
                        self.nanoseconds.value_namespace = name_space
                        self.nanoseconds.value_namespace_prefix = name_space_prefix
                    if(value_path == "seconds"):
                        self.seconds = value
                        self.seconds.value_namespace = name_space
                        self.seconds.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.lost_communication_time:
                    if (c.has_data()):
                        return True
                for c in self.up_time:
                    if (c.has_data()):
                        return True
                for leaf in self.interface_neighbor.getYLeafs():
                    if (leaf.yfilter != YFilter.not_set):
                        return True
                for leaf in self.local_node_address.getYLeafs():
                    if (leaf.yfilter != YFilter.not_set):
                        return True
                for leaf in self.lost_communication_reason.getYLeafs():
                    if (leaf.yfilter != YFilter.not_set):
                        return True
                for leaf in self.lost_communication_total.getYLeafs():
                    if (leaf.yfilter != YFilter.not_set):
                        return True
                for leaf in self.neighbor_hello_state.getYLeafs():
                    if (leaf.yfilter != YFilter.not_set):
                        return True
                return (
                    self.neighbor_address.is_set or
                    self.hello_interval.is_set or
                    self.is_gr_enabled.is_set or
                    self.is_recovery_timer_running.is_set or
                    self.is_restart_timer_running.is_set or
                    self.missed_hellos.is_set or
                    self.node_address.is_set or
                    self.pending_states.is_set or
                    self.recovery_time.is_set or
                    self.restart_state.is_set or
                    self.restart_time.is_set or
                    (self.global_neighbor_flags is not None and self.global_neighbor_flags.has_data()) or
                    (self.recovery_time_left is not None and self.recovery_time_left.has_data()) or
                    (self.recovery_timer_exp_time is not None and self.recovery_timer_exp_time.has_data()) or
                    (self.restart_time_left is not None and self.restart_time_left.has_data()) or
                    (self.restart_timer_expiry_time is not None and self.restart_timer_expiry_time.has_data()))

            def has_operation(self):
                for c in self.lost_communication_time:
                    if (c.has_operation()):
                        return True
                for c in self.up_time:
                    if (c.has_operation()):
                        return True
                for leaf in self.interface_neighbor.getYLeafs():
                    if (leaf.is_set):
                        return True
                for leaf in self.local_node_address.getYLeafs():
                    if (leaf.is_set):
                        return True
                for leaf in self.lost_communication_reason.getYLeafs():
                    if (leaf.is_set):
                        return True
                for leaf in self.lost_communication_total.getYLeafs():
                    if (leaf.is_set):
                        return True
                for leaf in self.neighbor_hello_state.getYLeafs():
                    if (leaf.is_set):
                        return True
                return (
                    self.yfilter != YFilter.not_set or
                    self.neighbor_address.yfilter != YFilter.not_set or
                    self.hello_interval.yfilter != YFilter.not_set or
                    self.interface_neighbor.yfilter != YFilter.not_set or
                    self.is_gr_enabled.yfilter != YFilter.not_set or
                    self.is_recovery_timer_running.yfilter != YFilter.not_set or
                    self.is_restart_timer_running.yfilter != YFilter.not_set or
                    self.local_node_address.yfilter != YFilter.not_set or
                    self.lost_communication_reason.yfilter != YFilter.not_set or
                    self.lost_communication_total.yfilter != YFilter.not_set or
                    self.missed_hellos.yfilter != YFilter.not_set or
                    self.neighbor_hello_state.yfilter != YFilter.not_set or
                    self.node_address.yfilter != YFilter.not_set or
                    self.pending_states.yfilter != YFilter.not_set or
                    self.recovery_time.yfilter != YFilter.not_set or
                    self.restart_state.yfilter != YFilter.not_set or
                    self.restart_time.yfilter != YFilter.not_set or
                    (self.global_neighbor_flags is not None and self.global_neighbor_flags.has_operation()) or
                    (self.recovery_time_left is not None and self.recovery_time_left.has_operation()) or
                    (self.recovery_timer_exp_time is not None and self.recovery_timer_exp_time.has_operation()) or
                    (self.restart_time_left is not None and self.restart_time_left.has_operation()) or
                    (self.restart_timer_expiry_time is not None and self.restart_timer_expiry_time.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "global-neighbor-detail" + "[neighbor-address='" + self.neighbor_address.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/global-neighbor-details/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.hello_interval.get_name_leafdata())
                if (self.is_gr_enabled.is_set or self.is_gr_enabled.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.is_gr_enabled.get_name_leafdata())
                if (self.is_recovery_timer_running.is_set or self.is_recovery_timer_running.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.is_recovery_timer_running.get_name_leafdata())
                if (self.is_restart_timer_running.is_set or self.is_restart_timer_running.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.is_restart_timer_running.get_name_leafdata())
                if (self.missed_hellos.is_set or self.missed_hellos.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.missed_hellos.get_name_leafdata())
                if (self.node_address.is_set or self.node_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.node_address.get_name_leafdata())
                if (self.pending_states.is_set or self.pending_states.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.pending_states.get_name_leafdata())
                if (self.recovery_time.is_set or self.recovery_time.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.recovery_time.get_name_leafdata())
                if (self.restart_state.is_set or self.restart_state.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.restart_state.get_name_leafdata())
                if (self.restart_time.is_set or self.restart_time.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.restart_time.get_name_leafdata())

                leaf_name_data.extend(self.interface_neighbor.get_name_leafdata())

                leaf_name_data.extend(self.local_node_address.get_name_leafdata())

                leaf_name_data.extend(self.lost_communication_reason.get_name_leafdata())

                leaf_name_data.extend(self.lost_communication_total.get_name_leafdata())

                leaf_name_data.extend(self.neighbor_hello_state.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "global-neighbor-flags"):
                    if (self.global_neighbor_flags is None):
                        self.global_neighbor_flags = RsvpStandby.GlobalNeighborDetails.GlobalNeighborDetail.GlobalNeighborFlags()
                        self.global_neighbor_flags.parent = self
                        self._children_name_map["global_neighbor_flags"] = "global-neighbor-flags"
                    return self.global_neighbor_flags

                if (child_yang_name == "lost-communication-time"):
                    for c in self.lost_communication_time:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = RsvpStandby.GlobalNeighborDetails.GlobalNeighborDetail.LostCommunicationTime()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.lost_communication_time.append(c)
                    return c

                if (child_yang_name == "recovery-time-left"):
                    if (self.recovery_time_left is None):
                        self.recovery_time_left = RsvpStandby.GlobalNeighborDetails.GlobalNeighborDetail.RecoveryTimeLeft()
                        self.recovery_time_left.parent = self
                        self._children_name_map["recovery_time_left"] = "recovery-time-left"
                    return self.recovery_time_left

                if (child_yang_name == "recovery-timer-exp-time"):
                    if (self.recovery_timer_exp_time is None):
                        self.recovery_timer_exp_time = RsvpStandby.GlobalNeighborDetails.GlobalNeighborDetail.RecoveryTimerExpTime()
                        self.recovery_timer_exp_time.parent = self
                        self._children_name_map["recovery_timer_exp_time"] = "recovery-timer-exp-time"
                    return self.recovery_timer_exp_time

                if (child_yang_name == "restart-time-left"):
                    if (self.restart_time_left is None):
                        self.restart_time_left = RsvpStandby.GlobalNeighborDetails.GlobalNeighborDetail.RestartTimeLeft()
                        self.restart_time_left.parent = self
                        self._children_name_map["restart_time_left"] = "restart-time-left"
                    return self.restart_time_left

                if (child_yang_name == "restart-timer-expiry-time"):
                    if (self.restart_timer_expiry_time is None):
                        self.restart_timer_expiry_time = RsvpStandby.GlobalNeighborDetails.GlobalNeighborDetail.RestartTimerExpiryTime()
                        self.restart_timer_expiry_time.parent = self
                        self._children_name_map["restart_timer_expiry_time"] = "restart-timer-expiry-time"
                    return self.restart_timer_expiry_time

                if (child_yang_name == "up-time"):
                    for c in self.up_time:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = RsvpStandby.GlobalNeighborDetails.GlobalNeighborDetail.UpTime()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.up_time.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "global-neighbor-flags" or name == "lost-communication-time" or name == "recovery-time-left" or name == "recovery-timer-exp-time" or name == "restart-time-left" or name == "restart-timer-expiry-time" or name == "up-time" or name == "neighbor-address" or name == "hello-interval" or name == "interface-neighbor" or name == "is-gr-enabled" or name == "is-recovery-timer-running" or name == "is-restart-timer-running" or name == "local-node-address" or name == "lost-communication-reason" or name == "lost-communication-total" or name == "missed-hellos" or name == "neighbor-hello-state" or name == "node-address" or name == "pending-states" or name == "recovery-time" or name == "restart-state" or name == "restart-time"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "neighbor-address"):
                    self.neighbor_address = value
                    self.neighbor_address.value_namespace = name_space
                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                if(value_path == "hello-interval"):
                    self.hello_interval = value
                    self.hello_interval.value_namespace = name_space
                    self.hello_interval.value_namespace_prefix = name_space_prefix
                if(value_path == "interface-neighbor"):
                    self.interface_neighbor.append(value)
                if(value_path == "is-gr-enabled"):
                    self.is_gr_enabled = value
                    self.is_gr_enabled.value_namespace = name_space
                    self.is_gr_enabled.value_namespace_prefix = name_space_prefix
                if(value_path == "is-recovery-timer-running"):
                    self.is_recovery_timer_running = value
                    self.is_recovery_timer_running.value_namespace = name_space
                    self.is_recovery_timer_running.value_namespace_prefix = name_space_prefix
                if(value_path == "is-restart-timer-running"):
                    self.is_restart_timer_running = value
                    self.is_restart_timer_running.value_namespace = name_space
                    self.is_restart_timer_running.value_namespace_prefix = name_space_prefix
                if(value_path == "local-node-address"):
                    self.local_node_address.append(value)
                if(value_path == "lost-communication-reason"):
                    self.lost_communication_reason.append(value)
                if(value_path == "lost-communication-total"):
                    self.lost_communication_total.append(value)
                if(value_path == "missed-hellos"):
                    self.missed_hellos = value
                    self.missed_hellos.value_namespace = name_space
                    self.missed_hellos.value_namespace_prefix = name_space_prefix
                if(value_path == "neighbor-hello-state"):
                    self.neighbor_hello_state.append(value)
                if(value_path == "node-address"):
                    self.node_address = value
                    self.node_address.value_namespace = name_space
                    self.node_address.value_namespace_prefix = name_space_prefix
                if(value_path == "pending-states"):
                    self.pending_states = value
                    self.pending_states.value_namespace = name_space
                    self.pending_states.value_namespace_prefix = name_space_prefix
                if(value_path == "recovery-time"):
                    self.recovery_time = value
                    self.recovery_time.value_namespace = name_space
                    self.recovery_time.value_namespace_prefix = name_space_prefix
                if(value_path == "restart-state"):
                    self.restart_state = value
                    self.restart_state.value_namespace = name_space
                    self.restart_state.value_namespace_prefix = name_space_prefix
                if(value_path == "restart-time"):
                    self.restart_time = value
                    self.restart_time.value_namespace = name_space
                    self.restart_time.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.global_neighbor_detail:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.global_neighbor_detail:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "global-neighbor-details" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "global-neighbor-detail"):
                for c in self.global_neighbor_detail:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = RsvpStandby.GlobalNeighborDetails.GlobalNeighborDetail()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.global_neighbor_detail.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "global-neighbor-detail"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class PsbBriefs(Entity):
        """
        Table of brief info about path state blocks
        
        .. attribute:: psb_brief
        
        	Brief info for a single path state block
        	**type**\: list of    :py:class:`PsbBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbBriefs.PsbBrief>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(RsvpStandby.PsbBriefs, self).__init__()

            self.yang_name = "psb-briefs"
            self.yang_parent_name = "rsvp-standby"

            self.psb_brief = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(RsvpStandby.PsbBriefs, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(RsvpStandby.PsbBriefs, self).__setattr__(name, value)


        class PsbBrief(Entity):
            """
            Brief info for a single path state block
            
            .. attribute:: destination_address
            
            	Destination Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: destination_port
            
            	Destination Port
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: extended_tunnel_id
            
            	Extended Tunnel ID
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: generic_traffic_spec
            
            	RSVP Generic Traffic Spec Info
            	**type**\:   :py:class:`GenericTrafficSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbBriefs.PsbBrief.GenericTrafficSpec>`
            
            .. attribute:: input_interface
            
            	Path Input Interface
            	**type**\:  str
            
            .. attribute:: p2mp_id
            
            	P2MP ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: protocol
            
            	Protocol
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: s2l_sub_lsp
            
            	RSVP S2L Sub\-LSP information
            	**type**\:   :py:class:`S2LSubLsp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbBriefs.PsbBrief.S2LSubLsp>`
            
            .. attribute:: session
            
            	RSVP Session Information
            	**type**\:   :py:class:`Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbBriefs.PsbBrief.Session>`
            
            .. attribute:: session_attribute
            
            	RSVP Session Attribute
            	**type**\:   :py:class:`SessionAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbBriefs.PsbBrief.SessionAttribute>`
            
            .. attribute:: session_type
            
            	Session Type
            	**type**\:   :py:class:`RsvpSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpSession>`
            
            .. attribute:: source_address
            
            	Source Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: source_port
            
            	Source Port 
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: sub_group_id
            
            	Subgroup ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: sub_group_origin
            
            	Subgroup Origin
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: template
            
            	RSVP Template
            	**type**\:   :py:class:`Template <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbBriefs.PsbBrief.Template>`
            
            .. attribute:: traffic_spec
            
            	RSVP Traffic Spec Info
            	**type**\:   :py:class:`TrafficSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbBriefs.PsbBrief.TrafficSpec>`
            
            .. attribute:: vrf_name
            
            	VRF Name
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(RsvpStandby.PsbBriefs.PsbBrief, self).__init__()

                self.yang_name = "psb-brief"
                self.yang_parent_name = "psb-briefs"

                self.destination_address = YLeaf(YType.str, "destination-address")

                self.destination_port = YLeaf(YType.int32, "destination-port")

                self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                self.input_interface = YLeaf(YType.str, "input-interface")

                self.p2mp_id = YLeaf(YType.int32, "p2mp-id")

                self.protocol = YLeaf(YType.int32, "protocol")

                self.session_type = YLeaf(YType.enumeration, "session-type")

                self.source_address = YLeaf(YType.str, "source-address")

                self.source_port = YLeaf(YType.int32, "source-port")

                self.sub_group_id = YLeaf(YType.int32, "sub-group-id")

                self.sub_group_origin = YLeaf(YType.str, "sub-group-origin")

                self.vrf_name = YLeaf(YType.str, "vrf-name")

                self.generic_traffic_spec = RsvpStandby.PsbBriefs.PsbBrief.GenericTrafficSpec()
                self.generic_traffic_spec.parent = self
                self._children_name_map["generic_traffic_spec"] = "generic-traffic-spec"
                self._children_yang_names.add("generic-traffic-spec")

                self.s2l_sub_lsp = RsvpStandby.PsbBriefs.PsbBrief.S2LSubLsp()
                self.s2l_sub_lsp.parent = self
                self._children_name_map["s2l_sub_lsp"] = "s2l-sub-lsp"
                self._children_yang_names.add("s2l-sub-lsp")

                self.session = RsvpStandby.PsbBriefs.PsbBrief.Session()
                self.session.parent = self
                self._children_name_map["session"] = "session"
                self._children_yang_names.add("session")

                self.session_attribute = RsvpStandby.PsbBriefs.PsbBrief.SessionAttribute()
                self.session_attribute.parent = self
                self._children_name_map["session_attribute"] = "session-attribute"
                self._children_yang_names.add("session-attribute")

                self.template = RsvpStandby.PsbBriefs.PsbBrief.Template()
                self.template.parent = self
                self._children_name_map["template"] = "template"
                self._children_yang_names.add("template")

                self.traffic_spec = RsvpStandby.PsbBriefs.PsbBrief.TrafficSpec()
                self.traffic_spec.parent = self
                self._children_name_map["traffic_spec"] = "traffic-spec"
                self._children_yang_names.add("traffic-spec")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("destination_address",
                                "destination_port",
                                "extended_tunnel_id",
                                "input_interface",
                                "p2mp_id",
                                "protocol",
                                "session_type",
                                "source_address",
                                "source_port",
                                "sub_group_id",
                                "sub_group_origin",
                                "vrf_name") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(RsvpStandby.PsbBriefs.PsbBrief, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(RsvpStandby.PsbBriefs.PsbBrief, self).__setattr__(name, value)


            class Session(Entity):
                """
                RSVP Session Information
                
                .. attribute:: rsvp_session
                
                	RSVP Session
                	**type**\:   :py:class:`RsvpSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbBriefs.PsbBrief.Session.RsvpSession>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.PsbBriefs.PsbBrief.Session, self).__init__()

                    self.yang_name = "session"
                    self.yang_parent_name = "psb-brief"

                    self.rsvp_session = RsvpStandby.PsbBriefs.PsbBrief.Session.RsvpSession()
                    self.rsvp_session.parent = self
                    self._children_name_map["rsvp_session"] = "rsvp-session"
                    self._children_yang_names.add("rsvp-session")


                class RsvpSession(Entity):
                    """
                    RSVP Session
                    
                    .. attribute:: ipv4
                    
                    	UDP IPv4 session
                    	**type**\:   :py:class:`Ipv4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbBriefs.PsbBrief.Session.RsvpSession.Ipv4>`
                    
                    .. attribute:: ipv4_lsp_session
                    
                    	IPv4 LSP session
                    	**type**\:   :py:class:`Ipv4LspSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbBriefs.PsbBrief.Session.RsvpSession.Ipv4LspSession>`
                    
                    .. attribute:: ipv4_p2mp_lsp_session
                    
                    	IPv4 P2MP LSP session
                    	**type**\:   :py:class:`Ipv4P2MpLspSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbBriefs.PsbBrief.Session.RsvpSession.Ipv4P2MpLspSession>`
                    
                    .. attribute:: ipv4_uni_session
                    
                    	IPv4 UNI session
                    	**type**\:   :py:class:`Ipv4UniSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbBriefs.PsbBrief.Session.RsvpSession.Ipv4UniSession>`
                    
                    .. attribute:: session_type
                    
                    	SessionType
                    	**type**\:   :py:class:`RsvpMgmtSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtSession>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.PsbBriefs.PsbBrief.Session.RsvpSession, self).__init__()

                        self.yang_name = "rsvp-session"
                        self.yang_parent_name = "session"

                        self.session_type = YLeaf(YType.enumeration, "session-type")

                        self.ipv4 = RsvpStandby.PsbBriefs.PsbBrief.Session.RsvpSession.Ipv4()
                        self.ipv4.parent = self
                        self._children_name_map["ipv4"] = "ipv4"
                        self._children_yang_names.add("ipv4")

                        self.ipv4_lsp_session = RsvpStandby.PsbBriefs.PsbBrief.Session.RsvpSession.Ipv4LspSession()
                        self.ipv4_lsp_session.parent = self
                        self._children_name_map["ipv4_lsp_session"] = "ipv4-lsp-session"
                        self._children_yang_names.add("ipv4-lsp-session")

                        self.ipv4_p2mp_lsp_session = RsvpStandby.PsbBriefs.PsbBrief.Session.RsvpSession.Ipv4P2MpLspSession()
                        self.ipv4_p2mp_lsp_session.parent = self
                        self._children_name_map["ipv4_p2mp_lsp_session"] = "ipv4-p2mp-lsp-session"
                        self._children_yang_names.add("ipv4-p2mp-lsp-session")

                        self.ipv4_uni_session = RsvpStandby.PsbBriefs.PsbBrief.Session.RsvpSession.Ipv4UniSession()
                        self.ipv4_uni_session.parent = self
                        self._children_name_map["ipv4_uni_session"] = "ipv4-uni-session"
                        self._children_yang_names.add("ipv4-uni-session")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("session_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.PsbBriefs.PsbBrief.Session.RsvpSession, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.PsbBriefs.PsbBrief.Session.RsvpSession, self).__setattr__(name, value)


                    class Ipv4(Entity):
                        """
                        UDP IPv4 session
                        
                        .. attribute:: destination_address
                        
                        	Destination address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: destination_port
                        
                        	The Session Destination Port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: protocol
                        
                        	Protocol type (originally defined in RFC 790, further values in subsequent RFCs)
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.PsbBriefs.PsbBrief.Session.RsvpSession.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "rsvp-session"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.destination_port = YLeaf(YType.uint16, "destination-port")

                            self.protocol = YLeaf(YType.uint8, "protocol")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "destination_port",
                                            "protocol") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.PsbBriefs.PsbBrief.Session.RsvpSession.Ipv4, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.PsbBriefs.PsbBrief.Session.RsvpSession.Ipv4, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination_address.is_set or
                                self.destination_port.is_set or
                                self.protocol.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.destination_port.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-briefs/psb-brief/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.destination_port.is_set or self.destination_port.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_port.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "destination-port" or name == "protocol"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "destination-port"):
                                self.destination_port = value
                                self.destination_port.value_namespace = name_space
                                self.destination_port.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix


                    class Ipv4LspSession(Entity):
                        """
                        IPv4 LSP session
                        
                        .. attribute:: destination_address
                        
                        	Destination address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: extended_tunnel_id
                        
                        	The Session Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: tunnel_id
                        
                        	The Session Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.PsbBriefs.PsbBrief.Session.RsvpSession.Ipv4LspSession, self).__init__()

                            self.yang_name = "ipv4-lsp-session"
                            self.yang_parent_name = "rsvp-session"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                            self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "extended_tunnel_id",
                                            "tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.PsbBriefs.PsbBrief.Session.RsvpSession.Ipv4LspSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.PsbBriefs.PsbBrief.Session.RsvpSession.Ipv4LspSession, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination_address.is_set or
                                self.extended_tunnel_id.is_set or
                                self.tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.extended_tunnel_id.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-lsp-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-briefs/psb-brief/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "extended-tunnel-id" or name == "tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "extended-tunnel-id"):
                                self.extended_tunnel_id = value
                                self.extended_tunnel_id.value_namespace = name_space
                                self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix


                    class Ipv4UniSession(Entity):
                        """
                        IPv4 UNI session
                        
                        .. attribute:: destination_address
                        
                        	Destination address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: extended_address
                        
                        	The Session Extended Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: tunnel_id
                        
                        	The Session Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.PsbBriefs.PsbBrief.Session.RsvpSession.Ipv4UniSession, self).__init__()

                            self.yang_name = "ipv4-uni-session"
                            self.yang_parent_name = "rsvp-session"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.extended_address = YLeaf(YType.str, "extended-address")

                            self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "extended_address",
                                            "tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.PsbBriefs.PsbBrief.Session.RsvpSession.Ipv4UniSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.PsbBriefs.PsbBrief.Session.RsvpSession.Ipv4UniSession, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination_address.is_set or
                                self.extended_address.is_set or
                                self.tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.extended_address.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-uni-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-briefs/psb-brief/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.extended_address.is_set or self.extended_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_address.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "extended-address" or name == "tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "extended-address"):
                                self.extended_address = value
                                self.extended_address.value_namespace = name_space
                                self.extended_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix


                    class Ipv4P2MpLspSession(Entity):
                        """
                        IPv4 P2MP LSP session
                        
                        .. attribute:: extended_tunnel_id
                        
                        	The Session Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: p2mp_id
                        
                        	The Point to Multipoint ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tunnel_id
                        
                        	The Session Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.PsbBriefs.PsbBrief.Session.RsvpSession.Ipv4P2MpLspSession, self).__init__()

                            self.yang_name = "ipv4-p2mp-lsp-session"
                            self.yang_parent_name = "rsvp-session"

                            self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                            self.p2mp_id = YLeaf(YType.uint32, "p2mp-id")

                            self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("extended_tunnel_id",
                                            "p2mp_id",
                                            "tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.PsbBriefs.PsbBrief.Session.RsvpSession.Ipv4P2MpLspSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.PsbBriefs.PsbBrief.Session.RsvpSession.Ipv4P2MpLspSession, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.extended_tunnel_id.is_set or
                                self.p2mp_id.is_set or
                                self.tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.extended_tunnel_id.yfilter != YFilter.not_set or
                                self.p2mp_id.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-p2mp-lsp-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-briefs/psb-brief/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                            if (self.p2mp_id.is_set or self.p2mp_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.p2mp_id.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "extended-tunnel-id" or name == "p2mp-id" or name == "tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "extended-tunnel-id"):
                                self.extended_tunnel_id = value
                                self.extended_tunnel_id.value_namespace = name_space
                                self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "p2mp-id"):
                                self.p2mp_id = value
                                self.p2mp_id.value_namespace = name_space
                                self.p2mp_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.session_type.is_set or
                            (self.ipv4 is not None and self.ipv4.has_data()) or
                            (self.ipv4_lsp_session is not None and self.ipv4_lsp_session.has_data()) or
                            (self.ipv4_p2mp_lsp_session is not None and self.ipv4_p2mp_lsp_session.has_data()) or
                            (self.ipv4_uni_session is not None and self.ipv4_uni_session.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.session_type.yfilter != YFilter.not_set or
                            (self.ipv4 is not None and self.ipv4.has_operation()) or
                            (self.ipv4_lsp_session is not None and self.ipv4_lsp_session.has_operation()) or
                            (self.ipv4_p2mp_lsp_session is not None and self.ipv4_p2mp_lsp_session.has_operation()) or
                            (self.ipv4_uni_session is not None and self.ipv4_uni_session.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rsvp-session" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-briefs/psb-brief/session/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.session_type.is_set or self.session_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.session_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "ipv4"):
                            if (self.ipv4 is None):
                                self.ipv4 = RsvpStandby.PsbBriefs.PsbBrief.Session.RsvpSession.Ipv4()
                                self.ipv4.parent = self
                                self._children_name_map["ipv4"] = "ipv4"
                            return self.ipv4

                        if (child_yang_name == "ipv4-lsp-session"):
                            if (self.ipv4_lsp_session is None):
                                self.ipv4_lsp_session = RsvpStandby.PsbBriefs.PsbBrief.Session.RsvpSession.Ipv4LspSession()
                                self.ipv4_lsp_session.parent = self
                                self._children_name_map["ipv4_lsp_session"] = "ipv4-lsp-session"
                            return self.ipv4_lsp_session

                        if (child_yang_name == "ipv4-p2mp-lsp-session"):
                            if (self.ipv4_p2mp_lsp_session is None):
                                self.ipv4_p2mp_lsp_session = RsvpStandby.PsbBriefs.PsbBrief.Session.RsvpSession.Ipv4P2MpLspSession()
                                self.ipv4_p2mp_lsp_session.parent = self
                                self._children_name_map["ipv4_p2mp_lsp_session"] = "ipv4-p2mp-lsp-session"
                            return self.ipv4_p2mp_lsp_session

                        if (child_yang_name == "ipv4-uni-session"):
                            if (self.ipv4_uni_session is None):
                                self.ipv4_uni_session = RsvpStandby.PsbBriefs.PsbBrief.Session.RsvpSession.Ipv4UniSession()
                                self.ipv4_uni_session.parent = self
                                self._children_name_map["ipv4_uni_session"] = "ipv4-uni-session"
                            return self.ipv4_uni_session

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ipv4" or name == "ipv4-lsp-session" or name == "ipv4-p2mp-lsp-session" or name == "ipv4-uni-session" or name == "session-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "session-type"):
                            self.session_type = value
                            self.session_type.value_namespace = name_space
                            self.session_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (self.rsvp_session is not None and self.rsvp_session.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.rsvp_session is not None and self.rsvp_session.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "session" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-briefs/psb-brief/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "rsvp-session"):
                        if (self.rsvp_session is None):
                            self.rsvp_session = RsvpStandby.PsbBriefs.PsbBrief.Session.RsvpSession()
                            self.rsvp_session.parent = self
                            self._children_name_map["rsvp_session"] = "rsvp-session"
                        return self.rsvp_session

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "rsvp-session"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class S2LSubLsp(Entity):
                """
                RSVP S2L Sub\-LSP information
                
                .. attribute:: s2l_destination_address
                
                	S2L Sub\-LSP Destination Address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.PsbBriefs.PsbBrief.S2LSubLsp, self).__init__()

                    self.yang_name = "s2l-sub-lsp"
                    self.yang_parent_name = "psb-brief"

                    self.s2l_destination_address = YLeaf(YType.str, "s2l-destination-address")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("s2l_destination_address") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.PsbBriefs.PsbBrief.S2LSubLsp, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.PsbBriefs.PsbBrief.S2LSubLsp, self).__setattr__(name, value)

                def has_data(self):
                    return self.s2l_destination_address.is_set

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.s2l_destination_address.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "s2l-sub-lsp" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-briefs/psb-brief/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.s2l_destination_address.is_set or self.s2l_destination_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.s2l_destination_address.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "s2l-destination-address"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "s2l-destination-address"):
                        self.s2l_destination_address = value
                        self.s2l_destination_address.value_namespace = name_space
                        self.s2l_destination_address.value_namespace_prefix = name_space_prefix


            class Template(Entity):
                """
                RSVP Template
                
                .. attribute:: rsvp_filter
                
                	RSVP Filter
                	**type**\:   :py:class:`RsvpFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbBriefs.PsbBrief.Template.RsvpFilter>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.PsbBriefs.PsbBrief.Template, self).__init__()

                    self.yang_name = "template"
                    self.yang_parent_name = "psb-brief"

                    self.rsvp_filter = RsvpStandby.PsbBriefs.PsbBrief.Template.RsvpFilter()
                    self.rsvp_filter.parent = self
                    self._children_name_map["rsvp_filter"] = "rsvp-filter"
                    self._children_yang_names.add("rsvp-filter")


                class RsvpFilter(Entity):
                    """
                    RSVP Filter
                    
                    .. attribute:: filter_type
                    
                    	FilterType
                    	**type**\:   :py:class:`RsvpMgmtFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtFilter>`
                    
                    .. attribute:: p2mp_ipv4_session
                    
                    	IPv4 P2MP LSP FilterSpec
                    	**type**\:   :py:class:`P2MpIpv4Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbBriefs.PsbBrief.Template.RsvpFilter.P2MpIpv4Session>`
                    
                    .. attribute:: udp_ipv4_session
                    
                    	UDP IPV4 FilterSpec
                    	**type**\:   :py:class:`UdpIpv4Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbBriefs.PsbBrief.Template.RsvpFilter.UdpIpv4Session>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.PsbBriefs.PsbBrief.Template.RsvpFilter, self).__init__()

                        self.yang_name = "rsvp-filter"
                        self.yang_parent_name = "template"

                        self.filter_type = YLeaf(YType.enumeration, "filter-type")

                        self.p2mp_ipv4_session = RsvpStandby.PsbBriefs.PsbBrief.Template.RsvpFilter.P2MpIpv4Session()
                        self.p2mp_ipv4_session.parent = self
                        self._children_name_map["p2mp_ipv4_session"] = "p2mp-ipv4-session"
                        self._children_yang_names.add("p2mp-ipv4-session")

                        self.udp_ipv4_session = RsvpStandby.PsbBriefs.PsbBrief.Template.RsvpFilter.UdpIpv4Session()
                        self.udp_ipv4_session.parent = self
                        self._children_name_map["udp_ipv4_session"] = "udp-ipv4-session"
                        self._children_yang_names.add("udp-ipv4-session")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("filter_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.PsbBriefs.PsbBrief.Template.RsvpFilter, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.PsbBriefs.PsbBrief.Template.RsvpFilter, self).__setattr__(name, value)


                    class UdpIpv4Session(Entity):
                        """
                        UDP IPV4 FilterSpec
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source_port
                        
                        	Source Port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.PsbBriefs.PsbBrief.Template.RsvpFilter.UdpIpv4Session, self).__init__()

                            self.yang_name = "udp-ipv4-session"
                            self.yang_parent_name = "rsvp-filter"

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.source_port = YLeaf(YType.uint16, "source-port")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("source_address",
                                            "source_port") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.PsbBriefs.PsbBrief.Template.RsvpFilter.UdpIpv4Session, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.PsbBriefs.PsbBrief.Template.RsvpFilter.UdpIpv4Session, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.source_address.is_set or
                                self.source_port.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                self.source_port.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "udp-ipv4-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-briefs/psb-brief/template/rsvp-filter/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())
                            if (self.source_port.is_set or self.source_port.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_port.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "source-address" or name == "source-port"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-port"):
                                self.source_port = value
                                self.source_port.value_namespace = name_space
                                self.source_port.value_namespace_prefix = name_space_prefix


                    class P2MpIpv4Session(Entity):
                        """
                        IPv4 P2MP LSP FilterSpec
                        
                        .. attribute:: p2mp_sub_group_origin
                        
                        	Point to Multipoint SubGroup Origin
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source_port
                        
                        	Source Port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: sub_group_id
                        
                        	Point to Multipoint Subgroup ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RsvpStandby.PsbBriefs.PsbBrief.Template.RsvpFilter.P2MpIpv4Session, self).__init__()

                            self.yang_name = "p2mp-ipv4-session"
                            self.yang_parent_name = "rsvp-filter"

                            self.p2mp_sub_group_origin = YLeaf(YType.str, "p2mp-sub-group-origin")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.source_port = YLeaf(YType.uint16, "source-port")

                            self.sub_group_id = YLeaf(YType.uint16, "sub-group-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("p2mp_sub_group_origin",
                                            "source_address",
                                            "source_port",
                                            "sub_group_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(RsvpStandby.PsbBriefs.PsbBrief.Template.RsvpFilter.P2MpIpv4Session, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(RsvpStandby.PsbBriefs.PsbBrief.Template.RsvpFilter.P2MpIpv4Session, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.p2mp_sub_group_origin.is_set or
                                self.source_address.is_set or
                                self.source_port.is_set or
                                self.sub_group_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.p2mp_sub_group_origin.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                self.source_port.yfilter != YFilter.not_set or
                                self.sub_group_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "p2mp-ipv4-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-briefs/psb-brief/template/rsvp-filter/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.p2mp_sub_group_origin.is_set or self.p2mp_sub_group_origin.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.p2mp_sub_group_origin.get_name_leafdata())
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())
                            if (self.source_port.is_set or self.source_port.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_port.get_name_leafdata())
                            if (self.sub_group_id.is_set or self.sub_group_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sub_group_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "p2mp-sub-group-origin" or name == "source-address" or name == "source-port" or name == "sub-group-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "p2mp-sub-group-origin"):
                                self.p2mp_sub_group_origin = value
                                self.p2mp_sub_group_origin.value_namespace = name_space
                                self.p2mp_sub_group_origin.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-port"):
                                self.source_port = value
                                self.source_port.value_namespace = name_space
                                self.source_port.value_namespace_prefix = name_space_prefix
                            if(value_path == "sub-group-id"):
                                self.sub_group_id = value
                                self.sub_group_id.value_namespace = name_space
                                self.sub_group_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.filter_type.is_set or
                            (self.p2mp_ipv4_session is not None and self.p2mp_ipv4_session.has_data()) or
                            (self.udp_ipv4_session is not None and self.udp_ipv4_session.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.filter_type.yfilter != YFilter.not_set or
                            (self.p2mp_ipv4_session is not None and self.p2mp_ipv4_session.has_operation()) or
                            (self.udp_ipv4_session is not None and self.udp_ipv4_session.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rsvp-filter" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-briefs/psb-brief/template/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.filter_type.is_set or self.filter_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.filter_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "p2mp-ipv4-session"):
                            if (self.p2mp_ipv4_session is None):
                                self.p2mp_ipv4_session = RsvpStandby.PsbBriefs.PsbBrief.Template.RsvpFilter.P2MpIpv4Session()
                                self.p2mp_ipv4_session.parent = self
                                self._children_name_map["p2mp_ipv4_session"] = "p2mp-ipv4-session"
                            return self.p2mp_ipv4_session

                        if (child_yang_name == "udp-ipv4-session"):
                            if (self.udp_ipv4_session is None):
                                self.udp_ipv4_session = RsvpStandby.PsbBriefs.PsbBrief.Template.RsvpFilter.UdpIpv4Session()
                                self.udp_ipv4_session.parent = self
                                self._children_name_map["udp_ipv4_session"] = "udp-ipv4-session"
                            return self.udp_ipv4_session

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "p2mp-ipv4-session" or name == "udp-ipv4-session" or name == "filter-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "filter-type"):
                            self.filter_type = value
                            self.filter_type.value_namespace = name_space
                            self.filter_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (self.rsvp_filter is not None and self.rsvp_filter.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.rsvp_filter is not None and self.rsvp_filter.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "template" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-briefs/psb-brief/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "rsvp-filter"):
                        if (self.rsvp_filter is None):
                            self.rsvp_filter = RsvpStandby.PsbBriefs.PsbBrief.Template.RsvpFilter()
                            self.rsvp_filter.parent = self
                            self._children_name_map["rsvp_filter"] = "rsvp-filter"
                        return self.rsvp_filter

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "rsvp-filter"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class SessionAttribute(Entity):
                """
                RSVP Session Attribute
                
                .. attribute:: reservation_priority
                
                	Reservation Priority
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: sess_attribute_flags
                
                	Session Attributes
                	**type**\:   :py:class:`SessAttributeFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbBriefs.PsbBrief.SessionAttribute.SessAttributeFlags>`
                
                .. attribute:: setup_priority
                
                	Setup Priority
                	**type**\:  int
                
                	**range:** 0..255
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.PsbBriefs.PsbBrief.SessionAttribute, self).__init__()

                    self.yang_name = "session-attribute"
                    self.yang_parent_name = "psb-brief"

                    self.reservation_priority = YLeaf(YType.uint8, "reservation-priority")

                    self.setup_priority = YLeaf(YType.uint8, "setup-priority")

                    self.sess_attribute_flags = RsvpStandby.PsbBriefs.PsbBrief.SessionAttribute.SessAttributeFlags()
                    self.sess_attribute_flags.parent = self
                    self._children_name_map["sess_attribute_flags"] = "sess-attribute-flags"
                    self._children_yang_names.add("sess-attribute-flags")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("reservation_priority",
                                    "setup_priority") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.PsbBriefs.PsbBrief.SessionAttribute, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.PsbBriefs.PsbBrief.SessionAttribute, self).__setattr__(name, value)


                class SessAttributeFlags(Entity):
                    """
                    Session Attributes
                    
                    .. attribute:: is_bandwidth_protect
                    
                    	Bandwidth Protection
                    	**type**\:  bool
                    
                    .. attribute:: is_local_protect
                    
                    	Local Protection
                    	**type**\:  bool
                    
                    .. attribute:: is_node_protect
                    
                    	Node Protection
                    	**type**\:  bool
                    
                    .. attribute:: is_record_labels
                    
                    	Records Labels
                    	**type**\:  bool
                    
                    .. attribute:: is_shared_explicit_requested
                    
                    	Shared Explicit Requested
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.PsbBriefs.PsbBrief.SessionAttribute.SessAttributeFlags, self).__init__()

                        self.yang_name = "sess-attribute-flags"
                        self.yang_parent_name = "session-attribute"

                        self.is_bandwidth_protect = YLeaf(YType.boolean, "is-bandwidth-protect")

                        self.is_local_protect = YLeaf(YType.boolean, "is-local-protect")

                        self.is_node_protect = YLeaf(YType.boolean, "is-node-protect")

                        self.is_record_labels = YLeaf(YType.boolean, "is-record-labels")

                        self.is_shared_explicit_requested = YLeaf(YType.boolean, "is-shared-explicit-requested")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("is_bandwidth_protect",
                                        "is_local_protect",
                                        "is_node_protect",
                                        "is_record_labels",
                                        "is_shared_explicit_requested") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.PsbBriefs.PsbBrief.SessionAttribute.SessAttributeFlags, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.PsbBriefs.PsbBrief.SessionAttribute.SessAttributeFlags, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.is_bandwidth_protect.is_set or
                            self.is_local_protect.is_set or
                            self.is_node_protect.is_set or
                            self.is_record_labels.is_set or
                            self.is_shared_explicit_requested.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.is_bandwidth_protect.yfilter != YFilter.not_set or
                            self.is_local_protect.yfilter != YFilter.not_set or
                            self.is_node_protect.yfilter != YFilter.not_set or
                            self.is_record_labels.yfilter != YFilter.not_set or
                            self.is_shared_explicit_requested.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "sess-attribute-flags" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-briefs/psb-brief/session-attribute/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.is_bandwidth_protect.is_set or self.is_bandwidth_protect.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_bandwidth_protect.get_name_leafdata())
                        if (self.is_local_protect.is_set or self.is_local_protect.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_local_protect.get_name_leafdata())
                        if (self.is_node_protect.is_set or self.is_node_protect.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_node_protect.get_name_leafdata())
                        if (self.is_record_labels.is_set or self.is_record_labels.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_record_labels.get_name_leafdata())
                        if (self.is_shared_explicit_requested.is_set or self.is_shared_explicit_requested.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_shared_explicit_requested.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "is-bandwidth-protect" or name == "is-local-protect" or name == "is-node-protect" or name == "is-record-labels" or name == "is-shared-explicit-requested"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "is-bandwidth-protect"):
                            self.is_bandwidth_protect = value
                            self.is_bandwidth_protect.value_namespace = name_space
                            self.is_bandwidth_protect.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-local-protect"):
                            self.is_local_protect = value
                            self.is_local_protect.value_namespace = name_space
                            self.is_local_protect.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-node-protect"):
                            self.is_node_protect = value
                            self.is_node_protect.value_namespace = name_space
                            self.is_node_protect.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-record-labels"):
                            self.is_record_labels = value
                            self.is_record_labels.value_namespace = name_space
                            self.is_record_labels.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-shared-explicit-requested"):
                            self.is_shared_explicit_requested = value
                            self.is_shared_explicit_requested.value_namespace = name_space
                            self.is_shared_explicit_requested.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.reservation_priority.is_set or
                        self.setup_priority.is_set or
                        (self.sess_attribute_flags is not None and self.sess_attribute_flags.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.reservation_priority.yfilter != YFilter.not_set or
                        self.setup_priority.yfilter != YFilter.not_set or
                        (self.sess_attribute_flags is not None and self.sess_attribute_flags.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "session-attribute" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-briefs/psb-brief/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.reservation_priority.is_set or self.reservation_priority.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reservation_priority.get_name_leafdata())
                    if (self.setup_priority.is_set or self.setup_priority.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.setup_priority.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "sess-attribute-flags"):
                        if (self.sess_attribute_flags is None):
                            self.sess_attribute_flags = RsvpStandby.PsbBriefs.PsbBrief.SessionAttribute.SessAttributeFlags()
                            self.sess_attribute_flags.parent = self
                            self._children_name_map["sess_attribute_flags"] = "sess-attribute-flags"
                        return self.sess_attribute_flags

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "sess-attribute-flags" or name == "reservation-priority" or name == "setup-priority"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "reservation-priority"):
                        self.reservation_priority = value
                        self.reservation_priority.value_namespace = name_space
                        self.reservation_priority.value_namespace_prefix = name_space_prefix
                    if(value_path == "setup-priority"):
                        self.setup_priority = value
                        self.setup_priority.value_namespace = name_space
                        self.setup_priority.value_namespace_prefix = name_space_prefix


            class TrafficSpec(Entity):
                """
                RSVP Traffic Spec Info
                
                .. attribute:: traffic_average_rate
                
                	Traffic Average Rate in bytes per second
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: byte/s
                
                .. attribute:: traffic_max_burst
                
                	Traffic Maximum Burst
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: traffic_max_unit
                
                	Traffic Maximum Unit
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: traffic_min_unit
                
                	Traffic Minimum Unit
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: traffic_peak_rate
                
                	Traffic Peak Rate in bytes per second
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: byte/s
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.PsbBriefs.PsbBrief.TrafficSpec, self).__init__()

                    self.yang_name = "traffic-spec"
                    self.yang_parent_name = "psb-brief"

                    self.traffic_average_rate = YLeaf(YType.uint64, "traffic-average-rate")

                    self.traffic_max_burst = YLeaf(YType.uint64, "traffic-max-burst")

                    self.traffic_max_unit = YLeaf(YType.uint32, "traffic-max-unit")

                    self.traffic_min_unit = YLeaf(YType.uint32, "traffic-min-unit")

                    self.traffic_peak_rate = YLeaf(YType.uint64, "traffic-peak-rate")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("traffic_average_rate",
                                    "traffic_max_burst",
                                    "traffic_max_unit",
                                    "traffic_min_unit",
                                    "traffic_peak_rate") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.PsbBriefs.PsbBrief.TrafficSpec, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.PsbBriefs.PsbBrief.TrafficSpec, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.traffic_average_rate.is_set or
                        self.traffic_max_burst.is_set or
                        self.traffic_max_unit.is_set or
                        self.traffic_min_unit.is_set or
                        self.traffic_peak_rate.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.traffic_average_rate.yfilter != YFilter.not_set or
                        self.traffic_max_burst.yfilter != YFilter.not_set or
                        self.traffic_max_unit.yfilter != YFilter.not_set or
                        self.traffic_min_unit.yfilter != YFilter.not_set or
                        self.traffic_peak_rate.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "traffic-spec" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-briefs/psb-brief/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.traffic_average_rate.is_set or self.traffic_average_rate.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.traffic_average_rate.get_name_leafdata())
                    if (self.traffic_max_burst.is_set or self.traffic_max_burst.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.traffic_max_burst.get_name_leafdata())
                    if (self.traffic_max_unit.is_set or self.traffic_max_unit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.traffic_max_unit.get_name_leafdata())
                    if (self.traffic_min_unit.is_set or self.traffic_min_unit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.traffic_min_unit.get_name_leafdata())
                    if (self.traffic_peak_rate.is_set or self.traffic_peak_rate.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.traffic_peak_rate.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "traffic-average-rate" or name == "traffic-max-burst" or name == "traffic-max-unit" or name == "traffic-min-unit" or name == "traffic-peak-rate"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "traffic-average-rate"):
                        self.traffic_average_rate = value
                        self.traffic_average_rate.value_namespace = name_space
                        self.traffic_average_rate.value_namespace_prefix = name_space_prefix
                    if(value_path == "traffic-max-burst"):
                        self.traffic_max_burst = value
                        self.traffic_max_burst.value_namespace = name_space
                        self.traffic_max_burst.value_namespace_prefix = name_space_prefix
                    if(value_path == "traffic-max-unit"):
                        self.traffic_max_unit = value
                        self.traffic_max_unit.value_namespace = name_space
                        self.traffic_max_unit.value_namespace_prefix = name_space_prefix
                    if(value_path == "traffic-min-unit"):
                        self.traffic_min_unit = value
                        self.traffic_min_unit.value_namespace = name_space
                        self.traffic_min_unit.value_namespace_prefix = name_space_prefix
                    if(value_path == "traffic-peak-rate"):
                        self.traffic_peak_rate = value
                        self.traffic_peak_rate.value_namespace = name_space
                        self.traffic_peak_rate.value_namespace_prefix = name_space_prefix


            class GenericTrafficSpec(Entity):
                """
                RSVP Generic Traffic Spec Info
                
                .. attribute:: g709otn_tspec
                
                	G709 OTN Sender Tspec
                	**type**\:   :py:class:`G709OtnTspec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbBriefs.PsbBrief.GenericTrafficSpec.G709OtnTspec>`
                
                .. attribute:: intsrv_tspec
                
                	Integrated Services Sender Tspec
                	**type**\:   :py:class:`IntsrvTspec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.PsbBriefs.PsbBrief.GenericTrafficSpec.IntsrvTspec>`
                
                .. attribute:: tspec_type
                
                	TspecType
                	**type**\:   :py:class:`RsvpMgmtTspec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtTspec>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.PsbBriefs.PsbBrief.GenericTrafficSpec, self).__init__()

                    self.yang_name = "generic-traffic-spec"
                    self.yang_parent_name = "psb-brief"

                    self.tspec_type = YLeaf(YType.enumeration, "tspec-type")

                    self.g709otn_tspec = RsvpStandby.PsbBriefs.PsbBrief.GenericTrafficSpec.G709OtnTspec()
                    self.g709otn_tspec.parent = self
                    self._children_name_map["g709otn_tspec"] = "g709otn-tspec"
                    self._children_yang_names.add("g709otn-tspec")

                    self.intsrv_tspec = RsvpStandby.PsbBriefs.PsbBrief.GenericTrafficSpec.IntsrvTspec()
                    self.intsrv_tspec.parent = self
                    self._children_name_map["intsrv_tspec"] = "intsrv-tspec"
                    self._children_yang_names.add("intsrv-tspec")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("tspec_type") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.PsbBriefs.PsbBrief.GenericTrafficSpec, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.PsbBriefs.PsbBrief.GenericTrafficSpec, self).__setattr__(name, value)


                class G709OtnTspec(Entity):
                    """
                    G709 OTN Sender Tspec
                    
                    .. attribute:: traffic_bit_rate
                    
                    	G709 OTN Traffic Bit Rate
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: traffic_multiplier
                    
                    	G709 OTN Traffic Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: traffic_nvc
                    
                    	G709 OTN Traffic NVC
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: traffic_signal_type
                    
                    	G709 OTN Traffic Signal Type (Refer G709 v3)
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.PsbBriefs.PsbBrief.GenericTrafficSpec.G709OtnTspec, self).__init__()

                        self.yang_name = "g709otn-tspec"
                        self.yang_parent_name = "generic-traffic-spec"

                        self.traffic_bit_rate = YLeaf(YType.uint64, "traffic-bit-rate")

                        self.traffic_multiplier = YLeaf(YType.uint16, "traffic-multiplier")

                        self.traffic_nvc = YLeaf(YType.uint16, "traffic-nvc")

                        self.traffic_signal_type = YLeaf(YType.uint8, "traffic-signal-type")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("traffic_bit_rate",
                                        "traffic_multiplier",
                                        "traffic_nvc",
                                        "traffic_signal_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.PsbBriefs.PsbBrief.GenericTrafficSpec.G709OtnTspec, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.PsbBriefs.PsbBrief.GenericTrafficSpec.G709OtnTspec, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.traffic_bit_rate.is_set or
                            self.traffic_multiplier.is_set or
                            self.traffic_nvc.is_set or
                            self.traffic_signal_type.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.traffic_bit_rate.yfilter != YFilter.not_set or
                            self.traffic_multiplier.yfilter != YFilter.not_set or
                            self.traffic_nvc.yfilter != YFilter.not_set or
                            self.traffic_signal_type.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "g709otn-tspec" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-briefs/psb-brief/generic-traffic-spec/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.traffic_bit_rate.is_set or self.traffic_bit_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.traffic_bit_rate.get_name_leafdata())
                        if (self.traffic_multiplier.is_set or self.traffic_multiplier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.traffic_multiplier.get_name_leafdata())
                        if (self.traffic_nvc.is_set or self.traffic_nvc.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.traffic_nvc.get_name_leafdata())
                        if (self.traffic_signal_type.is_set or self.traffic_signal_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.traffic_signal_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "traffic-bit-rate" or name == "traffic-multiplier" or name == "traffic-nvc" or name == "traffic-signal-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "traffic-bit-rate"):
                            self.traffic_bit_rate = value
                            self.traffic_bit_rate.value_namespace = name_space
                            self.traffic_bit_rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "traffic-multiplier"):
                            self.traffic_multiplier = value
                            self.traffic_multiplier.value_namespace = name_space
                            self.traffic_multiplier.value_namespace_prefix = name_space_prefix
                        if(value_path == "traffic-nvc"):
                            self.traffic_nvc = value
                            self.traffic_nvc.value_namespace = name_space
                            self.traffic_nvc.value_namespace_prefix = name_space_prefix
                        if(value_path == "traffic-signal-type"):
                            self.traffic_signal_type = value
                            self.traffic_signal_type.value_namespace = name_space
                            self.traffic_signal_type.value_namespace_prefix = name_space_prefix


                class IntsrvTspec(Entity):
                    """
                    Integrated Services Sender Tspec
                    
                    .. attribute:: traffic_average_rate
                    
                    	Traffic Average Rate in bytes per second
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: byte/s
                    
                    .. attribute:: traffic_max_burst
                    
                    	Traffic Maximum Burst
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: traffic_max_unit
                    
                    	Traffic Maximum Unit
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: traffic_min_unit
                    
                    	Traffic Minimum Unit
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: traffic_peak_rate
                    
                    	Traffic Peak Rate in bytes per second
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: byte/s
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RsvpStandby.PsbBriefs.PsbBrief.GenericTrafficSpec.IntsrvTspec, self).__init__()

                        self.yang_name = "intsrv-tspec"
                        self.yang_parent_name = "generic-traffic-spec"

                        self.traffic_average_rate = YLeaf(YType.uint64, "traffic-average-rate")

                        self.traffic_max_burst = YLeaf(YType.uint64, "traffic-max-burst")

                        self.traffic_max_unit = YLeaf(YType.uint32, "traffic-max-unit")

                        self.traffic_min_unit = YLeaf(YType.uint32, "traffic-min-unit")

                        self.traffic_peak_rate = YLeaf(YType.uint64, "traffic-peak-rate")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("traffic_average_rate",
                                        "traffic_max_burst",
                                        "traffic_max_unit",
                                        "traffic_min_unit",
                                        "traffic_peak_rate") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(RsvpStandby.PsbBriefs.PsbBrief.GenericTrafficSpec.IntsrvTspec, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(RsvpStandby.PsbBriefs.PsbBrief.GenericTrafficSpec.IntsrvTspec, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.traffic_average_rate.is_set or
                            self.traffic_max_burst.is_set or
                            self.traffic_max_unit.is_set or
                            self.traffic_min_unit.is_set or
                            self.traffic_peak_rate.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.traffic_average_rate.yfilter != YFilter.not_set or
                            self.traffic_max_burst.yfilter != YFilter.not_set or
                            self.traffic_max_unit.yfilter != YFilter.not_set or
                            self.traffic_min_unit.yfilter != YFilter.not_set or
                            self.traffic_peak_rate.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "intsrv-tspec" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-briefs/psb-brief/generic-traffic-spec/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.traffic_average_rate.is_set or self.traffic_average_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.traffic_average_rate.get_name_leafdata())
                        if (self.traffic_max_burst.is_set or self.traffic_max_burst.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.traffic_max_burst.get_name_leafdata())
                        if (self.traffic_max_unit.is_set or self.traffic_max_unit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.traffic_max_unit.get_name_leafdata())
                        if (self.traffic_min_unit.is_set or self.traffic_min_unit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.traffic_min_unit.get_name_leafdata())
                        if (self.traffic_peak_rate.is_set or self.traffic_peak_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.traffic_peak_rate.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "traffic-average-rate" or name == "traffic-max-burst" or name == "traffic-max-unit" or name == "traffic-min-unit" or name == "traffic-peak-rate"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "traffic-average-rate"):
                            self.traffic_average_rate = value
                            self.traffic_average_rate.value_namespace = name_space
                            self.traffic_average_rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "traffic-max-burst"):
                            self.traffic_max_burst = value
                            self.traffic_max_burst.value_namespace = name_space
                            self.traffic_max_burst.value_namespace_prefix = name_space_prefix
                        if(value_path == "traffic-max-unit"):
                            self.traffic_max_unit = value
                            self.traffic_max_unit.value_namespace = name_space
                            self.traffic_max_unit.value_namespace_prefix = name_space_prefix
                        if(value_path == "traffic-min-unit"):
                            self.traffic_min_unit = value
                            self.traffic_min_unit.value_namespace = name_space
                            self.traffic_min_unit.value_namespace_prefix = name_space_prefix
                        if(value_path == "traffic-peak-rate"):
                            self.traffic_peak_rate = value
                            self.traffic_peak_rate.value_namespace = name_space
                            self.traffic_peak_rate.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.tspec_type.is_set or
                        (self.g709otn_tspec is not None and self.g709otn_tspec.has_data()) or
                        (self.intsrv_tspec is not None and self.intsrv_tspec.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.tspec_type.yfilter != YFilter.not_set or
                        (self.g709otn_tspec is not None and self.g709otn_tspec.has_operation()) or
                        (self.intsrv_tspec is not None and self.intsrv_tspec.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "generic-traffic-spec" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-briefs/psb-brief/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.tspec_type.is_set or self.tspec_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tspec_type.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "g709otn-tspec"):
                        if (self.g709otn_tspec is None):
                            self.g709otn_tspec = RsvpStandby.PsbBriefs.PsbBrief.GenericTrafficSpec.G709OtnTspec()
                            self.g709otn_tspec.parent = self
                            self._children_name_map["g709otn_tspec"] = "g709otn-tspec"
                        return self.g709otn_tspec

                    if (child_yang_name == "intsrv-tspec"):
                        if (self.intsrv_tspec is None):
                            self.intsrv_tspec = RsvpStandby.PsbBriefs.PsbBrief.GenericTrafficSpec.IntsrvTspec()
                            self.intsrv_tspec.parent = self
                            self._children_name_map["intsrv_tspec"] = "intsrv-tspec"
                        return self.intsrv_tspec

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "g709otn-tspec" or name == "intsrv-tspec" or name == "tspec-type"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "tspec-type"):
                        self.tspec_type = value
                        self.tspec_type.value_namespace = name_space
                        self.tspec_type.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.destination_address.is_set or
                    self.destination_port.is_set or
                    self.extended_tunnel_id.is_set or
                    self.input_interface.is_set or
                    self.p2mp_id.is_set or
                    self.protocol.is_set or
                    self.session_type.is_set or
                    self.source_address.is_set or
                    self.source_port.is_set or
                    self.sub_group_id.is_set or
                    self.sub_group_origin.is_set or
                    self.vrf_name.is_set or
                    (self.generic_traffic_spec is not None and self.generic_traffic_spec.has_data()) or
                    (self.s2l_sub_lsp is not None and self.s2l_sub_lsp.has_data()) or
                    (self.session is not None and self.session.has_data()) or
                    (self.session_attribute is not None and self.session_attribute.has_data()) or
                    (self.template is not None and self.template.has_data()) or
                    (self.traffic_spec is not None and self.traffic_spec.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.destination_address.yfilter != YFilter.not_set or
                    self.destination_port.yfilter != YFilter.not_set or
                    self.extended_tunnel_id.yfilter != YFilter.not_set or
                    self.input_interface.yfilter != YFilter.not_set or
                    self.p2mp_id.yfilter != YFilter.not_set or
                    self.protocol.yfilter != YFilter.not_set or
                    self.session_type.yfilter != YFilter.not_set or
                    self.source_address.yfilter != YFilter.not_set or
                    self.source_port.yfilter != YFilter.not_set or
                    self.sub_group_id.yfilter != YFilter.not_set or
                    self.sub_group_origin.yfilter != YFilter.not_set or
                    self.vrf_name.yfilter != YFilter.not_set or
                    (self.generic_traffic_spec is not None and self.generic_traffic_spec.has_operation()) or
                    (self.s2l_sub_lsp is not None and self.s2l_sub_lsp.has_operation()) or
                    (self.session is not None and self.session.has_operation()) or
                    (self.session_attribute is not None and self.session_attribute.has_operation()) or
                    (self.template is not None and self.template.has_operation()) or
                    (self.traffic_spec is not None and self.traffic_spec.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "psb-brief" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/psb-briefs/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_address.get_name_leafdata())
                if (self.destination_port.is_set or self.destination_port.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_port.get_name_leafdata())
                if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                if (self.input_interface.is_set or self.input_interface.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.input_interface.get_name_leafdata())
                if (self.p2mp_id.is_set or self.p2mp_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.p2mp_id.get_name_leafdata())
                if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.protocol.get_name_leafdata())
                if (self.session_type.is_set or self.session_type.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.session_type.get_name_leafdata())
                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_address.get_name_leafdata())
                if (self.source_port.is_set or self.source_port.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_port.get_name_leafdata())
                if (self.sub_group_id.is_set or self.sub_group_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.sub_group_id.get_name_leafdata())
                if (self.sub_group_origin.is_set or self.sub_group_origin.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.sub_group_origin.get_name_leafdata())
                if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.vrf_name.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "generic-traffic-spec"):
                    if (self.generic_traffic_spec is None):
                        self.generic_traffic_spec = RsvpStandby.PsbBriefs.PsbBrief.GenericTrafficSpec()
                        self.generic_traffic_spec.parent = self
                        self._children_name_map["generic_traffic_spec"] = "generic-traffic-spec"
                    return self.generic_traffic_spec

                if (child_yang_name == "s2l-sub-lsp"):
                    if (self.s2l_sub_lsp is None):
                        self.s2l_sub_lsp = RsvpStandby.PsbBriefs.PsbBrief.S2LSubLsp()
                        self.s2l_sub_lsp.parent = self
                        self._children_name_map["s2l_sub_lsp"] = "s2l-sub-lsp"
                    return self.s2l_sub_lsp

                if (child_yang_name == "session"):
                    if (self.session is None):
                        self.session = RsvpStandby.PsbBriefs.PsbBrief.Session()
                        self.session.parent = self
                        self._children_name_map["session"] = "session"
                    return self.session

                if (child_yang_name == "session-attribute"):
                    if (self.session_attribute is None):
                        self.session_attribute = RsvpStandby.PsbBriefs.PsbBrief.SessionAttribute()
                        self.session_attribute.parent = self
                        self._children_name_map["session_attribute"] = "session-attribute"
                    return self.session_attribute

                if (child_yang_name == "template"):
                    if (self.template is None):
                        self.template = RsvpStandby.PsbBriefs.PsbBrief.Template()
                        self.template.parent = self
                        self._children_name_map["template"] = "template"
                    return self.template

                if (child_yang_name == "traffic-spec"):
                    if (self.traffic_spec is None):
                        self.traffic_spec = RsvpStandby.PsbBriefs.PsbBrief.TrafficSpec()
                        self.traffic_spec.parent = self
                        self._children_name_map["traffic_spec"] = "traffic-spec"
                    return self.traffic_spec

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "generic-traffic-spec" or name == "s2l-sub-lsp" or name == "session" or name == "session-attribute" or name == "template" or name == "traffic-spec" or name == "destination-address" or name == "destination-port" or name == "extended-tunnel-id" or name == "input-interface" or name == "p2mp-id" or name == "protocol" or name == "session-type" or name == "source-address" or name == "source-port" or name == "sub-group-id" or name == "sub-group-origin" or name == "vrf-name"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "destination-address"):
                    self.destination_address = value
                    self.destination_address.value_namespace = name_space
                    self.destination_address.value_namespace_prefix = name_space_prefix
                if(value_path == "destination-port"):
                    self.destination_port = value
                    self.destination_port.value_namespace = name_space
                    self.destination_port.value_namespace_prefix = name_space_prefix
                if(value_path == "extended-tunnel-id"):
                    self.extended_tunnel_id = value
                    self.extended_tunnel_id.value_namespace = name_space
                    self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                if(value_path == "input-interface"):
                    self.input_interface = value
                    self.input_interface.value_namespace = name_space
                    self.input_interface.value_namespace_prefix = name_space_prefix
                if(value_path == "p2mp-id"):
                    self.p2mp_id = value
                    self.p2mp_id.value_namespace = name_space
                    self.p2mp_id.value_namespace_prefix = name_space_prefix
                if(value_path == "protocol"):
                    self.protocol = value
                    self.protocol.value_namespace = name_space
                    self.protocol.value_namespace_prefix = name_space_prefix
                if(value_path == "session-type"):
                    self.session_type = value
                    self.session_type.value_namespace = name_space
                    self.session_type.value_namespace_prefix = name_space_prefix
                if(value_path == "source-address"):
                    self.source_address = value
                    self.source_address.value_namespace = name_space
                    self.source_address.value_namespace_prefix = name_space_prefix
                if(value_path == "source-port"):
                    self.source_port = value
                    self.source_port.value_namespace = name_space
                    self.source_port.value_namespace_prefix = name_space_prefix
                if(value_path == "sub-group-id"):
                    self.sub_group_id = value
                    self.sub_group_id.value_namespace = name_space
                    self.sub_group_id.value_namespace_prefix = name_space_prefix
                if(value_path == "sub-group-origin"):
                    self.sub_group_origin = value
                    self.sub_group_origin.value_namespace = name_space
                    self.sub_group_origin.value_namespace_prefix = name_space_prefix
                if(value_path == "vrf-name"):
                    self.vrf_name = value
                    self.vrf_name.value_namespace = name_space
                    self.vrf_name.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.psb_brief:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.psb_brief:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "psb-briefs" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "psb-brief"):
                for c in self.psb_brief:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = RsvpStandby.PsbBriefs.PsbBrief()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.psb_brief.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "psb-brief"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class GlobalNeighborBriefs(Entity):
        """
        Table of brief info about global neighbors
        
        .. attribute:: global_neighbor_brief
        
        	Brief info for a single global neighbor
        	**type**\: list of    :py:class:`GlobalNeighborBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.GlobalNeighborBriefs.GlobalNeighborBrief>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(RsvpStandby.GlobalNeighborBriefs, self).__init__()

            self.yang_name = "global-neighbor-briefs"
            self.yang_parent_name = "rsvp-standby"

            self.global_neighbor_brief = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(RsvpStandby.GlobalNeighborBriefs, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(RsvpStandby.GlobalNeighborBriefs, self).__setattr__(name, value)


        class GlobalNeighborBrief(Entity):
            """
            Brief info for a single global neighbor
            
            .. attribute:: neighbor_address  <key>
            
            	Address of global neighbor
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: global_neighbor_flags
            
            	Global Neighbor Flags
            	**type**\:   :py:class:`GlobalNeighborFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.GlobalNeighborBriefs.GlobalNeighborBrief.GlobalNeighborFlags>`
            
            .. attribute:: is_gr_enabled
            
            	Is GR enabled
            	**type**\:  bool
            
            .. attribute:: local_node_address
            
            	Local node address
            	**type**\:  list of str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: lost_communication_reason
            
            	Reason why communication was lost
            	**type**\:  list of   :py:class:`RsvpMgmtHelloDownReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtHelloDownReason>`
            
            .. attribute:: lost_communication_time
            
            	Time when communication was lost
            	**type**\: list of    :py:class:`LostCommunicationTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.GlobalNeighborBriefs.GlobalNeighborBrief.LostCommunicationTime>`
            
            .. attribute:: lost_communication_total
            
            	Total number of times communication got lost
            	**type**\:  list of int
            
            	**range:** 0..65535
            
            .. attribute:: neighbor_hello_state
            
            	Neighbor Hello state
            	**type**\:  list of   :py:class:`RsvpMgmtHelloState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtHelloState>`
            
            .. attribute:: node_address
            
            	Neighbor node address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: restart_state
            
            	Restart state
            	**type**\:   :py:class:`RsvpMgmtRestartState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtRestartState>`
            
            .. attribute:: up_time
            
            	Time hellos have been up
            	**type**\: list of    :py:class:`UpTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpStandby.GlobalNeighborBriefs.GlobalNeighborBrief.UpTime>`
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(RsvpStandby.GlobalNeighborBriefs.GlobalNeighborBrief, self).__init__()

                self.yang_name = "global-neighbor-brief"
                self.yang_parent_name = "global-neighbor-briefs"

                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                self.is_gr_enabled = YLeaf(YType.boolean, "is-gr-enabled")

                self.local_node_address = YLeafList(YType.str, "local-node-address")

                self.lost_communication_reason = YLeafList(YType.enumeration, "lost-communication-reason")

                self.lost_communication_total = YLeafList(YType.uint16, "lost-communication-total")

                self.neighbor_hello_state = YLeafList(YType.enumeration, "neighbor-hello-state")

                self.node_address = YLeaf(YType.str, "node-address")

                self.restart_state = YLeaf(YType.enumeration, "restart-state")

                self.global_neighbor_flags = RsvpStandby.GlobalNeighborBriefs.GlobalNeighborBrief.GlobalNeighborFlags()
                self.global_neighbor_flags.parent = self
                self._children_name_map["global_neighbor_flags"] = "global-neighbor-flags"
                self._children_yang_names.add("global-neighbor-flags")

                self.lost_communication_time = YList(self)
                self.up_time = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("neighbor_address",
                                "is_gr_enabled",
                                "local_node_address",
                                "lost_communication_reason",
                                "lost_communication_total",
                                "neighbor_hello_state",
                                "node_address",
                                "restart_state") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(RsvpStandby.GlobalNeighborBriefs.GlobalNeighborBrief, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(RsvpStandby.GlobalNeighborBriefs.GlobalNeighborBrief, self).__setattr__(name, value)


            class GlobalNeighborFlags(Entity):
                """
                Global Neighbor Flags
                
                .. attribute:: is_application_mpls
                
                	MPLS Application
                	**type**\:  bool
                
                .. attribute:: is_application_ouni
                
                	OUNI Application
                	**type**\:  bool
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.GlobalNeighborBriefs.GlobalNeighborBrief.GlobalNeighborFlags, self).__init__()

                    self.yang_name = "global-neighbor-flags"
                    self.yang_parent_name = "global-neighbor-brief"

                    self.is_application_mpls = YLeaf(YType.boolean, "is-application-mpls")

                    self.is_application_ouni = YLeaf(YType.boolean, "is-application-ouni")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("is_application_mpls",
                                    "is_application_ouni") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.GlobalNeighborBriefs.GlobalNeighborBrief.GlobalNeighborFlags, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.GlobalNeighborBriefs.GlobalNeighborBrief.GlobalNeighborFlags, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.is_application_mpls.is_set or
                        self.is_application_ouni.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.is_application_mpls.yfilter != YFilter.not_set or
                        self.is_application_ouni.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "global-neighbor-flags" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.is_application_mpls.is_set or self.is_application_mpls.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_application_mpls.get_name_leafdata())
                    if (self.is_application_ouni.is_set or self.is_application_ouni.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_application_ouni.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "is-application-mpls" or name == "is-application-ouni"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "is-application-mpls"):
                        self.is_application_mpls = value
                        self.is_application_mpls.value_namespace = name_space
                        self.is_application_mpls.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-application-ouni"):
                        self.is_application_ouni = value
                        self.is_application_ouni.value_namespace = name_space
                        self.is_application_ouni.value_namespace_prefix = name_space_prefix


            class UpTime(Entity):
                """
                Time hellos have been up
                
                .. attribute:: nanoseconds
                
                	Time Value in Nano\-seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: nanosecond
                
                .. attribute:: seconds
                
                	Time Value in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.GlobalNeighborBriefs.GlobalNeighborBrief.UpTime, self).__init__()

                    self.yang_name = "up-time"
                    self.yang_parent_name = "global-neighbor-brief"

                    self.nanoseconds = YLeaf(YType.int32, "nanoseconds")

                    self.seconds = YLeaf(YType.int32, "seconds")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("nanoseconds",
                                    "seconds") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.GlobalNeighborBriefs.GlobalNeighborBrief.UpTime, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.GlobalNeighborBriefs.GlobalNeighborBrief.UpTime, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.nanoseconds.is_set or
                        self.seconds.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.nanoseconds.yfilter != YFilter.not_set or
                        self.seconds.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "up-time" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.nanoseconds.is_set or self.nanoseconds.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.nanoseconds.get_name_leafdata())
                    if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.seconds.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "nanoseconds" or name == "seconds"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "nanoseconds"):
                        self.nanoseconds = value
                        self.nanoseconds.value_namespace = name_space
                        self.nanoseconds.value_namespace_prefix = name_space_prefix
                    if(value_path == "seconds"):
                        self.seconds = value
                        self.seconds.value_namespace = name_space
                        self.seconds.value_namespace_prefix = name_space_prefix


            class LostCommunicationTime(Entity):
                """
                Time when communication was lost
                
                .. attribute:: nanoseconds
                
                	Time Value in Nano\-seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: nanosecond
                
                .. attribute:: seconds
                
                	Time Value in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RsvpStandby.GlobalNeighborBriefs.GlobalNeighborBrief.LostCommunicationTime, self).__init__()

                    self.yang_name = "lost-communication-time"
                    self.yang_parent_name = "global-neighbor-brief"

                    self.nanoseconds = YLeaf(YType.int32, "nanoseconds")

                    self.seconds = YLeaf(YType.int32, "seconds")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("nanoseconds",
                                    "seconds") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(RsvpStandby.GlobalNeighborBriefs.GlobalNeighborBrief.LostCommunicationTime, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(RsvpStandby.GlobalNeighborBriefs.GlobalNeighborBrief.LostCommunicationTime, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.nanoseconds.is_set or
                        self.seconds.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.nanoseconds.yfilter != YFilter.not_set or
                        self.seconds.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "lost-communication-time" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.nanoseconds.is_set or self.nanoseconds.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.nanoseconds.get_name_leafdata())
                    if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.seconds.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "nanoseconds" or name == "seconds"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "nanoseconds"):
                        self.nanoseconds = value
                        self.nanoseconds.value_namespace = name_space
                        self.nanoseconds.value_namespace_prefix = name_space_prefix
                    if(value_path == "seconds"):
                        self.seconds = value
                        self.seconds.value_namespace = name_space
                        self.seconds.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.lost_communication_time:
                    if (c.has_data()):
                        return True
                for c in self.up_time:
                    if (c.has_data()):
                        return True
                for leaf in self.local_node_address.getYLeafs():
                    if (leaf.yfilter != YFilter.not_set):
                        return True
                for leaf in self.lost_communication_reason.getYLeafs():
                    if (leaf.yfilter != YFilter.not_set):
                        return True
                for leaf in self.lost_communication_total.getYLeafs():
                    if (leaf.yfilter != YFilter.not_set):
                        return True
                for leaf in self.neighbor_hello_state.getYLeafs():
                    if (leaf.yfilter != YFilter.not_set):
                        return True
                return (
                    self.neighbor_address.is_set or
                    self.is_gr_enabled.is_set or
                    self.node_address.is_set or
                    self.restart_state.is_set or
                    (self.global_neighbor_flags is not None and self.global_neighbor_flags.has_data()))

            def has_operation(self):
                for c in self.lost_communication_time:
                    if (c.has_operation()):
                        return True
                for c in self.up_time:
                    if (c.has_operation()):
                        return True
                for leaf in self.local_node_address.getYLeafs():
                    if (leaf.is_set):
                        return True
                for leaf in self.lost_communication_reason.getYLeafs():
                    if (leaf.is_set):
                        return True
                for leaf in self.lost_communication_total.getYLeafs():
                    if (leaf.is_set):
                        return True
                for leaf in self.neighbor_hello_state.getYLeafs():
                    if (leaf.is_set):
                        return True
                return (
                    self.yfilter != YFilter.not_set or
                    self.neighbor_address.yfilter != YFilter.not_set or
                    self.is_gr_enabled.yfilter != YFilter.not_set or
                    self.local_node_address.yfilter != YFilter.not_set or
                    self.lost_communication_reason.yfilter != YFilter.not_set or
                    self.lost_communication_total.yfilter != YFilter.not_set or
                    self.neighbor_hello_state.yfilter != YFilter.not_set or
                    self.node_address.yfilter != YFilter.not_set or
                    self.restart_state.yfilter != YFilter.not_set or
                    (self.global_neighbor_flags is not None and self.global_neighbor_flags.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "global-neighbor-brief" + "[neighbor-address='" + self.neighbor_address.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/global-neighbor-briefs/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                if (self.is_gr_enabled.is_set or self.is_gr_enabled.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.is_gr_enabled.get_name_leafdata())
                if (self.node_address.is_set or self.node_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.node_address.get_name_leafdata())
                if (self.restart_state.is_set or self.restart_state.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.restart_state.get_name_leafdata())

                leaf_name_data.extend(self.local_node_address.get_name_leafdata())

                leaf_name_data.extend(self.lost_communication_reason.get_name_leafdata())

                leaf_name_data.extend(self.lost_communication_total.get_name_leafdata())

                leaf_name_data.extend(self.neighbor_hello_state.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "global-neighbor-flags"):
                    if (self.global_neighbor_flags is None):
                        self.global_neighbor_flags = RsvpStandby.GlobalNeighborBriefs.GlobalNeighborBrief.GlobalNeighborFlags()
                        self.global_neighbor_flags.parent = self
                        self._children_name_map["global_neighbor_flags"] = "global-neighbor-flags"
                    return self.global_neighbor_flags

                if (child_yang_name == "lost-communication-time"):
                    for c in self.lost_communication_time:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = RsvpStandby.GlobalNeighborBriefs.GlobalNeighborBrief.LostCommunicationTime()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.lost_communication_time.append(c)
                    return c

                if (child_yang_name == "up-time"):
                    for c in self.up_time:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = RsvpStandby.GlobalNeighborBriefs.GlobalNeighborBrief.UpTime()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.up_time.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "global-neighbor-flags" or name == "lost-communication-time" or name == "up-time" or name == "neighbor-address" or name == "is-gr-enabled" or name == "local-node-address" or name == "lost-communication-reason" or name == "lost-communication-total" or name == "neighbor-hello-state" or name == "node-address" or name == "restart-state"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "neighbor-address"):
                    self.neighbor_address = value
                    self.neighbor_address.value_namespace = name_space
                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                if(value_path == "is-gr-enabled"):
                    self.is_gr_enabled = value
                    self.is_gr_enabled.value_namespace = name_space
                    self.is_gr_enabled.value_namespace_prefix = name_space_prefix
                if(value_path == "local-node-address"):
                    self.local_node_address.append(value)
                if(value_path == "lost-communication-reason"):
                    self.lost_communication_reason.append(value)
                if(value_path == "lost-communication-total"):
                    self.lost_communication_total.append(value)
                if(value_path == "neighbor-hello-state"):
                    self.neighbor_hello_state.append(value)
                if(value_path == "node-address"):
                    self.node_address = value
                    self.node_address.value_namespace = name_space
                    self.node_address.value_namespace_prefix = name_space_prefix
                if(value_path == "restart-state"):
                    self.restart_state = value
                    self.restart_state.value_namespace = name_space
                    self.restart_state.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.global_neighbor_brief:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.global_neighbor_brief:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "global-neighbor-briefs" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "global-neighbor-brief"):
                for c in self.global_neighbor_brief:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = RsvpStandby.GlobalNeighborBriefs.GlobalNeighborBrief()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.global_neighbor_brief.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "global-neighbor-brief"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass

    def has_data(self):
        return (
            (self.authentication_briefs is not None and self.authentication_briefs.has_data()) or
            (self.authentication_details is not None and self.authentication_details.has_data()) or
            (self.controller_briefs is not None and self.controller_briefs.has_data()) or
            (self.controller_detaileds is not None and self.controller_detaileds.has_data()) or
            (self.controller_summaries is not None and self.controller_summaries.has_data()) or
            (self.counters is not None and self.counters.has_data()) or
            (self.frr_summary is not None and self.frr_summary.has_data()) or
            (self.frrs is not None and self.frrs.has_data()) or
            (self.global_neighbor_briefs is not None and self.global_neighbor_briefs.has_data()) or
            (self.global_neighbor_details is not None and self.global_neighbor_details.has_data()) or
            (self.graceful_restart is not None and self.graceful_restart.has_data()) or
            (self.hello_instance_briefs is not None and self.hello_instance_briefs.has_data()) or
            (self.hello_instance_details is not None and self.hello_instance_details.has_data()) or
            (self.hello_interface_instance_briefs is not None and self.hello_interface_instance_briefs.has_data()) or
            (self.hello_interface_instance_details is not None and self.hello_interface_instance_details.has_data()) or
            (self.interface_briefs is not None and self.interface_briefs.has_data()) or
            (self.interface_detaileds is not None and self.interface_detaileds.has_data()) or
            (self.interface_neighbor_briefs is not None and self.interface_neighbor_briefs.has_data()) or
            (self.interface_neighbor_details is not None and self.interface_neighbor_details.has_data()) or
            (self.interface_summaries is not None and self.interface_summaries.has_data()) or
            (self.nsr is not None and self.nsr.has_data()) or
            (self.open_config is not None and self.open_config.has_data()) or
            (self.psb_briefs is not None and self.psb_briefs.has_data()) or
            (self.psb_detaileds is not None and self.psb_detaileds.has_data()) or
            (self.request_briefs is not None and self.request_briefs.has_data()) or
            (self.request_details is not None and self.request_details.has_data()) or
            (self.rsb_briefs is not None and self.rsb_briefs.has_data()) or
            (self.rsb_detaileds is not None and self.rsb_detaileds.has_data()) or
            (self.session_briefs is not None and self.session_briefs.has_data()) or
            (self.session_detaileds is not None and self.session_detaileds.has_data()) or
            (self.summary is not None and self.summary.has_data()))

    def has_operation(self):
        return (
            self.yfilter != YFilter.not_set or
            (self.authentication_briefs is not None and self.authentication_briefs.has_operation()) or
            (self.authentication_details is not None and self.authentication_details.has_operation()) or
            (self.controller_briefs is not None and self.controller_briefs.has_operation()) or
            (self.controller_detaileds is not None and self.controller_detaileds.has_operation()) or
            (self.controller_summaries is not None and self.controller_summaries.has_operation()) or
            (self.counters is not None and self.counters.has_operation()) or
            (self.frr_summary is not None and self.frr_summary.has_operation()) or
            (self.frrs is not None and self.frrs.has_operation()) or
            (self.global_neighbor_briefs is not None and self.global_neighbor_briefs.has_operation()) or
            (self.global_neighbor_details is not None and self.global_neighbor_details.has_operation()) or
            (self.graceful_restart is not None and self.graceful_restart.has_operation()) or
            (self.hello_instance_briefs is not None and self.hello_instance_briefs.has_operation()) or
            (self.hello_instance_details is not None and self.hello_instance_details.has_operation()) or
            (self.hello_interface_instance_briefs is not None and self.hello_interface_instance_briefs.has_operation()) or
            (self.hello_interface_instance_details is not None and self.hello_interface_instance_details.has_operation()) or
            (self.interface_briefs is not None and self.interface_briefs.has_operation()) or
            (self.interface_detaileds is not None and self.interface_detaileds.has_operation()) or
            (self.interface_neighbor_briefs is not None and self.interface_neighbor_briefs.has_operation()) or
            (self.interface_neighbor_details is not None and self.interface_neighbor_details.has_operation()) or
            (self.interface_summaries is not None and self.interface_summaries.has_operation()) or
            (self.nsr is not None and self.nsr.has_operation()) or
            (self.open_config is not None and self.open_config.has_operation()) or
            (self.psb_briefs is not None and self.psb_briefs.has_operation()) or
            (self.psb_detaileds is not None and self.psb_detaileds.has_operation()) or
            (self.request_briefs is not None and self.request_briefs.has_operation()) or
            (self.request_details is not None and self.request_details.has_operation()) or
            (self.rsb_briefs is not None and self.rsb_briefs.has_operation()) or
            (self.rsb_detaileds is not None and self.rsb_detaileds.has_operation()) or
            (self.session_briefs is not None and self.session_briefs.has_operation()) or
            (self.session_detaileds is not None and self.session_detaileds.has_operation()) or
            (self.summary is not None and self.summary.has_operation()))

    def get_segment_path(self):
        path_buffer = ""
        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp-standby" + path_buffer

        return path_buffer

    def get_entity_path(self, ancestor):
        path_buffer = ""
        if (not ancestor is None):
            raise YPYModelError("ancestor has to be None for top-level node")

        path_buffer = self.get_segment_path()
        leaf_name_data = LeafDataList()

        entity_path = EntityPath(path_buffer, leaf_name_data)
        return entity_path

    def get_child_by_name(self, child_yang_name, segment_path):
        child = self._get_child_by_seg_name([child_yang_name, segment_path])
        if child is not None:
            return child

        if (child_yang_name == "authentication-briefs"):
            if (self.authentication_briefs is None):
                self.authentication_briefs = RsvpStandby.AuthenticationBriefs()
                self.authentication_briefs.parent = self
                self._children_name_map["authentication_briefs"] = "authentication-briefs"
            return self.authentication_briefs

        if (child_yang_name == "authentication-details"):
            if (self.authentication_details is None):
                self.authentication_details = RsvpStandby.AuthenticationDetails()
                self.authentication_details.parent = self
                self._children_name_map["authentication_details"] = "authentication-details"
            return self.authentication_details

        if (child_yang_name == "controller-briefs"):
            if (self.controller_briefs is None):
                self.controller_briefs = RsvpStandby.ControllerBriefs()
                self.controller_briefs.parent = self
                self._children_name_map["controller_briefs"] = "controller-briefs"
            return self.controller_briefs

        if (child_yang_name == "controller-detaileds"):
            if (self.controller_detaileds is None):
                self.controller_detaileds = RsvpStandby.ControllerDetaileds()
                self.controller_detaileds.parent = self
                self._children_name_map["controller_detaileds"] = "controller-detaileds"
            return self.controller_detaileds

        if (child_yang_name == "controller-summaries"):
            if (self.controller_summaries is None):
                self.controller_summaries = RsvpStandby.ControllerSummaries()
                self.controller_summaries.parent = self
                self._children_name_map["controller_summaries"] = "controller-summaries"
            return self.controller_summaries

        if (child_yang_name == "counters"):
            if (self.counters is None):
                self.counters = RsvpStandby.Counters()
                self.counters.parent = self
                self._children_name_map["counters"] = "counters"
            return self.counters

        if (child_yang_name == "frr-summary"):
            if (self.frr_summary is None):
                self.frr_summary = RsvpStandby.FrrSummary()
                self.frr_summary.parent = self
                self._children_name_map["frr_summary"] = "frr-summary"
            return self.frr_summary

        if (child_yang_name == "frrs"):
            if (self.frrs is None):
                self.frrs = RsvpStandby.Frrs()
                self.frrs.parent = self
                self._children_name_map["frrs"] = "frrs"
            return self.frrs

        if (child_yang_name == "global-neighbor-briefs"):
            if (self.global_neighbor_briefs is None):
                self.global_neighbor_briefs = RsvpStandby.GlobalNeighborBriefs()
                self.global_neighbor_briefs.parent = self
                self._children_name_map["global_neighbor_briefs"] = "global-neighbor-briefs"
            return self.global_neighbor_briefs

        if (child_yang_name == "global-neighbor-details"):
            if (self.global_neighbor_details is None):
                self.global_neighbor_details = RsvpStandby.GlobalNeighborDetails()
                self.global_neighbor_details.parent = self
                self._children_name_map["global_neighbor_details"] = "global-neighbor-details"
            return self.global_neighbor_details

        if (child_yang_name == "graceful-restart"):
            if (self.graceful_restart is None):
                self.graceful_restart = RsvpStandby.GracefulRestart()
                self.graceful_restart.parent = self
                self._children_name_map["graceful_restart"] = "graceful-restart"
            return self.graceful_restart

        if (child_yang_name == "hello-instance-briefs"):
            if (self.hello_instance_briefs is None):
                self.hello_instance_briefs = RsvpStandby.HelloInstanceBriefs()
                self.hello_instance_briefs.parent = self
                self._children_name_map["hello_instance_briefs"] = "hello-instance-briefs"
            return self.hello_instance_briefs

        if (child_yang_name == "hello-instance-details"):
            if (self.hello_instance_details is None):
                self.hello_instance_details = RsvpStandby.HelloInstanceDetails()
                self.hello_instance_details.parent = self
                self._children_name_map["hello_instance_details"] = "hello-instance-details"
            return self.hello_instance_details

        if (child_yang_name == "hello-interface-instance-briefs"):
            if (self.hello_interface_instance_briefs is None):
                self.hello_interface_instance_briefs = RsvpStandby.HelloInterfaceInstanceBriefs()
                self.hello_interface_instance_briefs.parent = self
                self._children_name_map["hello_interface_instance_briefs"] = "hello-interface-instance-briefs"
            return self.hello_interface_instance_briefs

        if (child_yang_name == "hello-interface-instance-details"):
            if (self.hello_interface_instance_details is None):
                self.hello_interface_instance_details = RsvpStandby.HelloInterfaceInstanceDetails()
                self.hello_interface_instance_details.parent = self
                self._children_name_map["hello_interface_instance_details"] = "hello-interface-instance-details"
            return self.hello_interface_instance_details

        if (child_yang_name == "interface-briefs"):
            if (self.interface_briefs is None):
                self.interface_briefs = RsvpStandby.InterfaceBriefs()
                self.interface_briefs.parent = self
                self._children_name_map["interface_briefs"] = "interface-briefs"
            return self.interface_briefs

        if (child_yang_name == "interface-detaileds"):
            if (self.interface_detaileds is None):
                self.interface_detaileds = RsvpStandby.InterfaceDetaileds()
                self.interface_detaileds.parent = self
                self._children_name_map["interface_detaileds"] = "interface-detaileds"
            return self.interface_detaileds

        if (child_yang_name == "interface-neighbor-briefs"):
            if (self.interface_neighbor_briefs is None):
                self.interface_neighbor_briefs = RsvpStandby.InterfaceNeighborBriefs()
                self.interface_neighbor_briefs.parent = self
                self._children_name_map["interface_neighbor_briefs"] = "interface-neighbor-briefs"
            return self.interface_neighbor_briefs

        if (child_yang_name == "interface-neighbor-details"):
            if (self.interface_neighbor_details is None):
                self.interface_neighbor_details = RsvpStandby.InterfaceNeighborDetails()
                self.interface_neighbor_details.parent = self
                self._children_name_map["interface_neighbor_details"] = "interface-neighbor-details"
            return self.interface_neighbor_details

        if (child_yang_name == "interface-summaries"):
            if (self.interface_summaries is None):
                self.interface_summaries = RsvpStandby.InterfaceSummaries()
                self.interface_summaries.parent = self
                self._children_name_map["interface_summaries"] = "interface-summaries"
            return self.interface_summaries

        if (child_yang_name == "nsr"):
            if (self.nsr is None):
                self.nsr = RsvpStandby.Nsr()
                self.nsr.parent = self
                self._children_name_map["nsr"] = "nsr"
            return self.nsr

        if (child_yang_name == "open-config"):
            if (self.open_config is None):
                self.open_config = RsvpStandby.OpenConfig()
                self.open_config.parent = self
                self._children_name_map["open_config"] = "open-config"
            return self.open_config

        if (child_yang_name == "psb-briefs"):
            if (self.psb_briefs is None):
                self.psb_briefs = RsvpStandby.PsbBriefs()
                self.psb_briefs.parent = self
                self._children_name_map["psb_briefs"] = "psb-briefs"
            return self.psb_briefs

        if (child_yang_name == "psb-detaileds"):
            if (self.psb_detaileds is None):
                self.psb_detaileds = RsvpStandby.PsbDetaileds()
                self.psb_detaileds.parent = self
                self._children_name_map["psb_detaileds"] = "psb-detaileds"
            return self.psb_detaileds

        if (child_yang_name == "request-briefs"):
            if (self.request_briefs is None):
                self.request_briefs = RsvpStandby.RequestBriefs()
                self.request_briefs.parent = self
                self._children_name_map["request_briefs"] = "request-briefs"
            return self.request_briefs

        if (child_yang_name == "request-details"):
            if (self.request_details is None):
                self.request_details = RsvpStandby.RequestDetails()
                self.request_details.parent = self
                self._children_name_map["request_details"] = "request-details"
            return self.request_details

        if (child_yang_name == "rsb-briefs"):
            if (self.rsb_briefs is None):
                self.rsb_briefs = RsvpStandby.RsbBriefs()
                self.rsb_briefs.parent = self
                self._children_name_map["rsb_briefs"] = "rsb-briefs"
            return self.rsb_briefs

        if (child_yang_name == "rsb-detaileds"):
            if (self.rsb_detaileds is None):
                self.rsb_detaileds = RsvpStandby.RsbDetaileds()
                self.rsb_detaileds.parent = self
                self._children_name_map["rsb_detaileds"] = "rsb-detaileds"
            return self.rsb_detaileds

        if (child_yang_name == "session-briefs"):
            if (self.session_briefs is None):
                self.session_briefs = RsvpStandby.SessionBriefs()
                self.session_briefs.parent = self
                self._children_name_map["session_briefs"] = "session-briefs"
            return self.session_briefs

        if (child_yang_name == "session-detaileds"):
            if (self.session_detaileds is None):
                self.session_detaileds = RsvpStandby.SessionDetaileds()
                self.session_detaileds.parent = self
                self._children_name_map["session_detaileds"] = "session-detaileds"
            return self.session_detaileds

        if (child_yang_name == "summary"):
            if (self.summary is None):
                self.summary = RsvpStandby.Summary()
                self.summary.parent = self
                self._children_name_map["summary"] = "summary"
            return self.summary

        return None

    def has_leaf_or_child_of_name(self, name):
        if(name == "authentication-briefs" or name == "authentication-details" or name == "controller-briefs" or name == "controller-detaileds" or name == "controller-summaries" or name == "counters" or name == "frr-summary" or name == "frrs" or name == "global-neighbor-briefs" or name == "global-neighbor-details" or name == "graceful-restart" or name == "hello-instance-briefs" or name == "hello-instance-details" or name == "hello-interface-instance-briefs" or name == "hello-interface-instance-details" or name == "interface-briefs" or name == "interface-detaileds" or name == "interface-neighbor-briefs" or name == "interface-neighbor-details" or name == "interface-summaries" or name == "nsr" or name == "open-config" or name == "psb-briefs" or name == "psb-detaileds" or name == "request-briefs" or name == "request-details" or name == "rsb-briefs" or name == "rsb-detaileds" or name == "session-briefs" or name == "session-detaileds" or name == "summary"):
            return True
        return False

    def set_value(self, value_path, value, name_space, name_space_prefix):
        pass

    def clone_ptr(self):
        self._top_entity = RsvpStandby()
        return self._top_entity

class Rsvp(Entity):
    """
    rsvp
    
    .. attribute:: authentication_briefs
    
    	Table for Authentication related information
    	**type**\:   :py:class:`AuthenticationBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.AuthenticationBriefs>`
    
    .. attribute:: authentication_details
    
    	Table for detailed authentication related information
    	**type**\:   :py:class:`AuthenticationDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.AuthenticationDetails>`
    
    .. attribute:: bw_pool_info
    
    	All B/W Pool info
    	**type**\:   :py:class:`BwPoolInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.BwPoolInfo>`
    
    .. attribute:: controller_briefs
    
    	Table of brief info about RSVP\-enabled controller
    	**type**\:   :py:class:`ControllerBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.ControllerBriefs>`
    
    .. attribute:: controller_detaileds
    
    	Table of detailed info about RSVP\-enabled controllers
    	**type**\:   :py:class:`ControllerDetaileds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.ControllerDetaileds>`
    
    .. attribute:: controller_summaries
    
    	Table of summary info about RSVP\-enabled controllers
    	**type**\:   :py:class:`ControllerSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.ControllerSummaries>`
    
    .. attribute:: counters
    
    	Counters
    	**type**\:   :py:class:`Counters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Counters>`
    
    .. attribute:: frr_summary
    
    	Fast Re\-Route Summary State Information
    	**type**\:   :py:class:`FrrSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.FrrSummary>`
    
    .. attribute:: frrs
    
    	Table of detailed info about Fast Re\-route states
    	**type**\:   :py:class:`Frrs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Frrs>`
    
    .. attribute:: global_neighbor_briefs
    
    	Table of brief info about global neighbors
    	**type**\:   :py:class:`GlobalNeighborBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.GlobalNeighborBriefs>`
    
    .. attribute:: global_neighbor_details
    
    	Table of detailed info about global neighbors
    	**type**\:   :py:class:`GlobalNeighborDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.GlobalNeighborDetails>`
    
    .. attribute:: graceful_restart
    
    	Info about graceful\-restart
    	**type**\:   :py:class:`GracefulRestart <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.GracefulRestart>`
    
    .. attribute:: hello_instance_briefs
    
    	Table of brief info about hello instances
    	**type**\:   :py:class:`HelloInstanceBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.HelloInstanceBriefs>`
    
    .. attribute:: hello_instance_details
    
    	Table of detailed info about hello instances
    	**type**\:   :py:class:`HelloInstanceDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.HelloInstanceDetails>`
    
    .. attribute:: hello_interface_instance_briefs
    
    	Table of brief info about i/f\-based hello instances
    	**type**\:   :py:class:`HelloInterfaceInstanceBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.HelloInterfaceInstanceBriefs>`
    
    .. attribute:: hello_interface_instance_details
    
    	Table of detailed info about i/f\-based hello instances
    	**type**\:   :py:class:`HelloInterfaceInstanceDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.HelloInterfaceInstanceDetails>`
    
    .. attribute:: interface_briefs
    
    	Table of brief info about RSVP\-enabled interfaces
    	**type**\:   :py:class:`InterfaceBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.InterfaceBriefs>`
    
    .. attribute:: interface_detaileds
    
    	Table of detailed info about RSVP\-enabled interfaces
    	**type**\:   :py:class:`InterfaceDetaileds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.InterfaceDetaileds>`
    
    .. attribute:: interface_neighbor_briefs
    
    	Table of brief info about I/F neighbors
    	**type**\:   :py:class:`InterfaceNeighborBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.InterfaceNeighborBriefs>`
    
    .. attribute:: interface_neighbor_details
    
    	Table of detailed info about I/F neighbors
    	**type**\:   :py:class:`InterfaceNeighborDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.InterfaceNeighborDetails>`
    
    .. attribute:: interface_summaries
    
    	Table of summary info about RSVP\-enabled interfaces
    	**type**\:   :py:class:`InterfaceSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.InterfaceSummaries>`
    
    .. attribute:: issu
    
    	RSVP ISSU information
    	**type**\:   :py:class:`Issu <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Issu>`
    
    .. attribute:: nsr
    
    	RSVP NSR information
    	**type**\:   :py:class:`Nsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Nsr>`
    
    .. attribute:: open_config
    
    	OpenConfig info
    	**type**\:   :py:class:`OpenConfig <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.OpenConfig>`
    
    .. attribute:: psb_briefs
    
    	Table of brief info about path state blocks
    	**type**\:   :py:class:`PsbBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbBriefs>`
    
    .. attribute:: psb_detaileds
    
    	Table of detailed info about path state blocks
    	**type**\:   :py:class:`PsbDetaileds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbDetaileds>`
    
    .. attribute:: pxsb_details
    
    	Table of detailed PXSB info
    	**type**\:   :py:class:`PxsbDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PxsbDetails>`
    
    .. attribute:: request_briefs
    
    	Table of brief info about requests
    	**type**\:   :py:class:`RequestBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RequestBriefs>`
    
    .. attribute:: request_details
    
    	Table of detail info about requests
    	**type**\:   :py:class:`RequestDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RequestDetails>`
    
    .. attribute:: rsb_briefs
    
    	Table of brief info about reservation state blocks
    	**type**\:   :py:class:`RsbBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RsbBriefs>`
    
    .. attribute:: rsb_detaileds
    
    	Table of detailed info about reservation state blocks
    	**type**\:   :py:class:`RsbDetaileds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RsbDetaileds>`
    
    .. attribute:: rxsb_details
    
    	Table of detailed RXSB info
    	**type**\:   :py:class:`RxsbDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RxsbDetails>`
    
    .. attribute:: session_briefs
    
    	Table of brief info about sessions
    	**type**\:   :py:class:`SessionBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionBriefs>`
    
    .. attribute:: session_detaileds
    
    	Table of detailed info about sessions
    	**type**\:   :py:class:`SessionDetaileds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds>`
    
    .. attribute:: summary
    
    	RSVP summary information
    	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Summary>`
    
    

    """

    _prefix = 'ip-rsvp-oper'
    _revision = '2015-11-09'

    def __init__(self):
        super(Rsvp, self).__init__()
        self._top_entity = None

        self.yang_name = "rsvp"
        self.yang_parent_name = "Cisco-IOS-XR-ip-rsvp-oper"

        self.authentication_briefs = Rsvp.AuthenticationBriefs()
        self.authentication_briefs.parent = self
        self._children_name_map["authentication_briefs"] = "authentication-briefs"
        self._children_yang_names.add("authentication-briefs")

        self.authentication_details = Rsvp.AuthenticationDetails()
        self.authentication_details.parent = self
        self._children_name_map["authentication_details"] = "authentication-details"
        self._children_yang_names.add("authentication-details")

        self.bw_pool_info = Rsvp.BwPoolInfo()
        self.bw_pool_info.parent = self
        self._children_name_map["bw_pool_info"] = "bw-pool-info"
        self._children_yang_names.add("bw-pool-info")

        self.controller_briefs = Rsvp.ControllerBriefs()
        self.controller_briefs.parent = self
        self._children_name_map["controller_briefs"] = "controller-briefs"
        self._children_yang_names.add("controller-briefs")

        self.controller_detaileds = Rsvp.ControllerDetaileds()
        self.controller_detaileds.parent = self
        self._children_name_map["controller_detaileds"] = "controller-detaileds"
        self._children_yang_names.add("controller-detaileds")

        self.controller_summaries = Rsvp.ControllerSummaries()
        self.controller_summaries.parent = self
        self._children_name_map["controller_summaries"] = "controller-summaries"
        self._children_yang_names.add("controller-summaries")

        self.counters = Rsvp.Counters()
        self.counters.parent = self
        self._children_name_map["counters"] = "counters"
        self._children_yang_names.add("counters")

        self.frr_summary = Rsvp.FrrSummary()
        self.frr_summary.parent = self
        self._children_name_map["frr_summary"] = "frr-summary"
        self._children_yang_names.add("frr-summary")

        self.frrs = Rsvp.Frrs()
        self.frrs.parent = self
        self._children_name_map["frrs"] = "frrs"
        self._children_yang_names.add("frrs")

        self.global_neighbor_briefs = Rsvp.GlobalNeighborBriefs()
        self.global_neighbor_briefs.parent = self
        self._children_name_map["global_neighbor_briefs"] = "global-neighbor-briefs"
        self._children_yang_names.add("global-neighbor-briefs")

        self.global_neighbor_details = Rsvp.GlobalNeighborDetails()
        self.global_neighbor_details.parent = self
        self._children_name_map["global_neighbor_details"] = "global-neighbor-details"
        self._children_yang_names.add("global-neighbor-details")

        self.graceful_restart = Rsvp.GracefulRestart()
        self.graceful_restart.parent = self
        self._children_name_map["graceful_restart"] = "graceful-restart"
        self._children_yang_names.add("graceful-restart")

        self.hello_instance_briefs = Rsvp.HelloInstanceBriefs()
        self.hello_instance_briefs.parent = self
        self._children_name_map["hello_instance_briefs"] = "hello-instance-briefs"
        self._children_yang_names.add("hello-instance-briefs")

        self.hello_instance_details = Rsvp.HelloInstanceDetails()
        self.hello_instance_details.parent = self
        self._children_name_map["hello_instance_details"] = "hello-instance-details"
        self._children_yang_names.add("hello-instance-details")

        self.hello_interface_instance_briefs = Rsvp.HelloInterfaceInstanceBriefs()
        self.hello_interface_instance_briefs.parent = self
        self._children_name_map["hello_interface_instance_briefs"] = "hello-interface-instance-briefs"
        self._children_yang_names.add("hello-interface-instance-briefs")

        self.hello_interface_instance_details = Rsvp.HelloInterfaceInstanceDetails()
        self.hello_interface_instance_details.parent = self
        self._children_name_map["hello_interface_instance_details"] = "hello-interface-instance-details"
        self._children_yang_names.add("hello-interface-instance-details")

        self.interface_briefs = Rsvp.InterfaceBriefs()
        self.interface_briefs.parent = self
        self._children_name_map["interface_briefs"] = "interface-briefs"
        self._children_yang_names.add("interface-briefs")

        self.interface_detaileds = Rsvp.InterfaceDetaileds()
        self.interface_detaileds.parent = self
        self._children_name_map["interface_detaileds"] = "interface-detaileds"
        self._children_yang_names.add("interface-detaileds")

        self.interface_neighbor_briefs = Rsvp.InterfaceNeighborBriefs()
        self.interface_neighbor_briefs.parent = self
        self._children_name_map["interface_neighbor_briefs"] = "interface-neighbor-briefs"
        self._children_yang_names.add("interface-neighbor-briefs")

        self.interface_neighbor_details = Rsvp.InterfaceNeighborDetails()
        self.interface_neighbor_details.parent = self
        self._children_name_map["interface_neighbor_details"] = "interface-neighbor-details"
        self._children_yang_names.add("interface-neighbor-details")

        self.interface_summaries = Rsvp.InterfaceSummaries()
        self.interface_summaries.parent = self
        self._children_name_map["interface_summaries"] = "interface-summaries"
        self._children_yang_names.add("interface-summaries")

        self.issu = Rsvp.Issu()
        self.issu.parent = self
        self._children_name_map["issu"] = "issu"
        self._children_yang_names.add("issu")

        self.nsr = Rsvp.Nsr()
        self.nsr.parent = self
        self._children_name_map["nsr"] = "nsr"
        self._children_yang_names.add("nsr")

        self.open_config = Rsvp.OpenConfig()
        self.open_config.parent = self
        self._children_name_map["open_config"] = "open-config"
        self._children_yang_names.add("open-config")

        self.psb_briefs = Rsvp.PsbBriefs()
        self.psb_briefs.parent = self
        self._children_name_map["psb_briefs"] = "psb-briefs"
        self._children_yang_names.add("psb-briefs")

        self.psb_detaileds = Rsvp.PsbDetaileds()
        self.psb_detaileds.parent = self
        self._children_name_map["psb_detaileds"] = "psb-detaileds"
        self._children_yang_names.add("psb-detaileds")

        self.pxsb_details = Rsvp.PxsbDetails()
        self.pxsb_details.parent = self
        self._children_name_map["pxsb_details"] = "pxsb-details"
        self._children_yang_names.add("pxsb-details")

        self.request_briefs = Rsvp.RequestBriefs()
        self.request_briefs.parent = self
        self._children_name_map["request_briefs"] = "request-briefs"
        self._children_yang_names.add("request-briefs")

        self.request_details = Rsvp.RequestDetails()
        self.request_details.parent = self
        self._children_name_map["request_details"] = "request-details"
        self._children_yang_names.add("request-details")

        self.rsb_briefs = Rsvp.RsbBriefs()
        self.rsb_briefs.parent = self
        self._children_name_map["rsb_briefs"] = "rsb-briefs"
        self._children_yang_names.add("rsb-briefs")

        self.rsb_detaileds = Rsvp.RsbDetaileds()
        self.rsb_detaileds.parent = self
        self._children_name_map["rsb_detaileds"] = "rsb-detaileds"
        self._children_yang_names.add("rsb-detaileds")

        self.rxsb_details = Rsvp.RxsbDetails()
        self.rxsb_details.parent = self
        self._children_name_map["rxsb_details"] = "rxsb-details"
        self._children_yang_names.add("rxsb-details")

        self.session_briefs = Rsvp.SessionBriefs()
        self.session_briefs.parent = self
        self._children_name_map["session_briefs"] = "session-briefs"
        self._children_yang_names.add("session-briefs")

        self.session_detaileds = Rsvp.SessionDetaileds()
        self.session_detaileds.parent = self
        self._children_name_map["session_detaileds"] = "session-detaileds"
        self._children_yang_names.add("session-detaileds")

        self.summary = Rsvp.Summary()
        self.summary.parent = self
        self._children_name_map["summary"] = "summary"
        self._children_yang_names.add("summary")


    class Issu(Entity):
        """
        RSVP ISSU information
        
        .. attribute:: status
        
        	RSVP ISSU status information
        	**type**\:   :py:class:`Status <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Issu.Status>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Rsvp.Issu, self).__init__()

            self.yang_name = "issu"
            self.yang_parent_name = "rsvp"

            self.status = Rsvp.Issu.Status()
            self.status.parent = self
            self._children_name_map["status"] = "status"
            self._children_yang_names.add("status")


        class Status(Entity):
            """
            RSVP ISSU status information
            
            .. attribute:: idt_status
            
            	IDT status
            	**type**\:   :py:class:`IdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Issu.Status.IdtStatus>`
            
            .. attribute:: previous_idt_status
            
            	Previous IDT status
            	**type**\:   :py:class:`PreviousIdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Issu.Status.PreviousIdtStatus>`
            
            .. attribute:: role
            
            	Process role
            	**type**\:   :py:class:`RsvpProcRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpProcRole>`
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Rsvp.Issu.Status, self).__init__()

                self.yang_name = "status"
                self.yang_parent_name = "issu"

                self.role = YLeaf(YType.enumeration, "role")

                self.idt_status = Rsvp.Issu.Status.IdtStatus()
                self.idt_status.parent = self
                self._children_name_map["idt_status"] = "idt-status"
                self._children_yang_names.add("idt-status")

                self.previous_idt_status = Rsvp.Issu.Status.PreviousIdtStatus()
                self.previous_idt_status.parent = self
                self._children_name_map["previous_idt_status"] = "previous-idt-status"
                self._children_yang_names.add("previous-idt-status")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("role") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Rsvp.Issu.Status, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Rsvp.Issu.Status, self).__setattr__(name, value)


            class IdtStatus(Entity):
                """
                IDT status
                
                .. attribute:: declare_time
                
                	Declare ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_end_time
                
                	IDT end timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_start_time
                
                	IDT start timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: not_ready_reason
                
                	Not ready reason
                	**type**\:   :py:class:`RsvpProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpProcNsrNotReadyReason>`
                
                .. attribute:: sync_status
                
                	Sync status
                	**type**\:   :py:class:`RsvpSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpSyncStatus>`
                
                .. attribute:: withdraw_time
                
                	Withdraw ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.Issu.Status.IdtStatus, self).__init__()

                    self.yang_name = "idt-status"
                    self.yang_parent_name = "status"

                    self.declare_time = YLeaf(YType.uint32, "declare-time")

                    self.idt_end_time = YLeaf(YType.uint32, "idt-end-time")

                    self.idt_start_time = YLeaf(YType.uint32, "idt-start-time")

                    self.not_ready_reason = YLeaf(YType.enumeration, "not-ready-reason")

                    self.sync_status = YLeaf(YType.enumeration, "sync-status")

                    self.withdraw_time = YLeaf(YType.uint32, "withdraw-time")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("declare_time",
                                    "idt_end_time",
                                    "idt_start_time",
                                    "not_ready_reason",
                                    "sync_status",
                                    "withdraw_time") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.Issu.Status.IdtStatus, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.Issu.Status.IdtStatus, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.declare_time.is_set or
                        self.idt_end_time.is_set or
                        self.idt_start_time.is_set or
                        self.not_ready_reason.is_set or
                        self.sync_status.is_set or
                        self.withdraw_time.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.declare_time.yfilter != YFilter.not_set or
                        self.idt_end_time.yfilter != YFilter.not_set or
                        self.idt_start_time.yfilter != YFilter.not_set or
                        self.not_ready_reason.yfilter != YFilter.not_set or
                        self.sync_status.yfilter != YFilter.not_set or
                        self.withdraw_time.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "idt-status" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/issu/status/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.declare_time.is_set or self.declare_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.declare_time.get_name_leafdata())
                    if (self.idt_end_time.is_set or self.idt_end_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.idt_end_time.get_name_leafdata())
                    if (self.idt_start_time.is_set or self.idt_start_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.idt_start_time.get_name_leafdata())
                    if (self.not_ready_reason.is_set or self.not_ready_reason.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.not_ready_reason.get_name_leafdata())
                    if (self.sync_status.is_set or self.sync_status.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sync_status.get_name_leafdata())
                    if (self.withdraw_time.is_set or self.withdraw_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.withdraw_time.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "declare-time" or name == "idt-end-time" or name == "idt-start-time" or name == "not-ready-reason" or name == "sync-status" or name == "withdraw-time"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "declare-time"):
                        self.declare_time = value
                        self.declare_time.value_namespace = name_space
                        self.declare_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "idt-end-time"):
                        self.idt_end_time = value
                        self.idt_end_time.value_namespace = name_space
                        self.idt_end_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "idt-start-time"):
                        self.idt_start_time = value
                        self.idt_start_time.value_namespace = name_space
                        self.idt_start_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "not-ready-reason"):
                        self.not_ready_reason = value
                        self.not_ready_reason.value_namespace = name_space
                        self.not_ready_reason.value_namespace_prefix = name_space_prefix
                    if(value_path == "sync-status"):
                        self.sync_status = value
                        self.sync_status.value_namespace = name_space
                        self.sync_status.value_namespace_prefix = name_space_prefix
                    if(value_path == "withdraw-time"):
                        self.withdraw_time = value
                        self.withdraw_time.value_namespace = name_space
                        self.withdraw_time.value_namespace_prefix = name_space_prefix


            class PreviousIdtStatus(Entity):
                """
                Previous IDT status
                
                .. attribute:: declare_time
                
                	Declare ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_end_time
                
                	IDT end timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_start_time
                
                	IDT start timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: not_ready_reason
                
                	Not ready reason
                	**type**\:   :py:class:`RsvpProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpProcNsrNotReadyReason>`
                
                .. attribute:: sync_status
                
                	Sync status
                	**type**\:   :py:class:`RsvpSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpSyncStatus>`
                
                .. attribute:: withdraw_time
                
                	Withdraw ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.Issu.Status.PreviousIdtStatus, self).__init__()

                    self.yang_name = "previous-idt-status"
                    self.yang_parent_name = "status"

                    self.declare_time = YLeaf(YType.uint32, "declare-time")

                    self.idt_end_time = YLeaf(YType.uint32, "idt-end-time")

                    self.idt_start_time = YLeaf(YType.uint32, "idt-start-time")

                    self.not_ready_reason = YLeaf(YType.enumeration, "not-ready-reason")

                    self.sync_status = YLeaf(YType.enumeration, "sync-status")

                    self.withdraw_time = YLeaf(YType.uint32, "withdraw-time")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("declare_time",
                                    "idt_end_time",
                                    "idt_start_time",
                                    "not_ready_reason",
                                    "sync_status",
                                    "withdraw_time") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.Issu.Status.PreviousIdtStatus, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.Issu.Status.PreviousIdtStatus, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.declare_time.is_set or
                        self.idt_end_time.is_set or
                        self.idt_start_time.is_set or
                        self.not_ready_reason.is_set or
                        self.sync_status.is_set or
                        self.withdraw_time.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.declare_time.yfilter != YFilter.not_set or
                        self.idt_end_time.yfilter != YFilter.not_set or
                        self.idt_start_time.yfilter != YFilter.not_set or
                        self.not_ready_reason.yfilter != YFilter.not_set or
                        self.sync_status.yfilter != YFilter.not_set or
                        self.withdraw_time.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "previous-idt-status" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/issu/status/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.declare_time.is_set or self.declare_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.declare_time.get_name_leafdata())
                    if (self.idt_end_time.is_set or self.idt_end_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.idt_end_time.get_name_leafdata())
                    if (self.idt_start_time.is_set or self.idt_start_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.idt_start_time.get_name_leafdata())
                    if (self.not_ready_reason.is_set or self.not_ready_reason.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.not_ready_reason.get_name_leafdata())
                    if (self.sync_status.is_set or self.sync_status.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sync_status.get_name_leafdata())
                    if (self.withdraw_time.is_set or self.withdraw_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.withdraw_time.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "declare-time" or name == "idt-end-time" or name == "idt-start-time" or name == "not-ready-reason" or name == "sync-status" or name == "withdraw-time"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "declare-time"):
                        self.declare_time = value
                        self.declare_time.value_namespace = name_space
                        self.declare_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "idt-end-time"):
                        self.idt_end_time = value
                        self.idt_end_time.value_namespace = name_space
                        self.idt_end_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "idt-start-time"):
                        self.idt_start_time = value
                        self.idt_start_time.value_namespace = name_space
                        self.idt_start_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "not-ready-reason"):
                        self.not_ready_reason = value
                        self.not_ready_reason.value_namespace = name_space
                        self.not_ready_reason.value_namespace_prefix = name_space_prefix
                    if(value_path == "sync-status"):
                        self.sync_status = value
                        self.sync_status.value_namespace = name_space
                        self.sync_status.value_namespace_prefix = name_space_prefix
                    if(value_path == "withdraw-time"):
                        self.withdraw_time = value
                        self.withdraw_time.value_namespace = name_space
                        self.withdraw_time.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.role.is_set or
                    (self.idt_status is not None and self.idt_status.has_data()) or
                    (self.previous_idt_status is not None and self.previous_idt_status.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.role.yfilter != YFilter.not_set or
                    (self.idt_status is not None and self.idt_status.has_operation()) or
                    (self.previous_idt_status is not None and self.previous_idt_status.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "status" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/issu/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.role.is_set or self.role.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.role.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "idt-status"):
                    if (self.idt_status is None):
                        self.idt_status = Rsvp.Issu.Status.IdtStatus()
                        self.idt_status.parent = self
                        self._children_name_map["idt_status"] = "idt-status"
                    return self.idt_status

                if (child_yang_name == "previous-idt-status"):
                    if (self.previous_idt_status is None):
                        self.previous_idt_status = Rsvp.Issu.Status.PreviousIdtStatus()
                        self.previous_idt_status.parent = self
                        self._children_name_map["previous_idt_status"] = "previous-idt-status"
                    return self.previous_idt_status

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "idt-status" or name == "previous-idt-status" or name == "role"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "role"):
                    self.role = value
                    self.role.value_namespace = name_space
                    self.role.value_namespace_prefix = name_space_prefix

        def has_data(self):
            return (self.status is not None and self.status.has_data())

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.status is not None and self.status.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "issu" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "status"):
                if (self.status is None):
                    self.status = Rsvp.Issu.Status()
                    self.status.parent = self
                    self._children_name_map["status"] = "status"
                return self.status

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "status"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class BwPoolInfo(Entity):
        """
        All B/W Pool info
        
        .. attribute:: bandwidth_configuration_model
        
        	Bandwith configuration model currently in use (MAM/RDM)
        	**type**\:   :py:class:`IgpteLibBwModel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.IgpteLibBwModel>`
        
        .. attribute:: bc0_percent
        
        	BC0 I/F percent B/W
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        	**units**\: percentage
        
        .. attribute:: bc1_percent
        
        	BC1 I/F percent B/W
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        	**units**\: percentage
        
        .. attribute:: is_bc0_percent_configured
        
        	Is BC0 default I/F percent configured
        	**type**\:  bool
        
        .. attribute:: is_bc1_percent_configured
        
        	Is BC1 default I/F percent configured
        	**type**\:  bool
        
        .. attribute:: is_max_res_pool_percent_configured
        
        	Is maximum reservable default I/F percent configured
        	**type**\:  bool
        
        .. attribute:: max_res_pool_percent
        
        	Maxium reservable I/F percent B/W
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        	**units**\: percentage
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Rsvp.BwPoolInfo, self).__init__()

            self.yang_name = "bw-pool-info"
            self.yang_parent_name = "rsvp"

            self.bandwidth_configuration_model = YLeaf(YType.enumeration, "bandwidth-configuration-model")

            self.bc0_percent = YLeaf(YType.uint32, "bc0-percent")

            self.bc1_percent = YLeaf(YType.uint32, "bc1-percent")

            self.is_bc0_percent_configured = YLeaf(YType.boolean, "is-bc0-percent-configured")

            self.is_bc1_percent_configured = YLeaf(YType.boolean, "is-bc1-percent-configured")

            self.is_max_res_pool_percent_configured = YLeaf(YType.boolean, "is-max-res-pool-percent-configured")

            self.max_res_pool_percent = YLeaf(YType.uint32, "max-res-pool-percent")

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in ("bandwidth_configuration_model",
                            "bc0_percent",
                            "bc1_percent",
                            "is_bc0_percent_configured",
                            "is_bc1_percent_configured",
                            "is_max_res_pool_percent_configured",
                            "max_res_pool_percent") and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(Rsvp.BwPoolInfo, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(Rsvp.BwPoolInfo, self).__setattr__(name, value)

        def has_data(self):
            return (
                self.bandwidth_configuration_model.is_set or
                self.bc0_percent.is_set or
                self.bc1_percent.is_set or
                self.is_bc0_percent_configured.is_set or
                self.is_bc1_percent_configured.is_set or
                self.is_max_res_pool_percent_configured.is_set or
                self.max_res_pool_percent.is_set)

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                self.bandwidth_configuration_model.yfilter != YFilter.not_set or
                self.bc0_percent.yfilter != YFilter.not_set or
                self.bc1_percent.yfilter != YFilter.not_set or
                self.is_bc0_percent_configured.yfilter != YFilter.not_set or
                self.is_bc1_percent_configured.yfilter != YFilter.not_set or
                self.is_max_res_pool_percent_configured.yfilter != YFilter.not_set or
                self.max_res_pool_percent.yfilter != YFilter.not_set)

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "bw-pool-info" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()
            if (self.bandwidth_configuration_model.is_set or self.bandwidth_configuration_model.yfilter != YFilter.not_set):
                leaf_name_data.append(self.bandwidth_configuration_model.get_name_leafdata())
            if (self.bc0_percent.is_set or self.bc0_percent.yfilter != YFilter.not_set):
                leaf_name_data.append(self.bc0_percent.get_name_leafdata())
            if (self.bc1_percent.is_set or self.bc1_percent.yfilter != YFilter.not_set):
                leaf_name_data.append(self.bc1_percent.get_name_leafdata())
            if (self.is_bc0_percent_configured.is_set or self.is_bc0_percent_configured.yfilter != YFilter.not_set):
                leaf_name_data.append(self.is_bc0_percent_configured.get_name_leafdata())
            if (self.is_bc1_percent_configured.is_set or self.is_bc1_percent_configured.yfilter != YFilter.not_set):
                leaf_name_data.append(self.is_bc1_percent_configured.get_name_leafdata())
            if (self.is_max_res_pool_percent_configured.is_set or self.is_max_res_pool_percent_configured.yfilter != YFilter.not_set):
                leaf_name_data.append(self.is_max_res_pool_percent_configured.get_name_leafdata())
            if (self.max_res_pool_percent.is_set or self.max_res_pool_percent.yfilter != YFilter.not_set):
                leaf_name_data.append(self.max_res_pool_percent.get_name_leafdata())

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "bandwidth-configuration-model" or name == "bc0-percent" or name == "bc1-percent" or name == "is-bc0-percent-configured" or name == "is-bc1-percent-configured" or name == "is-max-res-pool-percent-configured" or name == "max-res-pool-percent"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            if(value_path == "bandwidth-configuration-model"):
                self.bandwidth_configuration_model = value
                self.bandwidth_configuration_model.value_namespace = name_space
                self.bandwidth_configuration_model.value_namespace_prefix = name_space_prefix
            if(value_path == "bc0-percent"):
                self.bc0_percent = value
                self.bc0_percent.value_namespace = name_space
                self.bc0_percent.value_namespace_prefix = name_space_prefix
            if(value_path == "bc1-percent"):
                self.bc1_percent = value
                self.bc1_percent.value_namespace = name_space
                self.bc1_percent.value_namespace_prefix = name_space_prefix
            if(value_path == "is-bc0-percent-configured"):
                self.is_bc0_percent_configured = value
                self.is_bc0_percent_configured.value_namespace = name_space
                self.is_bc0_percent_configured.value_namespace_prefix = name_space_prefix
            if(value_path == "is-bc1-percent-configured"):
                self.is_bc1_percent_configured = value
                self.is_bc1_percent_configured.value_namespace = name_space
                self.is_bc1_percent_configured.value_namespace_prefix = name_space_prefix
            if(value_path == "is-max-res-pool-percent-configured"):
                self.is_max_res_pool_percent_configured = value
                self.is_max_res_pool_percent_configured.value_namespace = name_space
                self.is_max_res_pool_percent_configured.value_namespace_prefix = name_space_prefix
            if(value_path == "max-res-pool-percent"):
                self.max_res_pool_percent = value
                self.max_res_pool_percent.value_namespace = name_space
                self.max_res_pool_percent.value_namespace_prefix = name_space_prefix


    class PxsbDetails(Entity):
        """
        Table of detailed PXSB info
        
        .. attribute:: pxsb_detail
        
        	Detailed PXSB info
        	**type**\: list of    :py:class:`PxsbDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PxsbDetails.PxsbDetail>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Rsvp.PxsbDetails, self).__init__()

            self.yang_name = "pxsb-details"
            self.yang_parent_name = "rsvp"

            self.pxsb_detail = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(Rsvp.PxsbDetails, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(Rsvp.PxsbDetails, self).__setattr__(name, value)


        class PxsbDetail(Entity):
            """
            Detailed PXSB info
            
            .. attribute:: destination_address
            
            	Destination Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: destination_port
            
            	Destination Port
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: dynamic_state
            
            	Dynamic State Handle
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: extended_tunnel_id
            
            	Extended Tunnel ID
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: generic_traffic_spec
            
            	RSVP Generic Traffic Spec Info
            	**type**\:   :py:class:`GenericTrafficSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PxsbDetails.PxsbDetail.GenericTrafficSpec>`
            
            .. attribute:: hop
            
            	Path Hop Info
            	**type**\:   :py:class:`Hop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PxsbDetails.PxsbDetail.Hop>`
            
            .. attribute:: input_interface
            
            	Path Input Interface
            	**type**\:  str
            
            .. attribute:: p2mp_id
            
            	P2MP ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: protocol
            
            	Protocol
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: rsvp_header
            
            	RSVP Header
            	**type**\:   :py:class:`RsvpHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PxsbDetails.PxsbDetail.RsvpHeader>`
            
            .. attribute:: s2l_sub_lsp
            
            	RSVP S2L Sub\-LSP information
            	**type**\:   :py:class:`S2LSubLsp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PxsbDetails.PxsbDetail.S2LSubLsp>`
            
            .. attribute:: session
            
            	RSVP Session Information
            	**type**\:   :py:class:`Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PxsbDetails.PxsbDetail.Session>`
            
            .. attribute:: session_type
            
            	Session Type
            	**type**\:   :py:class:`RsvpSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpSession>`
            
            .. attribute:: source_address
            
            	Source Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: source_port
            
            	Source Port
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: sub_group_id
            
            	Subgroup ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: sub_group_origin
            
            	Subgroup Origin
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: template
            
            	RSVP Template
            	**type**\:   :py:class:`Template <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PxsbDetails.PxsbDetail.Template>`
            
            .. attribute:: traffic_spec
            
            	RSVP Traffic Spec Info
            	**type**\:   :py:class:`TrafficSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PxsbDetails.PxsbDetail.TrafficSpec>`
            
            .. attribute:: vrf_name
            
            	VRF Name
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Rsvp.PxsbDetails.PxsbDetail, self).__init__()

                self.yang_name = "pxsb-detail"
                self.yang_parent_name = "pxsb-details"

                self.destination_address = YLeaf(YType.str, "destination-address")

                self.destination_port = YLeaf(YType.int32, "destination-port")

                self.dynamic_state = YLeaf(YType.uint32, "dynamic-state")

                self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                self.input_interface = YLeaf(YType.str, "input-interface")

                self.p2mp_id = YLeaf(YType.int32, "p2mp-id")

                self.protocol = YLeaf(YType.int32, "protocol")

                self.session_type = YLeaf(YType.enumeration, "session-type")

                self.source_address = YLeaf(YType.str, "source-address")

                self.source_port = YLeaf(YType.int32, "source-port")

                self.sub_group_id = YLeaf(YType.int32, "sub-group-id")

                self.sub_group_origin = YLeaf(YType.str, "sub-group-origin")

                self.vrf_name = YLeaf(YType.str, "vrf-name")

                self.generic_traffic_spec = Rsvp.PxsbDetails.PxsbDetail.GenericTrafficSpec()
                self.generic_traffic_spec.parent = self
                self._children_name_map["generic_traffic_spec"] = "generic-traffic-spec"
                self._children_yang_names.add("generic-traffic-spec")

                self.hop = Rsvp.PxsbDetails.PxsbDetail.Hop()
                self.hop.parent = self
                self._children_name_map["hop"] = "hop"
                self._children_yang_names.add("hop")

                self.rsvp_header = Rsvp.PxsbDetails.PxsbDetail.RsvpHeader()
                self.rsvp_header.parent = self
                self._children_name_map["rsvp_header"] = "rsvp-header"
                self._children_yang_names.add("rsvp-header")

                self.s2l_sub_lsp = Rsvp.PxsbDetails.PxsbDetail.S2LSubLsp()
                self.s2l_sub_lsp.parent = self
                self._children_name_map["s2l_sub_lsp"] = "s2l-sub-lsp"
                self._children_yang_names.add("s2l-sub-lsp")

                self.session = Rsvp.PxsbDetails.PxsbDetail.Session()
                self.session.parent = self
                self._children_name_map["session"] = "session"
                self._children_yang_names.add("session")

                self.template = Rsvp.PxsbDetails.PxsbDetail.Template()
                self.template.parent = self
                self._children_name_map["template"] = "template"
                self._children_yang_names.add("template")

                self.traffic_spec = Rsvp.PxsbDetails.PxsbDetail.TrafficSpec()
                self.traffic_spec.parent = self
                self._children_name_map["traffic_spec"] = "traffic-spec"
                self._children_yang_names.add("traffic-spec")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("destination_address",
                                "destination_port",
                                "dynamic_state",
                                "extended_tunnel_id",
                                "input_interface",
                                "p2mp_id",
                                "protocol",
                                "session_type",
                                "source_address",
                                "source_port",
                                "sub_group_id",
                                "sub_group_origin",
                                "vrf_name") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Rsvp.PxsbDetails.PxsbDetail, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Rsvp.PxsbDetails.PxsbDetail, self).__setattr__(name, value)


            class Session(Entity):
                """
                RSVP Session Information
                
                .. attribute:: rsvp_session
                
                	RSVP Session
                	**type**\:   :py:class:`RsvpSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PxsbDetails.PxsbDetail.Session.RsvpSession>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.PxsbDetails.PxsbDetail.Session, self).__init__()

                    self.yang_name = "session"
                    self.yang_parent_name = "pxsb-detail"

                    self.rsvp_session = Rsvp.PxsbDetails.PxsbDetail.Session.RsvpSession()
                    self.rsvp_session.parent = self
                    self._children_name_map["rsvp_session"] = "rsvp-session"
                    self._children_yang_names.add("rsvp-session")


                class RsvpSession(Entity):
                    """
                    RSVP Session
                    
                    .. attribute:: ipv4
                    
                    	UDP IPv4 session
                    	**type**\:   :py:class:`Ipv4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PxsbDetails.PxsbDetail.Session.RsvpSession.Ipv4>`
                    
                    .. attribute:: ipv4_lsp_session
                    
                    	IPv4 LSP session
                    	**type**\:   :py:class:`Ipv4LspSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PxsbDetails.PxsbDetail.Session.RsvpSession.Ipv4LspSession>`
                    
                    .. attribute:: ipv4_p2mp_lsp_session
                    
                    	IPv4 P2MP LSP session
                    	**type**\:   :py:class:`Ipv4P2MpLspSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PxsbDetails.PxsbDetail.Session.RsvpSession.Ipv4P2MpLspSession>`
                    
                    .. attribute:: ipv4_uni_session
                    
                    	IPv4 UNI session
                    	**type**\:   :py:class:`Ipv4UniSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PxsbDetails.PxsbDetail.Session.RsvpSession.Ipv4UniSession>`
                    
                    .. attribute:: session_type
                    
                    	SessionType
                    	**type**\:   :py:class:`RsvpMgmtSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtSession>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.PxsbDetails.PxsbDetail.Session.RsvpSession, self).__init__()

                        self.yang_name = "rsvp-session"
                        self.yang_parent_name = "session"

                        self.session_type = YLeaf(YType.enumeration, "session-type")

                        self.ipv4 = Rsvp.PxsbDetails.PxsbDetail.Session.RsvpSession.Ipv4()
                        self.ipv4.parent = self
                        self._children_name_map["ipv4"] = "ipv4"
                        self._children_yang_names.add("ipv4")

                        self.ipv4_lsp_session = Rsvp.PxsbDetails.PxsbDetail.Session.RsvpSession.Ipv4LspSession()
                        self.ipv4_lsp_session.parent = self
                        self._children_name_map["ipv4_lsp_session"] = "ipv4-lsp-session"
                        self._children_yang_names.add("ipv4-lsp-session")

                        self.ipv4_p2mp_lsp_session = Rsvp.PxsbDetails.PxsbDetail.Session.RsvpSession.Ipv4P2MpLspSession()
                        self.ipv4_p2mp_lsp_session.parent = self
                        self._children_name_map["ipv4_p2mp_lsp_session"] = "ipv4-p2mp-lsp-session"
                        self._children_yang_names.add("ipv4-p2mp-lsp-session")

                        self.ipv4_uni_session = Rsvp.PxsbDetails.PxsbDetail.Session.RsvpSession.Ipv4UniSession()
                        self.ipv4_uni_session.parent = self
                        self._children_name_map["ipv4_uni_session"] = "ipv4-uni-session"
                        self._children_yang_names.add("ipv4-uni-session")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("session_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.PxsbDetails.PxsbDetail.Session.RsvpSession, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.PxsbDetails.PxsbDetail.Session.RsvpSession, self).__setattr__(name, value)


                    class Ipv4(Entity):
                        """
                        UDP IPv4 session
                        
                        .. attribute:: destination_address
                        
                        	Destination address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: destination_port
                        
                        	The Session Destination Port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: protocol
                        
                        	Protocol type (originally defined in RFC 790, further values in subsequent RFCs)
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.PxsbDetails.PxsbDetail.Session.RsvpSession.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "rsvp-session"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.destination_port = YLeaf(YType.uint16, "destination-port")

                            self.protocol = YLeaf(YType.uint8, "protocol")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "destination_port",
                                            "protocol") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.PxsbDetails.PxsbDetail.Session.RsvpSession.Ipv4, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.PxsbDetails.PxsbDetail.Session.RsvpSession.Ipv4, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination_address.is_set or
                                self.destination_port.is_set or
                                self.protocol.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.destination_port.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/pxsb-details/pxsb-detail/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.destination_port.is_set or self.destination_port.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_port.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "destination-port" or name == "protocol"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "destination-port"):
                                self.destination_port = value
                                self.destination_port.value_namespace = name_space
                                self.destination_port.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix


                    class Ipv4LspSession(Entity):
                        """
                        IPv4 LSP session
                        
                        .. attribute:: destination_address
                        
                        	Destination address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: extended_tunnel_id
                        
                        	The Session Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: tunnel_id
                        
                        	The Session Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.PxsbDetails.PxsbDetail.Session.RsvpSession.Ipv4LspSession, self).__init__()

                            self.yang_name = "ipv4-lsp-session"
                            self.yang_parent_name = "rsvp-session"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                            self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "extended_tunnel_id",
                                            "tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.PxsbDetails.PxsbDetail.Session.RsvpSession.Ipv4LspSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.PxsbDetails.PxsbDetail.Session.RsvpSession.Ipv4LspSession, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination_address.is_set or
                                self.extended_tunnel_id.is_set or
                                self.tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.extended_tunnel_id.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-lsp-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/pxsb-details/pxsb-detail/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "extended-tunnel-id" or name == "tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "extended-tunnel-id"):
                                self.extended_tunnel_id = value
                                self.extended_tunnel_id.value_namespace = name_space
                                self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix


                    class Ipv4UniSession(Entity):
                        """
                        IPv4 UNI session
                        
                        .. attribute:: destination_address
                        
                        	Destination address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: extended_address
                        
                        	The Session Extended Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: tunnel_id
                        
                        	The Session Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.PxsbDetails.PxsbDetail.Session.RsvpSession.Ipv4UniSession, self).__init__()

                            self.yang_name = "ipv4-uni-session"
                            self.yang_parent_name = "rsvp-session"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.extended_address = YLeaf(YType.str, "extended-address")

                            self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "extended_address",
                                            "tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.PxsbDetails.PxsbDetail.Session.RsvpSession.Ipv4UniSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.PxsbDetails.PxsbDetail.Session.RsvpSession.Ipv4UniSession, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination_address.is_set or
                                self.extended_address.is_set or
                                self.tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.extended_address.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-uni-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/pxsb-details/pxsb-detail/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.extended_address.is_set or self.extended_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_address.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "extended-address" or name == "tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "extended-address"):
                                self.extended_address = value
                                self.extended_address.value_namespace = name_space
                                self.extended_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix


                    class Ipv4P2MpLspSession(Entity):
                        """
                        IPv4 P2MP LSP session
                        
                        .. attribute:: extended_tunnel_id
                        
                        	The Session Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: p2mp_id
                        
                        	The Point to Multipoint ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tunnel_id
                        
                        	The Session Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.PxsbDetails.PxsbDetail.Session.RsvpSession.Ipv4P2MpLspSession, self).__init__()

                            self.yang_name = "ipv4-p2mp-lsp-session"
                            self.yang_parent_name = "rsvp-session"

                            self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                            self.p2mp_id = YLeaf(YType.uint32, "p2mp-id")

                            self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("extended_tunnel_id",
                                            "p2mp_id",
                                            "tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.PxsbDetails.PxsbDetail.Session.RsvpSession.Ipv4P2MpLspSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.PxsbDetails.PxsbDetail.Session.RsvpSession.Ipv4P2MpLspSession, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.extended_tunnel_id.is_set or
                                self.p2mp_id.is_set or
                                self.tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.extended_tunnel_id.yfilter != YFilter.not_set or
                                self.p2mp_id.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-p2mp-lsp-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/pxsb-details/pxsb-detail/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                            if (self.p2mp_id.is_set or self.p2mp_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.p2mp_id.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "extended-tunnel-id" or name == "p2mp-id" or name == "tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "extended-tunnel-id"):
                                self.extended_tunnel_id = value
                                self.extended_tunnel_id.value_namespace = name_space
                                self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "p2mp-id"):
                                self.p2mp_id = value
                                self.p2mp_id.value_namespace = name_space
                                self.p2mp_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.session_type.is_set or
                            (self.ipv4 is not None and self.ipv4.has_data()) or
                            (self.ipv4_lsp_session is not None and self.ipv4_lsp_session.has_data()) or
                            (self.ipv4_p2mp_lsp_session is not None and self.ipv4_p2mp_lsp_session.has_data()) or
                            (self.ipv4_uni_session is not None and self.ipv4_uni_session.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.session_type.yfilter != YFilter.not_set or
                            (self.ipv4 is not None and self.ipv4.has_operation()) or
                            (self.ipv4_lsp_session is not None and self.ipv4_lsp_session.has_operation()) or
                            (self.ipv4_p2mp_lsp_session is not None and self.ipv4_p2mp_lsp_session.has_operation()) or
                            (self.ipv4_uni_session is not None and self.ipv4_uni_session.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rsvp-session" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/pxsb-details/pxsb-detail/session/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.session_type.is_set or self.session_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.session_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "ipv4"):
                            if (self.ipv4 is None):
                                self.ipv4 = Rsvp.PxsbDetails.PxsbDetail.Session.RsvpSession.Ipv4()
                                self.ipv4.parent = self
                                self._children_name_map["ipv4"] = "ipv4"
                            return self.ipv4

                        if (child_yang_name == "ipv4-lsp-session"):
                            if (self.ipv4_lsp_session is None):
                                self.ipv4_lsp_session = Rsvp.PxsbDetails.PxsbDetail.Session.RsvpSession.Ipv4LspSession()
                                self.ipv4_lsp_session.parent = self
                                self._children_name_map["ipv4_lsp_session"] = "ipv4-lsp-session"
                            return self.ipv4_lsp_session

                        if (child_yang_name == "ipv4-p2mp-lsp-session"):
                            if (self.ipv4_p2mp_lsp_session is None):
                                self.ipv4_p2mp_lsp_session = Rsvp.PxsbDetails.PxsbDetail.Session.RsvpSession.Ipv4P2MpLspSession()
                                self.ipv4_p2mp_lsp_session.parent = self
                                self._children_name_map["ipv4_p2mp_lsp_session"] = "ipv4-p2mp-lsp-session"
                            return self.ipv4_p2mp_lsp_session

                        if (child_yang_name == "ipv4-uni-session"):
                            if (self.ipv4_uni_session is None):
                                self.ipv4_uni_session = Rsvp.PxsbDetails.PxsbDetail.Session.RsvpSession.Ipv4UniSession()
                                self.ipv4_uni_session.parent = self
                                self._children_name_map["ipv4_uni_session"] = "ipv4-uni-session"
                            return self.ipv4_uni_session

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ipv4" or name == "ipv4-lsp-session" or name == "ipv4-p2mp-lsp-session" or name == "ipv4-uni-session" or name == "session-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "session-type"):
                            self.session_type = value
                            self.session_type.value_namespace = name_space
                            self.session_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (self.rsvp_session is not None and self.rsvp_session.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.rsvp_session is not None and self.rsvp_session.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "session" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/pxsb-details/pxsb-detail/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "rsvp-session"):
                        if (self.rsvp_session is None):
                            self.rsvp_session = Rsvp.PxsbDetails.PxsbDetail.Session.RsvpSession()
                            self.rsvp_session.parent = self
                            self._children_name_map["rsvp_session"] = "rsvp-session"
                        return self.rsvp_session

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "rsvp-session"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class S2LSubLsp(Entity):
                """
                RSVP S2L Sub\-LSP information
                
                .. attribute:: s2l_destination_address
                
                	S2L Sub\-LSP Destination Address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.PxsbDetails.PxsbDetail.S2LSubLsp, self).__init__()

                    self.yang_name = "s2l-sub-lsp"
                    self.yang_parent_name = "pxsb-detail"

                    self.s2l_destination_address = YLeaf(YType.str, "s2l-destination-address")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("s2l_destination_address") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.PxsbDetails.PxsbDetail.S2LSubLsp, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.PxsbDetails.PxsbDetail.S2LSubLsp, self).__setattr__(name, value)

                def has_data(self):
                    return self.s2l_destination_address.is_set

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.s2l_destination_address.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "s2l-sub-lsp" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/pxsb-details/pxsb-detail/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.s2l_destination_address.is_set or self.s2l_destination_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.s2l_destination_address.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "s2l-destination-address"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "s2l-destination-address"):
                        self.s2l_destination_address = value
                        self.s2l_destination_address.value_namespace = name_space
                        self.s2l_destination_address.value_namespace_prefix = name_space_prefix


            class Template(Entity):
                """
                RSVP Template
                
                .. attribute:: rsvp_filter
                
                	RSVP Filter
                	**type**\:   :py:class:`RsvpFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PxsbDetails.PxsbDetail.Template.RsvpFilter>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.PxsbDetails.PxsbDetail.Template, self).__init__()

                    self.yang_name = "template"
                    self.yang_parent_name = "pxsb-detail"

                    self.rsvp_filter = Rsvp.PxsbDetails.PxsbDetail.Template.RsvpFilter()
                    self.rsvp_filter.parent = self
                    self._children_name_map["rsvp_filter"] = "rsvp-filter"
                    self._children_yang_names.add("rsvp-filter")


                class RsvpFilter(Entity):
                    """
                    RSVP Filter
                    
                    .. attribute:: filter_type
                    
                    	FilterType
                    	**type**\:   :py:class:`RsvpMgmtFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtFilter>`
                    
                    .. attribute:: p2mp_ipv4_session
                    
                    	IPv4 P2MP LSP FilterSpec
                    	**type**\:   :py:class:`P2MpIpv4Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PxsbDetails.PxsbDetail.Template.RsvpFilter.P2MpIpv4Session>`
                    
                    .. attribute:: udp_ipv4_session
                    
                    	UDP IPV4 FilterSpec
                    	**type**\:   :py:class:`UdpIpv4Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PxsbDetails.PxsbDetail.Template.RsvpFilter.UdpIpv4Session>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.PxsbDetails.PxsbDetail.Template.RsvpFilter, self).__init__()

                        self.yang_name = "rsvp-filter"
                        self.yang_parent_name = "template"

                        self.filter_type = YLeaf(YType.enumeration, "filter-type")

                        self.p2mp_ipv4_session = Rsvp.PxsbDetails.PxsbDetail.Template.RsvpFilter.P2MpIpv4Session()
                        self.p2mp_ipv4_session.parent = self
                        self._children_name_map["p2mp_ipv4_session"] = "p2mp-ipv4-session"
                        self._children_yang_names.add("p2mp-ipv4-session")

                        self.udp_ipv4_session = Rsvp.PxsbDetails.PxsbDetail.Template.RsvpFilter.UdpIpv4Session()
                        self.udp_ipv4_session.parent = self
                        self._children_name_map["udp_ipv4_session"] = "udp-ipv4-session"
                        self._children_yang_names.add("udp-ipv4-session")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("filter_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.PxsbDetails.PxsbDetail.Template.RsvpFilter, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.PxsbDetails.PxsbDetail.Template.RsvpFilter, self).__setattr__(name, value)


                    class UdpIpv4Session(Entity):
                        """
                        UDP IPV4 FilterSpec
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source_port
                        
                        	Source Port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.PxsbDetails.PxsbDetail.Template.RsvpFilter.UdpIpv4Session, self).__init__()

                            self.yang_name = "udp-ipv4-session"
                            self.yang_parent_name = "rsvp-filter"

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.source_port = YLeaf(YType.uint16, "source-port")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("source_address",
                                            "source_port") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.PxsbDetails.PxsbDetail.Template.RsvpFilter.UdpIpv4Session, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.PxsbDetails.PxsbDetail.Template.RsvpFilter.UdpIpv4Session, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.source_address.is_set or
                                self.source_port.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                self.source_port.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "udp-ipv4-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/pxsb-details/pxsb-detail/template/rsvp-filter/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())
                            if (self.source_port.is_set or self.source_port.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_port.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "source-address" or name == "source-port"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-port"):
                                self.source_port = value
                                self.source_port.value_namespace = name_space
                                self.source_port.value_namespace_prefix = name_space_prefix


                    class P2MpIpv4Session(Entity):
                        """
                        IPv4 P2MP LSP FilterSpec
                        
                        .. attribute:: p2mp_sub_group_origin
                        
                        	Point to Multipoint SubGroup Origin
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source_port
                        
                        	Source Port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: sub_group_id
                        
                        	Point to Multipoint Subgroup ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.PxsbDetails.PxsbDetail.Template.RsvpFilter.P2MpIpv4Session, self).__init__()

                            self.yang_name = "p2mp-ipv4-session"
                            self.yang_parent_name = "rsvp-filter"

                            self.p2mp_sub_group_origin = YLeaf(YType.str, "p2mp-sub-group-origin")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.source_port = YLeaf(YType.uint16, "source-port")

                            self.sub_group_id = YLeaf(YType.uint16, "sub-group-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("p2mp_sub_group_origin",
                                            "source_address",
                                            "source_port",
                                            "sub_group_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.PxsbDetails.PxsbDetail.Template.RsvpFilter.P2MpIpv4Session, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.PxsbDetails.PxsbDetail.Template.RsvpFilter.P2MpIpv4Session, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.p2mp_sub_group_origin.is_set or
                                self.source_address.is_set or
                                self.source_port.is_set or
                                self.sub_group_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.p2mp_sub_group_origin.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                self.source_port.yfilter != YFilter.not_set or
                                self.sub_group_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "p2mp-ipv4-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/pxsb-details/pxsb-detail/template/rsvp-filter/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.p2mp_sub_group_origin.is_set or self.p2mp_sub_group_origin.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.p2mp_sub_group_origin.get_name_leafdata())
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())
                            if (self.source_port.is_set or self.source_port.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_port.get_name_leafdata())
                            if (self.sub_group_id.is_set or self.sub_group_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sub_group_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "p2mp-sub-group-origin" or name == "source-address" or name == "source-port" or name == "sub-group-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "p2mp-sub-group-origin"):
                                self.p2mp_sub_group_origin = value
                                self.p2mp_sub_group_origin.value_namespace = name_space
                                self.p2mp_sub_group_origin.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-port"):
                                self.source_port = value
                                self.source_port.value_namespace = name_space
                                self.source_port.value_namespace_prefix = name_space_prefix
                            if(value_path == "sub-group-id"):
                                self.sub_group_id = value
                                self.sub_group_id.value_namespace = name_space
                                self.sub_group_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.filter_type.is_set or
                            (self.p2mp_ipv4_session is not None and self.p2mp_ipv4_session.has_data()) or
                            (self.udp_ipv4_session is not None and self.udp_ipv4_session.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.filter_type.yfilter != YFilter.not_set or
                            (self.p2mp_ipv4_session is not None and self.p2mp_ipv4_session.has_operation()) or
                            (self.udp_ipv4_session is not None and self.udp_ipv4_session.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rsvp-filter" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/pxsb-details/pxsb-detail/template/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.filter_type.is_set or self.filter_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.filter_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "p2mp-ipv4-session"):
                            if (self.p2mp_ipv4_session is None):
                                self.p2mp_ipv4_session = Rsvp.PxsbDetails.PxsbDetail.Template.RsvpFilter.P2MpIpv4Session()
                                self.p2mp_ipv4_session.parent = self
                                self._children_name_map["p2mp_ipv4_session"] = "p2mp-ipv4-session"
                            return self.p2mp_ipv4_session

                        if (child_yang_name == "udp-ipv4-session"):
                            if (self.udp_ipv4_session is None):
                                self.udp_ipv4_session = Rsvp.PxsbDetails.PxsbDetail.Template.RsvpFilter.UdpIpv4Session()
                                self.udp_ipv4_session.parent = self
                                self._children_name_map["udp_ipv4_session"] = "udp-ipv4-session"
                            return self.udp_ipv4_session

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "p2mp-ipv4-session" or name == "udp-ipv4-session" or name == "filter-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "filter-type"):
                            self.filter_type = value
                            self.filter_type.value_namespace = name_space
                            self.filter_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (self.rsvp_filter is not None and self.rsvp_filter.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.rsvp_filter is not None and self.rsvp_filter.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "template" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/pxsb-details/pxsb-detail/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "rsvp-filter"):
                        if (self.rsvp_filter is None):
                            self.rsvp_filter = Rsvp.PxsbDetails.PxsbDetail.Template.RsvpFilter()
                            self.rsvp_filter.parent = self
                            self._children_name_map["rsvp_filter"] = "rsvp-filter"
                        return self.rsvp_filter

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "rsvp-filter"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class TrafficSpec(Entity):
                """
                RSVP Traffic Spec Info
                
                .. attribute:: traffic_average_rate
                
                	Traffic Average Rate in bytes per second
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: byte/s
                
                .. attribute:: traffic_max_burst
                
                	Traffic Maximum Burst
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: traffic_max_unit
                
                	Traffic Maximum Unit
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: traffic_min_unit
                
                	Traffic Minimum Unit
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: traffic_peak_rate
                
                	Traffic Peak Rate in bytes per second
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: byte/s
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.PxsbDetails.PxsbDetail.TrafficSpec, self).__init__()

                    self.yang_name = "traffic-spec"
                    self.yang_parent_name = "pxsb-detail"

                    self.traffic_average_rate = YLeaf(YType.uint64, "traffic-average-rate")

                    self.traffic_max_burst = YLeaf(YType.uint64, "traffic-max-burst")

                    self.traffic_max_unit = YLeaf(YType.uint32, "traffic-max-unit")

                    self.traffic_min_unit = YLeaf(YType.uint32, "traffic-min-unit")

                    self.traffic_peak_rate = YLeaf(YType.uint64, "traffic-peak-rate")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("traffic_average_rate",
                                    "traffic_max_burst",
                                    "traffic_max_unit",
                                    "traffic_min_unit",
                                    "traffic_peak_rate") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.PxsbDetails.PxsbDetail.TrafficSpec, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.PxsbDetails.PxsbDetail.TrafficSpec, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.traffic_average_rate.is_set or
                        self.traffic_max_burst.is_set or
                        self.traffic_max_unit.is_set or
                        self.traffic_min_unit.is_set or
                        self.traffic_peak_rate.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.traffic_average_rate.yfilter != YFilter.not_set or
                        self.traffic_max_burst.yfilter != YFilter.not_set or
                        self.traffic_max_unit.yfilter != YFilter.not_set or
                        self.traffic_min_unit.yfilter != YFilter.not_set or
                        self.traffic_peak_rate.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "traffic-spec" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/pxsb-details/pxsb-detail/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.traffic_average_rate.is_set or self.traffic_average_rate.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.traffic_average_rate.get_name_leafdata())
                    if (self.traffic_max_burst.is_set or self.traffic_max_burst.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.traffic_max_burst.get_name_leafdata())
                    if (self.traffic_max_unit.is_set or self.traffic_max_unit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.traffic_max_unit.get_name_leafdata())
                    if (self.traffic_min_unit.is_set or self.traffic_min_unit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.traffic_min_unit.get_name_leafdata())
                    if (self.traffic_peak_rate.is_set or self.traffic_peak_rate.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.traffic_peak_rate.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "traffic-average-rate" or name == "traffic-max-burst" or name == "traffic-max-unit" or name == "traffic-min-unit" or name == "traffic-peak-rate"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "traffic-average-rate"):
                        self.traffic_average_rate = value
                        self.traffic_average_rate.value_namespace = name_space
                        self.traffic_average_rate.value_namespace_prefix = name_space_prefix
                    if(value_path == "traffic-max-burst"):
                        self.traffic_max_burst = value
                        self.traffic_max_burst.value_namespace = name_space
                        self.traffic_max_burst.value_namespace_prefix = name_space_prefix
                    if(value_path == "traffic-max-unit"):
                        self.traffic_max_unit = value
                        self.traffic_max_unit.value_namespace = name_space
                        self.traffic_max_unit.value_namespace_prefix = name_space_prefix
                    if(value_path == "traffic-min-unit"):
                        self.traffic_min_unit = value
                        self.traffic_min_unit.value_namespace = name_space
                        self.traffic_min_unit.value_namespace_prefix = name_space_prefix
                    if(value_path == "traffic-peak-rate"):
                        self.traffic_peak_rate = value
                        self.traffic_peak_rate.value_namespace = name_space
                        self.traffic_peak_rate.value_namespace_prefix = name_space_prefix


            class GenericTrafficSpec(Entity):
                """
                RSVP Generic Traffic Spec Info
                
                .. attribute:: g709otn_tspec
                
                	G709 OTN Sender Tspec
                	**type**\:   :py:class:`G709OtnTspec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PxsbDetails.PxsbDetail.GenericTrafficSpec.G709OtnTspec>`
                
                .. attribute:: intsrv_tspec
                
                	Integrated Services Sender Tspec
                	**type**\:   :py:class:`IntsrvTspec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PxsbDetails.PxsbDetail.GenericTrafficSpec.IntsrvTspec>`
                
                .. attribute:: tspec_type
                
                	TspecType
                	**type**\:   :py:class:`RsvpMgmtTspec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtTspec>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.PxsbDetails.PxsbDetail.GenericTrafficSpec, self).__init__()

                    self.yang_name = "generic-traffic-spec"
                    self.yang_parent_name = "pxsb-detail"

                    self.tspec_type = YLeaf(YType.enumeration, "tspec-type")

                    self.g709otn_tspec = Rsvp.PxsbDetails.PxsbDetail.GenericTrafficSpec.G709OtnTspec()
                    self.g709otn_tspec.parent = self
                    self._children_name_map["g709otn_tspec"] = "g709otn-tspec"
                    self._children_yang_names.add("g709otn-tspec")

                    self.intsrv_tspec = Rsvp.PxsbDetails.PxsbDetail.GenericTrafficSpec.IntsrvTspec()
                    self.intsrv_tspec.parent = self
                    self._children_name_map["intsrv_tspec"] = "intsrv-tspec"
                    self._children_yang_names.add("intsrv-tspec")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("tspec_type") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.PxsbDetails.PxsbDetail.GenericTrafficSpec, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.PxsbDetails.PxsbDetail.GenericTrafficSpec, self).__setattr__(name, value)


                class G709OtnTspec(Entity):
                    """
                    G709 OTN Sender Tspec
                    
                    .. attribute:: traffic_bit_rate
                    
                    	G709 OTN Traffic Bit Rate
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: traffic_multiplier
                    
                    	G709 OTN Traffic Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: traffic_nvc
                    
                    	G709 OTN Traffic NVC
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: traffic_signal_type
                    
                    	G709 OTN Traffic Signal Type (Refer G709 v3)
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.PxsbDetails.PxsbDetail.GenericTrafficSpec.G709OtnTspec, self).__init__()

                        self.yang_name = "g709otn-tspec"
                        self.yang_parent_name = "generic-traffic-spec"

                        self.traffic_bit_rate = YLeaf(YType.uint64, "traffic-bit-rate")

                        self.traffic_multiplier = YLeaf(YType.uint16, "traffic-multiplier")

                        self.traffic_nvc = YLeaf(YType.uint16, "traffic-nvc")

                        self.traffic_signal_type = YLeaf(YType.uint8, "traffic-signal-type")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("traffic_bit_rate",
                                        "traffic_multiplier",
                                        "traffic_nvc",
                                        "traffic_signal_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.PxsbDetails.PxsbDetail.GenericTrafficSpec.G709OtnTspec, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.PxsbDetails.PxsbDetail.GenericTrafficSpec.G709OtnTspec, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.traffic_bit_rate.is_set or
                            self.traffic_multiplier.is_set or
                            self.traffic_nvc.is_set or
                            self.traffic_signal_type.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.traffic_bit_rate.yfilter != YFilter.not_set or
                            self.traffic_multiplier.yfilter != YFilter.not_set or
                            self.traffic_nvc.yfilter != YFilter.not_set or
                            self.traffic_signal_type.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "g709otn-tspec" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/pxsb-details/pxsb-detail/generic-traffic-spec/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.traffic_bit_rate.is_set or self.traffic_bit_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.traffic_bit_rate.get_name_leafdata())
                        if (self.traffic_multiplier.is_set or self.traffic_multiplier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.traffic_multiplier.get_name_leafdata())
                        if (self.traffic_nvc.is_set or self.traffic_nvc.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.traffic_nvc.get_name_leafdata())
                        if (self.traffic_signal_type.is_set or self.traffic_signal_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.traffic_signal_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "traffic-bit-rate" or name == "traffic-multiplier" or name == "traffic-nvc" or name == "traffic-signal-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "traffic-bit-rate"):
                            self.traffic_bit_rate = value
                            self.traffic_bit_rate.value_namespace = name_space
                            self.traffic_bit_rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "traffic-multiplier"):
                            self.traffic_multiplier = value
                            self.traffic_multiplier.value_namespace = name_space
                            self.traffic_multiplier.value_namespace_prefix = name_space_prefix
                        if(value_path == "traffic-nvc"):
                            self.traffic_nvc = value
                            self.traffic_nvc.value_namespace = name_space
                            self.traffic_nvc.value_namespace_prefix = name_space_prefix
                        if(value_path == "traffic-signal-type"):
                            self.traffic_signal_type = value
                            self.traffic_signal_type.value_namespace = name_space
                            self.traffic_signal_type.value_namespace_prefix = name_space_prefix


                class IntsrvTspec(Entity):
                    """
                    Integrated Services Sender Tspec
                    
                    .. attribute:: traffic_average_rate
                    
                    	Traffic Average Rate in bytes per second
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: byte/s
                    
                    .. attribute:: traffic_max_burst
                    
                    	Traffic Maximum Burst
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: traffic_max_unit
                    
                    	Traffic Maximum Unit
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: traffic_min_unit
                    
                    	Traffic Minimum Unit
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: traffic_peak_rate
                    
                    	Traffic Peak Rate in bytes per second
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: byte/s
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.PxsbDetails.PxsbDetail.GenericTrafficSpec.IntsrvTspec, self).__init__()

                        self.yang_name = "intsrv-tspec"
                        self.yang_parent_name = "generic-traffic-spec"

                        self.traffic_average_rate = YLeaf(YType.uint64, "traffic-average-rate")

                        self.traffic_max_burst = YLeaf(YType.uint64, "traffic-max-burst")

                        self.traffic_max_unit = YLeaf(YType.uint32, "traffic-max-unit")

                        self.traffic_min_unit = YLeaf(YType.uint32, "traffic-min-unit")

                        self.traffic_peak_rate = YLeaf(YType.uint64, "traffic-peak-rate")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("traffic_average_rate",
                                        "traffic_max_burst",
                                        "traffic_max_unit",
                                        "traffic_min_unit",
                                        "traffic_peak_rate") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.PxsbDetails.PxsbDetail.GenericTrafficSpec.IntsrvTspec, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.PxsbDetails.PxsbDetail.GenericTrafficSpec.IntsrvTspec, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.traffic_average_rate.is_set or
                            self.traffic_max_burst.is_set or
                            self.traffic_max_unit.is_set or
                            self.traffic_min_unit.is_set or
                            self.traffic_peak_rate.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.traffic_average_rate.yfilter != YFilter.not_set or
                            self.traffic_max_burst.yfilter != YFilter.not_set or
                            self.traffic_max_unit.yfilter != YFilter.not_set or
                            self.traffic_min_unit.yfilter != YFilter.not_set or
                            self.traffic_peak_rate.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "intsrv-tspec" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/pxsb-details/pxsb-detail/generic-traffic-spec/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.traffic_average_rate.is_set or self.traffic_average_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.traffic_average_rate.get_name_leafdata())
                        if (self.traffic_max_burst.is_set or self.traffic_max_burst.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.traffic_max_burst.get_name_leafdata())
                        if (self.traffic_max_unit.is_set or self.traffic_max_unit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.traffic_max_unit.get_name_leafdata())
                        if (self.traffic_min_unit.is_set or self.traffic_min_unit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.traffic_min_unit.get_name_leafdata())
                        if (self.traffic_peak_rate.is_set or self.traffic_peak_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.traffic_peak_rate.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "traffic-average-rate" or name == "traffic-max-burst" or name == "traffic-max-unit" or name == "traffic-min-unit" or name == "traffic-peak-rate"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "traffic-average-rate"):
                            self.traffic_average_rate = value
                            self.traffic_average_rate.value_namespace = name_space
                            self.traffic_average_rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "traffic-max-burst"):
                            self.traffic_max_burst = value
                            self.traffic_max_burst.value_namespace = name_space
                            self.traffic_max_burst.value_namespace_prefix = name_space_prefix
                        if(value_path == "traffic-max-unit"):
                            self.traffic_max_unit = value
                            self.traffic_max_unit.value_namespace = name_space
                            self.traffic_max_unit.value_namespace_prefix = name_space_prefix
                        if(value_path == "traffic-min-unit"):
                            self.traffic_min_unit = value
                            self.traffic_min_unit.value_namespace = name_space
                            self.traffic_min_unit.value_namespace_prefix = name_space_prefix
                        if(value_path == "traffic-peak-rate"):
                            self.traffic_peak_rate = value
                            self.traffic_peak_rate.value_namespace = name_space
                            self.traffic_peak_rate.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.tspec_type.is_set or
                        (self.g709otn_tspec is not None and self.g709otn_tspec.has_data()) or
                        (self.intsrv_tspec is not None and self.intsrv_tspec.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.tspec_type.yfilter != YFilter.not_set or
                        (self.g709otn_tspec is not None and self.g709otn_tspec.has_operation()) or
                        (self.intsrv_tspec is not None and self.intsrv_tspec.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "generic-traffic-spec" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/pxsb-details/pxsb-detail/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.tspec_type.is_set or self.tspec_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tspec_type.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "g709otn-tspec"):
                        if (self.g709otn_tspec is None):
                            self.g709otn_tspec = Rsvp.PxsbDetails.PxsbDetail.GenericTrafficSpec.G709OtnTspec()
                            self.g709otn_tspec.parent = self
                            self._children_name_map["g709otn_tspec"] = "g709otn-tspec"
                        return self.g709otn_tspec

                    if (child_yang_name == "intsrv-tspec"):
                        if (self.intsrv_tspec is None):
                            self.intsrv_tspec = Rsvp.PxsbDetails.PxsbDetail.GenericTrafficSpec.IntsrvTspec()
                            self.intsrv_tspec.parent = self
                            self._children_name_map["intsrv_tspec"] = "intsrv-tspec"
                        return self.intsrv_tspec

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "g709otn-tspec" or name == "intsrv-tspec" or name == "tspec-type"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "tspec-type"):
                        self.tspec_type = value
                        self.tspec_type.value_namespace = name_space
                        self.tspec_type.value_namespace_prefix = name_space_prefix


            class Hop(Entity):
                """
                Path Hop Info
                
                .. attribute:: neighbor_address
                
                	IP address of the neighbor
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: neighbor_logical_interface_name
                
                	Neighbor Logical Interface Name
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.PxsbDetails.PxsbDetail.Hop, self).__init__()

                    self.yang_name = "hop"
                    self.yang_parent_name = "pxsb-detail"

                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                    self.neighbor_logical_interface_name = YLeaf(YType.str, "neighbor-logical-interface-name")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("neighbor_address",
                                    "neighbor_logical_interface_name") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.PxsbDetails.PxsbDetail.Hop, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.PxsbDetails.PxsbDetail.Hop, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.neighbor_address.is_set or
                        self.neighbor_logical_interface_name.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.neighbor_address.yfilter != YFilter.not_set or
                        self.neighbor_logical_interface_name.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "hop" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/pxsb-details/pxsb-detail/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                    if (self.neighbor_logical_interface_name.is_set or self.neighbor_logical_interface_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.neighbor_logical_interface_name.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "neighbor-address" or name == "neighbor-logical-interface-name"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "neighbor-address"):
                        self.neighbor_address = value
                        self.neighbor_address.value_namespace = name_space
                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "neighbor-logical-interface-name"):
                        self.neighbor_logical_interface_name = value
                        self.neighbor_logical_interface_name.value_namespace = name_space
                        self.neighbor_logical_interface_name.value_namespace_prefix = name_space_prefix


            class RsvpHeader(Entity):
                """
                RSVP Header
                
                .. attribute:: ip_source_address
                
                	IP Source Address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: ip_tos
                
                	IP Type of Service
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: ip_ttl
                
                	IP TTL
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: rsvp_header_flags
                
                	RSVP Header Flags (defined in RFC2205 Section 3 .1.1)
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: rsvp_message_type
                
                	RSVP Message Type
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: rsvp_ttl
                
                	RSVP TTL
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: rsvp_version
                
                	RSVP Version
                	**type**\:  int
                
                	**range:** 0..255
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.PxsbDetails.PxsbDetail.RsvpHeader, self).__init__()

                    self.yang_name = "rsvp-header"
                    self.yang_parent_name = "pxsb-detail"

                    self.ip_source_address = YLeaf(YType.str, "ip-source-address")

                    self.ip_tos = YLeaf(YType.uint8, "ip-tos")

                    self.ip_ttl = YLeaf(YType.uint8, "ip-ttl")

                    self.rsvp_header_flags = YLeaf(YType.uint8, "rsvp-header-flags")

                    self.rsvp_message_type = YLeaf(YType.uint8, "rsvp-message-type")

                    self.rsvp_ttl = YLeaf(YType.uint8, "rsvp-ttl")

                    self.rsvp_version = YLeaf(YType.uint8, "rsvp-version")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("ip_source_address",
                                    "ip_tos",
                                    "ip_ttl",
                                    "rsvp_header_flags",
                                    "rsvp_message_type",
                                    "rsvp_ttl",
                                    "rsvp_version") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.PxsbDetails.PxsbDetail.RsvpHeader, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.PxsbDetails.PxsbDetail.RsvpHeader, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.ip_source_address.is_set or
                        self.ip_tos.is_set or
                        self.ip_ttl.is_set or
                        self.rsvp_header_flags.is_set or
                        self.rsvp_message_type.is_set or
                        self.rsvp_ttl.is_set or
                        self.rsvp_version.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.ip_source_address.yfilter != YFilter.not_set or
                        self.ip_tos.yfilter != YFilter.not_set or
                        self.ip_ttl.yfilter != YFilter.not_set or
                        self.rsvp_header_flags.yfilter != YFilter.not_set or
                        self.rsvp_message_type.yfilter != YFilter.not_set or
                        self.rsvp_ttl.yfilter != YFilter.not_set or
                        self.rsvp_version.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "rsvp-header" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/pxsb-details/pxsb-detail/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.ip_source_address.is_set or self.ip_source_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ip_source_address.get_name_leafdata())
                    if (self.ip_tos.is_set or self.ip_tos.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ip_tos.get_name_leafdata())
                    if (self.ip_ttl.is_set or self.ip_ttl.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ip_ttl.get_name_leafdata())
                    if (self.rsvp_header_flags.is_set or self.rsvp_header_flags.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_header_flags.get_name_leafdata())
                    if (self.rsvp_message_type.is_set or self.rsvp_message_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_message_type.get_name_leafdata())
                    if (self.rsvp_ttl.is_set or self.rsvp_ttl.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_ttl.get_name_leafdata())
                    if (self.rsvp_version.is_set or self.rsvp_version.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_version.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ip-source-address" or name == "ip-tos" or name == "ip-ttl" or name == "rsvp-header-flags" or name == "rsvp-message-type" or name == "rsvp-ttl" or name == "rsvp-version"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "ip-source-address"):
                        self.ip_source_address = value
                        self.ip_source_address.value_namespace = name_space
                        self.ip_source_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "ip-tos"):
                        self.ip_tos = value
                        self.ip_tos.value_namespace = name_space
                        self.ip_tos.value_namespace_prefix = name_space_prefix
                    if(value_path == "ip-ttl"):
                        self.ip_ttl = value
                        self.ip_ttl.value_namespace = name_space
                        self.ip_ttl.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-header-flags"):
                        self.rsvp_header_flags = value
                        self.rsvp_header_flags.value_namespace = name_space
                        self.rsvp_header_flags.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-message-type"):
                        self.rsvp_message_type = value
                        self.rsvp_message_type.value_namespace = name_space
                        self.rsvp_message_type.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-ttl"):
                        self.rsvp_ttl = value
                        self.rsvp_ttl.value_namespace = name_space
                        self.rsvp_ttl.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-version"):
                        self.rsvp_version = value
                        self.rsvp_version.value_namespace = name_space
                        self.rsvp_version.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.destination_address.is_set or
                    self.destination_port.is_set or
                    self.dynamic_state.is_set or
                    self.extended_tunnel_id.is_set or
                    self.input_interface.is_set or
                    self.p2mp_id.is_set or
                    self.protocol.is_set or
                    self.session_type.is_set or
                    self.source_address.is_set or
                    self.source_port.is_set or
                    self.sub_group_id.is_set or
                    self.sub_group_origin.is_set or
                    self.vrf_name.is_set or
                    (self.generic_traffic_spec is not None and self.generic_traffic_spec.has_data()) or
                    (self.hop is not None and self.hop.has_data()) or
                    (self.rsvp_header is not None and self.rsvp_header.has_data()) or
                    (self.s2l_sub_lsp is not None and self.s2l_sub_lsp.has_data()) or
                    (self.session is not None and self.session.has_data()) or
                    (self.template is not None and self.template.has_data()) or
                    (self.traffic_spec is not None and self.traffic_spec.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.destination_address.yfilter != YFilter.not_set or
                    self.destination_port.yfilter != YFilter.not_set or
                    self.dynamic_state.yfilter != YFilter.not_set or
                    self.extended_tunnel_id.yfilter != YFilter.not_set or
                    self.input_interface.yfilter != YFilter.not_set or
                    self.p2mp_id.yfilter != YFilter.not_set or
                    self.protocol.yfilter != YFilter.not_set or
                    self.session_type.yfilter != YFilter.not_set or
                    self.source_address.yfilter != YFilter.not_set or
                    self.source_port.yfilter != YFilter.not_set or
                    self.sub_group_id.yfilter != YFilter.not_set or
                    self.sub_group_origin.yfilter != YFilter.not_set or
                    self.vrf_name.yfilter != YFilter.not_set or
                    (self.generic_traffic_spec is not None and self.generic_traffic_spec.has_operation()) or
                    (self.hop is not None and self.hop.has_operation()) or
                    (self.rsvp_header is not None and self.rsvp_header.has_operation()) or
                    (self.s2l_sub_lsp is not None and self.s2l_sub_lsp.has_operation()) or
                    (self.session is not None and self.session.has_operation()) or
                    (self.template is not None and self.template.has_operation()) or
                    (self.traffic_spec is not None and self.traffic_spec.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "pxsb-detail" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/pxsb-details/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_address.get_name_leafdata())
                if (self.destination_port.is_set or self.destination_port.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_port.get_name_leafdata())
                if (self.dynamic_state.is_set or self.dynamic_state.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.dynamic_state.get_name_leafdata())
                if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                if (self.input_interface.is_set or self.input_interface.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.input_interface.get_name_leafdata())
                if (self.p2mp_id.is_set or self.p2mp_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.p2mp_id.get_name_leafdata())
                if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.protocol.get_name_leafdata())
                if (self.session_type.is_set or self.session_type.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.session_type.get_name_leafdata())
                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_address.get_name_leafdata())
                if (self.source_port.is_set or self.source_port.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_port.get_name_leafdata())
                if (self.sub_group_id.is_set or self.sub_group_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.sub_group_id.get_name_leafdata())
                if (self.sub_group_origin.is_set or self.sub_group_origin.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.sub_group_origin.get_name_leafdata())
                if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.vrf_name.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "generic-traffic-spec"):
                    if (self.generic_traffic_spec is None):
                        self.generic_traffic_spec = Rsvp.PxsbDetails.PxsbDetail.GenericTrafficSpec()
                        self.generic_traffic_spec.parent = self
                        self._children_name_map["generic_traffic_spec"] = "generic-traffic-spec"
                    return self.generic_traffic_spec

                if (child_yang_name == "hop"):
                    if (self.hop is None):
                        self.hop = Rsvp.PxsbDetails.PxsbDetail.Hop()
                        self.hop.parent = self
                        self._children_name_map["hop"] = "hop"
                    return self.hop

                if (child_yang_name == "rsvp-header"):
                    if (self.rsvp_header is None):
                        self.rsvp_header = Rsvp.PxsbDetails.PxsbDetail.RsvpHeader()
                        self.rsvp_header.parent = self
                        self._children_name_map["rsvp_header"] = "rsvp-header"
                    return self.rsvp_header

                if (child_yang_name == "s2l-sub-lsp"):
                    if (self.s2l_sub_lsp is None):
                        self.s2l_sub_lsp = Rsvp.PxsbDetails.PxsbDetail.S2LSubLsp()
                        self.s2l_sub_lsp.parent = self
                        self._children_name_map["s2l_sub_lsp"] = "s2l-sub-lsp"
                    return self.s2l_sub_lsp

                if (child_yang_name == "session"):
                    if (self.session is None):
                        self.session = Rsvp.PxsbDetails.PxsbDetail.Session()
                        self.session.parent = self
                        self._children_name_map["session"] = "session"
                    return self.session

                if (child_yang_name == "template"):
                    if (self.template is None):
                        self.template = Rsvp.PxsbDetails.PxsbDetail.Template()
                        self.template.parent = self
                        self._children_name_map["template"] = "template"
                    return self.template

                if (child_yang_name == "traffic-spec"):
                    if (self.traffic_spec is None):
                        self.traffic_spec = Rsvp.PxsbDetails.PxsbDetail.TrafficSpec()
                        self.traffic_spec.parent = self
                        self._children_name_map["traffic_spec"] = "traffic-spec"
                    return self.traffic_spec

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "generic-traffic-spec" or name == "hop" or name == "rsvp-header" or name == "s2l-sub-lsp" or name == "session" or name == "template" or name == "traffic-spec" or name == "destination-address" or name == "destination-port" or name == "dynamic-state" or name == "extended-tunnel-id" or name == "input-interface" or name == "p2mp-id" or name == "protocol" or name == "session-type" or name == "source-address" or name == "source-port" or name == "sub-group-id" or name == "sub-group-origin" or name == "vrf-name"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "destination-address"):
                    self.destination_address = value
                    self.destination_address.value_namespace = name_space
                    self.destination_address.value_namespace_prefix = name_space_prefix
                if(value_path == "destination-port"):
                    self.destination_port = value
                    self.destination_port.value_namespace = name_space
                    self.destination_port.value_namespace_prefix = name_space_prefix
                if(value_path == "dynamic-state"):
                    self.dynamic_state = value
                    self.dynamic_state.value_namespace = name_space
                    self.dynamic_state.value_namespace_prefix = name_space_prefix
                if(value_path == "extended-tunnel-id"):
                    self.extended_tunnel_id = value
                    self.extended_tunnel_id.value_namespace = name_space
                    self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                if(value_path == "input-interface"):
                    self.input_interface = value
                    self.input_interface.value_namespace = name_space
                    self.input_interface.value_namespace_prefix = name_space_prefix
                if(value_path == "p2mp-id"):
                    self.p2mp_id = value
                    self.p2mp_id.value_namespace = name_space
                    self.p2mp_id.value_namespace_prefix = name_space_prefix
                if(value_path == "protocol"):
                    self.protocol = value
                    self.protocol.value_namespace = name_space
                    self.protocol.value_namespace_prefix = name_space_prefix
                if(value_path == "session-type"):
                    self.session_type = value
                    self.session_type.value_namespace = name_space
                    self.session_type.value_namespace_prefix = name_space_prefix
                if(value_path == "source-address"):
                    self.source_address = value
                    self.source_address.value_namespace = name_space
                    self.source_address.value_namespace_prefix = name_space_prefix
                if(value_path == "source-port"):
                    self.source_port = value
                    self.source_port.value_namespace = name_space
                    self.source_port.value_namespace_prefix = name_space_prefix
                if(value_path == "sub-group-id"):
                    self.sub_group_id = value
                    self.sub_group_id.value_namespace = name_space
                    self.sub_group_id.value_namespace_prefix = name_space_prefix
                if(value_path == "sub-group-origin"):
                    self.sub_group_origin = value
                    self.sub_group_origin.value_namespace = name_space
                    self.sub_group_origin.value_namespace_prefix = name_space_prefix
                if(value_path == "vrf-name"):
                    self.vrf_name = value
                    self.vrf_name.value_namespace = name_space
                    self.vrf_name.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.pxsb_detail:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.pxsb_detail:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "pxsb-details" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "pxsb-detail"):
                for c in self.pxsb_detail:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = Rsvp.PxsbDetails.PxsbDetail()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.pxsb_detail.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "pxsb-detail"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class RxsbDetails(Entity):
        """
        Table of detailed RXSB info
        
        .. attribute:: rxsb_detail
        
        	Detailed RXSB info
        	**type**\: list of    :py:class:`RxsbDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RxsbDetails.RxsbDetail>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Rsvp.RxsbDetails, self).__init__()

            self.yang_name = "rxsb-details"
            self.yang_parent_name = "rsvp"

            self.rxsb_detail = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(Rsvp.RxsbDetails, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(Rsvp.RxsbDetails, self).__setattr__(name, value)


        class RxsbDetail(Entity):
            """
            Detailed RXSB info
            
            .. attribute:: destination_address
            
            	Destination Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: destination_port
            
            	Destination Port
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: dynamic_state
            
            	Dynamic State Handle
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: extended_tunnel_id
            
            	Extended Tunnel ID
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: filter
            
            	RSVP Filter
            	**type**\:   :py:class:`Filter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RxsbDetails.RxsbDetail.Filter>`
            
            .. attribute:: flow_spec
            
            	Flow Spec Information
            	**type**\:   :py:class:`FlowSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RxsbDetails.RxsbDetail.FlowSpec>`
            
            .. attribute:: generic_flow_spec
            
            	Generic Flow Spec Information
            	**type**\:   :py:class:`GenericFlowSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RxsbDetails.RxsbDetail.GenericFlowSpec>`
            
            .. attribute:: hop
            
            	Path Hop Info
            	**type**\:   :py:class:`Hop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RxsbDetails.RxsbDetail.Hop>`
            
            .. attribute:: input_interface
            
            	Path Input Interface
            	**type**\:  str
            
            .. attribute:: p2mp_id
            
            	P2MP ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: protocol
            
            	Protocol
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: rsvp_header
            
            	RSVP Header
            	**type**\:   :py:class:`RsvpHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RxsbDetails.RxsbDetail.RsvpHeader>`
            
            .. attribute:: s2l_sub_lsp
            
            	RSVP S2L Sub\-LSP information
            	**type**\:   :py:class:`S2LSubLsp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RxsbDetails.RxsbDetail.S2LSubLsp>`
            
            .. attribute:: session
            
            	RSVP Session Information
            	**type**\:   :py:class:`Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RxsbDetails.RxsbDetail.Session>`
            
            .. attribute:: session_type
            
            	Session Type
            	**type**\:   :py:class:`RsvpSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpSession>`
            
            .. attribute:: source_address
            
            	Source Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: source_port
            
            	Source Port
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: style
            
            	RSVP Style
            	**type**\:   :py:class:`Style <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RxsbDetails.RxsbDetail.Style>`
            
            .. attribute:: sub_group_id
            
            	Subgroup ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: sub_group_origin
            
            	Subgroup Origin
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: vrf_name
            
            	VRF Name
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Rsvp.RxsbDetails.RxsbDetail, self).__init__()

                self.yang_name = "rxsb-detail"
                self.yang_parent_name = "rxsb-details"

                self.destination_address = YLeaf(YType.str, "destination-address")

                self.destination_port = YLeaf(YType.int32, "destination-port")

                self.dynamic_state = YLeaf(YType.uint32, "dynamic-state")

                self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                self.input_interface = YLeaf(YType.str, "input-interface")

                self.p2mp_id = YLeaf(YType.int32, "p2mp-id")

                self.protocol = YLeaf(YType.int32, "protocol")

                self.session_type = YLeaf(YType.enumeration, "session-type")

                self.source_address = YLeaf(YType.str, "source-address")

                self.source_port = YLeaf(YType.int32, "source-port")

                self.sub_group_id = YLeaf(YType.int32, "sub-group-id")

                self.sub_group_origin = YLeaf(YType.str, "sub-group-origin")

                self.vrf_name = YLeaf(YType.str, "vrf-name")

                self.filter = Rsvp.RxsbDetails.RxsbDetail.Filter()
                self.filter.parent = self
                self._children_name_map["filter"] = "filter"
                self._children_yang_names.add("filter")

                self.flow_spec = Rsvp.RxsbDetails.RxsbDetail.FlowSpec()
                self.flow_spec.parent = self
                self._children_name_map["flow_spec"] = "flow-spec"
                self._children_yang_names.add("flow-spec")

                self.generic_flow_spec = Rsvp.RxsbDetails.RxsbDetail.GenericFlowSpec()
                self.generic_flow_spec.parent = self
                self._children_name_map["generic_flow_spec"] = "generic-flow-spec"
                self._children_yang_names.add("generic-flow-spec")

                self.hop = Rsvp.RxsbDetails.RxsbDetail.Hop()
                self.hop.parent = self
                self._children_name_map["hop"] = "hop"
                self._children_yang_names.add("hop")

                self.rsvp_header = Rsvp.RxsbDetails.RxsbDetail.RsvpHeader()
                self.rsvp_header.parent = self
                self._children_name_map["rsvp_header"] = "rsvp-header"
                self._children_yang_names.add("rsvp-header")

                self.s2l_sub_lsp = Rsvp.RxsbDetails.RxsbDetail.S2LSubLsp()
                self.s2l_sub_lsp.parent = self
                self._children_name_map["s2l_sub_lsp"] = "s2l-sub-lsp"
                self._children_yang_names.add("s2l-sub-lsp")

                self.session = Rsvp.RxsbDetails.RxsbDetail.Session()
                self.session.parent = self
                self._children_name_map["session"] = "session"
                self._children_yang_names.add("session")

                self.style = Rsvp.RxsbDetails.RxsbDetail.Style()
                self.style.parent = self
                self._children_name_map["style"] = "style"
                self._children_yang_names.add("style")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("destination_address",
                                "destination_port",
                                "dynamic_state",
                                "extended_tunnel_id",
                                "input_interface",
                                "p2mp_id",
                                "protocol",
                                "session_type",
                                "source_address",
                                "source_port",
                                "sub_group_id",
                                "sub_group_origin",
                                "vrf_name") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Rsvp.RxsbDetails.RxsbDetail, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Rsvp.RxsbDetails.RxsbDetail, self).__setattr__(name, value)


            class Session(Entity):
                """
                RSVP Session Information
                
                .. attribute:: rsvp_session
                
                	RSVP Session
                	**type**\:   :py:class:`RsvpSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RxsbDetails.RxsbDetail.Session.RsvpSession>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.RxsbDetails.RxsbDetail.Session, self).__init__()

                    self.yang_name = "session"
                    self.yang_parent_name = "rxsb-detail"

                    self.rsvp_session = Rsvp.RxsbDetails.RxsbDetail.Session.RsvpSession()
                    self.rsvp_session.parent = self
                    self._children_name_map["rsvp_session"] = "rsvp-session"
                    self._children_yang_names.add("rsvp-session")


                class RsvpSession(Entity):
                    """
                    RSVP Session
                    
                    .. attribute:: ipv4
                    
                    	UDP IPv4 session
                    	**type**\:   :py:class:`Ipv4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RxsbDetails.RxsbDetail.Session.RsvpSession.Ipv4>`
                    
                    .. attribute:: ipv4_lsp_session
                    
                    	IPv4 LSP session
                    	**type**\:   :py:class:`Ipv4LspSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RxsbDetails.RxsbDetail.Session.RsvpSession.Ipv4LspSession>`
                    
                    .. attribute:: ipv4_p2mp_lsp_session
                    
                    	IPv4 P2MP LSP session
                    	**type**\:   :py:class:`Ipv4P2MpLspSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RxsbDetails.RxsbDetail.Session.RsvpSession.Ipv4P2MpLspSession>`
                    
                    .. attribute:: ipv4_uni_session
                    
                    	IPv4 UNI session
                    	**type**\:   :py:class:`Ipv4UniSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RxsbDetails.RxsbDetail.Session.RsvpSession.Ipv4UniSession>`
                    
                    .. attribute:: session_type
                    
                    	SessionType
                    	**type**\:   :py:class:`RsvpMgmtSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtSession>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.RxsbDetails.RxsbDetail.Session.RsvpSession, self).__init__()

                        self.yang_name = "rsvp-session"
                        self.yang_parent_name = "session"

                        self.session_type = YLeaf(YType.enumeration, "session-type")

                        self.ipv4 = Rsvp.RxsbDetails.RxsbDetail.Session.RsvpSession.Ipv4()
                        self.ipv4.parent = self
                        self._children_name_map["ipv4"] = "ipv4"
                        self._children_yang_names.add("ipv4")

                        self.ipv4_lsp_session = Rsvp.RxsbDetails.RxsbDetail.Session.RsvpSession.Ipv4LspSession()
                        self.ipv4_lsp_session.parent = self
                        self._children_name_map["ipv4_lsp_session"] = "ipv4-lsp-session"
                        self._children_yang_names.add("ipv4-lsp-session")

                        self.ipv4_p2mp_lsp_session = Rsvp.RxsbDetails.RxsbDetail.Session.RsvpSession.Ipv4P2MpLspSession()
                        self.ipv4_p2mp_lsp_session.parent = self
                        self._children_name_map["ipv4_p2mp_lsp_session"] = "ipv4-p2mp-lsp-session"
                        self._children_yang_names.add("ipv4-p2mp-lsp-session")

                        self.ipv4_uni_session = Rsvp.RxsbDetails.RxsbDetail.Session.RsvpSession.Ipv4UniSession()
                        self.ipv4_uni_session.parent = self
                        self._children_name_map["ipv4_uni_session"] = "ipv4-uni-session"
                        self._children_yang_names.add("ipv4-uni-session")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("session_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.RxsbDetails.RxsbDetail.Session.RsvpSession, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.RxsbDetails.RxsbDetail.Session.RsvpSession, self).__setattr__(name, value)


                    class Ipv4(Entity):
                        """
                        UDP IPv4 session
                        
                        .. attribute:: destination_address
                        
                        	Destination address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: destination_port
                        
                        	The Session Destination Port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: protocol
                        
                        	Protocol type (originally defined in RFC 790, further values in subsequent RFCs)
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.RxsbDetails.RxsbDetail.Session.RsvpSession.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "rsvp-session"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.destination_port = YLeaf(YType.uint16, "destination-port")

                            self.protocol = YLeaf(YType.uint8, "protocol")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "destination_port",
                                            "protocol") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.RxsbDetails.RxsbDetail.Session.RsvpSession.Ipv4, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.RxsbDetails.RxsbDetail.Session.RsvpSession.Ipv4, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination_address.is_set or
                                self.destination_port.is_set or
                                self.protocol.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.destination_port.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rxsb-details/rxsb-detail/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.destination_port.is_set or self.destination_port.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_port.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "destination-port" or name == "protocol"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "destination-port"):
                                self.destination_port = value
                                self.destination_port.value_namespace = name_space
                                self.destination_port.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix


                    class Ipv4LspSession(Entity):
                        """
                        IPv4 LSP session
                        
                        .. attribute:: destination_address
                        
                        	Destination address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: extended_tunnel_id
                        
                        	The Session Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: tunnel_id
                        
                        	The Session Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.RxsbDetails.RxsbDetail.Session.RsvpSession.Ipv4LspSession, self).__init__()

                            self.yang_name = "ipv4-lsp-session"
                            self.yang_parent_name = "rsvp-session"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                            self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "extended_tunnel_id",
                                            "tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.RxsbDetails.RxsbDetail.Session.RsvpSession.Ipv4LspSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.RxsbDetails.RxsbDetail.Session.RsvpSession.Ipv4LspSession, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination_address.is_set or
                                self.extended_tunnel_id.is_set or
                                self.tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.extended_tunnel_id.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-lsp-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rxsb-details/rxsb-detail/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "extended-tunnel-id" or name == "tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "extended-tunnel-id"):
                                self.extended_tunnel_id = value
                                self.extended_tunnel_id.value_namespace = name_space
                                self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix


                    class Ipv4UniSession(Entity):
                        """
                        IPv4 UNI session
                        
                        .. attribute:: destination_address
                        
                        	Destination address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: extended_address
                        
                        	The Session Extended Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: tunnel_id
                        
                        	The Session Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.RxsbDetails.RxsbDetail.Session.RsvpSession.Ipv4UniSession, self).__init__()

                            self.yang_name = "ipv4-uni-session"
                            self.yang_parent_name = "rsvp-session"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.extended_address = YLeaf(YType.str, "extended-address")

                            self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "extended_address",
                                            "tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.RxsbDetails.RxsbDetail.Session.RsvpSession.Ipv4UniSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.RxsbDetails.RxsbDetail.Session.RsvpSession.Ipv4UniSession, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination_address.is_set or
                                self.extended_address.is_set or
                                self.tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.extended_address.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-uni-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rxsb-details/rxsb-detail/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.extended_address.is_set or self.extended_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_address.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "extended-address" or name == "tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "extended-address"):
                                self.extended_address = value
                                self.extended_address.value_namespace = name_space
                                self.extended_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix


                    class Ipv4P2MpLspSession(Entity):
                        """
                        IPv4 P2MP LSP session
                        
                        .. attribute:: extended_tunnel_id
                        
                        	The Session Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: p2mp_id
                        
                        	The Point to Multipoint ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tunnel_id
                        
                        	The Session Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.RxsbDetails.RxsbDetail.Session.RsvpSession.Ipv4P2MpLspSession, self).__init__()

                            self.yang_name = "ipv4-p2mp-lsp-session"
                            self.yang_parent_name = "rsvp-session"

                            self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                            self.p2mp_id = YLeaf(YType.uint32, "p2mp-id")

                            self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("extended_tunnel_id",
                                            "p2mp_id",
                                            "tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.RxsbDetails.RxsbDetail.Session.RsvpSession.Ipv4P2MpLspSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.RxsbDetails.RxsbDetail.Session.RsvpSession.Ipv4P2MpLspSession, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.extended_tunnel_id.is_set or
                                self.p2mp_id.is_set or
                                self.tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.extended_tunnel_id.yfilter != YFilter.not_set or
                                self.p2mp_id.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-p2mp-lsp-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rxsb-details/rxsb-detail/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                            if (self.p2mp_id.is_set or self.p2mp_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.p2mp_id.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "extended-tunnel-id" or name == "p2mp-id" or name == "tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "extended-tunnel-id"):
                                self.extended_tunnel_id = value
                                self.extended_tunnel_id.value_namespace = name_space
                                self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "p2mp-id"):
                                self.p2mp_id = value
                                self.p2mp_id.value_namespace = name_space
                                self.p2mp_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.session_type.is_set or
                            (self.ipv4 is not None and self.ipv4.has_data()) or
                            (self.ipv4_lsp_session is not None and self.ipv4_lsp_session.has_data()) or
                            (self.ipv4_p2mp_lsp_session is not None and self.ipv4_p2mp_lsp_session.has_data()) or
                            (self.ipv4_uni_session is not None and self.ipv4_uni_session.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.session_type.yfilter != YFilter.not_set or
                            (self.ipv4 is not None and self.ipv4.has_operation()) or
                            (self.ipv4_lsp_session is not None and self.ipv4_lsp_session.has_operation()) or
                            (self.ipv4_p2mp_lsp_session is not None and self.ipv4_p2mp_lsp_session.has_operation()) or
                            (self.ipv4_uni_session is not None and self.ipv4_uni_session.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rsvp-session" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rxsb-details/rxsb-detail/session/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.session_type.is_set or self.session_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.session_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "ipv4"):
                            if (self.ipv4 is None):
                                self.ipv4 = Rsvp.RxsbDetails.RxsbDetail.Session.RsvpSession.Ipv4()
                                self.ipv4.parent = self
                                self._children_name_map["ipv4"] = "ipv4"
                            return self.ipv4

                        if (child_yang_name == "ipv4-lsp-session"):
                            if (self.ipv4_lsp_session is None):
                                self.ipv4_lsp_session = Rsvp.RxsbDetails.RxsbDetail.Session.RsvpSession.Ipv4LspSession()
                                self.ipv4_lsp_session.parent = self
                                self._children_name_map["ipv4_lsp_session"] = "ipv4-lsp-session"
                            return self.ipv4_lsp_session

                        if (child_yang_name == "ipv4-p2mp-lsp-session"):
                            if (self.ipv4_p2mp_lsp_session is None):
                                self.ipv4_p2mp_lsp_session = Rsvp.RxsbDetails.RxsbDetail.Session.RsvpSession.Ipv4P2MpLspSession()
                                self.ipv4_p2mp_lsp_session.parent = self
                                self._children_name_map["ipv4_p2mp_lsp_session"] = "ipv4-p2mp-lsp-session"
                            return self.ipv4_p2mp_lsp_session

                        if (child_yang_name == "ipv4-uni-session"):
                            if (self.ipv4_uni_session is None):
                                self.ipv4_uni_session = Rsvp.RxsbDetails.RxsbDetail.Session.RsvpSession.Ipv4UniSession()
                                self.ipv4_uni_session.parent = self
                                self._children_name_map["ipv4_uni_session"] = "ipv4-uni-session"
                            return self.ipv4_uni_session

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ipv4" or name == "ipv4-lsp-session" or name == "ipv4-p2mp-lsp-session" or name == "ipv4-uni-session" or name == "session-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "session-type"):
                            self.session_type = value
                            self.session_type.value_namespace = name_space
                            self.session_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (self.rsvp_session is not None and self.rsvp_session.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.rsvp_session is not None and self.rsvp_session.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "session" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rxsb-details/rxsb-detail/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "rsvp-session"):
                        if (self.rsvp_session is None):
                            self.rsvp_session = Rsvp.RxsbDetails.RxsbDetail.Session.RsvpSession()
                            self.rsvp_session.parent = self
                            self._children_name_map["rsvp_session"] = "rsvp-session"
                        return self.rsvp_session

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "rsvp-session"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class S2LSubLsp(Entity):
                """
                RSVP S2L Sub\-LSP information
                
                .. attribute:: s2l_destination_address
                
                	S2L Sub\-LSP Destination Address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.RxsbDetails.RxsbDetail.S2LSubLsp, self).__init__()

                    self.yang_name = "s2l-sub-lsp"
                    self.yang_parent_name = "rxsb-detail"

                    self.s2l_destination_address = YLeaf(YType.str, "s2l-destination-address")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("s2l_destination_address") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.RxsbDetails.RxsbDetail.S2LSubLsp, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.RxsbDetails.RxsbDetail.S2LSubLsp, self).__setattr__(name, value)

                def has_data(self):
                    return self.s2l_destination_address.is_set

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.s2l_destination_address.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "s2l-sub-lsp" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rxsb-details/rxsb-detail/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.s2l_destination_address.is_set or self.s2l_destination_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.s2l_destination_address.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "s2l-destination-address"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "s2l-destination-address"):
                        self.s2l_destination_address = value
                        self.s2l_destination_address.value_namespace = name_space
                        self.s2l_destination_address.value_namespace_prefix = name_space_prefix


            class Style(Entity):
                """
                RSVP Style
                
                .. attribute:: reservation_type
                
                	The Reservation Type\: WF, SE or FF
                	**type**\:   :py:class:`RsvpMgmtReservationTypeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtReservationTypeEnum>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.RxsbDetails.RxsbDetail.Style, self).__init__()

                    self.yang_name = "style"
                    self.yang_parent_name = "rxsb-detail"

                    self.reservation_type = YLeaf(YType.enumeration, "reservation-type")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("reservation_type") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.RxsbDetails.RxsbDetail.Style, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.RxsbDetails.RxsbDetail.Style, self).__setattr__(name, value)

                def has_data(self):
                    return self.reservation_type.is_set

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.reservation_type.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "style" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rxsb-details/rxsb-detail/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.reservation_type.is_set or self.reservation_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reservation_type.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "reservation-type"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "reservation-type"):
                        self.reservation_type = value
                        self.reservation_type.value_namespace = name_space
                        self.reservation_type.value_namespace_prefix = name_space_prefix


            class Filter(Entity):
                """
                RSVP Filter
                
                .. attribute:: rsvp_filter
                
                	RSVP Filter
                	**type**\:   :py:class:`RsvpFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RxsbDetails.RxsbDetail.Filter.RsvpFilter>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.RxsbDetails.RxsbDetail.Filter, self).__init__()

                    self.yang_name = "filter"
                    self.yang_parent_name = "rxsb-detail"

                    self.rsvp_filter = Rsvp.RxsbDetails.RxsbDetail.Filter.RsvpFilter()
                    self.rsvp_filter.parent = self
                    self._children_name_map["rsvp_filter"] = "rsvp-filter"
                    self._children_yang_names.add("rsvp-filter")


                class RsvpFilter(Entity):
                    """
                    RSVP Filter
                    
                    .. attribute:: filter_type
                    
                    	FilterType
                    	**type**\:   :py:class:`RsvpMgmtFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtFilter>`
                    
                    .. attribute:: p2mp_ipv4_session
                    
                    	IPv4 P2MP LSP FilterSpec
                    	**type**\:   :py:class:`P2MpIpv4Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RxsbDetails.RxsbDetail.Filter.RsvpFilter.P2MpIpv4Session>`
                    
                    .. attribute:: udp_ipv4_session
                    
                    	UDP IPV4 FilterSpec
                    	**type**\:   :py:class:`UdpIpv4Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RxsbDetails.RxsbDetail.Filter.RsvpFilter.UdpIpv4Session>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.RxsbDetails.RxsbDetail.Filter.RsvpFilter, self).__init__()

                        self.yang_name = "rsvp-filter"
                        self.yang_parent_name = "filter"

                        self.filter_type = YLeaf(YType.enumeration, "filter-type")

                        self.p2mp_ipv4_session = Rsvp.RxsbDetails.RxsbDetail.Filter.RsvpFilter.P2MpIpv4Session()
                        self.p2mp_ipv4_session.parent = self
                        self._children_name_map["p2mp_ipv4_session"] = "p2mp-ipv4-session"
                        self._children_yang_names.add("p2mp-ipv4-session")

                        self.udp_ipv4_session = Rsvp.RxsbDetails.RxsbDetail.Filter.RsvpFilter.UdpIpv4Session()
                        self.udp_ipv4_session.parent = self
                        self._children_name_map["udp_ipv4_session"] = "udp-ipv4-session"
                        self._children_yang_names.add("udp-ipv4-session")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("filter_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.RxsbDetails.RxsbDetail.Filter.RsvpFilter, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.RxsbDetails.RxsbDetail.Filter.RsvpFilter, self).__setattr__(name, value)


                    class UdpIpv4Session(Entity):
                        """
                        UDP IPV4 FilterSpec
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source_port
                        
                        	Source Port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.RxsbDetails.RxsbDetail.Filter.RsvpFilter.UdpIpv4Session, self).__init__()

                            self.yang_name = "udp-ipv4-session"
                            self.yang_parent_name = "rsvp-filter"

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.source_port = YLeaf(YType.uint16, "source-port")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("source_address",
                                            "source_port") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.RxsbDetails.RxsbDetail.Filter.RsvpFilter.UdpIpv4Session, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.RxsbDetails.RxsbDetail.Filter.RsvpFilter.UdpIpv4Session, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.source_address.is_set or
                                self.source_port.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                self.source_port.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "udp-ipv4-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rxsb-details/rxsb-detail/filter/rsvp-filter/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())
                            if (self.source_port.is_set or self.source_port.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_port.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "source-address" or name == "source-port"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-port"):
                                self.source_port = value
                                self.source_port.value_namespace = name_space
                                self.source_port.value_namespace_prefix = name_space_prefix


                    class P2MpIpv4Session(Entity):
                        """
                        IPv4 P2MP LSP FilterSpec
                        
                        .. attribute:: p2mp_sub_group_origin
                        
                        	Point to Multipoint SubGroup Origin
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source_port
                        
                        	Source Port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: sub_group_id
                        
                        	Point to Multipoint Subgroup ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.RxsbDetails.RxsbDetail.Filter.RsvpFilter.P2MpIpv4Session, self).__init__()

                            self.yang_name = "p2mp-ipv4-session"
                            self.yang_parent_name = "rsvp-filter"

                            self.p2mp_sub_group_origin = YLeaf(YType.str, "p2mp-sub-group-origin")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.source_port = YLeaf(YType.uint16, "source-port")

                            self.sub_group_id = YLeaf(YType.uint16, "sub-group-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("p2mp_sub_group_origin",
                                            "source_address",
                                            "source_port",
                                            "sub_group_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.RxsbDetails.RxsbDetail.Filter.RsvpFilter.P2MpIpv4Session, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.RxsbDetails.RxsbDetail.Filter.RsvpFilter.P2MpIpv4Session, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.p2mp_sub_group_origin.is_set or
                                self.source_address.is_set or
                                self.source_port.is_set or
                                self.sub_group_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.p2mp_sub_group_origin.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                self.source_port.yfilter != YFilter.not_set or
                                self.sub_group_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "p2mp-ipv4-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rxsb-details/rxsb-detail/filter/rsvp-filter/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.p2mp_sub_group_origin.is_set or self.p2mp_sub_group_origin.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.p2mp_sub_group_origin.get_name_leafdata())
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())
                            if (self.source_port.is_set or self.source_port.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_port.get_name_leafdata())
                            if (self.sub_group_id.is_set or self.sub_group_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sub_group_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "p2mp-sub-group-origin" or name == "source-address" or name == "source-port" or name == "sub-group-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "p2mp-sub-group-origin"):
                                self.p2mp_sub_group_origin = value
                                self.p2mp_sub_group_origin.value_namespace = name_space
                                self.p2mp_sub_group_origin.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-port"):
                                self.source_port = value
                                self.source_port.value_namespace = name_space
                                self.source_port.value_namespace_prefix = name_space_prefix
                            if(value_path == "sub-group-id"):
                                self.sub_group_id = value
                                self.sub_group_id.value_namespace = name_space
                                self.sub_group_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.filter_type.is_set or
                            (self.p2mp_ipv4_session is not None and self.p2mp_ipv4_session.has_data()) or
                            (self.udp_ipv4_session is not None and self.udp_ipv4_session.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.filter_type.yfilter != YFilter.not_set or
                            (self.p2mp_ipv4_session is not None and self.p2mp_ipv4_session.has_operation()) or
                            (self.udp_ipv4_session is not None and self.udp_ipv4_session.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rsvp-filter" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rxsb-details/rxsb-detail/filter/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.filter_type.is_set or self.filter_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.filter_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "p2mp-ipv4-session"):
                            if (self.p2mp_ipv4_session is None):
                                self.p2mp_ipv4_session = Rsvp.RxsbDetails.RxsbDetail.Filter.RsvpFilter.P2MpIpv4Session()
                                self.p2mp_ipv4_session.parent = self
                                self._children_name_map["p2mp_ipv4_session"] = "p2mp-ipv4-session"
                            return self.p2mp_ipv4_session

                        if (child_yang_name == "udp-ipv4-session"):
                            if (self.udp_ipv4_session is None):
                                self.udp_ipv4_session = Rsvp.RxsbDetails.RxsbDetail.Filter.RsvpFilter.UdpIpv4Session()
                                self.udp_ipv4_session.parent = self
                                self._children_name_map["udp_ipv4_session"] = "udp-ipv4-session"
                            return self.udp_ipv4_session

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "p2mp-ipv4-session" or name == "udp-ipv4-session" or name == "filter-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "filter-type"):
                            self.filter_type = value
                            self.filter_type.value_namespace = name_space
                            self.filter_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (self.rsvp_filter is not None and self.rsvp_filter.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.rsvp_filter is not None and self.rsvp_filter.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "filter" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rxsb-details/rxsb-detail/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "rsvp-filter"):
                        if (self.rsvp_filter is None):
                            self.rsvp_filter = Rsvp.RxsbDetails.RxsbDetail.Filter.RsvpFilter()
                            self.rsvp_filter.parent = self
                            self._children_name_map["rsvp_filter"] = "rsvp-filter"
                        return self.rsvp_filter

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "rsvp-filter"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class FlowSpec(Entity):
                """
                Flow Spec Information
                
                .. attribute:: flow_average_rate
                
                	The Flow Average Rate in bytes per second
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: byte/s
                
                .. attribute:: flow_max_burst
                
                	The Flow Maximum Burst
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: flow_max_unit
                
                	The Flow Maximum Unit
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: flow_min_unit
                
                	The Flow Minimum Unit
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: flow_peak_rate
                
                	The Flow Peak Rate in bytes per second
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: byte/s
                
                .. attribute:: flow_qos
                
                	The Flow Quality of Service
                	**type**\:   :py:class:`RsvpMgmtQosServiceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtQosServiceEnum>`
                
                .. attribute:: flow_requested_rate
                
                	The Flow Requested Rate in bytes per second
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: byte/s
                
                .. attribute:: flow_slack
                
                	The Flow Slack
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.RxsbDetails.RxsbDetail.FlowSpec, self).__init__()

                    self.yang_name = "flow-spec"
                    self.yang_parent_name = "rxsb-detail"

                    self.flow_average_rate = YLeaf(YType.uint64, "flow-average-rate")

                    self.flow_max_burst = YLeaf(YType.uint64, "flow-max-burst")

                    self.flow_max_unit = YLeaf(YType.uint32, "flow-max-unit")

                    self.flow_min_unit = YLeaf(YType.uint32, "flow-min-unit")

                    self.flow_peak_rate = YLeaf(YType.uint64, "flow-peak-rate")

                    self.flow_qos = YLeaf(YType.enumeration, "flow-qos")

                    self.flow_requested_rate = YLeaf(YType.uint64, "flow-requested-rate")

                    self.flow_slack = YLeaf(YType.uint32, "flow-slack")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("flow_average_rate",
                                    "flow_max_burst",
                                    "flow_max_unit",
                                    "flow_min_unit",
                                    "flow_peak_rate",
                                    "flow_qos",
                                    "flow_requested_rate",
                                    "flow_slack") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.RxsbDetails.RxsbDetail.FlowSpec, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.RxsbDetails.RxsbDetail.FlowSpec, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.flow_average_rate.is_set or
                        self.flow_max_burst.is_set or
                        self.flow_max_unit.is_set or
                        self.flow_min_unit.is_set or
                        self.flow_peak_rate.is_set or
                        self.flow_qos.is_set or
                        self.flow_requested_rate.is_set or
                        self.flow_slack.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.flow_average_rate.yfilter != YFilter.not_set or
                        self.flow_max_burst.yfilter != YFilter.not_set or
                        self.flow_max_unit.yfilter != YFilter.not_set or
                        self.flow_min_unit.yfilter != YFilter.not_set or
                        self.flow_peak_rate.yfilter != YFilter.not_set or
                        self.flow_qos.yfilter != YFilter.not_set or
                        self.flow_requested_rate.yfilter != YFilter.not_set or
                        self.flow_slack.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "flow-spec" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rxsb-details/rxsb-detail/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.flow_average_rate.is_set or self.flow_average_rate.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_average_rate.get_name_leafdata())
                    if (self.flow_max_burst.is_set or self.flow_max_burst.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_max_burst.get_name_leafdata())
                    if (self.flow_max_unit.is_set or self.flow_max_unit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_max_unit.get_name_leafdata())
                    if (self.flow_min_unit.is_set or self.flow_min_unit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_min_unit.get_name_leafdata())
                    if (self.flow_peak_rate.is_set or self.flow_peak_rate.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_peak_rate.get_name_leafdata())
                    if (self.flow_qos.is_set or self.flow_qos.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_qos.get_name_leafdata())
                    if (self.flow_requested_rate.is_set or self.flow_requested_rate.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_requested_rate.get_name_leafdata())
                    if (self.flow_slack.is_set or self.flow_slack.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_slack.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "flow-average-rate" or name == "flow-max-burst" or name == "flow-max-unit" or name == "flow-min-unit" or name == "flow-peak-rate" or name == "flow-qos" or name == "flow-requested-rate" or name == "flow-slack"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "flow-average-rate"):
                        self.flow_average_rate = value
                        self.flow_average_rate.value_namespace = name_space
                        self.flow_average_rate.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-max-burst"):
                        self.flow_max_burst = value
                        self.flow_max_burst.value_namespace = name_space
                        self.flow_max_burst.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-max-unit"):
                        self.flow_max_unit = value
                        self.flow_max_unit.value_namespace = name_space
                        self.flow_max_unit.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-min-unit"):
                        self.flow_min_unit = value
                        self.flow_min_unit.value_namespace = name_space
                        self.flow_min_unit.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-peak-rate"):
                        self.flow_peak_rate = value
                        self.flow_peak_rate.value_namespace = name_space
                        self.flow_peak_rate.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-qos"):
                        self.flow_qos = value
                        self.flow_qos.value_namespace = name_space
                        self.flow_qos.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-requested-rate"):
                        self.flow_requested_rate = value
                        self.flow_requested_rate.value_namespace = name_space
                        self.flow_requested_rate.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-slack"):
                        self.flow_slack = value
                        self.flow_slack.value_namespace = name_space
                        self.flow_slack.value_namespace_prefix = name_space_prefix


            class GenericFlowSpec(Entity):
                """
                Generic Flow Spec Information
                
                .. attribute:: flow_spec_type
                
                	FlowSpecType
                	**type**\:   :py:class:`RsvpMgmtFlowSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtFlowSpec>`
                
                .. attribute:: g709otn_flow_spec
                
                	G709 OTN FlowSpec
                	**type**\:   :py:class:`G709OtnFlowSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RxsbDetails.RxsbDetail.GenericFlowSpec.G709OtnFlowSpec>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.RxsbDetails.RxsbDetail.GenericFlowSpec, self).__init__()

                    self.yang_name = "generic-flow-spec"
                    self.yang_parent_name = "rxsb-detail"

                    self.flow_spec_type = YLeaf(YType.enumeration, "flow-spec-type")

                    self.g709otn_flow_spec = Rsvp.RxsbDetails.RxsbDetail.GenericFlowSpec.G709OtnFlowSpec()
                    self.g709otn_flow_spec.parent = self
                    self._children_name_map["g709otn_flow_spec"] = "g709otn-flow-spec"
                    self._children_yang_names.add("g709otn-flow-spec")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("flow_spec_type") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.RxsbDetails.RxsbDetail.GenericFlowSpec, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.RxsbDetails.RxsbDetail.GenericFlowSpec, self).__setattr__(name, value)


                class G709OtnFlowSpec(Entity):
                    """
                    G709 OTN FlowSpec
                    
                    .. attribute:: flow_bit_rate
                    
                    	G709 OTN Flow Bit Rate
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: flow_multiplier
                    
                    	G709 OTN Flow Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: flow_nvc
                    
                    	G709 OTN Flow NVC
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: flow_signal_type
                    
                    	G709 OTN Flow Signal Type (Refer G709 v3)
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.RxsbDetails.RxsbDetail.GenericFlowSpec.G709OtnFlowSpec, self).__init__()

                        self.yang_name = "g709otn-flow-spec"
                        self.yang_parent_name = "generic-flow-spec"

                        self.flow_bit_rate = YLeaf(YType.uint64, "flow-bit-rate")

                        self.flow_multiplier = YLeaf(YType.uint16, "flow-multiplier")

                        self.flow_nvc = YLeaf(YType.uint16, "flow-nvc")

                        self.flow_signal_type = YLeaf(YType.uint8, "flow-signal-type")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("flow_bit_rate",
                                        "flow_multiplier",
                                        "flow_nvc",
                                        "flow_signal_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.RxsbDetails.RxsbDetail.GenericFlowSpec.G709OtnFlowSpec, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.RxsbDetails.RxsbDetail.GenericFlowSpec.G709OtnFlowSpec, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.flow_bit_rate.is_set or
                            self.flow_multiplier.is_set or
                            self.flow_nvc.is_set or
                            self.flow_signal_type.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.flow_bit_rate.yfilter != YFilter.not_set or
                            self.flow_multiplier.yfilter != YFilter.not_set or
                            self.flow_nvc.yfilter != YFilter.not_set or
                            self.flow_signal_type.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "g709otn-flow-spec" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rxsb-details/rxsb-detail/generic-flow-spec/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.flow_bit_rate.is_set or self.flow_bit_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.flow_bit_rate.get_name_leafdata())
                        if (self.flow_multiplier.is_set or self.flow_multiplier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.flow_multiplier.get_name_leafdata())
                        if (self.flow_nvc.is_set or self.flow_nvc.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.flow_nvc.get_name_leafdata())
                        if (self.flow_signal_type.is_set or self.flow_signal_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.flow_signal_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "flow-bit-rate" or name == "flow-multiplier" or name == "flow-nvc" or name == "flow-signal-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "flow-bit-rate"):
                            self.flow_bit_rate = value
                            self.flow_bit_rate.value_namespace = name_space
                            self.flow_bit_rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "flow-multiplier"):
                            self.flow_multiplier = value
                            self.flow_multiplier.value_namespace = name_space
                            self.flow_multiplier.value_namespace_prefix = name_space_prefix
                        if(value_path == "flow-nvc"):
                            self.flow_nvc = value
                            self.flow_nvc.value_namespace = name_space
                            self.flow_nvc.value_namespace_prefix = name_space_prefix
                        if(value_path == "flow-signal-type"):
                            self.flow_signal_type = value
                            self.flow_signal_type.value_namespace = name_space
                            self.flow_signal_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.flow_spec_type.is_set or
                        (self.g709otn_flow_spec is not None and self.g709otn_flow_spec.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.flow_spec_type.yfilter != YFilter.not_set or
                        (self.g709otn_flow_spec is not None and self.g709otn_flow_spec.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "generic-flow-spec" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rxsb-details/rxsb-detail/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.flow_spec_type.is_set or self.flow_spec_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_spec_type.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "g709otn-flow-spec"):
                        if (self.g709otn_flow_spec is None):
                            self.g709otn_flow_spec = Rsvp.RxsbDetails.RxsbDetail.GenericFlowSpec.G709OtnFlowSpec()
                            self.g709otn_flow_spec.parent = self
                            self._children_name_map["g709otn_flow_spec"] = "g709otn-flow-spec"
                        return self.g709otn_flow_spec

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "g709otn-flow-spec" or name == "flow-spec-type"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "flow-spec-type"):
                        self.flow_spec_type = value
                        self.flow_spec_type.value_namespace = name_space
                        self.flow_spec_type.value_namespace_prefix = name_space_prefix


            class Hop(Entity):
                """
                Path Hop Info
                
                .. attribute:: neighbor_address
                
                	IP address of the neighbor
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: neighbor_logical_interface_name
                
                	Neighbor Logical Interface Name
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.RxsbDetails.RxsbDetail.Hop, self).__init__()

                    self.yang_name = "hop"
                    self.yang_parent_name = "rxsb-detail"

                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                    self.neighbor_logical_interface_name = YLeaf(YType.str, "neighbor-logical-interface-name")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("neighbor_address",
                                    "neighbor_logical_interface_name") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.RxsbDetails.RxsbDetail.Hop, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.RxsbDetails.RxsbDetail.Hop, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.neighbor_address.is_set or
                        self.neighbor_logical_interface_name.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.neighbor_address.yfilter != YFilter.not_set or
                        self.neighbor_logical_interface_name.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "hop" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rxsb-details/rxsb-detail/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                    if (self.neighbor_logical_interface_name.is_set or self.neighbor_logical_interface_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.neighbor_logical_interface_name.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "neighbor-address" or name == "neighbor-logical-interface-name"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "neighbor-address"):
                        self.neighbor_address = value
                        self.neighbor_address.value_namespace = name_space
                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "neighbor-logical-interface-name"):
                        self.neighbor_logical_interface_name = value
                        self.neighbor_logical_interface_name.value_namespace = name_space
                        self.neighbor_logical_interface_name.value_namespace_prefix = name_space_prefix


            class RsvpHeader(Entity):
                """
                RSVP Header
                
                .. attribute:: ip_source_address
                
                	IP Source Address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: ip_tos
                
                	IP Type of Service
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: ip_ttl
                
                	IP TTL
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: rsvp_header_flags
                
                	RSVP Header Flags (defined in RFC2205 Section 3 .1.1)
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: rsvp_message_type
                
                	RSVP Message Type
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: rsvp_ttl
                
                	RSVP TTL
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: rsvp_version
                
                	RSVP Version
                	**type**\:  int
                
                	**range:** 0..255
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.RxsbDetails.RxsbDetail.RsvpHeader, self).__init__()

                    self.yang_name = "rsvp-header"
                    self.yang_parent_name = "rxsb-detail"

                    self.ip_source_address = YLeaf(YType.str, "ip-source-address")

                    self.ip_tos = YLeaf(YType.uint8, "ip-tos")

                    self.ip_ttl = YLeaf(YType.uint8, "ip-ttl")

                    self.rsvp_header_flags = YLeaf(YType.uint8, "rsvp-header-flags")

                    self.rsvp_message_type = YLeaf(YType.uint8, "rsvp-message-type")

                    self.rsvp_ttl = YLeaf(YType.uint8, "rsvp-ttl")

                    self.rsvp_version = YLeaf(YType.uint8, "rsvp-version")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("ip_source_address",
                                    "ip_tos",
                                    "ip_ttl",
                                    "rsvp_header_flags",
                                    "rsvp_message_type",
                                    "rsvp_ttl",
                                    "rsvp_version") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.RxsbDetails.RxsbDetail.RsvpHeader, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.RxsbDetails.RxsbDetail.RsvpHeader, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.ip_source_address.is_set or
                        self.ip_tos.is_set or
                        self.ip_ttl.is_set or
                        self.rsvp_header_flags.is_set or
                        self.rsvp_message_type.is_set or
                        self.rsvp_ttl.is_set or
                        self.rsvp_version.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.ip_source_address.yfilter != YFilter.not_set or
                        self.ip_tos.yfilter != YFilter.not_set or
                        self.ip_ttl.yfilter != YFilter.not_set or
                        self.rsvp_header_flags.yfilter != YFilter.not_set or
                        self.rsvp_message_type.yfilter != YFilter.not_set or
                        self.rsvp_ttl.yfilter != YFilter.not_set or
                        self.rsvp_version.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "rsvp-header" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rxsb-details/rxsb-detail/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.ip_source_address.is_set or self.ip_source_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ip_source_address.get_name_leafdata())
                    if (self.ip_tos.is_set or self.ip_tos.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ip_tos.get_name_leafdata())
                    if (self.ip_ttl.is_set or self.ip_ttl.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ip_ttl.get_name_leafdata())
                    if (self.rsvp_header_flags.is_set or self.rsvp_header_flags.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_header_flags.get_name_leafdata())
                    if (self.rsvp_message_type.is_set or self.rsvp_message_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_message_type.get_name_leafdata())
                    if (self.rsvp_ttl.is_set or self.rsvp_ttl.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_ttl.get_name_leafdata())
                    if (self.rsvp_version.is_set or self.rsvp_version.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_version.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ip-source-address" or name == "ip-tos" or name == "ip-ttl" or name == "rsvp-header-flags" or name == "rsvp-message-type" or name == "rsvp-ttl" or name == "rsvp-version"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "ip-source-address"):
                        self.ip_source_address = value
                        self.ip_source_address.value_namespace = name_space
                        self.ip_source_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "ip-tos"):
                        self.ip_tos = value
                        self.ip_tos.value_namespace = name_space
                        self.ip_tos.value_namespace_prefix = name_space_prefix
                    if(value_path == "ip-ttl"):
                        self.ip_ttl = value
                        self.ip_ttl.value_namespace = name_space
                        self.ip_ttl.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-header-flags"):
                        self.rsvp_header_flags = value
                        self.rsvp_header_flags.value_namespace = name_space
                        self.rsvp_header_flags.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-message-type"):
                        self.rsvp_message_type = value
                        self.rsvp_message_type.value_namespace = name_space
                        self.rsvp_message_type.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-ttl"):
                        self.rsvp_ttl = value
                        self.rsvp_ttl.value_namespace = name_space
                        self.rsvp_ttl.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-version"):
                        self.rsvp_version = value
                        self.rsvp_version.value_namespace = name_space
                        self.rsvp_version.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.destination_address.is_set or
                    self.destination_port.is_set or
                    self.dynamic_state.is_set or
                    self.extended_tunnel_id.is_set or
                    self.input_interface.is_set or
                    self.p2mp_id.is_set or
                    self.protocol.is_set or
                    self.session_type.is_set or
                    self.source_address.is_set or
                    self.source_port.is_set or
                    self.sub_group_id.is_set or
                    self.sub_group_origin.is_set or
                    self.vrf_name.is_set or
                    (self.filter is not None and self.filter.has_data()) or
                    (self.flow_spec is not None and self.flow_spec.has_data()) or
                    (self.generic_flow_spec is not None and self.generic_flow_spec.has_data()) or
                    (self.hop is not None and self.hop.has_data()) or
                    (self.rsvp_header is not None and self.rsvp_header.has_data()) or
                    (self.s2l_sub_lsp is not None and self.s2l_sub_lsp.has_data()) or
                    (self.session is not None and self.session.has_data()) or
                    (self.style is not None and self.style.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.destination_address.yfilter != YFilter.not_set or
                    self.destination_port.yfilter != YFilter.not_set or
                    self.dynamic_state.yfilter != YFilter.not_set or
                    self.extended_tunnel_id.yfilter != YFilter.not_set or
                    self.input_interface.yfilter != YFilter.not_set or
                    self.p2mp_id.yfilter != YFilter.not_set or
                    self.protocol.yfilter != YFilter.not_set or
                    self.session_type.yfilter != YFilter.not_set or
                    self.source_address.yfilter != YFilter.not_set or
                    self.source_port.yfilter != YFilter.not_set or
                    self.sub_group_id.yfilter != YFilter.not_set or
                    self.sub_group_origin.yfilter != YFilter.not_set or
                    self.vrf_name.yfilter != YFilter.not_set or
                    (self.filter is not None and self.filter.has_operation()) or
                    (self.flow_spec is not None and self.flow_spec.has_operation()) or
                    (self.generic_flow_spec is not None and self.generic_flow_spec.has_operation()) or
                    (self.hop is not None and self.hop.has_operation()) or
                    (self.rsvp_header is not None and self.rsvp_header.has_operation()) or
                    (self.s2l_sub_lsp is not None and self.s2l_sub_lsp.has_operation()) or
                    (self.session is not None and self.session.has_operation()) or
                    (self.style is not None and self.style.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "rxsb-detail" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rxsb-details/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_address.get_name_leafdata())
                if (self.destination_port.is_set or self.destination_port.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_port.get_name_leafdata())
                if (self.dynamic_state.is_set or self.dynamic_state.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.dynamic_state.get_name_leafdata())
                if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                if (self.input_interface.is_set or self.input_interface.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.input_interface.get_name_leafdata())
                if (self.p2mp_id.is_set or self.p2mp_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.p2mp_id.get_name_leafdata())
                if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.protocol.get_name_leafdata())
                if (self.session_type.is_set or self.session_type.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.session_type.get_name_leafdata())
                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_address.get_name_leafdata())
                if (self.source_port.is_set or self.source_port.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_port.get_name_leafdata())
                if (self.sub_group_id.is_set or self.sub_group_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.sub_group_id.get_name_leafdata())
                if (self.sub_group_origin.is_set or self.sub_group_origin.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.sub_group_origin.get_name_leafdata())
                if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.vrf_name.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "filter"):
                    if (self.filter is None):
                        self.filter = Rsvp.RxsbDetails.RxsbDetail.Filter()
                        self.filter.parent = self
                        self._children_name_map["filter"] = "filter"
                    return self.filter

                if (child_yang_name == "flow-spec"):
                    if (self.flow_spec is None):
                        self.flow_spec = Rsvp.RxsbDetails.RxsbDetail.FlowSpec()
                        self.flow_spec.parent = self
                        self._children_name_map["flow_spec"] = "flow-spec"
                    return self.flow_spec

                if (child_yang_name == "generic-flow-spec"):
                    if (self.generic_flow_spec is None):
                        self.generic_flow_spec = Rsvp.RxsbDetails.RxsbDetail.GenericFlowSpec()
                        self.generic_flow_spec.parent = self
                        self._children_name_map["generic_flow_spec"] = "generic-flow-spec"
                    return self.generic_flow_spec

                if (child_yang_name == "hop"):
                    if (self.hop is None):
                        self.hop = Rsvp.RxsbDetails.RxsbDetail.Hop()
                        self.hop.parent = self
                        self._children_name_map["hop"] = "hop"
                    return self.hop

                if (child_yang_name == "rsvp-header"):
                    if (self.rsvp_header is None):
                        self.rsvp_header = Rsvp.RxsbDetails.RxsbDetail.RsvpHeader()
                        self.rsvp_header.parent = self
                        self._children_name_map["rsvp_header"] = "rsvp-header"
                    return self.rsvp_header

                if (child_yang_name == "s2l-sub-lsp"):
                    if (self.s2l_sub_lsp is None):
                        self.s2l_sub_lsp = Rsvp.RxsbDetails.RxsbDetail.S2LSubLsp()
                        self.s2l_sub_lsp.parent = self
                        self._children_name_map["s2l_sub_lsp"] = "s2l-sub-lsp"
                    return self.s2l_sub_lsp

                if (child_yang_name == "session"):
                    if (self.session is None):
                        self.session = Rsvp.RxsbDetails.RxsbDetail.Session()
                        self.session.parent = self
                        self._children_name_map["session"] = "session"
                    return self.session

                if (child_yang_name == "style"):
                    if (self.style is None):
                        self.style = Rsvp.RxsbDetails.RxsbDetail.Style()
                        self.style.parent = self
                        self._children_name_map["style"] = "style"
                    return self.style

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "filter" or name == "flow-spec" or name == "generic-flow-spec" or name == "hop" or name == "rsvp-header" or name == "s2l-sub-lsp" or name == "session" or name == "style" or name == "destination-address" or name == "destination-port" or name == "dynamic-state" or name == "extended-tunnel-id" or name == "input-interface" or name == "p2mp-id" or name == "protocol" or name == "session-type" or name == "source-address" or name == "source-port" or name == "sub-group-id" or name == "sub-group-origin" or name == "vrf-name"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "destination-address"):
                    self.destination_address = value
                    self.destination_address.value_namespace = name_space
                    self.destination_address.value_namespace_prefix = name_space_prefix
                if(value_path == "destination-port"):
                    self.destination_port = value
                    self.destination_port.value_namespace = name_space
                    self.destination_port.value_namespace_prefix = name_space_prefix
                if(value_path == "dynamic-state"):
                    self.dynamic_state = value
                    self.dynamic_state.value_namespace = name_space
                    self.dynamic_state.value_namespace_prefix = name_space_prefix
                if(value_path == "extended-tunnel-id"):
                    self.extended_tunnel_id = value
                    self.extended_tunnel_id.value_namespace = name_space
                    self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                if(value_path == "input-interface"):
                    self.input_interface = value
                    self.input_interface.value_namespace = name_space
                    self.input_interface.value_namespace_prefix = name_space_prefix
                if(value_path == "p2mp-id"):
                    self.p2mp_id = value
                    self.p2mp_id.value_namespace = name_space
                    self.p2mp_id.value_namespace_prefix = name_space_prefix
                if(value_path == "protocol"):
                    self.protocol = value
                    self.protocol.value_namespace = name_space
                    self.protocol.value_namespace_prefix = name_space_prefix
                if(value_path == "session-type"):
                    self.session_type = value
                    self.session_type.value_namespace = name_space
                    self.session_type.value_namespace_prefix = name_space_prefix
                if(value_path == "source-address"):
                    self.source_address = value
                    self.source_address.value_namespace = name_space
                    self.source_address.value_namespace_prefix = name_space_prefix
                if(value_path == "source-port"):
                    self.source_port = value
                    self.source_port.value_namespace = name_space
                    self.source_port.value_namespace_prefix = name_space_prefix
                if(value_path == "sub-group-id"):
                    self.sub_group_id = value
                    self.sub_group_id.value_namespace = name_space
                    self.sub_group_id.value_namespace_prefix = name_space_prefix
                if(value_path == "sub-group-origin"):
                    self.sub_group_origin = value
                    self.sub_group_origin.value_namespace = name_space
                    self.sub_group_origin.value_namespace_prefix = name_space_prefix
                if(value_path == "vrf-name"):
                    self.vrf_name = value
                    self.vrf_name.value_namespace = name_space
                    self.vrf_name.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.rxsb_detail:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.rxsb_detail:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "rxsb-details" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "rxsb-detail"):
                for c in self.rxsb_detail:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = Rsvp.RxsbDetails.RxsbDetail()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.rxsb_detail.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "rxsb-detail"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class InterfaceNeighborBriefs(Entity):
        """
        Table of brief info about I/F neighbors
        
        .. attribute:: interface_neighbor_brief
        
        	Brief info for a single interface neighbor
        	**type**\: list of    :py:class:`InterfaceNeighborBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.InterfaceNeighborBriefs.InterfaceNeighborBrief>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Rsvp.InterfaceNeighborBriefs, self).__init__()

            self.yang_name = "interface-neighbor-briefs"
            self.yang_parent_name = "rsvp"

            self.interface_neighbor_brief = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(Rsvp.InterfaceNeighborBriefs, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(Rsvp.InterfaceNeighborBriefs, self).__setattr__(name, value)


        class InterfaceNeighborBrief(Entity):
            """
            Brief info for a single interface neighbor
            
            .. attribute:: neighbor_address  <key>
            
            	Address of global neighbor
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: interface_neighbor_list_compact
            
            	Compact list of I/F Neighbors
            	**type**\: list of    :py:class:`InterfaceNeighborListCompact <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.InterfaceNeighborBriefs.InterfaceNeighborBrief.InterfaceNeighborListCompact>`
            
            .. attribute:: node_address
            
            	Neighbor node address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Rsvp.InterfaceNeighborBriefs.InterfaceNeighborBrief, self).__init__()

                self.yang_name = "interface-neighbor-brief"
                self.yang_parent_name = "interface-neighbor-briefs"

                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                self.node_address = YLeaf(YType.str, "node-address")

                self.interface_neighbor_list_compact = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("neighbor_address",
                                "node_address") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Rsvp.InterfaceNeighborBriefs.InterfaceNeighborBrief, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Rsvp.InterfaceNeighborBriefs.InterfaceNeighborBrief, self).__setattr__(name, value)


            class InterfaceNeighborListCompact(Entity):
                """
                Compact list of I/F Neighbors
                
                .. attribute:: interface_neighbor_address
                
                	Interface Neighbor address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: neighbor_interface_name
                
                	Neighbor's Interface handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.InterfaceNeighborBriefs.InterfaceNeighborBrief.InterfaceNeighborListCompact, self).__init__()

                    self.yang_name = "interface-neighbor-list-compact"
                    self.yang_parent_name = "interface-neighbor-brief"

                    self.interface_neighbor_address = YLeaf(YType.str, "interface-neighbor-address")

                    self.neighbor_interface_name = YLeaf(YType.str, "neighbor-interface-name")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("interface_neighbor_address",
                                    "neighbor_interface_name") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.InterfaceNeighborBriefs.InterfaceNeighborBrief.InterfaceNeighborListCompact, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.InterfaceNeighborBriefs.InterfaceNeighborBrief.InterfaceNeighborListCompact, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.interface_neighbor_address.is_set or
                        self.neighbor_interface_name.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.interface_neighbor_address.yfilter != YFilter.not_set or
                        self.neighbor_interface_name.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "interface-neighbor-list-compact" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.interface_neighbor_address.is_set or self.interface_neighbor_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface_neighbor_address.get_name_leafdata())
                    if (self.neighbor_interface_name.is_set or self.neighbor_interface_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.neighbor_interface_name.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface-neighbor-address" or name == "neighbor-interface-name"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "interface-neighbor-address"):
                        self.interface_neighbor_address = value
                        self.interface_neighbor_address.value_namespace = name_space
                        self.interface_neighbor_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "neighbor-interface-name"):
                        self.neighbor_interface_name = value
                        self.neighbor_interface_name.value_namespace = name_space
                        self.neighbor_interface_name.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.interface_neighbor_list_compact:
                    if (c.has_data()):
                        return True
                return (
                    self.neighbor_address.is_set or
                    self.node_address.is_set)

            def has_operation(self):
                for c in self.interface_neighbor_list_compact:
                    if (c.has_operation()):
                        return True
                return (
                    self.yfilter != YFilter.not_set or
                    self.neighbor_address.yfilter != YFilter.not_set or
                    self.node_address.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "interface-neighbor-brief" + "[neighbor-address='" + self.neighbor_address.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/interface-neighbor-briefs/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                if (self.node_address.is_set or self.node_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.node_address.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "interface-neighbor-list-compact"):
                    for c in self.interface_neighbor_list_compact:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = Rsvp.InterfaceNeighborBriefs.InterfaceNeighborBrief.InterfaceNeighborListCompact()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.interface_neighbor_list_compact.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "interface-neighbor-list-compact" or name == "neighbor-address" or name == "node-address"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "neighbor-address"):
                    self.neighbor_address = value
                    self.neighbor_address.value_namespace = name_space
                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                if(value_path == "node-address"):
                    self.node_address = value
                    self.node_address.value_namespace = name_space
                    self.node_address.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.interface_neighbor_brief:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.interface_neighbor_brief:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "interface-neighbor-briefs" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "interface-neighbor-brief"):
                for c in self.interface_neighbor_brief:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = Rsvp.InterfaceNeighborBriefs.InterfaceNeighborBrief()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.interface_neighbor_brief.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "interface-neighbor-brief"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class ControllerSummaries(Entity):
        """
        Table of summary info about RSVP\-enabled
        controllers
        
        .. attribute:: controller_summary
        
        	Summary info about an RSVP\-enabled controller
        	**type**\: list of    :py:class:`ControllerSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.ControllerSummaries.ControllerSummary>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Rsvp.ControllerSummaries, self).__init__()

            self.yang_name = "controller-summaries"
            self.yang_parent_name = "rsvp"

            self.controller_summary = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(Rsvp.ControllerSummaries, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(Rsvp.ControllerSummaries, self).__setattr__(name, value)


        class ControllerSummary(Entity):
            """
            Summary info about an RSVP\-enabled controller
            
            .. attribute:: controller_name  <key>
            
            	Controller Name
            	**type**\:  str
            
            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
            
            .. attribute:: bandwidth_information
            
            	Interface bandwidth information
            	**type**\:   :py:class:`BandwidthInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.ControllerSummaries.ControllerSummary.BandwidthInformation>`
            
            .. attribute:: interface_name_xr
            
            	Interface Name
            	**type**\:  str
            
            .. attribute:: paths_in
            
            	Number of locally created and incoming path states
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: paths_out
            
            	Number of outgoing path states
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: reservations_in
            
            	Number of locally created and incoming reservation states
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: reservations_out
            
            	Number of outgoing reservation states
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Rsvp.ControllerSummaries.ControllerSummary, self).__init__()

                self.yang_name = "controller-summary"
                self.yang_parent_name = "controller-summaries"

                self.controller_name = YLeaf(YType.str, "controller-name")

                self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                self.paths_in = YLeaf(YType.uint32, "paths-in")

                self.paths_out = YLeaf(YType.uint32, "paths-out")

                self.reservations_in = YLeaf(YType.uint32, "reservations-in")

                self.reservations_out = YLeaf(YType.uint32, "reservations-out")

                self.bandwidth_information = Rsvp.ControllerSummaries.ControllerSummary.BandwidthInformation()
                self.bandwidth_information.parent = self
                self._children_name_map["bandwidth_information"] = "bandwidth-information"
                self._children_yang_names.add("bandwidth-information")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("controller_name",
                                "interface_name_xr",
                                "paths_in",
                                "paths_out",
                                "reservations_in",
                                "reservations_out") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Rsvp.ControllerSummaries.ControllerSummary, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Rsvp.ControllerSummaries.ControllerSummary, self).__setattr__(name, value)


            class BandwidthInformation(Entity):
                """
                Interface bandwidth information
                
                .. attribute:: dste_mode
                
                	DSTEMode
                	**type**\:   :py:class:`RsvpMgmtDsteModes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtDsteModes>`
                
                .. attribute:: pre_standard_dste_interface
                
                	Prestandard DSTE interface information
                	**type**\:   :py:class:`PreStandardDsteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.ControllerSummaries.ControllerSummary.BandwidthInformation.PreStandardDsteInterface>`
                
                .. attribute:: standard_dste_interface
                
                	Standard DSTE interface information
                	**type**\:   :py:class:`StandardDsteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.ControllerSummaries.ControllerSummary.BandwidthInformation.StandardDsteInterface>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.ControllerSummaries.ControllerSummary.BandwidthInformation, self).__init__()

                    self.yang_name = "bandwidth-information"
                    self.yang_parent_name = "controller-summary"

                    self.dste_mode = YLeaf(YType.enumeration, "dste-mode")

                    self.pre_standard_dste_interface = Rsvp.ControllerSummaries.ControllerSummary.BandwidthInformation.PreStandardDsteInterface()
                    self.pre_standard_dste_interface.parent = self
                    self._children_name_map["pre_standard_dste_interface"] = "pre-standard-dste-interface"
                    self._children_yang_names.add("pre-standard-dste-interface")

                    self.standard_dste_interface = Rsvp.ControllerSummaries.ControllerSummary.BandwidthInformation.StandardDsteInterface()
                    self.standard_dste_interface.parent = self
                    self._children_name_map["standard_dste_interface"] = "standard-dste-interface"
                    self._children_yang_names.add("standard-dste-interface")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("dste_mode") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.ControllerSummaries.ControllerSummary.BandwidthInformation, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.ControllerSummaries.ControllerSummary.BandwidthInformation, self).__setattr__(name, value)


                class PreStandardDsteInterface(Entity):
                    """
                    Prestandard DSTE interface information
                    
                    .. attribute:: allocated_bit_rate
                    
                    	Bandwidth (bits per second) now allocated
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: is_max_bandwidth_absolute
                    
                    	True if the Max B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: is_max_subpool_bandwidth_absolute
                    
                    	True if the Max sub\-pool B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: max_bandwidth
                    
                    	Max bandwidth (bits per second) allowed
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_flow_bandwidth
                    
                    	Max bandwidth (bits per second) allowed per flow
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_subpool_bandwidth
                    
                    	Max bandwidth (bits per second) allowed in subpool
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.ControllerSummaries.ControllerSummary.BandwidthInformation.PreStandardDsteInterface, self).__init__()

                        self.yang_name = "pre-standard-dste-interface"
                        self.yang_parent_name = "bandwidth-information"

                        self.allocated_bit_rate = YLeaf(YType.uint64, "allocated-bit-rate")

                        self.is_max_bandwidth_absolute = YLeaf(YType.boolean, "is-max-bandwidth-absolute")

                        self.is_max_subpool_bandwidth_absolute = YLeaf(YType.boolean, "is-max-subpool-bandwidth-absolute")

                        self.max_bandwidth = YLeaf(YType.uint64, "max-bandwidth")

                        self.max_flow_bandwidth = YLeaf(YType.uint64, "max-flow-bandwidth")

                        self.max_subpool_bandwidth = YLeaf(YType.uint64, "max-subpool-bandwidth")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("allocated_bit_rate",
                                        "is_max_bandwidth_absolute",
                                        "is_max_subpool_bandwidth_absolute",
                                        "max_bandwidth",
                                        "max_flow_bandwidth",
                                        "max_subpool_bandwidth") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.ControllerSummaries.ControllerSummary.BandwidthInformation.PreStandardDsteInterface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.ControllerSummaries.ControllerSummary.BandwidthInformation.PreStandardDsteInterface, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.allocated_bit_rate.is_set or
                            self.is_max_bandwidth_absolute.is_set or
                            self.is_max_subpool_bandwidth_absolute.is_set or
                            self.max_bandwidth.is_set or
                            self.max_flow_bandwidth.is_set or
                            self.max_subpool_bandwidth.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.allocated_bit_rate.yfilter != YFilter.not_set or
                            self.is_max_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.is_max_subpool_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.max_bandwidth.yfilter != YFilter.not_set or
                            self.max_flow_bandwidth.yfilter != YFilter.not_set or
                            self.max_subpool_bandwidth.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "pre-standard-dste-interface" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.allocated_bit_rate.is_set or self.allocated_bit_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.allocated_bit_rate.get_name_leafdata())
                        if (self.is_max_bandwidth_absolute.is_set or self.is_max_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_bandwidth_absolute.get_name_leafdata())
                        if (self.is_max_subpool_bandwidth_absolute.is_set or self.is_max_subpool_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_subpool_bandwidth_absolute.get_name_leafdata())
                        if (self.max_bandwidth.is_set or self.max_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_bandwidth.get_name_leafdata())
                        if (self.max_flow_bandwidth.is_set or self.max_flow_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_flow_bandwidth.get_name_leafdata())
                        if (self.max_subpool_bandwidth.is_set or self.max_subpool_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_subpool_bandwidth.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "allocated-bit-rate" or name == "is-max-bandwidth-absolute" or name == "is-max-subpool-bandwidth-absolute" or name == "max-bandwidth" or name == "max-flow-bandwidth" or name == "max-subpool-bandwidth"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "allocated-bit-rate"):
                            self.allocated_bit_rate = value
                            self.allocated_bit_rate.value_namespace = name_space
                            self.allocated_bit_rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-bandwidth-absolute"):
                            self.is_max_bandwidth_absolute = value
                            self.is_max_bandwidth_absolute.value_namespace = name_space
                            self.is_max_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-subpool-bandwidth-absolute"):
                            self.is_max_subpool_bandwidth_absolute = value
                            self.is_max_subpool_bandwidth_absolute.value_namespace = name_space
                            self.is_max_subpool_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-bandwidth"):
                            self.max_bandwidth = value
                            self.max_bandwidth.value_namespace = name_space
                            self.max_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-flow-bandwidth"):
                            self.max_flow_bandwidth = value
                            self.max_flow_bandwidth.value_namespace = name_space
                            self.max_flow_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-subpool-bandwidth"):
                            self.max_subpool_bandwidth = value
                            self.max_subpool_bandwidth.value_namespace = name_space
                            self.max_subpool_bandwidth.value_namespace_prefix = name_space_prefix


                class StandardDsteInterface(Entity):
                    """
                    Standard DSTE interface information
                    
                    .. attribute:: allocated_bit_rate
                    
                    	Bandwidth (bits per second) now allocated
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: is_max_bandwidth_absolute
                    
                    	True if the Max B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: is_max_bc0_bandwidth_absolute
                    
                    	True if the Max BC0 B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: is_max_bc1_bandwidth_absolute
                    
                    	True if the Max BC1 sub\-pool B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: max_bandwidth
                    
                    	Max bandwidth (bits per second) allowed
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_flow_bandwidth
                    
                    	Max bandwidth (bits per second) allowed per flow
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_pool0_bandwidth
                    
                    	Max bandwidth (bits per second) allowed in BC0 pool
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_pool1_bandwidth
                    
                    	Max bandwidth (bits per second) allowed in BC1 pool
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.ControllerSummaries.ControllerSummary.BandwidthInformation.StandardDsteInterface, self).__init__()

                        self.yang_name = "standard-dste-interface"
                        self.yang_parent_name = "bandwidth-information"

                        self.allocated_bit_rate = YLeaf(YType.uint64, "allocated-bit-rate")

                        self.is_max_bandwidth_absolute = YLeaf(YType.boolean, "is-max-bandwidth-absolute")

                        self.is_max_bc0_bandwidth_absolute = YLeaf(YType.boolean, "is-max-bc0-bandwidth-absolute")

                        self.is_max_bc1_bandwidth_absolute = YLeaf(YType.boolean, "is-max-bc1-bandwidth-absolute")

                        self.max_bandwidth = YLeaf(YType.uint64, "max-bandwidth")

                        self.max_flow_bandwidth = YLeaf(YType.uint64, "max-flow-bandwidth")

                        self.max_pool0_bandwidth = YLeaf(YType.uint64, "max-pool0-bandwidth")

                        self.max_pool1_bandwidth = YLeaf(YType.uint64, "max-pool1-bandwidth")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("allocated_bit_rate",
                                        "is_max_bandwidth_absolute",
                                        "is_max_bc0_bandwidth_absolute",
                                        "is_max_bc1_bandwidth_absolute",
                                        "max_bandwidth",
                                        "max_flow_bandwidth",
                                        "max_pool0_bandwidth",
                                        "max_pool1_bandwidth") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.ControllerSummaries.ControllerSummary.BandwidthInformation.StandardDsteInterface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.ControllerSummaries.ControllerSummary.BandwidthInformation.StandardDsteInterface, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.allocated_bit_rate.is_set or
                            self.is_max_bandwidth_absolute.is_set or
                            self.is_max_bc0_bandwidth_absolute.is_set or
                            self.is_max_bc1_bandwidth_absolute.is_set or
                            self.max_bandwidth.is_set or
                            self.max_flow_bandwidth.is_set or
                            self.max_pool0_bandwidth.is_set or
                            self.max_pool1_bandwidth.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.allocated_bit_rate.yfilter != YFilter.not_set or
                            self.is_max_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.is_max_bc0_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.is_max_bc1_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.max_bandwidth.yfilter != YFilter.not_set or
                            self.max_flow_bandwidth.yfilter != YFilter.not_set or
                            self.max_pool0_bandwidth.yfilter != YFilter.not_set or
                            self.max_pool1_bandwidth.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "standard-dste-interface" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.allocated_bit_rate.is_set or self.allocated_bit_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.allocated_bit_rate.get_name_leafdata())
                        if (self.is_max_bandwidth_absolute.is_set or self.is_max_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_bandwidth_absolute.get_name_leafdata())
                        if (self.is_max_bc0_bandwidth_absolute.is_set or self.is_max_bc0_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_bc0_bandwidth_absolute.get_name_leafdata())
                        if (self.is_max_bc1_bandwidth_absolute.is_set or self.is_max_bc1_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_bc1_bandwidth_absolute.get_name_leafdata())
                        if (self.max_bandwidth.is_set or self.max_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_bandwidth.get_name_leafdata())
                        if (self.max_flow_bandwidth.is_set or self.max_flow_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_flow_bandwidth.get_name_leafdata())
                        if (self.max_pool0_bandwidth.is_set or self.max_pool0_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_pool0_bandwidth.get_name_leafdata())
                        if (self.max_pool1_bandwidth.is_set or self.max_pool1_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_pool1_bandwidth.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "allocated-bit-rate" or name == "is-max-bandwidth-absolute" or name == "is-max-bc0-bandwidth-absolute" or name == "is-max-bc1-bandwidth-absolute" or name == "max-bandwidth" or name == "max-flow-bandwidth" or name == "max-pool0-bandwidth" or name == "max-pool1-bandwidth"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "allocated-bit-rate"):
                            self.allocated_bit_rate = value
                            self.allocated_bit_rate.value_namespace = name_space
                            self.allocated_bit_rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-bandwidth-absolute"):
                            self.is_max_bandwidth_absolute = value
                            self.is_max_bandwidth_absolute.value_namespace = name_space
                            self.is_max_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-bc0-bandwidth-absolute"):
                            self.is_max_bc0_bandwidth_absolute = value
                            self.is_max_bc0_bandwidth_absolute.value_namespace = name_space
                            self.is_max_bc0_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-bc1-bandwidth-absolute"):
                            self.is_max_bc1_bandwidth_absolute = value
                            self.is_max_bc1_bandwidth_absolute.value_namespace = name_space
                            self.is_max_bc1_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-bandwidth"):
                            self.max_bandwidth = value
                            self.max_bandwidth.value_namespace = name_space
                            self.max_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-flow-bandwidth"):
                            self.max_flow_bandwidth = value
                            self.max_flow_bandwidth.value_namespace = name_space
                            self.max_flow_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-pool0-bandwidth"):
                            self.max_pool0_bandwidth = value
                            self.max_pool0_bandwidth.value_namespace = name_space
                            self.max_pool0_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-pool1-bandwidth"):
                            self.max_pool1_bandwidth = value
                            self.max_pool1_bandwidth.value_namespace = name_space
                            self.max_pool1_bandwidth.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.dste_mode.is_set or
                        (self.pre_standard_dste_interface is not None and self.pre_standard_dste_interface.has_data()) or
                        (self.standard_dste_interface is not None and self.standard_dste_interface.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.dste_mode.yfilter != YFilter.not_set or
                        (self.pre_standard_dste_interface is not None and self.pre_standard_dste_interface.has_operation()) or
                        (self.standard_dste_interface is not None and self.standard_dste_interface.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bandwidth-information" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.dste_mode.is_set or self.dste_mode.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.dste_mode.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "pre-standard-dste-interface"):
                        if (self.pre_standard_dste_interface is None):
                            self.pre_standard_dste_interface = Rsvp.ControllerSummaries.ControllerSummary.BandwidthInformation.PreStandardDsteInterface()
                            self.pre_standard_dste_interface.parent = self
                            self._children_name_map["pre_standard_dste_interface"] = "pre-standard-dste-interface"
                        return self.pre_standard_dste_interface

                    if (child_yang_name == "standard-dste-interface"):
                        if (self.standard_dste_interface is None):
                            self.standard_dste_interface = Rsvp.ControllerSummaries.ControllerSummary.BandwidthInformation.StandardDsteInterface()
                            self.standard_dste_interface.parent = self
                            self._children_name_map["standard_dste_interface"] = "standard-dste-interface"
                        return self.standard_dste_interface

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "pre-standard-dste-interface" or name == "standard-dste-interface" or name == "dste-mode"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "dste-mode"):
                        self.dste_mode = value
                        self.dste_mode.value_namespace = name_space
                        self.dste_mode.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.controller_name.is_set or
                    self.interface_name_xr.is_set or
                    self.paths_in.is_set or
                    self.paths_out.is_set or
                    self.reservations_in.is_set or
                    self.reservations_out.is_set or
                    (self.bandwidth_information is not None and self.bandwidth_information.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.controller_name.yfilter != YFilter.not_set or
                    self.interface_name_xr.yfilter != YFilter.not_set or
                    self.paths_in.yfilter != YFilter.not_set or
                    self.paths_out.yfilter != YFilter.not_set or
                    self.reservations_in.yfilter != YFilter.not_set or
                    self.reservations_out.yfilter != YFilter.not_set or
                    (self.bandwidth_information is not None and self.bandwidth_information.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "controller-summary" + "[controller-name='" + self.controller_name.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/controller-summaries/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.controller_name.is_set or self.controller_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.controller_name.get_name_leafdata())
                if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                if (self.paths_in.is_set or self.paths_in.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.paths_in.get_name_leafdata())
                if (self.paths_out.is_set or self.paths_out.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.paths_out.get_name_leafdata())
                if (self.reservations_in.is_set or self.reservations_in.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.reservations_in.get_name_leafdata())
                if (self.reservations_out.is_set or self.reservations_out.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.reservations_out.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "bandwidth-information"):
                    if (self.bandwidth_information is None):
                        self.bandwidth_information = Rsvp.ControllerSummaries.ControllerSummary.BandwidthInformation()
                        self.bandwidth_information.parent = self
                        self._children_name_map["bandwidth_information"] = "bandwidth-information"
                    return self.bandwidth_information

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "bandwidth-information" or name == "controller-name" or name == "interface-name-xr" or name == "paths-in" or name == "paths-out" or name == "reservations-in" or name == "reservations-out"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "controller-name"):
                    self.controller_name = value
                    self.controller_name.value_namespace = name_space
                    self.controller_name.value_namespace_prefix = name_space_prefix
                if(value_path == "interface-name-xr"):
                    self.interface_name_xr = value
                    self.interface_name_xr.value_namespace = name_space
                    self.interface_name_xr.value_namespace_prefix = name_space_prefix
                if(value_path == "paths-in"):
                    self.paths_in = value
                    self.paths_in.value_namespace = name_space
                    self.paths_in.value_namespace_prefix = name_space_prefix
                if(value_path == "paths-out"):
                    self.paths_out = value
                    self.paths_out.value_namespace = name_space
                    self.paths_out.value_namespace_prefix = name_space_prefix
                if(value_path == "reservations-in"):
                    self.reservations_in = value
                    self.reservations_in.value_namespace = name_space
                    self.reservations_in.value_namespace_prefix = name_space_prefix
                if(value_path == "reservations-out"):
                    self.reservations_out = value
                    self.reservations_out.value_namespace = name_space
                    self.reservations_out.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.controller_summary:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.controller_summary:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "controller-summaries" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "controller-summary"):
                for c in self.controller_summary:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = Rsvp.ControllerSummaries.ControllerSummary()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.controller_summary.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "controller-summary"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class AuthenticationBriefs(Entity):
        """
        Table for Authentication related information
        
        .. attribute:: authentication_brief
        
        	Brief Authentication information
        	**type**\: list of    :py:class:`AuthenticationBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.AuthenticationBriefs.AuthenticationBrief>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Rsvp.AuthenticationBriefs, self).__init__()

            self.yang_name = "authentication-briefs"
            self.yang_parent_name = "rsvp"

            self.authentication_brief = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(Rsvp.AuthenticationBriefs, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(Rsvp.AuthenticationBriefs, self).__setattr__(name, value)


        class AuthenticationBrief(Entity):
            """
            Brief Authentication information
            
            .. attribute:: source_address  <key>
            
            	Source Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: destination_address  <key>
            
            	Destination Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: mode_id  <key>
            
            	Mode (Tx or Rx)
            	**type**\:   :py:class:`RsvpMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMode>`
            
            .. attribute:: interface_name  <key>
            
            	InterfaceName
            	**type**\:  str
            
            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
            
            .. attribute:: destination_address_xr
            
            	Destination address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: direction
            
            	Direction
            	**type**\:   :py:class:`RsvpMgmtAuthDirection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtAuthDirection>`
            
            .. attribute:: key_id
            
            	Key ID
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: key_id_valid
            
            	Key validity
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: key_source
            
            	Key source
            	**type**\:  str
            
            .. attribute:: key_type
            
            	Key type
            	**type**\:   :py:class:`RsvpMgmtAuthKi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtAuthKi>`
            
            .. attribute:: neighbor_address
            
            	Neighbor address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: source_address_xr
            
            	Source address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Rsvp.AuthenticationBriefs.AuthenticationBrief, self).__init__()

                self.yang_name = "authentication-brief"
                self.yang_parent_name = "authentication-briefs"

                self.source_address = YLeaf(YType.str, "source-address")

                self.destination_address = YLeaf(YType.str, "destination-address")

                self.mode_id = YLeaf(YType.enumeration, "mode-id")

                self.interface_name = YLeaf(YType.str, "interface-name")

                self.destination_address_xr = YLeaf(YType.str, "destination-address-xr")

                self.direction = YLeaf(YType.enumeration, "direction")

                self.key_id = YLeaf(YType.uint64, "key-id")

                self.key_id_valid = YLeaf(YType.uint32, "key-id-valid")

                self.key_source = YLeaf(YType.str, "key-source")

                self.key_type = YLeaf(YType.enumeration, "key-type")

                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                self.source_address_xr = YLeaf(YType.str, "source-address-xr")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("source_address",
                                "destination_address",
                                "mode_id",
                                "interface_name",
                                "destination_address_xr",
                                "direction",
                                "key_id",
                                "key_id_valid",
                                "key_source",
                                "key_type",
                                "neighbor_address",
                                "source_address_xr") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Rsvp.AuthenticationBriefs.AuthenticationBrief, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Rsvp.AuthenticationBriefs.AuthenticationBrief, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.source_address.is_set or
                    self.destination_address.is_set or
                    self.mode_id.is_set or
                    self.interface_name.is_set or
                    self.destination_address_xr.is_set or
                    self.direction.is_set or
                    self.key_id.is_set or
                    self.key_id_valid.is_set or
                    self.key_source.is_set or
                    self.key_type.is_set or
                    self.neighbor_address.is_set or
                    self.source_address_xr.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.source_address.yfilter != YFilter.not_set or
                    self.destination_address.yfilter != YFilter.not_set or
                    self.mode_id.yfilter != YFilter.not_set or
                    self.interface_name.yfilter != YFilter.not_set or
                    self.destination_address_xr.yfilter != YFilter.not_set or
                    self.direction.yfilter != YFilter.not_set or
                    self.key_id.yfilter != YFilter.not_set or
                    self.key_id_valid.yfilter != YFilter.not_set or
                    self.key_source.yfilter != YFilter.not_set or
                    self.key_type.yfilter != YFilter.not_set or
                    self.neighbor_address.yfilter != YFilter.not_set or
                    self.source_address_xr.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "authentication-brief" + "[source-address='" + self.source_address.get() + "']" + "[destination-address='" + self.destination_address.get() + "']" + "[mode-id='" + self.mode_id.get() + "']" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/authentication-briefs/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_address.get_name_leafdata())
                if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_address.get_name_leafdata())
                if (self.mode_id.is_set or self.mode_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.mode_id.get_name_leafdata())
                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                if (self.destination_address_xr.is_set or self.destination_address_xr.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_address_xr.get_name_leafdata())
                if (self.direction.is_set or self.direction.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.direction.get_name_leafdata())
                if (self.key_id.is_set or self.key_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.key_id.get_name_leafdata())
                if (self.key_id_valid.is_set or self.key_id_valid.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.key_id_valid.get_name_leafdata())
                if (self.key_source.is_set or self.key_source.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.key_source.get_name_leafdata())
                if (self.key_type.is_set or self.key_type.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.key_type.get_name_leafdata())
                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                if (self.source_address_xr.is_set or self.source_address_xr.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_address_xr.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "source-address" or name == "destination-address" or name == "mode-id" or name == "interface-name" or name == "destination-address-xr" or name == "direction" or name == "key-id" or name == "key-id-valid" or name == "key-source" or name == "key-type" or name == "neighbor-address" or name == "source-address-xr"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "source-address"):
                    self.source_address = value
                    self.source_address.value_namespace = name_space
                    self.source_address.value_namespace_prefix = name_space_prefix
                if(value_path == "destination-address"):
                    self.destination_address = value
                    self.destination_address.value_namespace = name_space
                    self.destination_address.value_namespace_prefix = name_space_prefix
                if(value_path == "mode-id"):
                    self.mode_id = value
                    self.mode_id.value_namespace = name_space
                    self.mode_id.value_namespace_prefix = name_space_prefix
                if(value_path == "interface-name"):
                    self.interface_name = value
                    self.interface_name.value_namespace = name_space
                    self.interface_name.value_namespace_prefix = name_space_prefix
                if(value_path == "destination-address-xr"):
                    self.destination_address_xr = value
                    self.destination_address_xr.value_namespace = name_space
                    self.destination_address_xr.value_namespace_prefix = name_space_prefix
                if(value_path == "direction"):
                    self.direction = value
                    self.direction.value_namespace = name_space
                    self.direction.value_namespace_prefix = name_space_prefix
                if(value_path == "key-id"):
                    self.key_id = value
                    self.key_id.value_namespace = name_space
                    self.key_id.value_namespace_prefix = name_space_prefix
                if(value_path == "key-id-valid"):
                    self.key_id_valid = value
                    self.key_id_valid.value_namespace = name_space
                    self.key_id_valid.value_namespace_prefix = name_space_prefix
                if(value_path == "key-source"):
                    self.key_source = value
                    self.key_source.value_namespace = name_space
                    self.key_source.value_namespace_prefix = name_space_prefix
                if(value_path == "key-type"):
                    self.key_type = value
                    self.key_type.value_namespace = name_space
                    self.key_type.value_namespace_prefix = name_space_prefix
                if(value_path == "neighbor-address"):
                    self.neighbor_address = value
                    self.neighbor_address.value_namespace = name_space
                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                if(value_path == "source-address-xr"):
                    self.source_address_xr = value
                    self.source_address_xr.value_namespace = name_space
                    self.source_address_xr.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.authentication_brief:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.authentication_brief:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "authentication-briefs" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "authentication-brief"):
                for c in self.authentication_brief:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = Rsvp.AuthenticationBriefs.AuthenticationBrief()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.authentication_brief.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "authentication-brief"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class SessionBriefs(Entity):
        """
        Table of brief info about sessions
        
        .. attribute:: session_brief
        
        	Brief info about session
        	**type**\: list of    :py:class:`SessionBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionBriefs.SessionBrief>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Rsvp.SessionBriefs, self).__init__()

            self.yang_name = "session-briefs"
            self.yang_parent_name = "rsvp"

            self.session_brief = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(Rsvp.SessionBriefs, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(Rsvp.SessionBriefs, self).__setattr__(name, value)


        class SessionBrief(Entity):
            """
            Brief info about session
            
            .. attribute:: destination_address
            
            	Destination Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: destination_port
            
            	Destination Port
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: detail_list_size
            
            	Number of elements in detail list
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: extended_tunnel_id
            
            	Extended Tunnel ID
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: p2mp_id
            
            	P2MP ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: protocol
            
            	Protocol
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: ps_bs
            
            	Number of path state block states
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: requests
            
            	Number of request states
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: rs_bs
            
            	Number of reservation state block states
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: session
            
            	RSVP Session Information
            	**type**\:   :py:class:`Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionBriefs.SessionBrief.Session>`
            
            .. attribute:: session_type
            
            	Session Type
            	**type**\:   :py:class:`RsvpSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpSession>`
            
            .. attribute:: vrf_name
            
            	VRF Name
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Rsvp.SessionBriefs.SessionBrief, self).__init__()

                self.yang_name = "session-brief"
                self.yang_parent_name = "session-briefs"

                self.destination_address = YLeaf(YType.str, "destination-address")

                self.destination_port = YLeaf(YType.int32, "destination-port")

                self.detail_list_size = YLeaf(YType.uint32, "detail-list-size")

                self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                self.p2mp_id = YLeaf(YType.int32, "p2mp-id")

                self.protocol = YLeaf(YType.int32, "protocol")

                self.ps_bs = YLeaf(YType.uint32, "ps-bs")

                self.requests = YLeaf(YType.uint32, "requests")

                self.rs_bs = YLeaf(YType.uint32, "rs-bs")

                self.session_type = YLeaf(YType.enumeration, "session-type")

                self.vrf_name = YLeaf(YType.str, "vrf-name")

                self.session = Rsvp.SessionBriefs.SessionBrief.Session()
                self.session.parent = self
                self._children_name_map["session"] = "session"
                self._children_yang_names.add("session")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("destination_address",
                                "destination_port",
                                "detail_list_size",
                                "extended_tunnel_id",
                                "p2mp_id",
                                "protocol",
                                "ps_bs",
                                "requests",
                                "rs_bs",
                                "session_type",
                                "vrf_name") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Rsvp.SessionBriefs.SessionBrief, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Rsvp.SessionBriefs.SessionBrief, self).__setattr__(name, value)


            class Session(Entity):
                """
                RSVP Session Information
                
                .. attribute:: rsvp_session
                
                	RSVP Session
                	**type**\:   :py:class:`RsvpSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionBriefs.SessionBrief.Session.RsvpSession>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.SessionBriefs.SessionBrief.Session, self).__init__()

                    self.yang_name = "session"
                    self.yang_parent_name = "session-brief"

                    self.rsvp_session = Rsvp.SessionBriefs.SessionBrief.Session.RsvpSession()
                    self.rsvp_session.parent = self
                    self._children_name_map["rsvp_session"] = "rsvp-session"
                    self._children_yang_names.add("rsvp-session")


                class RsvpSession(Entity):
                    """
                    RSVP Session
                    
                    .. attribute:: ipv4
                    
                    	UDP IPv4 session
                    	**type**\:   :py:class:`Ipv4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionBriefs.SessionBrief.Session.RsvpSession.Ipv4>`
                    
                    .. attribute:: ipv4_lsp_session
                    
                    	IPv4 LSP session
                    	**type**\:   :py:class:`Ipv4LspSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionBriefs.SessionBrief.Session.RsvpSession.Ipv4LspSession>`
                    
                    .. attribute:: ipv4_p2mp_lsp_session
                    
                    	IPv4 P2MP LSP session
                    	**type**\:   :py:class:`Ipv4P2MpLspSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionBriefs.SessionBrief.Session.RsvpSession.Ipv4P2MpLspSession>`
                    
                    .. attribute:: ipv4_uni_session
                    
                    	IPv4 UNI session
                    	**type**\:   :py:class:`Ipv4UniSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionBriefs.SessionBrief.Session.RsvpSession.Ipv4UniSession>`
                    
                    .. attribute:: session_type
                    
                    	SessionType
                    	**type**\:   :py:class:`RsvpMgmtSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtSession>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.SessionBriefs.SessionBrief.Session.RsvpSession, self).__init__()

                        self.yang_name = "rsvp-session"
                        self.yang_parent_name = "session"

                        self.session_type = YLeaf(YType.enumeration, "session-type")

                        self.ipv4 = Rsvp.SessionBriefs.SessionBrief.Session.RsvpSession.Ipv4()
                        self.ipv4.parent = self
                        self._children_name_map["ipv4"] = "ipv4"
                        self._children_yang_names.add("ipv4")

                        self.ipv4_lsp_session = Rsvp.SessionBriefs.SessionBrief.Session.RsvpSession.Ipv4LspSession()
                        self.ipv4_lsp_session.parent = self
                        self._children_name_map["ipv4_lsp_session"] = "ipv4-lsp-session"
                        self._children_yang_names.add("ipv4-lsp-session")

                        self.ipv4_p2mp_lsp_session = Rsvp.SessionBriefs.SessionBrief.Session.RsvpSession.Ipv4P2MpLspSession()
                        self.ipv4_p2mp_lsp_session.parent = self
                        self._children_name_map["ipv4_p2mp_lsp_session"] = "ipv4-p2mp-lsp-session"
                        self._children_yang_names.add("ipv4-p2mp-lsp-session")

                        self.ipv4_uni_session = Rsvp.SessionBriefs.SessionBrief.Session.RsvpSession.Ipv4UniSession()
                        self.ipv4_uni_session.parent = self
                        self._children_name_map["ipv4_uni_session"] = "ipv4-uni-session"
                        self._children_yang_names.add("ipv4-uni-session")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("session_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.SessionBriefs.SessionBrief.Session.RsvpSession, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.SessionBriefs.SessionBrief.Session.RsvpSession, self).__setattr__(name, value)


                    class Ipv4(Entity):
                        """
                        UDP IPv4 session
                        
                        .. attribute:: destination_address
                        
                        	Destination address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: destination_port
                        
                        	The Session Destination Port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: protocol
                        
                        	Protocol type (originally defined in RFC 790, further values in subsequent RFCs)
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.SessionBriefs.SessionBrief.Session.RsvpSession.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "rsvp-session"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.destination_port = YLeaf(YType.uint16, "destination-port")

                            self.protocol = YLeaf(YType.uint8, "protocol")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "destination_port",
                                            "protocol") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.SessionBriefs.SessionBrief.Session.RsvpSession.Ipv4, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.SessionBriefs.SessionBrief.Session.RsvpSession.Ipv4, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination_address.is_set or
                                self.destination_port.is_set or
                                self.protocol.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.destination_port.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-briefs/session-brief/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.destination_port.is_set or self.destination_port.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_port.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "destination-port" or name == "protocol"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "destination-port"):
                                self.destination_port = value
                                self.destination_port.value_namespace = name_space
                                self.destination_port.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix


                    class Ipv4LspSession(Entity):
                        """
                        IPv4 LSP session
                        
                        .. attribute:: destination_address
                        
                        	Destination address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: extended_tunnel_id
                        
                        	The Session Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: tunnel_id
                        
                        	The Session Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.SessionBriefs.SessionBrief.Session.RsvpSession.Ipv4LspSession, self).__init__()

                            self.yang_name = "ipv4-lsp-session"
                            self.yang_parent_name = "rsvp-session"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                            self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "extended_tunnel_id",
                                            "tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.SessionBriefs.SessionBrief.Session.RsvpSession.Ipv4LspSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.SessionBriefs.SessionBrief.Session.RsvpSession.Ipv4LspSession, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination_address.is_set or
                                self.extended_tunnel_id.is_set or
                                self.tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.extended_tunnel_id.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-lsp-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-briefs/session-brief/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "extended-tunnel-id" or name == "tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "extended-tunnel-id"):
                                self.extended_tunnel_id = value
                                self.extended_tunnel_id.value_namespace = name_space
                                self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix


                    class Ipv4UniSession(Entity):
                        """
                        IPv4 UNI session
                        
                        .. attribute:: destination_address
                        
                        	Destination address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: extended_address
                        
                        	The Session Extended Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: tunnel_id
                        
                        	The Session Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.SessionBriefs.SessionBrief.Session.RsvpSession.Ipv4UniSession, self).__init__()

                            self.yang_name = "ipv4-uni-session"
                            self.yang_parent_name = "rsvp-session"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.extended_address = YLeaf(YType.str, "extended-address")

                            self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "extended_address",
                                            "tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.SessionBriefs.SessionBrief.Session.RsvpSession.Ipv4UniSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.SessionBriefs.SessionBrief.Session.RsvpSession.Ipv4UniSession, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination_address.is_set or
                                self.extended_address.is_set or
                                self.tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.extended_address.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-uni-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-briefs/session-brief/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.extended_address.is_set or self.extended_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_address.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "extended-address" or name == "tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "extended-address"):
                                self.extended_address = value
                                self.extended_address.value_namespace = name_space
                                self.extended_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix


                    class Ipv4P2MpLspSession(Entity):
                        """
                        IPv4 P2MP LSP session
                        
                        .. attribute:: extended_tunnel_id
                        
                        	The Session Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: p2mp_id
                        
                        	The Point to Multipoint ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tunnel_id
                        
                        	The Session Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.SessionBriefs.SessionBrief.Session.RsvpSession.Ipv4P2MpLspSession, self).__init__()

                            self.yang_name = "ipv4-p2mp-lsp-session"
                            self.yang_parent_name = "rsvp-session"

                            self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                            self.p2mp_id = YLeaf(YType.uint32, "p2mp-id")

                            self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("extended_tunnel_id",
                                            "p2mp_id",
                                            "tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.SessionBriefs.SessionBrief.Session.RsvpSession.Ipv4P2MpLspSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.SessionBriefs.SessionBrief.Session.RsvpSession.Ipv4P2MpLspSession, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.extended_tunnel_id.is_set or
                                self.p2mp_id.is_set or
                                self.tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.extended_tunnel_id.yfilter != YFilter.not_set or
                                self.p2mp_id.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-p2mp-lsp-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-briefs/session-brief/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                            if (self.p2mp_id.is_set or self.p2mp_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.p2mp_id.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "extended-tunnel-id" or name == "p2mp-id" or name == "tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "extended-tunnel-id"):
                                self.extended_tunnel_id = value
                                self.extended_tunnel_id.value_namespace = name_space
                                self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "p2mp-id"):
                                self.p2mp_id = value
                                self.p2mp_id.value_namespace = name_space
                                self.p2mp_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.session_type.is_set or
                            (self.ipv4 is not None and self.ipv4.has_data()) or
                            (self.ipv4_lsp_session is not None and self.ipv4_lsp_session.has_data()) or
                            (self.ipv4_p2mp_lsp_session is not None and self.ipv4_p2mp_lsp_session.has_data()) or
                            (self.ipv4_uni_session is not None and self.ipv4_uni_session.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.session_type.yfilter != YFilter.not_set or
                            (self.ipv4 is not None and self.ipv4.has_operation()) or
                            (self.ipv4_lsp_session is not None and self.ipv4_lsp_session.has_operation()) or
                            (self.ipv4_p2mp_lsp_session is not None and self.ipv4_p2mp_lsp_session.has_operation()) or
                            (self.ipv4_uni_session is not None and self.ipv4_uni_session.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rsvp-session" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-briefs/session-brief/session/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.session_type.is_set or self.session_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.session_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "ipv4"):
                            if (self.ipv4 is None):
                                self.ipv4 = Rsvp.SessionBriefs.SessionBrief.Session.RsvpSession.Ipv4()
                                self.ipv4.parent = self
                                self._children_name_map["ipv4"] = "ipv4"
                            return self.ipv4

                        if (child_yang_name == "ipv4-lsp-session"):
                            if (self.ipv4_lsp_session is None):
                                self.ipv4_lsp_session = Rsvp.SessionBriefs.SessionBrief.Session.RsvpSession.Ipv4LspSession()
                                self.ipv4_lsp_session.parent = self
                                self._children_name_map["ipv4_lsp_session"] = "ipv4-lsp-session"
                            return self.ipv4_lsp_session

                        if (child_yang_name == "ipv4-p2mp-lsp-session"):
                            if (self.ipv4_p2mp_lsp_session is None):
                                self.ipv4_p2mp_lsp_session = Rsvp.SessionBriefs.SessionBrief.Session.RsvpSession.Ipv4P2MpLspSession()
                                self.ipv4_p2mp_lsp_session.parent = self
                                self._children_name_map["ipv4_p2mp_lsp_session"] = "ipv4-p2mp-lsp-session"
                            return self.ipv4_p2mp_lsp_session

                        if (child_yang_name == "ipv4-uni-session"):
                            if (self.ipv4_uni_session is None):
                                self.ipv4_uni_session = Rsvp.SessionBriefs.SessionBrief.Session.RsvpSession.Ipv4UniSession()
                                self.ipv4_uni_session.parent = self
                                self._children_name_map["ipv4_uni_session"] = "ipv4-uni-session"
                            return self.ipv4_uni_session

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ipv4" or name == "ipv4-lsp-session" or name == "ipv4-p2mp-lsp-session" or name == "ipv4-uni-session" or name == "session-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "session-type"):
                            self.session_type = value
                            self.session_type.value_namespace = name_space
                            self.session_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (self.rsvp_session is not None and self.rsvp_session.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.rsvp_session is not None and self.rsvp_session.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "session" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-briefs/session-brief/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "rsvp-session"):
                        if (self.rsvp_session is None):
                            self.rsvp_session = Rsvp.SessionBriefs.SessionBrief.Session.RsvpSession()
                            self.rsvp_session.parent = self
                            self._children_name_map["rsvp_session"] = "rsvp-session"
                        return self.rsvp_session

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "rsvp-session"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (
                    self.destination_address.is_set or
                    self.destination_port.is_set or
                    self.detail_list_size.is_set or
                    self.extended_tunnel_id.is_set or
                    self.p2mp_id.is_set or
                    self.protocol.is_set or
                    self.ps_bs.is_set or
                    self.requests.is_set or
                    self.rs_bs.is_set or
                    self.session_type.is_set or
                    self.vrf_name.is_set or
                    (self.session is not None and self.session.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.destination_address.yfilter != YFilter.not_set or
                    self.destination_port.yfilter != YFilter.not_set or
                    self.detail_list_size.yfilter != YFilter.not_set or
                    self.extended_tunnel_id.yfilter != YFilter.not_set or
                    self.p2mp_id.yfilter != YFilter.not_set or
                    self.protocol.yfilter != YFilter.not_set or
                    self.ps_bs.yfilter != YFilter.not_set or
                    self.requests.yfilter != YFilter.not_set or
                    self.rs_bs.yfilter != YFilter.not_set or
                    self.session_type.yfilter != YFilter.not_set or
                    self.vrf_name.yfilter != YFilter.not_set or
                    (self.session is not None and self.session.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "session-brief" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-briefs/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_address.get_name_leafdata())
                if (self.destination_port.is_set or self.destination_port.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_port.get_name_leafdata())
                if (self.detail_list_size.is_set or self.detail_list_size.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.detail_list_size.get_name_leafdata())
                if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                if (self.p2mp_id.is_set or self.p2mp_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.p2mp_id.get_name_leafdata())
                if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.protocol.get_name_leafdata())
                if (self.ps_bs.is_set or self.ps_bs.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.ps_bs.get_name_leafdata())
                if (self.requests.is_set or self.requests.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.requests.get_name_leafdata())
                if (self.rs_bs.is_set or self.rs_bs.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.rs_bs.get_name_leafdata())
                if (self.session_type.is_set or self.session_type.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.session_type.get_name_leafdata())
                if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.vrf_name.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "session"):
                    if (self.session is None):
                        self.session = Rsvp.SessionBriefs.SessionBrief.Session()
                        self.session.parent = self
                        self._children_name_map["session"] = "session"
                    return self.session

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "session" or name == "destination-address" or name == "destination-port" or name == "detail-list-size" or name == "extended-tunnel-id" or name == "p2mp-id" or name == "protocol" or name == "ps-bs" or name == "requests" or name == "rs-bs" or name == "session-type" or name == "vrf-name"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "destination-address"):
                    self.destination_address = value
                    self.destination_address.value_namespace = name_space
                    self.destination_address.value_namespace_prefix = name_space_prefix
                if(value_path == "destination-port"):
                    self.destination_port = value
                    self.destination_port.value_namespace = name_space
                    self.destination_port.value_namespace_prefix = name_space_prefix
                if(value_path == "detail-list-size"):
                    self.detail_list_size = value
                    self.detail_list_size.value_namespace = name_space
                    self.detail_list_size.value_namespace_prefix = name_space_prefix
                if(value_path == "extended-tunnel-id"):
                    self.extended_tunnel_id = value
                    self.extended_tunnel_id.value_namespace = name_space
                    self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                if(value_path == "p2mp-id"):
                    self.p2mp_id = value
                    self.p2mp_id.value_namespace = name_space
                    self.p2mp_id.value_namespace_prefix = name_space_prefix
                if(value_path == "protocol"):
                    self.protocol = value
                    self.protocol.value_namespace = name_space
                    self.protocol.value_namespace_prefix = name_space_prefix
                if(value_path == "ps-bs"):
                    self.ps_bs = value
                    self.ps_bs.value_namespace = name_space
                    self.ps_bs.value_namespace_prefix = name_space_prefix
                if(value_path == "requests"):
                    self.requests = value
                    self.requests.value_namespace = name_space
                    self.requests.value_namespace_prefix = name_space_prefix
                if(value_path == "rs-bs"):
                    self.rs_bs = value
                    self.rs_bs.value_namespace = name_space
                    self.rs_bs.value_namespace_prefix = name_space_prefix
                if(value_path == "session-type"):
                    self.session_type = value
                    self.session_type.value_namespace = name_space
                    self.session_type.value_namespace_prefix = name_space_prefix
                if(value_path == "vrf-name"):
                    self.vrf_name = value
                    self.vrf_name.value_namespace = name_space
                    self.vrf_name.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.session_brief:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.session_brief:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "session-briefs" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "session-brief"):
                for c in self.session_brief:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = Rsvp.SessionBriefs.SessionBrief()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.session_brief.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "session-brief"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class PsbDetaileds(Entity):
        """
        Table of detailed info about path state blocks
        
        .. attribute:: psb_detailed
        
        	Detailed info for a single path state block
        	**type**\: list of    :py:class:`PsbDetailed <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbDetaileds.PsbDetailed>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Rsvp.PsbDetaileds, self).__init__()

            self.yang_name = "psb-detaileds"
            self.yang_parent_name = "rsvp"

            self.psb_detailed = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(Rsvp.PsbDetaileds, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(Rsvp.PsbDetaileds, self).__setattr__(name, value)


        class PsbDetailed(Entity):
            """
            Detailed info for a single path state block
            
            .. attribute:: backup_tunnel_name
            
            	Path Backup Tunnel
            	**type**\:  str
            
            .. attribute:: class_type
            
            	DS\-TE Class\-Type
            	**type**\:   :py:class:`ClassType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbDetaileds.PsbDetailed.ClassType>`
            
            .. attribute:: destination_address
            
            	Destination Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: destination_port
            
            	Destination Port
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: expiry_time
            
            	Expiry Time
            	**type**\:   :py:class:`ExpiryTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbDetaileds.PsbDetailed.ExpiryTime>`
            
            .. attribute:: extended_tunnel_id
            
            	Extended Tunnel ID
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: generic_traffic_spec
            
            	RSVP Generic Traffic Spec Info
            	**type**\:   :py:class:`GenericTrafficSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbDetaileds.PsbDetailed.GenericTrafficSpec>`
            
            .. attribute:: header
            
            	RSVP Header Info
            	**type**\:   :py:class:`Header <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbDetaileds.PsbDetailed.Header>`
            
            .. attribute:: hop
            
            	Path Hop Info
            	**type**\:   :py:class:`Hop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbDetaileds.PsbDetailed.Hop>`
            
            .. attribute:: in_ero
            
            	Incoming Explicit Route Sub Objects
            	**type**\: list of    :py:class:`InEro <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbDetaileds.PsbDetailed.InEro>`
            
            .. attribute:: input_interface
            
            	Path Input Interface
            	**type**\:  str
            
            .. attribute:: is_in_ero_valid
            
            	Incoming ERO validity
            	**type**\:  bool
            
            .. attribute:: is_out_ero_valid
            
            	Outgoing ERO validity
            	**type**\:  bool
            
            .. attribute:: label_info
            
            	Label Information
            	**type**\:   :py:class:`LabelInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbDetaileds.PsbDetailed.LabelInfo>`
            
            .. attribute:: out_ero
            
            	Outgoing Explicit Route Sub Objects
            	**type**\: list of    :py:class:`OutEro <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbDetaileds.PsbDetailed.OutEro>`
            
            .. attribute:: p2mp_id
            
            	P2MP ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: path_flags
            
            	Path Flags
            	**type**\:   :py:class:`PathFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbDetaileds.PsbDetailed.PathFlags>`
            
            .. attribute:: pfc
            
            	Path Forwarding Contexts
            	**type**\: list of    :py:class:`Pfc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbDetaileds.PsbDetailed.Pfc>`
            
            .. attribute:: policy_flags
            
            	Policy Flags
            	**type**\:   :py:class:`PolicyFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbDetaileds.PsbDetailed.PolicyFlags>`
            
            .. attribute:: policy_query_flags
            
            	Policy Query Flags
            	**type**\:   :py:class:`PolicyQueryFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbDetaileds.PsbDetailed.PolicyQueryFlags>`
            
            .. attribute:: policy_source_info
            
            	Policy Sources Info
            	**type**\:   :py:class:`PolicySourceInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbDetaileds.PsbDetailed.PolicySourceInfo>`
            
            .. attribute:: protocol
            
            	Protocol
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: s2l_sub_lsp
            
            	RSVP S2L Sub\-LSP information
            	**type**\:   :py:class:`S2LSubLsp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbDetaileds.PsbDetailed.S2LSubLsp>`
            
            .. attribute:: session
            
            	RSVP Session Information
            	**type**\:   :py:class:`Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbDetaileds.PsbDetailed.Session>`
            
            .. attribute:: session_attribute
            
            	RSVP Session Attribute
            	**type**\:   :py:class:`SessionAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbDetaileds.PsbDetailed.SessionAttribute>`
            
            .. attribute:: session_type
            
            	Session Type
            	**type**\:   :py:class:`RsvpSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpSession>`
            
            .. attribute:: source_address
            
            	Source Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: source_port
            
            	Source Port 
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: sub_group_id
            
            	Subgroup ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: sub_group_origin
            
            	Subgroup Origin
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: template
            
            	RSVP Template
            	**type**\:   :py:class:`Template <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbDetaileds.PsbDetailed.Template>`
            
            .. attribute:: traffic_spec
            
            	RSVP Traffic Spec Info
            	**type**\:   :py:class:`TrafficSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbDetaileds.PsbDetailed.TrafficSpec>`
            
            .. attribute:: vrf_name
            
            	VRF Name
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Rsvp.PsbDetaileds.PsbDetailed, self).__init__()

                self.yang_name = "psb-detailed"
                self.yang_parent_name = "psb-detaileds"

                self.backup_tunnel_name = YLeaf(YType.str, "backup-tunnel-name")

                self.destination_address = YLeaf(YType.str, "destination-address")

                self.destination_port = YLeaf(YType.int32, "destination-port")

                self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                self.input_interface = YLeaf(YType.str, "input-interface")

                self.is_in_ero_valid = YLeaf(YType.boolean, "is-in-ero-valid")

                self.is_out_ero_valid = YLeaf(YType.boolean, "is-out-ero-valid")

                self.p2mp_id = YLeaf(YType.int32, "p2mp-id")

                self.protocol = YLeaf(YType.int32, "protocol")

                self.session_type = YLeaf(YType.enumeration, "session-type")

                self.source_address = YLeaf(YType.str, "source-address")

                self.source_port = YLeaf(YType.int32, "source-port")

                self.sub_group_id = YLeaf(YType.int32, "sub-group-id")

                self.sub_group_origin = YLeaf(YType.str, "sub-group-origin")

                self.vrf_name = YLeaf(YType.str, "vrf-name")

                self.class_type = Rsvp.PsbDetaileds.PsbDetailed.ClassType()
                self.class_type.parent = self
                self._children_name_map["class_type"] = "class-type"
                self._children_yang_names.add("class-type")

                self.expiry_time = Rsvp.PsbDetaileds.PsbDetailed.ExpiryTime()
                self.expiry_time.parent = self
                self._children_name_map["expiry_time"] = "expiry-time"
                self._children_yang_names.add("expiry-time")

                self.generic_traffic_spec = Rsvp.PsbDetaileds.PsbDetailed.GenericTrafficSpec()
                self.generic_traffic_spec.parent = self
                self._children_name_map["generic_traffic_spec"] = "generic-traffic-spec"
                self._children_yang_names.add("generic-traffic-spec")

                self.header = Rsvp.PsbDetaileds.PsbDetailed.Header()
                self.header.parent = self
                self._children_name_map["header"] = "header"
                self._children_yang_names.add("header")

                self.hop = Rsvp.PsbDetaileds.PsbDetailed.Hop()
                self.hop.parent = self
                self._children_name_map["hop"] = "hop"
                self._children_yang_names.add("hop")

                self.label_info = Rsvp.PsbDetaileds.PsbDetailed.LabelInfo()
                self.label_info.parent = self
                self._children_name_map["label_info"] = "label-info"
                self._children_yang_names.add("label-info")

                self.path_flags = Rsvp.PsbDetaileds.PsbDetailed.PathFlags()
                self.path_flags.parent = self
                self._children_name_map["path_flags"] = "path-flags"
                self._children_yang_names.add("path-flags")

                self.policy_flags = Rsvp.PsbDetaileds.PsbDetailed.PolicyFlags()
                self.policy_flags.parent = self
                self._children_name_map["policy_flags"] = "policy-flags"
                self._children_yang_names.add("policy-flags")

                self.policy_query_flags = Rsvp.PsbDetaileds.PsbDetailed.PolicyQueryFlags()
                self.policy_query_flags.parent = self
                self._children_name_map["policy_query_flags"] = "policy-query-flags"
                self._children_yang_names.add("policy-query-flags")

                self.policy_source_info = Rsvp.PsbDetaileds.PsbDetailed.PolicySourceInfo()
                self.policy_source_info.parent = self
                self._children_name_map["policy_source_info"] = "policy-source-info"
                self._children_yang_names.add("policy-source-info")

                self.s2l_sub_lsp = Rsvp.PsbDetaileds.PsbDetailed.S2LSubLsp()
                self.s2l_sub_lsp.parent = self
                self._children_name_map["s2l_sub_lsp"] = "s2l-sub-lsp"
                self._children_yang_names.add("s2l-sub-lsp")

                self.session = Rsvp.PsbDetaileds.PsbDetailed.Session()
                self.session.parent = self
                self._children_name_map["session"] = "session"
                self._children_yang_names.add("session")

                self.session_attribute = Rsvp.PsbDetaileds.PsbDetailed.SessionAttribute()
                self.session_attribute.parent = self
                self._children_name_map["session_attribute"] = "session-attribute"
                self._children_yang_names.add("session-attribute")

                self.template = Rsvp.PsbDetaileds.PsbDetailed.Template()
                self.template.parent = self
                self._children_name_map["template"] = "template"
                self._children_yang_names.add("template")

                self.traffic_spec = Rsvp.PsbDetaileds.PsbDetailed.TrafficSpec()
                self.traffic_spec.parent = self
                self._children_name_map["traffic_spec"] = "traffic-spec"
                self._children_yang_names.add("traffic-spec")

                self.in_ero = YList(self)
                self.out_ero = YList(self)
                self.pfc = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("backup_tunnel_name",
                                "destination_address",
                                "destination_port",
                                "extended_tunnel_id",
                                "input_interface",
                                "is_in_ero_valid",
                                "is_out_ero_valid",
                                "p2mp_id",
                                "protocol",
                                "session_type",
                                "source_address",
                                "source_port",
                                "sub_group_id",
                                "sub_group_origin",
                                "vrf_name") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Rsvp.PsbDetaileds.PsbDetailed, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Rsvp.PsbDetaileds.PsbDetailed, self).__setattr__(name, value)


            class Session(Entity):
                """
                RSVP Session Information
                
                .. attribute:: rsvp_session
                
                	RSVP Session
                	**type**\:   :py:class:`RsvpSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbDetaileds.PsbDetailed.Session.RsvpSession>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.PsbDetaileds.PsbDetailed.Session, self).__init__()

                    self.yang_name = "session"
                    self.yang_parent_name = "psb-detailed"

                    self.rsvp_session = Rsvp.PsbDetaileds.PsbDetailed.Session.RsvpSession()
                    self.rsvp_session.parent = self
                    self._children_name_map["rsvp_session"] = "rsvp-session"
                    self._children_yang_names.add("rsvp-session")


                class RsvpSession(Entity):
                    """
                    RSVP Session
                    
                    .. attribute:: ipv4
                    
                    	UDP IPv4 session
                    	**type**\:   :py:class:`Ipv4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbDetaileds.PsbDetailed.Session.RsvpSession.Ipv4>`
                    
                    .. attribute:: ipv4_lsp_session
                    
                    	IPv4 LSP session
                    	**type**\:   :py:class:`Ipv4LspSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbDetaileds.PsbDetailed.Session.RsvpSession.Ipv4LspSession>`
                    
                    .. attribute:: ipv4_p2mp_lsp_session
                    
                    	IPv4 P2MP LSP session
                    	**type**\:   :py:class:`Ipv4P2MpLspSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbDetaileds.PsbDetailed.Session.RsvpSession.Ipv4P2MpLspSession>`
                    
                    .. attribute:: ipv4_uni_session
                    
                    	IPv4 UNI session
                    	**type**\:   :py:class:`Ipv4UniSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbDetaileds.PsbDetailed.Session.RsvpSession.Ipv4UniSession>`
                    
                    .. attribute:: session_type
                    
                    	SessionType
                    	**type**\:   :py:class:`RsvpMgmtSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtSession>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.PsbDetaileds.PsbDetailed.Session.RsvpSession, self).__init__()

                        self.yang_name = "rsvp-session"
                        self.yang_parent_name = "session"

                        self.session_type = YLeaf(YType.enumeration, "session-type")

                        self.ipv4 = Rsvp.PsbDetaileds.PsbDetailed.Session.RsvpSession.Ipv4()
                        self.ipv4.parent = self
                        self._children_name_map["ipv4"] = "ipv4"
                        self._children_yang_names.add("ipv4")

                        self.ipv4_lsp_session = Rsvp.PsbDetaileds.PsbDetailed.Session.RsvpSession.Ipv4LspSession()
                        self.ipv4_lsp_session.parent = self
                        self._children_name_map["ipv4_lsp_session"] = "ipv4-lsp-session"
                        self._children_yang_names.add("ipv4-lsp-session")

                        self.ipv4_p2mp_lsp_session = Rsvp.PsbDetaileds.PsbDetailed.Session.RsvpSession.Ipv4P2MpLspSession()
                        self.ipv4_p2mp_lsp_session.parent = self
                        self._children_name_map["ipv4_p2mp_lsp_session"] = "ipv4-p2mp-lsp-session"
                        self._children_yang_names.add("ipv4-p2mp-lsp-session")

                        self.ipv4_uni_session = Rsvp.PsbDetaileds.PsbDetailed.Session.RsvpSession.Ipv4UniSession()
                        self.ipv4_uni_session.parent = self
                        self._children_name_map["ipv4_uni_session"] = "ipv4-uni-session"
                        self._children_yang_names.add("ipv4-uni-session")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("session_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.PsbDetaileds.PsbDetailed.Session.RsvpSession, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.PsbDetaileds.PsbDetailed.Session.RsvpSession, self).__setattr__(name, value)


                    class Ipv4(Entity):
                        """
                        UDP IPv4 session
                        
                        .. attribute:: destination_address
                        
                        	Destination address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: destination_port
                        
                        	The Session Destination Port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: protocol
                        
                        	Protocol type (originally defined in RFC 790, further values in subsequent RFCs)
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.PsbDetaileds.PsbDetailed.Session.RsvpSession.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "rsvp-session"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.destination_port = YLeaf(YType.uint16, "destination-port")

                            self.protocol = YLeaf(YType.uint8, "protocol")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "destination_port",
                                            "protocol") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.PsbDetaileds.PsbDetailed.Session.RsvpSession.Ipv4, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.PsbDetaileds.PsbDetailed.Session.RsvpSession.Ipv4, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination_address.is_set or
                                self.destination_port.is_set or
                                self.protocol.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.destination_port.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-detaileds/psb-detailed/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.destination_port.is_set or self.destination_port.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_port.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "destination-port" or name == "protocol"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "destination-port"):
                                self.destination_port = value
                                self.destination_port.value_namespace = name_space
                                self.destination_port.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix


                    class Ipv4LspSession(Entity):
                        """
                        IPv4 LSP session
                        
                        .. attribute:: destination_address
                        
                        	Destination address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: extended_tunnel_id
                        
                        	The Session Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: tunnel_id
                        
                        	The Session Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.PsbDetaileds.PsbDetailed.Session.RsvpSession.Ipv4LspSession, self).__init__()

                            self.yang_name = "ipv4-lsp-session"
                            self.yang_parent_name = "rsvp-session"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                            self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "extended_tunnel_id",
                                            "tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.PsbDetaileds.PsbDetailed.Session.RsvpSession.Ipv4LspSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.PsbDetaileds.PsbDetailed.Session.RsvpSession.Ipv4LspSession, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination_address.is_set or
                                self.extended_tunnel_id.is_set or
                                self.tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.extended_tunnel_id.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-lsp-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-detaileds/psb-detailed/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "extended-tunnel-id" or name == "tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "extended-tunnel-id"):
                                self.extended_tunnel_id = value
                                self.extended_tunnel_id.value_namespace = name_space
                                self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix


                    class Ipv4UniSession(Entity):
                        """
                        IPv4 UNI session
                        
                        .. attribute:: destination_address
                        
                        	Destination address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: extended_address
                        
                        	The Session Extended Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: tunnel_id
                        
                        	The Session Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.PsbDetaileds.PsbDetailed.Session.RsvpSession.Ipv4UniSession, self).__init__()

                            self.yang_name = "ipv4-uni-session"
                            self.yang_parent_name = "rsvp-session"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.extended_address = YLeaf(YType.str, "extended-address")

                            self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "extended_address",
                                            "tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.PsbDetaileds.PsbDetailed.Session.RsvpSession.Ipv4UniSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.PsbDetaileds.PsbDetailed.Session.RsvpSession.Ipv4UniSession, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination_address.is_set or
                                self.extended_address.is_set or
                                self.tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.extended_address.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-uni-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-detaileds/psb-detailed/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.extended_address.is_set or self.extended_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_address.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "extended-address" or name == "tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "extended-address"):
                                self.extended_address = value
                                self.extended_address.value_namespace = name_space
                                self.extended_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix


                    class Ipv4P2MpLspSession(Entity):
                        """
                        IPv4 P2MP LSP session
                        
                        .. attribute:: extended_tunnel_id
                        
                        	The Session Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: p2mp_id
                        
                        	The Point to Multipoint ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tunnel_id
                        
                        	The Session Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.PsbDetaileds.PsbDetailed.Session.RsvpSession.Ipv4P2MpLspSession, self).__init__()

                            self.yang_name = "ipv4-p2mp-lsp-session"
                            self.yang_parent_name = "rsvp-session"

                            self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                            self.p2mp_id = YLeaf(YType.uint32, "p2mp-id")

                            self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("extended_tunnel_id",
                                            "p2mp_id",
                                            "tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.PsbDetaileds.PsbDetailed.Session.RsvpSession.Ipv4P2MpLspSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.PsbDetaileds.PsbDetailed.Session.RsvpSession.Ipv4P2MpLspSession, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.extended_tunnel_id.is_set or
                                self.p2mp_id.is_set or
                                self.tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.extended_tunnel_id.yfilter != YFilter.not_set or
                                self.p2mp_id.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-p2mp-lsp-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-detaileds/psb-detailed/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                            if (self.p2mp_id.is_set or self.p2mp_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.p2mp_id.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "extended-tunnel-id" or name == "p2mp-id" or name == "tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "extended-tunnel-id"):
                                self.extended_tunnel_id = value
                                self.extended_tunnel_id.value_namespace = name_space
                                self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "p2mp-id"):
                                self.p2mp_id = value
                                self.p2mp_id.value_namespace = name_space
                                self.p2mp_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.session_type.is_set or
                            (self.ipv4 is not None and self.ipv4.has_data()) or
                            (self.ipv4_lsp_session is not None and self.ipv4_lsp_session.has_data()) or
                            (self.ipv4_p2mp_lsp_session is not None and self.ipv4_p2mp_lsp_session.has_data()) or
                            (self.ipv4_uni_session is not None and self.ipv4_uni_session.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.session_type.yfilter != YFilter.not_set or
                            (self.ipv4 is not None and self.ipv4.has_operation()) or
                            (self.ipv4_lsp_session is not None and self.ipv4_lsp_session.has_operation()) or
                            (self.ipv4_p2mp_lsp_session is not None and self.ipv4_p2mp_lsp_session.has_operation()) or
                            (self.ipv4_uni_session is not None and self.ipv4_uni_session.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rsvp-session" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-detaileds/psb-detailed/session/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.session_type.is_set or self.session_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.session_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "ipv4"):
                            if (self.ipv4 is None):
                                self.ipv4 = Rsvp.PsbDetaileds.PsbDetailed.Session.RsvpSession.Ipv4()
                                self.ipv4.parent = self
                                self._children_name_map["ipv4"] = "ipv4"
                            return self.ipv4

                        if (child_yang_name == "ipv4-lsp-session"):
                            if (self.ipv4_lsp_session is None):
                                self.ipv4_lsp_session = Rsvp.PsbDetaileds.PsbDetailed.Session.RsvpSession.Ipv4LspSession()
                                self.ipv4_lsp_session.parent = self
                                self._children_name_map["ipv4_lsp_session"] = "ipv4-lsp-session"
                            return self.ipv4_lsp_session

                        if (child_yang_name == "ipv4-p2mp-lsp-session"):
                            if (self.ipv4_p2mp_lsp_session is None):
                                self.ipv4_p2mp_lsp_session = Rsvp.PsbDetaileds.PsbDetailed.Session.RsvpSession.Ipv4P2MpLspSession()
                                self.ipv4_p2mp_lsp_session.parent = self
                                self._children_name_map["ipv4_p2mp_lsp_session"] = "ipv4-p2mp-lsp-session"
                            return self.ipv4_p2mp_lsp_session

                        if (child_yang_name == "ipv4-uni-session"):
                            if (self.ipv4_uni_session is None):
                                self.ipv4_uni_session = Rsvp.PsbDetaileds.PsbDetailed.Session.RsvpSession.Ipv4UniSession()
                                self.ipv4_uni_session.parent = self
                                self._children_name_map["ipv4_uni_session"] = "ipv4-uni-session"
                            return self.ipv4_uni_session

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ipv4" or name == "ipv4-lsp-session" or name == "ipv4-p2mp-lsp-session" or name == "ipv4-uni-session" or name == "session-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "session-type"):
                            self.session_type = value
                            self.session_type.value_namespace = name_space
                            self.session_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (self.rsvp_session is not None and self.rsvp_session.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.rsvp_session is not None and self.rsvp_session.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "session" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-detaileds/psb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "rsvp-session"):
                        if (self.rsvp_session is None):
                            self.rsvp_session = Rsvp.PsbDetaileds.PsbDetailed.Session.RsvpSession()
                            self.rsvp_session.parent = self
                            self._children_name_map["rsvp_session"] = "rsvp-session"
                        return self.rsvp_session

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "rsvp-session"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class S2LSubLsp(Entity):
                """
                RSVP S2L Sub\-LSP information
                
                .. attribute:: s2l_destination_address
                
                	S2L Sub\-LSP Destination Address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.PsbDetaileds.PsbDetailed.S2LSubLsp, self).__init__()

                    self.yang_name = "s2l-sub-lsp"
                    self.yang_parent_name = "psb-detailed"

                    self.s2l_destination_address = YLeaf(YType.str, "s2l-destination-address")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("s2l_destination_address") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.PsbDetaileds.PsbDetailed.S2LSubLsp, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.PsbDetaileds.PsbDetailed.S2LSubLsp, self).__setattr__(name, value)

                def has_data(self):
                    return self.s2l_destination_address.is_set

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.s2l_destination_address.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "s2l-sub-lsp" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-detaileds/psb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.s2l_destination_address.is_set or self.s2l_destination_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.s2l_destination_address.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "s2l-destination-address"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "s2l-destination-address"):
                        self.s2l_destination_address = value
                        self.s2l_destination_address.value_namespace = name_space
                        self.s2l_destination_address.value_namespace_prefix = name_space_prefix


            class Template(Entity):
                """
                RSVP Template
                
                .. attribute:: rsvp_filter
                
                	RSVP Filter
                	**type**\:   :py:class:`RsvpFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbDetaileds.PsbDetailed.Template.RsvpFilter>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.PsbDetaileds.PsbDetailed.Template, self).__init__()

                    self.yang_name = "template"
                    self.yang_parent_name = "psb-detailed"

                    self.rsvp_filter = Rsvp.PsbDetaileds.PsbDetailed.Template.RsvpFilter()
                    self.rsvp_filter.parent = self
                    self._children_name_map["rsvp_filter"] = "rsvp-filter"
                    self._children_yang_names.add("rsvp-filter")


                class RsvpFilter(Entity):
                    """
                    RSVP Filter
                    
                    .. attribute:: filter_type
                    
                    	FilterType
                    	**type**\:   :py:class:`RsvpMgmtFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtFilter>`
                    
                    .. attribute:: p2mp_ipv4_session
                    
                    	IPv4 P2MP LSP FilterSpec
                    	**type**\:   :py:class:`P2MpIpv4Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbDetaileds.PsbDetailed.Template.RsvpFilter.P2MpIpv4Session>`
                    
                    .. attribute:: udp_ipv4_session
                    
                    	UDP IPV4 FilterSpec
                    	**type**\:   :py:class:`UdpIpv4Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbDetaileds.PsbDetailed.Template.RsvpFilter.UdpIpv4Session>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.PsbDetaileds.PsbDetailed.Template.RsvpFilter, self).__init__()

                        self.yang_name = "rsvp-filter"
                        self.yang_parent_name = "template"

                        self.filter_type = YLeaf(YType.enumeration, "filter-type")

                        self.p2mp_ipv4_session = Rsvp.PsbDetaileds.PsbDetailed.Template.RsvpFilter.P2MpIpv4Session()
                        self.p2mp_ipv4_session.parent = self
                        self._children_name_map["p2mp_ipv4_session"] = "p2mp-ipv4-session"
                        self._children_yang_names.add("p2mp-ipv4-session")

                        self.udp_ipv4_session = Rsvp.PsbDetaileds.PsbDetailed.Template.RsvpFilter.UdpIpv4Session()
                        self.udp_ipv4_session.parent = self
                        self._children_name_map["udp_ipv4_session"] = "udp-ipv4-session"
                        self._children_yang_names.add("udp-ipv4-session")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("filter_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.PsbDetaileds.PsbDetailed.Template.RsvpFilter, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.PsbDetaileds.PsbDetailed.Template.RsvpFilter, self).__setattr__(name, value)


                    class UdpIpv4Session(Entity):
                        """
                        UDP IPV4 FilterSpec
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source_port
                        
                        	Source Port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.PsbDetaileds.PsbDetailed.Template.RsvpFilter.UdpIpv4Session, self).__init__()

                            self.yang_name = "udp-ipv4-session"
                            self.yang_parent_name = "rsvp-filter"

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.source_port = YLeaf(YType.uint16, "source-port")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("source_address",
                                            "source_port") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.PsbDetaileds.PsbDetailed.Template.RsvpFilter.UdpIpv4Session, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.PsbDetaileds.PsbDetailed.Template.RsvpFilter.UdpIpv4Session, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.source_address.is_set or
                                self.source_port.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                self.source_port.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "udp-ipv4-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-detaileds/psb-detailed/template/rsvp-filter/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())
                            if (self.source_port.is_set or self.source_port.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_port.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "source-address" or name == "source-port"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-port"):
                                self.source_port = value
                                self.source_port.value_namespace = name_space
                                self.source_port.value_namespace_prefix = name_space_prefix


                    class P2MpIpv4Session(Entity):
                        """
                        IPv4 P2MP LSP FilterSpec
                        
                        .. attribute:: p2mp_sub_group_origin
                        
                        	Point to Multipoint SubGroup Origin
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source_port
                        
                        	Source Port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: sub_group_id
                        
                        	Point to Multipoint Subgroup ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.PsbDetaileds.PsbDetailed.Template.RsvpFilter.P2MpIpv4Session, self).__init__()

                            self.yang_name = "p2mp-ipv4-session"
                            self.yang_parent_name = "rsvp-filter"

                            self.p2mp_sub_group_origin = YLeaf(YType.str, "p2mp-sub-group-origin")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.source_port = YLeaf(YType.uint16, "source-port")

                            self.sub_group_id = YLeaf(YType.uint16, "sub-group-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("p2mp_sub_group_origin",
                                            "source_address",
                                            "source_port",
                                            "sub_group_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.PsbDetaileds.PsbDetailed.Template.RsvpFilter.P2MpIpv4Session, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.PsbDetaileds.PsbDetailed.Template.RsvpFilter.P2MpIpv4Session, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.p2mp_sub_group_origin.is_set or
                                self.source_address.is_set or
                                self.source_port.is_set or
                                self.sub_group_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.p2mp_sub_group_origin.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                self.source_port.yfilter != YFilter.not_set or
                                self.sub_group_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "p2mp-ipv4-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-detaileds/psb-detailed/template/rsvp-filter/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.p2mp_sub_group_origin.is_set or self.p2mp_sub_group_origin.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.p2mp_sub_group_origin.get_name_leafdata())
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())
                            if (self.source_port.is_set or self.source_port.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_port.get_name_leafdata())
                            if (self.sub_group_id.is_set or self.sub_group_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sub_group_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "p2mp-sub-group-origin" or name == "source-address" or name == "source-port" or name == "sub-group-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "p2mp-sub-group-origin"):
                                self.p2mp_sub_group_origin = value
                                self.p2mp_sub_group_origin.value_namespace = name_space
                                self.p2mp_sub_group_origin.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-port"):
                                self.source_port = value
                                self.source_port.value_namespace = name_space
                                self.source_port.value_namespace_prefix = name_space_prefix
                            if(value_path == "sub-group-id"):
                                self.sub_group_id = value
                                self.sub_group_id.value_namespace = name_space
                                self.sub_group_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.filter_type.is_set or
                            (self.p2mp_ipv4_session is not None and self.p2mp_ipv4_session.has_data()) or
                            (self.udp_ipv4_session is not None and self.udp_ipv4_session.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.filter_type.yfilter != YFilter.not_set or
                            (self.p2mp_ipv4_session is not None and self.p2mp_ipv4_session.has_operation()) or
                            (self.udp_ipv4_session is not None and self.udp_ipv4_session.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rsvp-filter" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-detaileds/psb-detailed/template/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.filter_type.is_set or self.filter_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.filter_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "p2mp-ipv4-session"):
                            if (self.p2mp_ipv4_session is None):
                                self.p2mp_ipv4_session = Rsvp.PsbDetaileds.PsbDetailed.Template.RsvpFilter.P2MpIpv4Session()
                                self.p2mp_ipv4_session.parent = self
                                self._children_name_map["p2mp_ipv4_session"] = "p2mp-ipv4-session"
                            return self.p2mp_ipv4_session

                        if (child_yang_name == "udp-ipv4-session"):
                            if (self.udp_ipv4_session is None):
                                self.udp_ipv4_session = Rsvp.PsbDetaileds.PsbDetailed.Template.RsvpFilter.UdpIpv4Session()
                                self.udp_ipv4_session.parent = self
                                self._children_name_map["udp_ipv4_session"] = "udp-ipv4-session"
                            return self.udp_ipv4_session

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "p2mp-ipv4-session" or name == "udp-ipv4-session" or name == "filter-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "filter-type"):
                            self.filter_type = value
                            self.filter_type.value_namespace = name_space
                            self.filter_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (self.rsvp_filter is not None and self.rsvp_filter.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.rsvp_filter is not None and self.rsvp_filter.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "template" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-detaileds/psb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "rsvp-filter"):
                        if (self.rsvp_filter is None):
                            self.rsvp_filter = Rsvp.PsbDetaileds.PsbDetailed.Template.RsvpFilter()
                            self.rsvp_filter.parent = self
                            self._children_name_map["rsvp_filter"] = "rsvp-filter"
                        return self.rsvp_filter

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "rsvp-filter"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class SessionAttribute(Entity):
                """
                RSVP Session Attribute
                
                .. attribute:: reservation_priority
                
                	Reservation Priority
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: sess_attribute_flags
                
                	Session Attributes
                	**type**\:   :py:class:`SessAttributeFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbDetaileds.PsbDetailed.SessionAttribute.SessAttributeFlags>`
                
                .. attribute:: setup_priority
                
                	Setup Priority
                	**type**\:  int
                
                	**range:** 0..255
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.PsbDetaileds.PsbDetailed.SessionAttribute, self).__init__()

                    self.yang_name = "session-attribute"
                    self.yang_parent_name = "psb-detailed"

                    self.reservation_priority = YLeaf(YType.uint8, "reservation-priority")

                    self.setup_priority = YLeaf(YType.uint8, "setup-priority")

                    self.sess_attribute_flags = Rsvp.PsbDetaileds.PsbDetailed.SessionAttribute.SessAttributeFlags()
                    self.sess_attribute_flags.parent = self
                    self._children_name_map["sess_attribute_flags"] = "sess-attribute-flags"
                    self._children_yang_names.add("sess-attribute-flags")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("reservation_priority",
                                    "setup_priority") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.PsbDetaileds.PsbDetailed.SessionAttribute, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.PsbDetaileds.PsbDetailed.SessionAttribute, self).__setattr__(name, value)


                class SessAttributeFlags(Entity):
                    """
                    Session Attributes
                    
                    .. attribute:: is_bandwidth_protect
                    
                    	Bandwidth Protection
                    	**type**\:  bool
                    
                    .. attribute:: is_local_protect
                    
                    	Local Protection
                    	**type**\:  bool
                    
                    .. attribute:: is_node_protect
                    
                    	Node Protection
                    	**type**\:  bool
                    
                    .. attribute:: is_record_labels
                    
                    	Records Labels
                    	**type**\:  bool
                    
                    .. attribute:: is_shared_explicit_requested
                    
                    	Shared Explicit Requested
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.PsbDetaileds.PsbDetailed.SessionAttribute.SessAttributeFlags, self).__init__()

                        self.yang_name = "sess-attribute-flags"
                        self.yang_parent_name = "session-attribute"

                        self.is_bandwidth_protect = YLeaf(YType.boolean, "is-bandwidth-protect")

                        self.is_local_protect = YLeaf(YType.boolean, "is-local-protect")

                        self.is_node_protect = YLeaf(YType.boolean, "is-node-protect")

                        self.is_record_labels = YLeaf(YType.boolean, "is-record-labels")

                        self.is_shared_explicit_requested = YLeaf(YType.boolean, "is-shared-explicit-requested")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("is_bandwidth_protect",
                                        "is_local_protect",
                                        "is_node_protect",
                                        "is_record_labels",
                                        "is_shared_explicit_requested") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.PsbDetaileds.PsbDetailed.SessionAttribute.SessAttributeFlags, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.PsbDetaileds.PsbDetailed.SessionAttribute.SessAttributeFlags, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.is_bandwidth_protect.is_set or
                            self.is_local_protect.is_set or
                            self.is_node_protect.is_set or
                            self.is_record_labels.is_set or
                            self.is_shared_explicit_requested.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.is_bandwidth_protect.yfilter != YFilter.not_set or
                            self.is_local_protect.yfilter != YFilter.not_set or
                            self.is_node_protect.yfilter != YFilter.not_set or
                            self.is_record_labels.yfilter != YFilter.not_set or
                            self.is_shared_explicit_requested.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "sess-attribute-flags" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-detaileds/psb-detailed/session-attribute/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.is_bandwidth_protect.is_set or self.is_bandwidth_protect.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_bandwidth_protect.get_name_leafdata())
                        if (self.is_local_protect.is_set or self.is_local_protect.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_local_protect.get_name_leafdata())
                        if (self.is_node_protect.is_set or self.is_node_protect.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_node_protect.get_name_leafdata())
                        if (self.is_record_labels.is_set or self.is_record_labels.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_record_labels.get_name_leafdata())
                        if (self.is_shared_explicit_requested.is_set or self.is_shared_explicit_requested.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_shared_explicit_requested.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "is-bandwidth-protect" or name == "is-local-protect" or name == "is-node-protect" or name == "is-record-labels" or name == "is-shared-explicit-requested"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "is-bandwidth-protect"):
                            self.is_bandwidth_protect = value
                            self.is_bandwidth_protect.value_namespace = name_space
                            self.is_bandwidth_protect.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-local-protect"):
                            self.is_local_protect = value
                            self.is_local_protect.value_namespace = name_space
                            self.is_local_protect.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-node-protect"):
                            self.is_node_protect = value
                            self.is_node_protect.value_namespace = name_space
                            self.is_node_protect.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-record-labels"):
                            self.is_record_labels = value
                            self.is_record_labels.value_namespace = name_space
                            self.is_record_labels.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-shared-explicit-requested"):
                            self.is_shared_explicit_requested = value
                            self.is_shared_explicit_requested.value_namespace = name_space
                            self.is_shared_explicit_requested.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.reservation_priority.is_set or
                        self.setup_priority.is_set or
                        (self.sess_attribute_flags is not None and self.sess_attribute_flags.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.reservation_priority.yfilter != YFilter.not_set or
                        self.setup_priority.yfilter != YFilter.not_set or
                        (self.sess_attribute_flags is not None and self.sess_attribute_flags.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "session-attribute" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-detaileds/psb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.reservation_priority.is_set or self.reservation_priority.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reservation_priority.get_name_leafdata())
                    if (self.setup_priority.is_set or self.setup_priority.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.setup_priority.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "sess-attribute-flags"):
                        if (self.sess_attribute_flags is None):
                            self.sess_attribute_flags = Rsvp.PsbDetaileds.PsbDetailed.SessionAttribute.SessAttributeFlags()
                            self.sess_attribute_flags.parent = self
                            self._children_name_map["sess_attribute_flags"] = "sess-attribute-flags"
                        return self.sess_attribute_flags

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "sess-attribute-flags" or name == "reservation-priority" or name == "setup-priority"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "reservation-priority"):
                        self.reservation_priority = value
                        self.reservation_priority.value_namespace = name_space
                        self.reservation_priority.value_namespace_prefix = name_space_prefix
                    if(value_path == "setup-priority"):
                        self.setup_priority = value
                        self.setup_priority.value_namespace = name_space
                        self.setup_priority.value_namespace_prefix = name_space_prefix


            class TrafficSpec(Entity):
                """
                RSVP Traffic Spec Info
                
                .. attribute:: traffic_average_rate
                
                	Traffic Average Rate in bytes per second
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: byte/s
                
                .. attribute:: traffic_max_burst
                
                	Traffic Maximum Burst
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: traffic_max_unit
                
                	Traffic Maximum Unit
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: traffic_min_unit
                
                	Traffic Minimum Unit
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: traffic_peak_rate
                
                	Traffic Peak Rate in bytes per second
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: byte/s
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.PsbDetaileds.PsbDetailed.TrafficSpec, self).__init__()

                    self.yang_name = "traffic-spec"
                    self.yang_parent_name = "psb-detailed"

                    self.traffic_average_rate = YLeaf(YType.uint64, "traffic-average-rate")

                    self.traffic_max_burst = YLeaf(YType.uint64, "traffic-max-burst")

                    self.traffic_max_unit = YLeaf(YType.uint32, "traffic-max-unit")

                    self.traffic_min_unit = YLeaf(YType.uint32, "traffic-min-unit")

                    self.traffic_peak_rate = YLeaf(YType.uint64, "traffic-peak-rate")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("traffic_average_rate",
                                    "traffic_max_burst",
                                    "traffic_max_unit",
                                    "traffic_min_unit",
                                    "traffic_peak_rate") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.PsbDetaileds.PsbDetailed.TrafficSpec, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.PsbDetaileds.PsbDetailed.TrafficSpec, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.traffic_average_rate.is_set or
                        self.traffic_max_burst.is_set or
                        self.traffic_max_unit.is_set or
                        self.traffic_min_unit.is_set or
                        self.traffic_peak_rate.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.traffic_average_rate.yfilter != YFilter.not_set or
                        self.traffic_max_burst.yfilter != YFilter.not_set or
                        self.traffic_max_unit.yfilter != YFilter.not_set or
                        self.traffic_min_unit.yfilter != YFilter.not_set or
                        self.traffic_peak_rate.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "traffic-spec" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-detaileds/psb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.traffic_average_rate.is_set or self.traffic_average_rate.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.traffic_average_rate.get_name_leafdata())
                    if (self.traffic_max_burst.is_set or self.traffic_max_burst.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.traffic_max_burst.get_name_leafdata())
                    if (self.traffic_max_unit.is_set or self.traffic_max_unit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.traffic_max_unit.get_name_leafdata())
                    if (self.traffic_min_unit.is_set or self.traffic_min_unit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.traffic_min_unit.get_name_leafdata())
                    if (self.traffic_peak_rate.is_set or self.traffic_peak_rate.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.traffic_peak_rate.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "traffic-average-rate" or name == "traffic-max-burst" or name == "traffic-max-unit" or name == "traffic-min-unit" or name == "traffic-peak-rate"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "traffic-average-rate"):
                        self.traffic_average_rate = value
                        self.traffic_average_rate.value_namespace = name_space
                        self.traffic_average_rate.value_namespace_prefix = name_space_prefix
                    if(value_path == "traffic-max-burst"):
                        self.traffic_max_burst = value
                        self.traffic_max_burst.value_namespace = name_space
                        self.traffic_max_burst.value_namespace_prefix = name_space_prefix
                    if(value_path == "traffic-max-unit"):
                        self.traffic_max_unit = value
                        self.traffic_max_unit.value_namespace = name_space
                        self.traffic_max_unit.value_namespace_prefix = name_space_prefix
                    if(value_path == "traffic-min-unit"):
                        self.traffic_min_unit = value
                        self.traffic_min_unit.value_namespace = name_space
                        self.traffic_min_unit.value_namespace_prefix = name_space_prefix
                    if(value_path == "traffic-peak-rate"):
                        self.traffic_peak_rate = value
                        self.traffic_peak_rate.value_namespace = name_space
                        self.traffic_peak_rate.value_namespace_prefix = name_space_prefix


            class GenericTrafficSpec(Entity):
                """
                RSVP Generic Traffic Spec Info
                
                .. attribute:: g709otn_tspec
                
                	G709 OTN Sender Tspec
                	**type**\:   :py:class:`G709OtnTspec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbDetaileds.PsbDetailed.GenericTrafficSpec.G709OtnTspec>`
                
                .. attribute:: intsrv_tspec
                
                	Integrated Services Sender Tspec
                	**type**\:   :py:class:`IntsrvTspec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbDetaileds.PsbDetailed.GenericTrafficSpec.IntsrvTspec>`
                
                .. attribute:: tspec_type
                
                	TspecType
                	**type**\:   :py:class:`RsvpMgmtTspec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtTspec>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.PsbDetaileds.PsbDetailed.GenericTrafficSpec, self).__init__()

                    self.yang_name = "generic-traffic-spec"
                    self.yang_parent_name = "psb-detailed"

                    self.tspec_type = YLeaf(YType.enumeration, "tspec-type")

                    self.g709otn_tspec = Rsvp.PsbDetaileds.PsbDetailed.GenericTrafficSpec.G709OtnTspec()
                    self.g709otn_tspec.parent = self
                    self._children_name_map["g709otn_tspec"] = "g709otn-tspec"
                    self._children_yang_names.add("g709otn-tspec")

                    self.intsrv_tspec = Rsvp.PsbDetaileds.PsbDetailed.GenericTrafficSpec.IntsrvTspec()
                    self.intsrv_tspec.parent = self
                    self._children_name_map["intsrv_tspec"] = "intsrv-tspec"
                    self._children_yang_names.add("intsrv-tspec")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("tspec_type") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.PsbDetaileds.PsbDetailed.GenericTrafficSpec, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.PsbDetaileds.PsbDetailed.GenericTrafficSpec, self).__setattr__(name, value)


                class G709OtnTspec(Entity):
                    """
                    G709 OTN Sender Tspec
                    
                    .. attribute:: traffic_bit_rate
                    
                    	G709 OTN Traffic Bit Rate
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: traffic_multiplier
                    
                    	G709 OTN Traffic Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: traffic_nvc
                    
                    	G709 OTN Traffic NVC
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: traffic_signal_type
                    
                    	G709 OTN Traffic Signal Type (Refer G709 v3)
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.PsbDetaileds.PsbDetailed.GenericTrafficSpec.G709OtnTspec, self).__init__()

                        self.yang_name = "g709otn-tspec"
                        self.yang_parent_name = "generic-traffic-spec"

                        self.traffic_bit_rate = YLeaf(YType.uint64, "traffic-bit-rate")

                        self.traffic_multiplier = YLeaf(YType.uint16, "traffic-multiplier")

                        self.traffic_nvc = YLeaf(YType.uint16, "traffic-nvc")

                        self.traffic_signal_type = YLeaf(YType.uint8, "traffic-signal-type")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("traffic_bit_rate",
                                        "traffic_multiplier",
                                        "traffic_nvc",
                                        "traffic_signal_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.PsbDetaileds.PsbDetailed.GenericTrafficSpec.G709OtnTspec, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.PsbDetaileds.PsbDetailed.GenericTrafficSpec.G709OtnTspec, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.traffic_bit_rate.is_set or
                            self.traffic_multiplier.is_set or
                            self.traffic_nvc.is_set or
                            self.traffic_signal_type.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.traffic_bit_rate.yfilter != YFilter.not_set or
                            self.traffic_multiplier.yfilter != YFilter.not_set or
                            self.traffic_nvc.yfilter != YFilter.not_set or
                            self.traffic_signal_type.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "g709otn-tspec" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-detaileds/psb-detailed/generic-traffic-spec/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.traffic_bit_rate.is_set or self.traffic_bit_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.traffic_bit_rate.get_name_leafdata())
                        if (self.traffic_multiplier.is_set or self.traffic_multiplier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.traffic_multiplier.get_name_leafdata())
                        if (self.traffic_nvc.is_set or self.traffic_nvc.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.traffic_nvc.get_name_leafdata())
                        if (self.traffic_signal_type.is_set or self.traffic_signal_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.traffic_signal_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "traffic-bit-rate" or name == "traffic-multiplier" or name == "traffic-nvc" or name == "traffic-signal-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "traffic-bit-rate"):
                            self.traffic_bit_rate = value
                            self.traffic_bit_rate.value_namespace = name_space
                            self.traffic_bit_rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "traffic-multiplier"):
                            self.traffic_multiplier = value
                            self.traffic_multiplier.value_namespace = name_space
                            self.traffic_multiplier.value_namespace_prefix = name_space_prefix
                        if(value_path == "traffic-nvc"):
                            self.traffic_nvc = value
                            self.traffic_nvc.value_namespace = name_space
                            self.traffic_nvc.value_namespace_prefix = name_space_prefix
                        if(value_path == "traffic-signal-type"):
                            self.traffic_signal_type = value
                            self.traffic_signal_type.value_namespace = name_space
                            self.traffic_signal_type.value_namespace_prefix = name_space_prefix


                class IntsrvTspec(Entity):
                    """
                    Integrated Services Sender Tspec
                    
                    .. attribute:: traffic_average_rate
                    
                    	Traffic Average Rate in bytes per second
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: byte/s
                    
                    .. attribute:: traffic_max_burst
                    
                    	Traffic Maximum Burst
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: traffic_max_unit
                    
                    	Traffic Maximum Unit
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: traffic_min_unit
                    
                    	Traffic Minimum Unit
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: traffic_peak_rate
                    
                    	Traffic Peak Rate in bytes per second
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: byte/s
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.PsbDetaileds.PsbDetailed.GenericTrafficSpec.IntsrvTspec, self).__init__()

                        self.yang_name = "intsrv-tspec"
                        self.yang_parent_name = "generic-traffic-spec"

                        self.traffic_average_rate = YLeaf(YType.uint64, "traffic-average-rate")

                        self.traffic_max_burst = YLeaf(YType.uint64, "traffic-max-burst")

                        self.traffic_max_unit = YLeaf(YType.uint32, "traffic-max-unit")

                        self.traffic_min_unit = YLeaf(YType.uint32, "traffic-min-unit")

                        self.traffic_peak_rate = YLeaf(YType.uint64, "traffic-peak-rate")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("traffic_average_rate",
                                        "traffic_max_burst",
                                        "traffic_max_unit",
                                        "traffic_min_unit",
                                        "traffic_peak_rate") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.PsbDetaileds.PsbDetailed.GenericTrafficSpec.IntsrvTspec, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.PsbDetaileds.PsbDetailed.GenericTrafficSpec.IntsrvTspec, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.traffic_average_rate.is_set or
                            self.traffic_max_burst.is_set or
                            self.traffic_max_unit.is_set or
                            self.traffic_min_unit.is_set or
                            self.traffic_peak_rate.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.traffic_average_rate.yfilter != YFilter.not_set or
                            self.traffic_max_burst.yfilter != YFilter.not_set or
                            self.traffic_max_unit.yfilter != YFilter.not_set or
                            self.traffic_min_unit.yfilter != YFilter.not_set or
                            self.traffic_peak_rate.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "intsrv-tspec" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-detaileds/psb-detailed/generic-traffic-spec/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.traffic_average_rate.is_set or self.traffic_average_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.traffic_average_rate.get_name_leafdata())
                        if (self.traffic_max_burst.is_set or self.traffic_max_burst.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.traffic_max_burst.get_name_leafdata())
                        if (self.traffic_max_unit.is_set or self.traffic_max_unit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.traffic_max_unit.get_name_leafdata())
                        if (self.traffic_min_unit.is_set or self.traffic_min_unit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.traffic_min_unit.get_name_leafdata())
                        if (self.traffic_peak_rate.is_set or self.traffic_peak_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.traffic_peak_rate.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "traffic-average-rate" or name == "traffic-max-burst" or name == "traffic-max-unit" or name == "traffic-min-unit" or name == "traffic-peak-rate"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "traffic-average-rate"):
                            self.traffic_average_rate = value
                            self.traffic_average_rate.value_namespace = name_space
                            self.traffic_average_rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "traffic-max-burst"):
                            self.traffic_max_burst = value
                            self.traffic_max_burst.value_namespace = name_space
                            self.traffic_max_burst.value_namespace_prefix = name_space_prefix
                        if(value_path == "traffic-max-unit"):
                            self.traffic_max_unit = value
                            self.traffic_max_unit.value_namespace = name_space
                            self.traffic_max_unit.value_namespace_prefix = name_space_prefix
                        if(value_path == "traffic-min-unit"):
                            self.traffic_min_unit = value
                            self.traffic_min_unit.value_namespace = name_space
                            self.traffic_min_unit.value_namespace_prefix = name_space_prefix
                        if(value_path == "traffic-peak-rate"):
                            self.traffic_peak_rate = value
                            self.traffic_peak_rate.value_namespace = name_space
                            self.traffic_peak_rate.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.tspec_type.is_set or
                        (self.g709otn_tspec is not None and self.g709otn_tspec.has_data()) or
                        (self.intsrv_tspec is not None and self.intsrv_tspec.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.tspec_type.yfilter != YFilter.not_set or
                        (self.g709otn_tspec is not None and self.g709otn_tspec.has_operation()) or
                        (self.intsrv_tspec is not None and self.intsrv_tspec.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "generic-traffic-spec" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-detaileds/psb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.tspec_type.is_set or self.tspec_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tspec_type.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "g709otn-tspec"):
                        if (self.g709otn_tspec is None):
                            self.g709otn_tspec = Rsvp.PsbDetaileds.PsbDetailed.GenericTrafficSpec.G709OtnTspec()
                            self.g709otn_tspec.parent = self
                            self._children_name_map["g709otn_tspec"] = "g709otn-tspec"
                        return self.g709otn_tspec

                    if (child_yang_name == "intsrv-tspec"):
                        if (self.intsrv_tspec is None):
                            self.intsrv_tspec = Rsvp.PsbDetaileds.PsbDetailed.GenericTrafficSpec.IntsrvTspec()
                            self.intsrv_tspec.parent = self
                            self._children_name_map["intsrv_tspec"] = "intsrv-tspec"
                        return self.intsrv_tspec

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "g709otn-tspec" or name == "intsrv-tspec" or name == "tspec-type"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "tspec-type"):
                        self.tspec_type = value
                        self.tspec_type.value_namespace = name_space
                        self.tspec_type.value_namespace_prefix = name_space_prefix


            class PathFlags(Entity):
                """
                Path Flags
                
                .. attribute:: is_bidirectional
                
                	Bidirectional
                	**type**\:  bool
                
                .. attribute:: is_local_repair
                
                	Rerouted
                	**type**\:  bool
                
                .. attribute:: is_local_sender
                
                	Local Sender
                	**type**\:  bool
                
                .. attribute:: is_lockout
                
                	Locked Out
                	**type**\:  bool
                
                .. attribute:: is_message_id_valid
                
                	MessageID Valid
                	**type**\:  bool
                
                .. attribute:: is_non_rsvp_hop_upstream
                
                	Non\-RSVP Hop Upstream
                	**type**\:  bool
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.PsbDetaileds.PsbDetailed.PathFlags, self).__init__()

                    self.yang_name = "path-flags"
                    self.yang_parent_name = "psb-detailed"

                    self.is_bidirectional = YLeaf(YType.boolean, "is-bidirectional")

                    self.is_local_repair = YLeaf(YType.boolean, "is-local-repair")

                    self.is_local_sender = YLeaf(YType.boolean, "is-local-sender")

                    self.is_lockout = YLeaf(YType.boolean, "is-lockout")

                    self.is_message_id_valid = YLeaf(YType.boolean, "is-message-id-valid")

                    self.is_non_rsvp_hop_upstream = YLeaf(YType.boolean, "is-non-rsvp-hop-upstream")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("is_bidirectional",
                                    "is_local_repair",
                                    "is_local_sender",
                                    "is_lockout",
                                    "is_message_id_valid",
                                    "is_non_rsvp_hop_upstream") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.PsbDetaileds.PsbDetailed.PathFlags, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.PsbDetaileds.PsbDetailed.PathFlags, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.is_bidirectional.is_set or
                        self.is_local_repair.is_set or
                        self.is_local_sender.is_set or
                        self.is_lockout.is_set or
                        self.is_message_id_valid.is_set or
                        self.is_non_rsvp_hop_upstream.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.is_bidirectional.yfilter != YFilter.not_set or
                        self.is_local_repair.yfilter != YFilter.not_set or
                        self.is_local_sender.yfilter != YFilter.not_set or
                        self.is_lockout.yfilter != YFilter.not_set or
                        self.is_message_id_valid.yfilter != YFilter.not_set or
                        self.is_non_rsvp_hop_upstream.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "path-flags" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-detaileds/psb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.is_bidirectional.is_set or self.is_bidirectional.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_bidirectional.get_name_leafdata())
                    if (self.is_local_repair.is_set or self.is_local_repair.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_local_repair.get_name_leafdata())
                    if (self.is_local_sender.is_set or self.is_local_sender.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_local_sender.get_name_leafdata())
                    if (self.is_lockout.is_set or self.is_lockout.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_lockout.get_name_leafdata())
                    if (self.is_message_id_valid.is_set or self.is_message_id_valid.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_message_id_valid.get_name_leafdata())
                    if (self.is_non_rsvp_hop_upstream.is_set or self.is_non_rsvp_hop_upstream.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_non_rsvp_hop_upstream.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "is-bidirectional" or name == "is-local-repair" or name == "is-local-sender" or name == "is-lockout" or name == "is-message-id-valid" or name == "is-non-rsvp-hop-upstream"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "is-bidirectional"):
                        self.is_bidirectional = value
                        self.is_bidirectional.value_namespace = name_space
                        self.is_bidirectional.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-local-repair"):
                        self.is_local_repair = value
                        self.is_local_repair.value_namespace = name_space
                        self.is_local_repair.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-local-sender"):
                        self.is_local_sender = value
                        self.is_local_sender.value_namespace = name_space
                        self.is_local_sender.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-lockout"):
                        self.is_lockout = value
                        self.is_lockout.value_namespace = name_space
                        self.is_lockout.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-message-id-valid"):
                        self.is_message_id_valid = value
                        self.is_message_id_valid.value_namespace = name_space
                        self.is_message_id_valid.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-non-rsvp-hop-upstream"):
                        self.is_non_rsvp_hop_upstream = value
                        self.is_non_rsvp_hop_upstream.value_namespace = name_space
                        self.is_non_rsvp_hop_upstream.value_namespace_prefix = name_space_prefix


            class Hop(Entity):
                """
                Path Hop Info
                
                .. attribute:: neighbor_address
                
                	IP address of the neighbor
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: neighbor_logical_interface_name
                
                	Neighbor Logical Interface Name
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.PsbDetaileds.PsbDetailed.Hop, self).__init__()

                    self.yang_name = "hop"
                    self.yang_parent_name = "psb-detailed"

                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                    self.neighbor_logical_interface_name = YLeaf(YType.str, "neighbor-logical-interface-name")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("neighbor_address",
                                    "neighbor_logical_interface_name") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.PsbDetaileds.PsbDetailed.Hop, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.PsbDetaileds.PsbDetailed.Hop, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.neighbor_address.is_set or
                        self.neighbor_logical_interface_name.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.neighbor_address.yfilter != YFilter.not_set or
                        self.neighbor_logical_interface_name.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "hop" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-detaileds/psb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                    if (self.neighbor_logical_interface_name.is_set or self.neighbor_logical_interface_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.neighbor_logical_interface_name.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "neighbor-address" or name == "neighbor-logical-interface-name"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "neighbor-address"):
                        self.neighbor_address = value
                        self.neighbor_address.value_namespace = name_space
                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "neighbor-logical-interface-name"):
                        self.neighbor_logical_interface_name = value
                        self.neighbor_logical_interface_name.value_namespace = name_space
                        self.neighbor_logical_interface_name.value_namespace_prefix = name_space_prefix


            class PolicySourceInfo(Entity):
                """
                Policy Sources Info
                
                .. attribute:: is_cable
                
                	Policy Source is Cable
                	**type**\:  bool
                
                .. attribute:: is_cops
                
                	Policy Source is COPS
                	**type**\:  bool
                
                .. attribute:: is_default
                
                	Policy Source is Default
                	**type**\:  bool
                
                .. attribute:: is_local
                
                	Policy Source is Local
                	**type**\:  bool
                
                .. attribute:: is_te_link
                
                	Policy Source is TE Link
                	**type**\:  bool
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.PsbDetaileds.PsbDetailed.PolicySourceInfo, self).__init__()

                    self.yang_name = "policy-source-info"
                    self.yang_parent_name = "psb-detailed"

                    self.is_cable = YLeaf(YType.boolean, "is-cable")

                    self.is_cops = YLeaf(YType.boolean, "is-cops")

                    self.is_default = YLeaf(YType.boolean, "is-default")

                    self.is_local = YLeaf(YType.boolean, "is-local")

                    self.is_te_link = YLeaf(YType.boolean, "is-te-link")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("is_cable",
                                    "is_cops",
                                    "is_default",
                                    "is_local",
                                    "is_te_link") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.PsbDetaileds.PsbDetailed.PolicySourceInfo, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.PsbDetaileds.PsbDetailed.PolicySourceInfo, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.is_cable.is_set or
                        self.is_cops.is_set or
                        self.is_default.is_set or
                        self.is_local.is_set or
                        self.is_te_link.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.is_cable.yfilter != YFilter.not_set or
                        self.is_cops.yfilter != YFilter.not_set or
                        self.is_default.yfilter != YFilter.not_set or
                        self.is_local.yfilter != YFilter.not_set or
                        self.is_te_link.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "policy-source-info" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-detaileds/psb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.is_cable.is_set or self.is_cable.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_cable.get_name_leafdata())
                    if (self.is_cops.is_set or self.is_cops.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_cops.get_name_leafdata())
                    if (self.is_default.is_set or self.is_default.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_default.get_name_leafdata())
                    if (self.is_local.is_set or self.is_local.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_local.get_name_leafdata())
                    if (self.is_te_link.is_set or self.is_te_link.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_te_link.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "is-cable" or name == "is-cops" or name == "is-default" or name == "is-local" or name == "is-te-link"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "is-cable"):
                        self.is_cable = value
                        self.is_cable.value_namespace = name_space
                        self.is_cable.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-cops"):
                        self.is_cops = value
                        self.is_cops.value_namespace = name_space
                        self.is_cops.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-default"):
                        self.is_default = value
                        self.is_default.value_namespace = name_space
                        self.is_default.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-local"):
                        self.is_local = value
                        self.is_local.value_namespace = name_space
                        self.is_local.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-te-link"):
                        self.is_te_link = value
                        self.is_te_link.value_namespace = name_space
                        self.is_te_link.value_namespace_prefix = name_space_prefix


            class Header(Entity):
                """
                RSVP Header Info
                
                .. attribute:: ip_source_address
                
                	IP Source Address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: ip_tos
                
                	IP Type of Service
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: ip_ttl
                
                	IP TTL
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: rsvp_header_flags
                
                	RSVP Header Flags (defined in RFC2205 Section 3 .1.1)
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: rsvp_message_type
                
                	RSVP Message Type
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: rsvp_ttl
                
                	RSVP TTL
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: rsvp_version
                
                	RSVP Version
                	**type**\:  int
                
                	**range:** 0..255
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.PsbDetaileds.PsbDetailed.Header, self).__init__()

                    self.yang_name = "header"
                    self.yang_parent_name = "psb-detailed"

                    self.ip_source_address = YLeaf(YType.str, "ip-source-address")

                    self.ip_tos = YLeaf(YType.uint8, "ip-tos")

                    self.ip_ttl = YLeaf(YType.uint8, "ip-ttl")

                    self.rsvp_header_flags = YLeaf(YType.uint8, "rsvp-header-flags")

                    self.rsvp_message_type = YLeaf(YType.uint8, "rsvp-message-type")

                    self.rsvp_ttl = YLeaf(YType.uint8, "rsvp-ttl")

                    self.rsvp_version = YLeaf(YType.uint8, "rsvp-version")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("ip_source_address",
                                    "ip_tos",
                                    "ip_ttl",
                                    "rsvp_header_flags",
                                    "rsvp_message_type",
                                    "rsvp_ttl",
                                    "rsvp_version") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.PsbDetaileds.PsbDetailed.Header, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.PsbDetaileds.PsbDetailed.Header, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.ip_source_address.is_set or
                        self.ip_tos.is_set or
                        self.ip_ttl.is_set or
                        self.rsvp_header_flags.is_set or
                        self.rsvp_message_type.is_set or
                        self.rsvp_ttl.is_set or
                        self.rsvp_version.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.ip_source_address.yfilter != YFilter.not_set or
                        self.ip_tos.yfilter != YFilter.not_set or
                        self.ip_ttl.yfilter != YFilter.not_set or
                        self.rsvp_header_flags.yfilter != YFilter.not_set or
                        self.rsvp_message_type.yfilter != YFilter.not_set or
                        self.rsvp_ttl.yfilter != YFilter.not_set or
                        self.rsvp_version.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "header" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-detaileds/psb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.ip_source_address.is_set or self.ip_source_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ip_source_address.get_name_leafdata())
                    if (self.ip_tos.is_set or self.ip_tos.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ip_tos.get_name_leafdata())
                    if (self.ip_ttl.is_set or self.ip_ttl.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ip_ttl.get_name_leafdata())
                    if (self.rsvp_header_flags.is_set or self.rsvp_header_flags.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_header_flags.get_name_leafdata())
                    if (self.rsvp_message_type.is_set or self.rsvp_message_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_message_type.get_name_leafdata())
                    if (self.rsvp_ttl.is_set or self.rsvp_ttl.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_ttl.get_name_leafdata())
                    if (self.rsvp_version.is_set or self.rsvp_version.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_version.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ip-source-address" or name == "ip-tos" or name == "ip-ttl" or name == "rsvp-header-flags" or name == "rsvp-message-type" or name == "rsvp-ttl" or name == "rsvp-version"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "ip-source-address"):
                        self.ip_source_address = value
                        self.ip_source_address.value_namespace = name_space
                        self.ip_source_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "ip-tos"):
                        self.ip_tos = value
                        self.ip_tos.value_namespace = name_space
                        self.ip_tos.value_namespace_prefix = name_space_prefix
                    if(value_path == "ip-ttl"):
                        self.ip_ttl = value
                        self.ip_ttl.value_namespace = name_space
                        self.ip_ttl.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-header-flags"):
                        self.rsvp_header_flags = value
                        self.rsvp_header_flags.value_namespace = name_space
                        self.rsvp_header_flags.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-message-type"):
                        self.rsvp_message_type = value
                        self.rsvp_message_type.value_namespace = name_space
                        self.rsvp_message_type.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-ttl"):
                        self.rsvp_ttl = value
                        self.rsvp_ttl.value_namespace = name_space
                        self.rsvp_ttl.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-version"):
                        self.rsvp_version = value
                        self.rsvp_version.value_namespace = name_space
                        self.rsvp_version.value_namespace_prefix = name_space_prefix


            class ExpiryTime(Entity):
                """
                Expiry Time
                
                .. attribute:: nanoseconds
                
                	Time Value in Nano\-seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: nanosecond
                
                .. attribute:: seconds
                
                	Time Value in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.PsbDetaileds.PsbDetailed.ExpiryTime, self).__init__()

                    self.yang_name = "expiry-time"
                    self.yang_parent_name = "psb-detailed"

                    self.nanoseconds = YLeaf(YType.int32, "nanoseconds")

                    self.seconds = YLeaf(YType.int32, "seconds")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("nanoseconds",
                                    "seconds") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.PsbDetaileds.PsbDetailed.ExpiryTime, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.PsbDetaileds.PsbDetailed.ExpiryTime, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.nanoseconds.is_set or
                        self.seconds.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.nanoseconds.yfilter != YFilter.not_set or
                        self.seconds.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "expiry-time" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-detaileds/psb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.nanoseconds.is_set or self.nanoseconds.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.nanoseconds.get_name_leafdata())
                    if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.seconds.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "nanoseconds" or name == "seconds"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "nanoseconds"):
                        self.nanoseconds = value
                        self.nanoseconds.value_namespace = name_space
                        self.nanoseconds.value_namespace_prefix = name_space_prefix
                    if(value_path == "seconds"):
                        self.seconds = value
                        self.seconds.value_namespace = name_space
                        self.seconds.value_namespace_prefix = name_space_prefix


            class PolicyFlags(Entity):
                """
                Policy Flags
                
                .. attribute:: is_accepted
                
                	Accepted
                	**type**\:  bool
                
                .. attribute:: is_forwarding
                
                	Forwarding
                	**type**\:  bool
                
                .. attribute:: is_installed
                
                	Installed
                	**type**\:  bool
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.PsbDetaileds.PsbDetailed.PolicyFlags, self).__init__()

                    self.yang_name = "policy-flags"
                    self.yang_parent_name = "psb-detailed"

                    self.is_accepted = YLeaf(YType.boolean, "is-accepted")

                    self.is_forwarding = YLeaf(YType.boolean, "is-forwarding")

                    self.is_installed = YLeaf(YType.boolean, "is-installed")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("is_accepted",
                                    "is_forwarding",
                                    "is_installed") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.PsbDetaileds.PsbDetailed.PolicyFlags, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.PsbDetaileds.PsbDetailed.PolicyFlags, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.is_accepted.is_set or
                        self.is_forwarding.is_set or
                        self.is_installed.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.is_accepted.yfilter != YFilter.not_set or
                        self.is_forwarding.yfilter != YFilter.not_set or
                        self.is_installed.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "policy-flags" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-detaileds/psb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.is_accepted.is_set or self.is_accepted.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_accepted.get_name_leafdata())
                    if (self.is_forwarding.is_set or self.is_forwarding.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_forwarding.get_name_leafdata())
                    if (self.is_installed.is_set or self.is_installed.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_installed.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "is-accepted" or name == "is-forwarding" or name == "is-installed"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "is-accepted"):
                        self.is_accepted = value
                        self.is_accepted.value_namespace = name_space
                        self.is_accepted.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-forwarding"):
                        self.is_forwarding = value
                        self.is_forwarding.value_namespace = name_space
                        self.is_forwarding.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-installed"):
                        self.is_installed = value
                        self.is_installed.value_namespace = name_space
                        self.is_installed.value_namespace_prefix = name_space_prefix


            class PolicyQueryFlags(Entity):
                """
                Policy Query Flags
                
                .. attribute:: is_bypass
                
                	Bypass
                	**type**\:  bool
                
                .. attribute:: is_needed
                
                	Needed
                	**type**\:  bool
                
                .. attribute:: is_report_required
                
                	Report Required
                	**type**\:  bool
                
                .. attribute:: is_resync
                
                	Resynchronization
                	**type**\:  bool
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.PsbDetaileds.PsbDetailed.PolicyQueryFlags, self).__init__()

                    self.yang_name = "policy-query-flags"
                    self.yang_parent_name = "psb-detailed"

                    self.is_bypass = YLeaf(YType.boolean, "is-bypass")

                    self.is_needed = YLeaf(YType.boolean, "is-needed")

                    self.is_report_required = YLeaf(YType.boolean, "is-report-required")

                    self.is_resync = YLeaf(YType.boolean, "is-resync")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("is_bypass",
                                    "is_needed",
                                    "is_report_required",
                                    "is_resync") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.PsbDetaileds.PsbDetailed.PolicyQueryFlags, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.PsbDetaileds.PsbDetailed.PolicyQueryFlags, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.is_bypass.is_set or
                        self.is_needed.is_set or
                        self.is_report_required.is_set or
                        self.is_resync.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.is_bypass.yfilter != YFilter.not_set or
                        self.is_needed.yfilter != YFilter.not_set or
                        self.is_report_required.yfilter != YFilter.not_set or
                        self.is_resync.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "policy-query-flags" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-detaileds/psb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.is_bypass.is_set or self.is_bypass.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_bypass.get_name_leafdata())
                    if (self.is_needed.is_set or self.is_needed.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_needed.get_name_leafdata())
                    if (self.is_report_required.is_set or self.is_report_required.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_report_required.get_name_leafdata())
                    if (self.is_resync.is_set or self.is_resync.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_resync.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "is-bypass" or name == "is-needed" or name == "is-report-required" or name == "is-resync"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "is-bypass"):
                        self.is_bypass = value
                        self.is_bypass.value_namespace = name_space
                        self.is_bypass.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-needed"):
                        self.is_needed = value
                        self.is_needed.value_namespace = name_space
                        self.is_needed.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-report-required"):
                        self.is_report_required = value
                        self.is_report_required.value_namespace = name_space
                        self.is_report_required.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-resync"):
                        self.is_resync = value
                        self.is_resync.value_namespace = name_space
                        self.is_resync.value_namespace_prefix = name_space_prefix


            class LabelInfo(Entity):
                """
                Label Information
                
                .. attribute:: generic_local_downstream_label
                
                	Generic Local Downstream Label
                	**type**\:   :py:class:`GenericLocalDownstreamLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericLocalDownstreamLabel>`
                
                .. attribute:: generic_local_upstream_label
                
                	Generic Local Upstream Label
                	**type**\:   :py:class:`GenericLocalUpstreamLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericLocalUpstreamLabel>`
                
                .. attribute:: generic_merge_point_label
                
                	Generic MergePoint Label
                	**type**\:   :py:class:`GenericMergePointLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericMergePointLabel>`
                
                .. attribute:: generic_outgoing_downstream_label
                
                	Generic Outgoing Downstream Label
                	**type**\:   :py:class:`GenericOutgoingDownstreamLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericOutgoingDownstreamLabel>`
                
                .. attribute:: generic_outgoing_upstream_label
                
                	Generic Outgoing Upstream Label
                	**type**\:   :py:class:`GenericOutgoingUpstreamLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericOutgoingUpstreamLabel>`
                
                .. attribute:: generic_recovery_label
                
                	Generic Recovery Label
                	**type**\:   :py:class:`GenericRecoveryLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericRecoveryLabel>`
                
                .. attribute:: is_valid
                
                	Is the label information valid
                	**type**\:  bool
                
                .. attribute:: local_downstream_label
                
                	Local Downstream Label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: local_upstream_label
                
                	Local Upstream Label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: lsp_wrap_label
                
                	LSP Wrap Label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: merge_point_label
                
                	MergePoint Label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: outgoing_downstream_label
                
                	Outgoing Downstream Label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: outgoing_upstream_label
                
                	Outgoing Upstream Label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: recovery_label
                
                	Recovery Label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.PsbDetaileds.PsbDetailed.LabelInfo, self).__init__()

                    self.yang_name = "label-info"
                    self.yang_parent_name = "psb-detailed"

                    self.is_valid = YLeaf(YType.boolean, "is-valid")

                    self.local_downstream_label = YLeaf(YType.uint32, "local-downstream-label")

                    self.local_upstream_label = YLeaf(YType.uint32, "local-upstream-label")

                    self.lsp_wrap_label = YLeaf(YType.uint32, "lsp-wrap-label")

                    self.merge_point_label = YLeaf(YType.uint32, "merge-point-label")

                    self.outgoing_downstream_label = YLeaf(YType.uint32, "outgoing-downstream-label")

                    self.outgoing_upstream_label = YLeaf(YType.uint32, "outgoing-upstream-label")

                    self.recovery_label = YLeaf(YType.uint32, "recovery-label")

                    self.generic_local_downstream_label = Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericLocalDownstreamLabel()
                    self.generic_local_downstream_label.parent = self
                    self._children_name_map["generic_local_downstream_label"] = "generic-local-downstream-label"
                    self._children_yang_names.add("generic-local-downstream-label")

                    self.generic_local_upstream_label = Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericLocalUpstreamLabel()
                    self.generic_local_upstream_label.parent = self
                    self._children_name_map["generic_local_upstream_label"] = "generic-local-upstream-label"
                    self._children_yang_names.add("generic-local-upstream-label")

                    self.generic_merge_point_label = Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericMergePointLabel()
                    self.generic_merge_point_label.parent = self
                    self._children_name_map["generic_merge_point_label"] = "generic-merge-point-label"
                    self._children_yang_names.add("generic-merge-point-label")

                    self.generic_outgoing_downstream_label = Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericOutgoingDownstreamLabel()
                    self.generic_outgoing_downstream_label.parent = self
                    self._children_name_map["generic_outgoing_downstream_label"] = "generic-outgoing-downstream-label"
                    self._children_yang_names.add("generic-outgoing-downstream-label")

                    self.generic_outgoing_upstream_label = Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericOutgoingUpstreamLabel()
                    self.generic_outgoing_upstream_label.parent = self
                    self._children_name_map["generic_outgoing_upstream_label"] = "generic-outgoing-upstream-label"
                    self._children_yang_names.add("generic-outgoing-upstream-label")

                    self.generic_recovery_label = Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericRecoveryLabel()
                    self.generic_recovery_label.parent = self
                    self._children_name_map["generic_recovery_label"] = "generic-recovery-label"
                    self._children_yang_names.add("generic-recovery-label")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("is_valid",
                                    "local_downstream_label",
                                    "local_upstream_label",
                                    "lsp_wrap_label",
                                    "merge_point_label",
                                    "outgoing_downstream_label",
                                    "outgoing_upstream_label",
                                    "recovery_label") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.PsbDetaileds.PsbDetailed.LabelInfo, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.PsbDetaileds.PsbDetailed.LabelInfo, self).__setattr__(name, value)


                class GenericLocalDownstreamLabel(Entity):
                    """
                    Generic Local Downstream Label
                    
                    .. attribute:: generalized_label
                    
                    	Generalized Label
                    	**type**\:   :py:class:`GeneralizedLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericLocalDownstreamLabel.GeneralizedLabel>`
                    
                    .. attribute:: generic_label_type
                    
                    	GenericLabelType
                    	**type**\:   :py:class:`RsvpMgmtGenericLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtGenericLabel>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericLocalDownstreamLabel, self).__init__()

                        self.yang_name = "generic-local-downstream-label"
                        self.yang_parent_name = "label-info"

                        self.generic_label_type = YLeaf(YType.enumeration, "generic-label-type")

                        self.generalized_label = Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericLocalDownstreamLabel.GeneralizedLabel()
                        self.generalized_label.parent = self
                        self._children_name_map["generalized_label"] = "generalized-label"
                        self._children_yang_names.add("generalized-label")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("generic_label_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericLocalDownstreamLabel, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericLocalDownstreamLabel, self).__setattr__(name, value)


                    class GeneralizedLabel(Entity):
                        """
                        Generalized Label
                        
                        .. attribute:: value
                        
                        	Generalized Label Value
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericLocalDownstreamLabel.GeneralizedLabel, self).__init__()

                            self.yang_name = "generalized-label"
                            self.yang_parent_name = "generic-local-downstream-label"

                            self.value = YLeafList(YType.uint32, "value")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("value") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericLocalDownstreamLabel.GeneralizedLabel, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericLocalDownstreamLabel.GeneralizedLabel, self).__setattr__(name, value)

                        def has_data(self):
                            for leaf in self.value.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            return False

                        def has_operation(self):
                            for leaf in self.value.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.value.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "generalized-label" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-detaileds/psb-detailed/label-info/generic-local-downstream-label/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            leaf_name_data.extend(self.value.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "value"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "value"):
                                self.value.append(value)

                    def has_data(self):
                        return (
                            self.generic_label_type.is_set or
                            (self.generalized_label is not None and self.generalized_label.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.generic_label_type.yfilter != YFilter.not_set or
                            (self.generalized_label is not None and self.generalized_label.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "generic-local-downstream-label" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-detaileds/psb-detailed/label-info/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.generic_label_type.is_set or self.generic_label_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.generic_label_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "generalized-label"):
                            if (self.generalized_label is None):
                                self.generalized_label = Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericLocalDownstreamLabel.GeneralizedLabel()
                                self.generalized_label.parent = self
                                self._children_name_map["generalized_label"] = "generalized-label"
                            return self.generalized_label

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "generalized-label" or name == "generic-label-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "generic-label-type"):
                            self.generic_label_type = value
                            self.generic_label_type.value_namespace = name_space
                            self.generic_label_type.value_namespace_prefix = name_space_prefix


                class GenericOutgoingDownstreamLabel(Entity):
                    """
                    Generic Outgoing Downstream Label
                    
                    .. attribute:: generalized_label
                    
                    	Generalized Label
                    	**type**\:   :py:class:`GeneralizedLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericOutgoingDownstreamLabel.GeneralizedLabel>`
                    
                    .. attribute:: generic_label_type
                    
                    	GenericLabelType
                    	**type**\:   :py:class:`RsvpMgmtGenericLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtGenericLabel>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericOutgoingDownstreamLabel, self).__init__()

                        self.yang_name = "generic-outgoing-downstream-label"
                        self.yang_parent_name = "label-info"

                        self.generic_label_type = YLeaf(YType.enumeration, "generic-label-type")

                        self.generalized_label = Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericOutgoingDownstreamLabel.GeneralizedLabel()
                        self.generalized_label.parent = self
                        self._children_name_map["generalized_label"] = "generalized-label"
                        self._children_yang_names.add("generalized-label")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("generic_label_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericOutgoingDownstreamLabel, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericOutgoingDownstreamLabel, self).__setattr__(name, value)


                    class GeneralizedLabel(Entity):
                        """
                        Generalized Label
                        
                        .. attribute:: value
                        
                        	Generalized Label Value
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericOutgoingDownstreamLabel.GeneralizedLabel, self).__init__()

                            self.yang_name = "generalized-label"
                            self.yang_parent_name = "generic-outgoing-downstream-label"

                            self.value = YLeafList(YType.uint32, "value")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("value") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericOutgoingDownstreamLabel.GeneralizedLabel, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericOutgoingDownstreamLabel.GeneralizedLabel, self).__setattr__(name, value)

                        def has_data(self):
                            for leaf in self.value.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            return False

                        def has_operation(self):
                            for leaf in self.value.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.value.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "generalized-label" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-detaileds/psb-detailed/label-info/generic-outgoing-downstream-label/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            leaf_name_data.extend(self.value.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "value"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "value"):
                                self.value.append(value)

                    def has_data(self):
                        return (
                            self.generic_label_type.is_set or
                            (self.generalized_label is not None and self.generalized_label.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.generic_label_type.yfilter != YFilter.not_set or
                            (self.generalized_label is not None and self.generalized_label.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "generic-outgoing-downstream-label" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-detaileds/psb-detailed/label-info/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.generic_label_type.is_set or self.generic_label_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.generic_label_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "generalized-label"):
                            if (self.generalized_label is None):
                                self.generalized_label = Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericOutgoingDownstreamLabel.GeneralizedLabel()
                                self.generalized_label.parent = self
                                self._children_name_map["generalized_label"] = "generalized-label"
                            return self.generalized_label

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "generalized-label" or name == "generic-label-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "generic-label-type"):
                            self.generic_label_type = value
                            self.generic_label_type.value_namespace = name_space
                            self.generic_label_type.value_namespace_prefix = name_space_prefix


                class GenericMergePointLabel(Entity):
                    """
                    Generic MergePoint Label
                    
                    .. attribute:: generalized_label
                    
                    	Generalized Label
                    	**type**\:   :py:class:`GeneralizedLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericMergePointLabel.GeneralizedLabel>`
                    
                    .. attribute:: generic_label_type
                    
                    	GenericLabelType
                    	**type**\:   :py:class:`RsvpMgmtGenericLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtGenericLabel>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericMergePointLabel, self).__init__()

                        self.yang_name = "generic-merge-point-label"
                        self.yang_parent_name = "label-info"

                        self.generic_label_type = YLeaf(YType.enumeration, "generic-label-type")

                        self.generalized_label = Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericMergePointLabel.GeneralizedLabel()
                        self.generalized_label.parent = self
                        self._children_name_map["generalized_label"] = "generalized-label"
                        self._children_yang_names.add("generalized-label")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("generic_label_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericMergePointLabel, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericMergePointLabel, self).__setattr__(name, value)


                    class GeneralizedLabel(Entity):
                        """
                        Generalized Label
                        
                        .. attribute:: value
                        
                        	Generalized Label Value
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericMergePointLabel.GeneralizedLabel, self).__init__()

                            self.yang_name = "generalized-label"
                            self.yang_parent_name = "generic-merge-point-label"

                            self.value = YLeafList(YType.uint32, "value")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("value") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericMergePointLabel.GeneralizedLabel, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericMergePointLabel.GeneralizedLabel, self).__setattr__(name, value)

                        def has_data(self):
                            for leaf in self.value.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            return False

                        def has_operation(self):
                            for leaf in self.value.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.value.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "generalized-label" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-detaileds/psb-detailed/label-info/generic-merge-point-label/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            leaf_name_data.extend(self.value.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "value"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "value"):
                                self.value.append(value)

                    def has_data(self):
                        return (
                            self.generic_label_type.is_set or
                            (self.generalized_label is not None and self.generalized_label.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.generic_label_type.yfilter != YFilter.not_set or
                            (self.generalized_label is not None and self.generalized_label.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "generic-merge-point-label" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-detaileds/psb-detailed/label-info/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.generic_label_type.is_set or self.generic_label_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.generic_label_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "generalized-label"):
                            if (self.generalized_label is None):
                                self.generalized_label = Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericMergePointLabel.GeneralizedLabel()
                                self.generalized_label.parent = self
                                self._children_name_map["generalized_label"] = "generalized-label"
                            return self.generalized_label

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "generalized-label" or name == "generic-label-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "generic-label-type"):
                            self.generic_label_type = value
                            self.generic_label_type.value_namespace = name_space
                            self.generic_label_type.value_namespace_prefix = name_space_prefix


                class GenericOutgoingUpstreamLabel(Entity):
                    """
                    Generic Outgoing Upstream Label
                    
                    .. attribute:: generalized_label
                    
                    	Generalized Label
                    	**type**\:   :py:class:`GeneralizedLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericOutgoingUpstreamLabel.GeneralizedLabel>`
                    
                    .. attribute:: generic_label_type
                    
                    	GenericLabelType
                    	**type**\:   :py:class:`RsvpMgmtGenericLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtGenericLabel>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericOutgoingUpstreamLabel, self).__init__()

                        self.yang_name = "generic-outgoing-upstream-label"
                        self.yang_parent_name = "label-info"

                        self.generic_label_type = YLeaf(YType.enumeration, "generic-label-type")

                        self.generalized_label = Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericOutgoingUpstreamLabel.GeneralizedLabel()
                        self.generalized_label.parent = self
                        self._children_name_map["generalized_label"] = "generalized-label"
                        self._children_yang_names.add("generalized-label")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("generic_label_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericOutgoingUpstreamLabel, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericOutgoingUpstreamLabel, self).__setattr__(name, value)


                    class GeneralizedLabel(Entity):
                        """
                        Generalized Label
                        
                        .. attribute:: value
                        
                        	Generalized Label Value
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericOutgoingUpstreamLabel.GeneralizedLabel, self).__init__()

                            self.yang_name = "generalized-label"
                            self.yang_parent_name = "generic-outgoing-upstream-label"

                            self.value = YLeafList(YType.uint32, "value")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("value") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericOutgoingUpstreamLabel.GeneralizedLabel, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericOutgoingUpstreamLabel.GeneralizedLabel, self).__setattr__(name, value)

                        def has_data(self):
                            for leaf in self.value.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            return False

                        def has_operation(self):
                            for leaf in self.value.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.value.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "generalized-label" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-detaileds/psb-detailed/label-info/generic-outgoing-upstream-label/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            leaf_name_data.extend(self.value.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "value"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "value"):
                                self.value.append(value)

                    def has_data(self):
                        return (
                            self.generic_label_type.is_set or
                            (self.generalized_label is not None and self.generalized_label.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.generic_label_type.yfilter != YFilter.not_set or
                            (self.generalized_label is not None and self.generalized_label.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "generic-outgoing-upstream-label" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-detaileds/psb-detailed/label-info/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.generic_label_type.is_set or self.generic_label_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.generic_label_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "generalized-label"):
                            if (self.generalized_label is None):
                                self.generalized_label = Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericOutgoingUpstreamLabel.GeneralizedLabel()
                                self.generalized_label.parent = self
                                self._children_name_map["generalized_label"] = "generalized-label"
                            return self.generalized_label

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "generalized-label" or name == "generic-label-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "generic-label-type"):
                            self.generic_label_type = value
                            self.generic_label_type.value_namespace = name_space
                            self.generic_label_type.value_namespace_prefix = name_space_prefix


                class GenericLocalUpstreamLabel(Entity):
                    """
                    Generic Local Upstream Label
                    
                    .. attribute:: generalized_label
                    
                    	Generalized Label
                    	**type**\:   :py:class:`GeneralizedLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericLocalUpstreamLabel.GeneralizedLabel>`
                    
                    .. attribute:: generic_label_type
                    
                    	GenericLabelType
                    	**type**\:   :py:class:`RsvpMgmtGenericLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtGenericLabel>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericLocalUpstreamLabel, self).__init__()

                        self.yang_name = "generic-local-upstream-label"
                        self.yang_parent_name = "label-info"

                        self.generic_label_type = YLeaf(YType.enumeration, "generic-label-type")

                        self.generalized_label = Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericLocalUpstreamLabel.GeneralizedLabel()
                        self.generalized_label.parent = self
                        self._children_name_map["generalized_label"] = "generalized-label"
                        self._children_yang_names.add("generalized-label")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("generic_label_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericLocalUpstreamLabel, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericLocalUpstreamLabel, self).__setattr__(name, value)


                    class GeneralizedLabel(Entity):
                        """
                        Generalized Label
                        
                        .. attribute:: value
                        
                        	Generalized Label Value
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericLocalUpstreamLabel.GeneralizedLabel, self).__init__()

                            self.yang_name = "generalized-label"
                            self.yang_parent_name = "generic-local-upstream-label"

                            self.value = YLeafList(YType.uint32, "value")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("value") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericLocalUpstreamLabel.GeneralizedLabel, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericLocalUpstreamLabel.GeneralizedLabel, self).__setattr__(name, value)

                        def has_data(self):
                            for leaf in self.value.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            return False

                        def has_operation(self):
                            for leaf in self.value.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.value.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "generalized-label" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-detaileds/psb-detailed/label-info/generic-local-upstream-label/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            leaf_name_data.extend(self.value.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "value"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "value"):
                                self.value.append(value)

                    def has_data(self):
                        return (
                            self.generic_label_type.is_set or
                            (self.generalized_label is not None and self.generalized_label.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.generic_label_type.yfilter != YFilter.not_set or
                            (self.generalized_label is not None and self.generalized_label.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "generic-local-upstream-label" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-detaileds/psb-detailed/label-info/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.generic_label_type.is_set or self.generic_label_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.generic_label_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "generalized-label"):
                            if (self.generalized_label is None):
                                self.generalized_label = Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericLocalUpstreamLabel.GeneralizedLabel()
                                self.generalized_label.parent = self
                                self._children_name_map["generalized_label"] = "generalized-label"
                            return self.generalized_label

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "generalized-label" or name == "generic-label-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "generic-label-type"):
                            self.generic_label_type = value
                            self.generic_label_type.value_namespace = name_space
                            self.generic_label_type.value_namespace_prefix = name_space_prefix


                class GenericRecoveryLabel(Entity):
                    """
                    Generic Recovery Label
                    
                    .. attribute:: generalized_label
                    
                    	Generalized Label
                    	**type**\:   :py:class:`GeneralizedLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericRecoveryLabel.GeneralizedLabel>`
                    
                    .. attribute:: generic_label_type
                    
                    	GenericLabelType
                    	**type**\:   :py:class:`RsvpMgmtGenericLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtGenericLabel>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericRecoveryLabel, self).__init__()

                        self.yang_name = "generic-recovery-label"
                        self.yang_parent_name = "label-info"

                        self.generic_label_type = YLeaf(YType.enumeration, "generic-label-type")

                        self.generalized_label = Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericRecoveryLabel.GeneralizedLabel()
                        self.generalized_label.parent = self
                        self._children_name_map["generalized_label"] = "generalized-label"
                        self._children_yang_names.add("generalized-label")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("generic_label_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericRecoveryLabel, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericRecoveryLabel, self).__setattr__(name, value)


                    class GeneralizedLabel(Entity):
                        """
                        Generalized Label
                        
                        .. attribute:: value
                        
                        	Generalized Label Value
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericRecoveryLabel.GeneralizedLabel, self).__init__()

                            self.yang_name = "generalized-label"
                            self.yang_parent_name = "generic-recovery-label"

                            self.value = YLeafList(YType.uint32, "value")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("value") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericRecoveryLabel.GeneralizedLabel, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericRecoveryLabel.GeneralizedLabel, self).__setattr__(name, value)

                        def has_data(self):
                            for leaf in self.value.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            return False

                        def has_operation(self):
                            for leaf in self.value.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.value.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "generalized-label" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-detaileds/psb-detailed/label-info/generic-recovery-label/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            leaf_name_data.extend(self.value.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "value"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "value"):
                                self.value.append(value)

                    def has_data(self):
                        return (
                            self.generic_label_type.is_set or
                            (self.generalized_label is not None and self.generalized_label.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.generic_label_type.yfilter != YFilter.not_set or
                            (self.generalized_label is not None and self.generalized_label.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "generic-recovery-label" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-detaileds/psb-detailed/label-info/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.generic_label_type.is_set or self.generic_label_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.generic_label_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "generalized-label"):
                            if (self.generalized_label is None):
                                self.generalized_label = Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericRecoveryLabel.GeneralizedLabel()
                                self.generalized_label.parent = self
                                self._children_name_map["generalized_label"] = "generalized-label"
                            return self.generalized_label

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "generalized-label" or name == "generic-label-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "generic-label-type"):
                            self.generic_label_type = value
                            self.generic_label_type.value_namespace = name_space
                            self.generic_label_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.is_valid.is_set or
                        self.local_downstream_label.is_set or
                        self.local_upstream_label.is_set or
                        self.lsp_wrap_label.is_set or
                        self.merge_point_label.is_set or
                        self.outgoing_downstream_label.is_set or
                        self.outgoing_upstream_label.is_set or
                        self.recovery_label.is_set or
                        (self.generic_local_downstream_label is not None and self.generic_local_downstream_label.has_data()) or
                        (self.generic_local_upstream_label is not None and self.generic_local_upstream_label.has_data()) or
                        (self.generic_merge_point_label is not None and self.generic_merge_point_label.has_data()) or
                        (self.generic_outgoing_downstream_label is not None and self.generic_outgoing_downstream_label.has_data()) or
                        (self.generic_outgoing_upstream_label is not None and self.generic_outgoing_upstream_label.has_data()) or
                        (self.generic_recovery_label is not None and self.generic_recovery_label.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.is_valid.yfilter != YFilter.not_set or
                        self.local_downstream_label.yfilter != YFilter.not_set or
                        self.local_upstream_label.yfilter != YFilter.not_set or
                        self.lsp_wrap_label.yfilter != YFilter.not_set or
                        self.merge_point_label.yfilter != YFilter.not_set or
                        self.outgoing_downstream_label.yfilter != YFilter.not_set or
                        self.outgoing_upstream_label.yfilter != YFilter.not_set or
                        self.recovery_label.yfilter != YFilter.not_set or
                        (self.generic_local_downstream_label is not None and self.generic_local_downstream_label.has_operation()) or
                        (self.generic_local_upstream_label is not None and self.generic_local_upstream_label.has_operation()) or
                        (self.generic_merge_point_label is not None and self.generic_merge_point_label.has_operation()) or
                        (self.generic_outgoing_downstream_label is not None and self.generic_outgoing_downstream_label.has_operation()) or
                        (self.generic_outgoing_upstream_label is not None and self.generic_outgoing_upstream_label.has_operation()) or
                        (self.generic_recovery_label is not None and self.generic_recovery_label.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "label-info" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-detaileds/psb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_valid.get_name_leafdata())
                    if (self.local_downstream_label.is_set or self.local_downstream_label.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.local_downstream_label.get_name_leafdata())
                    if (self.local_upstream_label.is_set or self.local_upstream_label.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.local_upstream_label.get_name_leafdata())
                    if (self.lsp_wrap_label.is_set or self.lsp_wrap_label.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.lsp_wrap_label.get_name_leafdata())
                    if (self.merge_point_label.is_set or self.merge_point_label.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.merge_point_label.get_name_leafdata())
                    if (self.outgoing_downstream_label.is_set or self.outgoing_downstream_label.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.outgoing_downstream_label.get_name_leafdata())
                    if (self.outgoing_upstream_label.is_set or self.outgoing_upstream_label.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.outgoing_upstream_label.get_name_leafdata())
                    if (self.recovery_label.is_set or self.recovery_label.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.recovery_label.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "generic-local-downstream-label"):
                        if (self.generic_local_downstream_label is None):
                            self.generic_local_downstream_label = Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericLocalDownstreamLabel()
                            self.generic_local_downstream_label.parent = self
                            self._children_name_map["generic_local_downstream_label"] = "generic-local-downstream-label"
                        return self.generic_local_downstream_label

                    if (child_yang_name == "generic-local-upstream-label"):
                        if (self.generic_local_upstream_label is None):
                            self.generic_local_upstream_label = Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericLocalUpstreamLabel()
                            self.generic_local_upstream_label.parent = self
                            self._children_name_map["generic_local_upstream_label"] = "generic-local-upstream-label"
                        return self.generic_local_upstream_label

                    if (child_yang_name == "generic-merge-point-label"):
                        if (self.generic_merge_point_label is None):
                            self.generic_merge_point_label = Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericMergePointLabel()
                            self.generic_merge_point_label.parent = self
                            self._children_name_map["generic_merge_point_label"] = "generic-merge-point-label"
                        return self.generic_merge_point_label

                    if (child_yang_name == "generic-outgoing-downstream-label"):
                        if (self.generic_outgoing_downstream_label is None):
                            self.generic_outgoing_downstream_label = Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericOutgoingDownstreamLabel()
                            self.generic_outgoing_downstream_label.parent = self
                            self._children_name_map["generic_outgoing_downstream_label"] = "generic-outgoing-downstream-label"
                        return self.generic_outgoing_downstream_label

                    if (child_yang_name == "generic-outgoing-upstream-label"):
                        if (self.generic_outgoing_upstream_label is None):
                            self.generic_outgoing_upstream_label = Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericOutgoingUpstreamLabel()
                            self.generic_outgoing_upstream_label.parent = self
                            self._children_name_map["generic_outgoing_upstream_label"] = "generic-outgoing-upstream-label"
                        return self.generic_outgoing_upstream_label

                    if (child_yang_name == "generic-recovery-label"):
                        if (self.generic_recovery_label is None):
                            self.generic_recovery_label = Rsvp.PsbDetaileds.PsbDetailed.LabelInfo.GenericRecoveryLabel()
                            self.generic_recovery_label.parent = self
                            self._children_name_map["generic_recovery_label"] = "generic-recovery-label"
                        return self.generic_recovery_label

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "generic-local-downstream-label" or name == "generic-local-upstream-label" or name == "generic-merge-point-label" or name == "generic-outgoing-downstream-label" or name == "generic-outgoing-upstream-label" or name == "generic-recovery-label" or name == "is-valid" or name == "local-downstream-label" or name == "local-upstream-label" or name == "lsp-wrap-label" or name == "merge-point-label" or name == "outgoing-downstream-label" or name == "outgoing-upstream-label" or name == "recovery-label"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "is-valid"):
                        self.is_valid = value
                        self.is_valid.value_namespace = name_space
                        self.is_valid.value_namespace_prefix = name_space_prefix
                    if(value_path == "local-downstream-label"):
                        self.local_downstream_label = value
                        self.local_downstream_label.value_namespace = name_space
                        self.local_downstream_label.value_namespace_prefix = name_space_prefix
                    if(value_path == "local-upstream-label"):
                        self.local_upstream_label = value
                        self.local_upstream_label.value_namespace = name_space
                        self.local_upstream_label.value_namespace_prefix = name_space_prefix
                    if(value_path == "lsp-wrap-label"):
                        self.lsp_wrap_label = value
                        self.lsp_wrap_label.value_namespace = name_space
                        self.lsp_wrap_label.value_namespace_prefix = name_space_prefix
                    if(value_path == "merge-point-label"):
                        self.merge_point_label = value
                        self.merge_point_label.value_namespace = name_space
                        self.merge_point_label.value_namespace_prefix = name_space_prefix
                    if(value_path == "outgoing-downstream-label"):
                        self.outgoing_downstream_label = value
                        self.outgoing_downstream_label.value_namespace = name_space
                        self.outgoing_downstream_label.value_namespace_prefix = name_space_prefix
                    if(value_path == "outgoing-upstream-label"):
                        self.outgoing_upstream_label = value
                        self.outgoing_upstream_label.value_namespace = name_space
                        self.outgoing_upstream_label.value_namespace_prefix = name_space_prefix
                    if(value_path == "recovery-label"):
                        self.recovery_label = value
                        self.recovery_label.value_namespace = name_space
                        self.recovery_label.value_namespace_prefix = name_space_prefix


            class ClassType(Entity):
                """
                DS\-TE Class\-Type
                
                .. attribute:: class_type
                
                	DS\-TE Class\-Type
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: is_class_type_info_valid
                
                	Is the Class\-Type information valid
                	**type**\:  bool
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.PsbDetaileds.PsbDetailed.ClassType, self).__init__()

                    self.yang_name = "class-type"
                    self.yang_parent_name = "psb-detailed"

                    self.class_type = YLeaf(YType.uint8, "class-type")

                    self.is_class_type_info_valid = YLeaf(YType.boolean, "is-class-type-info-valid")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("class_type",
                                    "is_class_type_info_valid") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.PsbDetaileds.PsbDetailed.ClassType, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.PsbDetaileds.PsbDetailed.ClassType, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.class_type.is_set or
                        self.is_class_type_info_valid.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.class_type.yfilter != YFilter.not_set or
                        self.is_class_type_info_valid.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "class-type" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-detaileds/psb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.class_type.is_set or self.class_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.class_type.get_name_leafdata())
                    if (self.is_class_type_info_valid.is_set or self.is_class_type_info_valid.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_class_type_info_valid.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "class-type" or name == "is-class-type-info-valid"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "class-type"):
                        self.class_type = value
                        self.class_type.value_namespace = name_space
                        self.class_type.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-class-type-info-valid"):
                        self.is_class_type_info_valid = value
                        self.is_class_type_info_valid.value_namespace = name_space
                        self.is_class_type_info_valid.value_namespace_prefix = name_space_prefix


            class Pfc(Entity):
                """
                Path Forwarding Contexts
                
                .. attribute:: output_interface
                
                	Output interface
                	**type**\:  str
                
                .. attribute:: policy_flags
                
                	Policy Flags
                	**type**\:   :py:class:`PolicyFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbDetaileds.PsbDetailed.Pfc.PolicyFlags>`
                
                .. attribute:: policy_query_flags
                
                	Policy Query Flags
                	**type**\:   :py:class:`PolicyQueryFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbDetaileds.PsbDetailed.Pfc.PolicyQueryFlags>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.PsbDetaileds.PsbDetailed.Pfc, self).__init__()

                    self.yang_name = "pfc"
                    self.yang_parent_name = "psb-detailed"

                    self.output_interface = YLeaf(YType.str, "output-interface")

                    self.policy_flags = Rsvp.PsbDetaileds.PsbDetailed.Pfc.PolicyFlags()
                    self.policy_flags.parent = self
                    self._children_name_map["policy_flags"] = "policy-flags"
                    self._children_yang_names.add("policy-flags")

                    self.policy_query_flags = Rsvp.PsbDetaileds.PsbDetailed.Pfc.PolicyQueryFlags()
                    self.policy_query_flags.parent = self
                    self._children_name_map["policy_query_flags"] = "policy-query-flags"
                    self._children_yang_names.add("policy-query-flags")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("output_interface") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.PsbDetaileds.PsbDetailed.Pfc, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.PsbDetaileds.PsbDetailed.Pfc, self).__setattr__(name, value)


                class PolicyFlags(Entity):
                    """
                    Policy Flags
                    
                    .. attribute:: is_accepted
                    
                    	Accepted
                    	**type**\:  bool
                    
                    .. attribute:: is_forwarding
                    
                    	Forwarding
                    	**type**\:  bool
                    
                    .. attribute:: is_installed
                    
                    	Installed
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.PsbDetaileds.PsbDetailed.Pfc.PolicyFlags, self).__init__()

                        self.yang_name = "policy-flags"
                        self.yang_parent_name = "pfc"

                        self.is_accepted = YLeaf(YType.boolean, "is-accepted")

                        self.is_forwarding = YLeaf(YType.boolean, "is-forwarding")

                        self.is_installed = YLeaf(YType.boolean, "is-installed")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("is_accepted",
                                        "is_forwarding",
                                        "is_installed") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.PsbDetaileds.PsbDetailed.Pfc.PolicyFlags, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.PsbDetaileds.PsbDetailed.Pfc.PolicyFlags, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.is_accepted.is_set or
                            self.is_forwarding.is_set or
                            self.is_installed.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.is_accepted.yfilter != YFilter.not_set or
                            self.is_forwarding.yfilter != YFilter.not_set or
                            self.is_installed.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "policy-flags" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-detaileds/psb-detailed/pfc/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.is_accepted.is_set or self.is_accepted.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_accepted.get_name_leafdata())
                        if (self.is_forwarding.is_set or self.is_forwarding.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_forwarding.get_name_leafdata())
                        if (self.is_installed.is_set or self.is_installed.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_installed.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "is-accepted" or name == "is-forwarding" or name == "is-installed"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "is-accepted"):
                            self.is_accepted = value
                            self.is_accepted.value_namespace = name_space
                            self.is_accepted.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-forwarding"):
                            self.is_forwarding = value
                            self.is_forwarding.value_namespace = name_space
                            self.is_forwarding.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-installed"):
                            self.is_installed = value
                            self.is_installed.value_namespace = name_space
                            self.is_installed.value_namespace_prefix = name_space_prefix


                class PolicyQueryFlags(Entity):
                    """
                    Policy Query Flags
                    
                    .. attribute:: is_bypass
                    
                    	Bypass
                    	**type**\:  bool
                    
                    .. attribute:: is_needed
                    
                    	Needed
                    	**type**\:  bool
                    
                    .. attribute:: is_report_required
                    
                    	Report Required
                    	**type**\:  bool
                    
                    .. attribute:: is_resync
                    
                    	Resynchronization
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.PsbDetaileds.PsbDetailed.Pfc.PolicyQueryFlags, self).__init__()

                        self.yang_name = "policy-query-flags"
                        self.yang_parent_name = "pfc"

                        self.is_bypass = YLeaf(YType.boolean, "is-bypass")

                        self.is_needed = YLeaf(YType.boolean, "is-needed")

                        self.is_report_required = YLeaf(YType.boolean, "is-report-required")

                        self.is_resync = YLeaf(YType.boolean, "is-resync")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("is_bypass",
                                        "is_needed",
                                        "is_report_required",
                                        "is_resync") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.PsbDetaileds.PsbDetailed.Pfc.PolicyQueryFlags, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.PsbDetaileds.PsbDetailed.Pfc.PolicyQueryFlags, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.is_bypass.is_set or
                            self.is_needed.is_set or
                            self.is_report_required.is_set or
                            self.is_resync.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.is_bypass.yfilter != YFilter.not_set or
                            self.is_needed.yfilter != YFilter.not_set or
                            self.is_report_required.yfilter != YFilter.not_set or
                            self.is_resync.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "policy-query-flags" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-detaileds/psb-detailed/pfc/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.is_bypass.is_set or self.is_bypass.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_bypass.get_name_leafdata())
                        if (self.is_needed.is_set or self.is_needed.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_needed.get_name_leafdata())
                        if (self.is_report_required.is_set or self.is_report_required.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_report_required.get_name_leafdata())
                        if (self.is_resync.is_set or self.is_resync.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_resync.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "is-bypass" or name == "is-needed" or name == "is-report-required" or name == "is-resync"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "is-bypass"):
                            self.is_bypass = value
                            self.is_bypass.value_namespace = name_space
                            self.is_bypass.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-needed"):
                            self.is_needed = value
                            self.is_needed.value_namespace = name_space
                            self.is_needed.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-report-required"):
                            self.is_report_required = value
                            self.is_report_required.value_namespace = name_space
                            self.is_report_required.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-resync"):
                            self.is_resync = value
                            self.is_resync.value_namespace = name_space
                            self.is_resync.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.output_interface.is_set or
                        (self.policy_flags is not None and self.policy_flags.has_data()) or
                        (self.policy_query_flags is not None and self.policy_query_flags.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.output_interface.yfilter != YFilter.not_set or
                        (self.policy_flags is not None and self.policy_flags.has_operation()) or
                        (self.policy_query_flags is not None and self.policy_query_flags.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "pfc" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-detaileds/psb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.output_interface.is_set or self.output_interface.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.output_interface.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "policy-flags"):
                        if (self.policy_flags is None):
                            self.policy_flags = Rsvp.PsbDetaileds.PsbDetailed.Pfc.PolicyFlags()
                            self.policy_flags.parent = self
                            self._children_name_map["policy_flags"] = "policy-flags"
                        return self.policy_flags

                    if (child_yang_name == "policy-query-flags"):
                        if (self.policy_query_flags is None):
                            self.policy_query_flags = Rsvp.PsbDetaileds.PsbDetailed.Pfc.PolicyQueryFlags()
                            self.policy_query_flags.parent = self
                            self._children_name_map["policy_query_flags"] = "policy-query-flags"
                        return self.policy_query_flags

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "policy-flags" or name == "policy-query-flags" or name == "output-interface"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "output-interface"):
                        self.output_interface = value
                        self.output_interface.value_namespace = name_space
                        self.output_interface.value_namespace_prefix = name_space_prefix


            class InEro(Entity):
                """
                Incoming Explicit Route Sub Objects
                
                .. attribute:: ero_type
                
                	EROType
                	**type**\:   :py:class:`RsvpMgmtEroSubobj <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtEroSubobj>`
                
                .. attribute:: ipv4ero_sub_object
                
                	IPV4 ERO Sub Object
                	**type**\:   :py:class:`Ipv4EroSubObject <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbDetaileds.PsbDetailed.InEro.Ipv4EroSubObject>`
                
                .. attribute:: unnumbered_ero_sub_object
                
                	Unnumbered ERO Sub Object
                	**type**\:   :py:class:`UnnumberedEroSubObject <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbDetaileds.PsbDetailed.InEro.UnnumberedEroSubObject>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.PsbDetaileds.PsbDetailed.InEro, self).__init__()

                    self.yang_name = "in-ero"
                    self.yang_parent_name = "psb-detailed"

                    self.ero_type = YLeaf(YType.enumeration, "ero-type")

                    self.ipv4ero_sub_object = Rsvp.PsbDetaileds.PsbDetailed.InEro.Ipv4EroSubObject()
                    self.ipv4ero_sub_object.parent = self
                    self._children_name_map["ipv4ero_sub_object"] = "ipv4ero-sub-object"
                    self._children_yang_names.add("ipv4ero-sub-object")

                    self.unnumbered_ero_sub_object = Rsvp.PsbDetaileds.PsbDetailed.InEro.UnnumberedEroSubObject()
                    self.unnumbered_ero_sub_object.parent = self
                    self._children_name_map["unnumbered_ero_sub_object"] = "unnumbered-ero-sub-object"
                    self._children_yang_names.add("unnumbered-ero-sub-object")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("ero_type") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.PsbDetaileds.PsbDetailed.InEro, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.PsbDetaileds.PsbDetailed.InEro, self).__setattr__(name, value)


                class Ipv4EroSubObject(Entity):
                    """
                    IPV4 ERO Sub Object
                    
                    .. attribute:: ero_address
                    
                    	The ERO IPV4 Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: is_strict_route
                    
                    	ERO Entry Is Strict
                    	**type**\:  bool
                    
                    .. attribute:: prefix_length
                    
                    	ERO Prefix Length
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.PsbDetaileds.PsbDetailed.InEro.Ipv4EroSubObject, self).__init__()

                        self.yang_name = "ipv4ero-sub-object"
                        self.yang_parent_name = "in-ero"

                        self.ero_address = YLeaf(YType.str, "ero-address")

                        self.is_strict_route = YLeaf(YType.boolean, "is-strict-route")

                        self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("ero_address",
                                        "is_strict_route",
                                        "prefix_length") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.PsbDetaileds.PsbDetailed.InEro.Ipv4EroSubObject, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.PsbDetaileds.PsbDetailed.InEro.Ipv4EroSubObject, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.ero_address.is_set or
                            self.is_strict_route.is_set or
                            self.prefix_length.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.ero_address.yfilter != YFilter.not_set or
                            self.is_strict_route.yfilter != YFilter.not_set or
                            self.prefix_length.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ipv4ero-sub-object" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-detaileds/psb-detailed/in-ero/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.ero_address.is_set or self.ero_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ero_address.get_name_leafdata())
                        if (self.is_strict_route.is_set or self.is_strict_route.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_strict_route.get_name_leafdata())
                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix_length.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ero-address" or name == "is-strict-route" or name == "prefix-length"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "ero-address"):
                            self.ero_address = value
                            self.ero_address.value_namespace = name_space
                            self.ero_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-strict-route"):
                            self.is_strict_route = value
                            self.is_strict_route.value_namespace = name_space
                            self.is_strict_route.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix-length"):
                            self.prefix_length = value
                            self.prefix_length.value_namespace = name_space
                            self.prefix_length.value_namespace_prefix = name_space_prefix


                class UnnumberedEroSubObject(Entity):
                    """
                    Unnumbered ERO Sub Object
                    
                    .. attribute:: ero_interface_id
                    
                    	The Interface ID in ERO
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ero_router_id
                    
                    	The Router ID in ERO
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: is_strict_route
                    
                    	ERO Entry Is Strict
                    	**type**\:  bool
                    
                    .. attribute:: status
                    
                    	Status of ERO
                    	**type**\:   :py:class:`RsvpMgmtEroSubobjStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtEroSubobjStatus>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.PsbDetaileds.PsbDetailed.InEro.UnnumberedEroSubObject, self).__init__()

                        self.yang_name = "unnumbered-ero-sub-object"
                        self.yang_parent_name = "in-ero"

                        self.ero_interface_id = YLeaf(YType.uint32, "ero-interface-id")

                        self.ero_router_id = YLeaf(YType.str, "ero-router-id")

                        self.is_strict_route = YLeaf(YType.boolean, "is-strict-route")

                        self.status = YLeaf(YType.enumeration, "status")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("ero_interface_id",
                                        "ero_router_id",
                                        "is_strict_route",
                                        "status") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.PsbDetaileds.PsbDetailed.InEro.UnnumberedEroSubObject, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.PsbDetaileds.PsbDetailed.InEro.UnnumberedEroSubObject, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.ero_interface_id.is_set or
                            self.ero_router_id.is_set or
                            self.is_strict_route.is_set or
                            self.status.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.ero_interface_id.yfilter != YFilter.not_set or
                            self.ero_router_id.yfilter != YFilter.not_set or
                            self.is_strict_route.yfilter != YFilter.not_set or
                            self.status.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "unnumbered-ero-sub-object" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-detaileds/psb-detailed/in-ero/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.ero_interface_id.is_set or self.ero_interface_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ero_interface_id.get_name_leafdata())
                        if (self.ero_router_id.is_set or self.ero_router_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ero_router_id.get_name_leafdata())
                        if (self.is_strict_route.is_set or self.is_strict_route.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_strict_route.get_name_leafdata())
                        if (self.status.is_set or self.status.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.status.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ero-interface-id" or name == "ero-router-id" or name == "is-strict-route" or name == "status"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "ero-interface-id"):
                            self.ero_interface_id = value
                            self.ero_interface_id.value_namespace = name_space
                            self.ero_interface_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "ero-router-id"):
                            self.ero_router_id = value
                            self.ero_router_id.value_namespace = name_space
                            self.ero_router_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-strict-route"):
                            self.is_strict_route = value
                            self.is_strict_route.value_namespace = name_space
                            self.is_strict_route.value_namespace_prefix = name_space_prefix
                        if(value_path == "status"):
                            self.status = value
                            self.status.value_namespace = name_space
                            self.status.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.ero_type.is_set or
                        (self.ipv4ero_sub_object is not None and self.ipv4ero_sub_object.has_data()) or
                        (self.unnumbered_ero_sub_object is not None and self.unnumbered_ero_sub_object.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.ero_type.yfilter != YFilter.not_set or
                        (self.ipv4ero_sub_object is not None and self.ipv4ero_sub_object.has_operation()) or
                        (self.unnumbered_ero_sub_object is not None and self.unnumbered_ero_sub_object.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "in-ero" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-detaileds/psb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.ero_type.is_set or self.ero_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ero_type.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "ipv4ero-sub-object"):
                        if (self.ipv4ero_sub_object is None):
                            self.ipv4ero_sub_object = Rsvp.PsbDetaileds.PsbDetailed.InEro.Ipv4EroSubObject()
                            self.ipv4ero_sub_object.parent = self
                            self._children_name_map["ipv4ero_sub_object"] = "ipv4ero-sub-object"
                        return self.ipv4ero_sub_object

                    if (child_yang_name == "unnumbered-ero-sub-object"):
                        if (self.unnumbered_ero_sub_object is None):
                            self.unnumbered_ero_sub_object = Rsvp.PsbDetaileds.PsbDetailed.InEro.UnnumberedEroSubObject()
                            self.unnumbered_ero_sub_object.parent = self
                            self._children_name_map["unnumbered_ero_sub_object"] = "unnumbered-ero-sub-object"
                        return self.unnumbered_ero_sub_object

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ipv4ero-sub-object" or name == "unnumbered-ero-sub-object" or name == "ero-type"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "ero-type"):
                        self.ero_type = value
                        self.ero_type.value_namespace = name_space
                        self.ero_type.value_namespace_prefix = name_space_prefix


            class OutEro(Entity):
                """
                Outgoing Explicit Route Sub Objects
                
                .. attribute:: ero_type
                
                	EROType
                	**type**\:   :py:class:`RsvpMgmtEroSubobj <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtEroSubobj>`
                
                .. attribute:: ipv4ero_sub_object
                
                	IPV4 ERO Sub Object
                	**type**\:   :py:class:`Ipv4EroSubObject <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbDetaileds.PsbDetailed.OutEro.Ipv4EroSubObject>`
                
                .. attribute:: unnumbered_ero_sub_object
                
                	Unnumbered ERO Sub Object
                	**type**\:   :py:class:`UnnumberedEroSubObject <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbDetaileds.PsbDetailed.OutEro.UnnumberedEroSubObject>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.PsbDetaileds.PsbDetailed.OutEro, self).__init__()

                    self.yang_name = "out-ero"
                    self.yang_parent_name = "psb-detailed"

                    self.ero_type = YLeaf(YType.enumeration, "ero-type")

                    self.ipv4ero_sub_object = Rsvp.PsbDetaileds.PsbDetailed.OutEro.Ipv4EroSubObject()
                    self.ipv4ero_sub_object.parent = self
                    self._children_name_map["ipv4ero_sub_object"] = "ipv4ero-sub-object"
                    self._children_yang_names.add("ipv4ero-sub-object")

                    self.unnumbered_ero_sub_object = Rsvp.PsbDetaileds.PsbDetailed.OutEro.UnnumberedEroSubObject()
                    self.unnumbered_ero_sub_object.parent = self
                    self._children_name_map["unnumbered_ero_sub_object"] = "unnumbered-ero-sub-object"
                    self._children_yang_names.add("unnumbered-ero-sub-object")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("ero_type") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.PsbDetaileds.PsbDetailed.OutEro, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.PsbDetaileds.PsbDetailed.OutEro, self).__setattr__(name, value)


                class Ipv4EroSubObject(Entity):
                    """
                    IPV4 ERO Sub Object
                    
                    .. attribute:: ero_address
                    
                    	The ERO IPV4 Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: is_strict_route
                    
                    	ERO Entry Is Strict
                    	**type**\:  bool
                    
                    .. attribute:: prefix_length
                    
                    	ERO Prefix Length
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.PsbDetaileds.PsbDetailed.OutEro.Ipv4EroSubObject, self).__init__()

                        self.yang_name = "ipv4ero-sub-object"
                        self.yang_parent_name = "out-ero"

                        self.ero_address = YLeaf(YType.str, "ero-address")

                        self.is_strict_route = YLeaf(YType.boolean, "is-strict-route")

                        self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("ero_address",
                                        "is_strict_route",
                                        "prefix_length") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.PsbDetaileds.PsbDetailed.OutEro.Ipv4EroSubObject, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.PsbDetaileds.PsbDetailed.OutEro.Ipv4EroSubObject, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.ero_address.is_set or
                            self.is_strict_route.is_set or
                            self.prefix_length.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.ero_address.yfilter != YFilter.not_set or
                            self.is_strict_route.yfilter != YFilter.not_set or
                            self.prefix_length.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "ipv4ero-sub-object" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-detaileds/psb-detailed/out-ero/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.ero_address.is_set or self.ero_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ero_address.get_name_leafdata())
                        if (self.is_strict_route.is_set or self.is_strict_route.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_strict_route.get_name_leafdata())
                        if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.prefix_length.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ero-address" or name == "is-strict-route" or name == "prefix-length"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "ero-address"):
                            self.ero_address = value
                            self.ero_address.value_namespace = name_space
                            self.ero_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-strict-route"):
                            self.is_strict_route = value
                            self.is_strict_route.value_namespace = name_space
                            self.is_strict_route.value_namespace_prefix = name_space_prefix
                        if(value_path == "prefix-length"):
                            self.prefix_length = value
                            self.prefix_length.value_namespace = name_space
                            self.prefix_length.value_namespace_prefix = name_space_prefix


                class UnnumberedEroSubObject(Entity):
                    """
                    Unnumbered ERO Sub Object
                    
                    .. attribute:: ero_interface_id
                    
                    	The Interface ID in ERO
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ero_router_id
                    
                    	The Router ID in ERO
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: is_strict_route
                    
                    	ERO Entry Is Strict
                    	**type**\:  bool
                    
                    .. attribute:: status
                    
                    	Status of ERO
                    	**type**\:   :py:class:`RsvpMgmtEroSubobjStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtEroSubobjStatus>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.PsbDetaileds.PsbDetailed.OutEro.UnnumberedEroSubObject, self).__init__()

                        self.yang_name = "unnumbered-ero-sub-object"
                        self.yang_parent_name = "out-ero"

                        self.ero_interface_id = YLeaf(YType.uint32, "ero-interface-id")

                        self.ero_router_id = YLeaf(YType.str, "ero-router-id")

                        self.is_strict_route = YLeaf(YType.boolean, "is-strict-route")

                        self.status = YLeaf(YType.enumeration, "status")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("ero_interface_id",
                                        "ero_router_id",
                                        "is_strict_route",
                                        "status") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.PsbDetaileds.PsbDetailed.OutEro.UnnumberedEroSubObject, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.PsbDetaileds.PsbDetailed.OutEro.UnnumberedEroSubObject, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.ero_interface_id.is_set or
                            self.ero_router_id.is_set or
                            self.is_strict_route.is_set or
                            self.status.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.ero_interface_id.yfilter != YFilter.not_set or
                            self.ero_router_id.yfilter != YFilter.not_set or
                            self.is_strict_route.yfilter != YFilter.not_set or
                            self.status.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "unnumbered-ero-sub-object" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-detaileds/psb-detailed/out-ero/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.ero_interface_id.is_set or self.ero_interface_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ero_interface_id.get_name_leafdata())
                        if (self.ero_router_id.is_set or self.ero_router_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ero_router_id.get_name_leafdata())
                        if (self.is_strict_route.is_set or self.is_strict_route.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_strict_route.get_name_leafdata())
                        if (self.status.is_set or self.status.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.status.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ero-interface-id" or name == "ero-router-id" or name == "is-strict-route" or name == "status"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "ero-interface-id"):
                            self.ero_interface_id = value
                            self.ero_interface_id.value_namespace = name_space
                            self.ero_interface_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "ero-router-id"):
                            self.ero_router_id = value
                            self.ero_router_id.value_namespace = name_space
                            self.ero_router_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-strict-route"):
                            self.is_strict_route = value
                            self.is_strict_route.value_namespace = name_space
                            self.is_strict_route.value_namespace_prefix = name_space_prefix
                        if(value_path == "status"):
                            self.status = value
                            self.status.value_namespace = name_space
                            self.status.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.ero_type.is_set or
                        (self.ipv4ero_sub_object is not None and self.ipv4ero_sub_object.has_data()) or
                        (self.unnumbered_ero_sub_object is not None and self.unnumbered_ero_sub_object.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.ero_type.yfilter != YFilter.not_set or
                        (self.ipv4ero_sub_object is not None and self.ipv4ero_sub_object.has_operation()) or
                        (self.unnumbered_ero_sub_object is not None and self.unnumbered_ero_sub_object.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "out-ero" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-detaileds/psb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.ero_type.is_set or self.ero_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ero_type.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "ipv4ero-sub-object"):
                        if (self.ipv4ero_sub_object is None):
                            self.ipv4ero_sub_object = Rsvp.PsbDetaileds.PsbDetailed.OutEro.Ipv4EroSubObject()
                            self.ipv4ero_sub_object.parent = self
                            self._children_name_map["ipv4ero_sub_object"] = "ipv4ero-sub-object"
                        return self.ipv4ero_sub_object

                    if (child_yang_name == "unnumbered-ero-sub-object"):
                        if (self.unnumbered_ero_sub_object is None):
                            self.unnumbered_ero_sub_object = Rsvp.PsbDetaileds.PsbDetailed.OutEro.UnnumberedEroSubObject()
                            self.unnumbered_ero_sub_object.parent = self
                            self._children_name_map["unnumbered_ero_sub_object"] = "unnumbered-ero-sub-object"
                        return self.unnumbered_ero_sub_object

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ipv4ero-sub-object" or name == "unnumbered-ero-sub-object" or name == "ero-type"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "ero-type"):
                        self.ero_type = value
                        self.ero_type.value_namespace = name_space
                        self.ero_type.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.in_ero:
                    if (c.has_data()):
                        return True
                for c in self.out_ero:
                    if (c.has_data()):
                        return True
                for c in self.pfc:
                    if (c.has_data()):
                        return True
                return (
                    self.backup_tunnel_name.is_set or
                    self.destination_address.is_set or
                    self.destination_port.is_set or
                    self.extended_tunnel_id.is_set or
                    self.input_interface.is_set or
                    self.is_in_ero_valid.is_set or
                    self.is_out_ero_valid.is_set or
                    self.p2mp_id.is_set or
                    self.protocol.is_set or
                    self.session_type.is_set or
                    self.source_address.is_set or
                    self.source_port.is_set or
                    self.sub_group_id.is_set or
                    self.sub_group_origin.is_set or
                    self.vrf_name.is_set or
                    (self.class_type is not None and self.class_type.has_data()) or
                    (self.expiry_time is not None and self.expiry_time.has_data()) or
                    (self.generic_traffic_spec is not None and self.generic_traffic_spec.has_data()) or
                    (self.header is not None and self.header.has_data()) or
                    (self.hop is not None and self.hop.has_data()) or
                    (self.label_info is not None and self.label_info.has_data()) or
                    (self.path_flags is not None and self.path_flags.has_data()) or
                    (self.policy_flags is not None and self.policy_flags.has_data()) or
                    (self.policy_query_flags is not None and self.policy_query_flags.has_data()) or
                    (self.policy_source_info is not None and self.policy_source_info.has_data()) or
                    (self.s2l_sub_lsp is not None and self.s2l_sub_lsp.has_data()) or
                    (self.session is not None and self.session.has_data()) or
                    (self.session_attribute is not None and self.session_attribute.has_data()) or
                    (self.template is not None and self.template.has_data()) or
                    (self.traffic_spec is not None and self.traffic_spec.has_data()))

            def has_operation(self):
                for c in self.in_ero:
                    if (c.has_operation()):
                        return True
                for c in self.out_ero:
                    if (c.has_operation()):
                        return True
                for c in self.pfc:
                    if (c.has_operation()):
                        return True
                return (
                    self.yfilter != YFilter.not_set or
                    self.backup_tunnel_name.yfilter != YFilter.not_set or
                    self.destination_address.yfilter != YFilter.not_set or
                    self.destination_port.yfilter != YFilter.not_set or
                    self.extended_tunnel_id.yfilter != YFilter.not_set or
                    self.input_interface.yfilter != YFilter.not_set or
                    self.is_in_ero_valid.yfilter != YFilter.not_set or
                    self.is_out_ero_valid.yfilter != YFilter.not_set or
                    self.p2mp_id.yfilter != YFilter.not_set or
                    self.protocol.yfilter != YFilter.not_set or
                    self.session_type.yfilter != YFilter.not_set or
                    self.source_address.yfilter != YFilter.not_set or
                    self.source_port.yfilter != YFilter.not_set or
                    self.sub_group_id.yfilter != YFilter.not_set or
                    self.sub_group_origin.yfilter != YFilter.not_set or
                    self.vrf_name.yfilter != YFilter.not_set or
                    (self.class_type is not None and self.class_type.has_operation()) or
                    (self.expiry_time is not None and self.expiry_time.has_operation()) or
                    (self.generic_traffic_spec is not None and self.generic_traffic_spec.has_operation()) or
                    (self.header is not None and self.header.has_operation()) or
                    (self.hop is not None and self.hop.has_operation()) or
                    (self.label_info is not None and self.label_info.has_operation()) or
                    (self.path_flags is not None and self.path_flags.has_operation()) or
                    (self.policy_flags is not None and self.policy_flags.has_operation()) or
                    (self.policy_query_flags is not None and self.policy_query_flags.has_operation()) or
                    (self.policy_source_info is not None and self.policy_source_info.has_operation()) or
                    (self.s2l_sub_lsp is not None and self.s2l_sub_lsp.has_operation()) or
                    (self.session is not None and self.session.has_operation()) or
                    (self.session_attribute is not None and self.session_attribute.has_operation()) or
                    (self.template is not None and self.template.has_operation()) or
                    (self.traffic_spec is not None and self.traffic_spec.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "psb-detailed" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-detaileds/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.backup_tunnel_name.is_set or self.backup_tunnel_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.backup_tunnel_name.get_name_leafdata())
                if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_address.get_name_leafdata())
                if (self.destination_port.is_set or self.destination_port.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_port.get_name_leafdata())
                if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                if (self.input_interface.is_set or self.input_interface.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.input_interface.get_name_leafdata())
                if (self.is_in_ero_valid.is_set or self.is_in_ero_valid.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.is_in_ero_valid.get_name_leafdata())
                if (self.is_out_ero_valid.is_set or self.is_out_ero_valid.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.is_out_ero_valid.get_name_leafdata())
                if (self.p2mp_id.is_set or self.p2mp_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.p2mp_id.get_name_leafdata())
                if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.protocol.get_name_leafdata())
                if (self.session_type.is_set or self.session_type.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.session_type.get_name_leafdata())
                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_address.get_name_leafdata())
                if (self.source_port.is_set or self.source_port.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_port.get_name_leafdata())
                if (self.sub_group_id.is_set or self.sub_group_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.sub_group_id.get_name_leafdata())
                if (self.sub_group_origin.is_set or self.sub_group_origin.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.sub_group_origin.get_name_leafdata())
                if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.vrf_name.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "class-type"):
                    if (self.class_type is None):
                        self.class_type = Rsvp.PsbDetaileds.PsbDetailed.ClassType()
                        self.class_type.parent = self
                        self._children_name_map["class_type"] = "class-type"
                    return self.class_type

                if (child_yang_name == "expiry-time"):
                    if (self.expiry_time is None):
                        self.expiry_time = Rsvp.PsbDetaileds.PsbDetailed.ExpiryTime()
                        self.expiry_time.parent = self
                        self._children_name_map["expiry_time"] = "expiry-time"
                    return self.expiry_time

                if (child_yang_name == "generic-traffic-spec"):
                    if (self.generic_traffic_spec is None):
                        self.generic_traffic_spec = Rsvp.PsbDetaileds.PsbDetailed.GenericTrafficSpec()
                        self.generic_traffic_spec.parent = self
                        self._children_name_map["generic_traffic_spec"] = "generic-traffic-spec"
                    return self.generic_traffic_spec

                if (child_yang_name == "header"):
                    if (self.header is None):
                        self.header = Rsvp.PsbDetaileds.PsbDetailed.Header()
                        self.header.parent = self
                        self._children_name_map["header"] = "header"
                    return self.header

                if (child_yang_name == "hop"):
                    if (self.hop is None):
                        self.hop = Rsvp.PsbDetaileds.PsbDetailed.Hop()
                        self.hop.parent = self
                        self._children_name_map["hop"] = "hop"
                    return self.hop

                if (child_yang_name == "in-ero"):
                    for c in self.in_ero:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = Rsvp.PsbDetaileds.PsbDetailed.InEro()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.in_ero.append(c)
                    return c

                if (child_yang_name == "label-info"):
                    if (self.label_info is None):
                        self.label_info = Rsvp.PsbDetaileds.PsbDetailed.LabelInfo()
                        self.label_info.parent = self
                        self._children_name_map["label_info"] = "label-info"
                    return self.label_info

                if (child_yang_name == "out-ero"):
                    for c in self.out_ero:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = Rsvp.PsbDetaileds.PsbDetailed.OutEro()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.out_ero.append(c)
                    return c

                if (child_yang_name == "path-flags"):
                    if (self.path_flags is None):
                        self.path_flags = Rsvp.PsbDetaileds.PsbDetailed.PathFlags()
                        self.path_flags.parent = self
                        self._children_name_map["path_flags"] = "path-flags"
                    return self.path_flags

                if (child_yang_name == "pfc"):
                    for c in self.pfc:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = Rsvp.PsbDetaileds.PsbDetailed.Pfc()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.pfc.append(c)
                    return c

                if (child_yang_name == "policy-flags"):
                    if (self.policy_flags is None):
                        self.policy_flags = Rsvp.PsbDetaileds.PsbDetailed.PolicyFlags()
                        self.policy_flags.parent = self
                        self._children_name_map["policy_flags"] = "policy-flags"
                    return self.policy_flags

                if (child_yang_name == "policy-query-flags"):
                    if (self.policy_query_flags is None):
                        self.policy_query_flags = Rsvp.PsbDetaileds.PsbDetailed.PolicyQueryFlags()
                        self.policy_query_flags.parent = self
                        self._children_name_map["policy_query_flags"] = "policy-query-flags"
                    return self.policy_query_flags

                if (child_yang_name == "policy-source-info"):
                    if (self.policy_source_info is None):
                        self.policy_source_info = Rsvp.PsbDetaileds.PsbDetailed.PolicySourceInfo()
                        self.policy_source_info.parent = self
                        self._children_name_map["policy_source_info"] = "policy-source-info"
                    return self.policy_source_info

                if (child_yang_name == "s2l-sub-lsp"):
                    if (self.s2l_sub_lsp is None):
                        self.s2l_sub_lsp = Rsvp.PsbDetaileds.PsbDetailed.S2LSubLsp()
                        self.s2l_sub_lsp.parent = self
                        self._children_name_map["s2l_sub_lsp"] = "s2l-sub-lsp"
                    return self.s2l_sub_lsp

                if (child_yang_name == "session"):
                    if (self.session is None):
                        self.session = Rsvp.PsbDetaileds.PsbDetailed.Session()
                        self.session.parent = self
                        self._children_name_map["session"] = "session"
                    return self.session

                if (child_yang_name == "session-attribute"):
                    if (self.session_attribute is None):
                        self.session_attribute = Rsvp.PsbDetaileds.PsbDetailed.SessionAttribute()
                        self.session_attribute.parent = self
                        self._children_name_map["session_attribute"] = "session-attribute"
                    return self.session_attribute

                if (child_yang_name == "template"):
                    if (self.template is None):
                        self.template = Rsvp.PsbDetaileds.PsbDetailed.Template()
                        self.template.parent = self
                        self._children_name_map["template"] = "template"
                    return self.template

                if (child_yang_name == "traffic-spec"):
                    if (self.traffic_spec is None):
                        self.traffic_spec = Rsvp.PsbDetaileds.PsbDetailed.TrafficSpec()
                        self.traffic_spec.parent = self
                        self._children_name_map["traffic_spec"] = "traffic-spec"
                    return self.traffic_spec

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "class-type" or name == "expiry-time" or name == "generic-traffic-spec" or name == "header" or name == "hop" or name == "in-ero" or name == "label-info" or name == "out-ero" or name == "path-flags" or name == "pfc" or name == "policy-flags" or name == "policy-query-flags" or name == "policy-source-info" or name == "s2l-sub-lsp" or name == "session" or name == "session-attribute" or name == "template" or name == "traffic-spec" or name == "backup-tunnel-name" or name == "destination-address" or name == "destination-port" or name == "extended-tunnel-id" or name == "input-interface" or name == "is-in-ero-valid" or name == "is-out-ero-valid" or name == "p2mp-id" or name == "protocol" or name == "session-type" or name == "source-address" or name == "source-port" or name == "sub-group-id" or name == "sub-group-origin" or name == "vrf-name"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "backup-tunnel-name"):
                    self.backup_tunnel_name = value
                    self.backup_tunnel_name.value_namespace = name_space
                    self.backup_tunnel_name.value_namespace_prefix = name_space_prefix
                if(value_path == "destination-address"):
                    self.destination_address = value
                    self.destination_address.value_namespace = name_space
                    self.destination_address.value_namespace_prefix = name_space_prefix
                if(value_path == "destination-port"):
                    self.destination_port = value
                    self.destination_port.value_namespace = name_space
                    self.destination_port.value_namespace_prefix = name_space_prefix
                if(value_path == "extended-tunnel-id"):
                    self.extended_tunnel_id = value
                    self.extended_tunnel_id.value_namespace = name_space
                    self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                if(value_path == "input-interface"):
                    self.input_interface = value
                    self.input_interface.value_namespace = name_space
                    self.input_interface.value_namespace_prefix = name_space_prefix
                if(value_path == "is-in-ero-valid"):
                    self.is_in_ero_valid = value
                    self.is_in_ero_valid.value_namespace = name_space
                    self.is_in_ero_valid.value_namespace_prefix = name_space_prefix
                if(value_path == "is-out-ero-valid"):
                    self.is_out_ero_valid = value
                    self.is_out_ero_valid.value_namespace = name_space
                    self.is_out_ero_valid.value_namespace_prefix = name_space_prefix
                if(value_path == "p2mp-id"):
                    self.p2mp_id = value
                    self.p2mp_id.value_namespace = name_space
                    self.p2mp_id.value_namespace_prefix = name_space_prefix
                if(value_path == "protocol"):
                    self.protocol = value
                    self.protocol.value_namespace = name_space
                    self.protocol.value_namespace_prefix = name_space_prefix
                if(value_path == "session-type"):
                    self.session_type = value
                    self.session_type.value_namespace = name_space
                    self.session_type.value_namespace_prefix = name_space_prefix
                if(value_path == "source-address"):
                    self.source_address = value
                    self.source_address.value_namespace = name_space
                    self.source_address.value_namespace_prefix = name_space_prefix
                if(value_path == "source-port"):
                    self.source_port = value
                    self.source_port.value_namespace = name_space
                    self.source_port.value_namespace_prefix = name_space_prefix
                if(value_path == "sub-group-id"):
                    self.sub_group_id = value
                    self.sub_group_id.value_namespace = name_space
                    self.sub_group_id.value_namespace_prefix = name_space_prefix
                if(value_path == "sub-group-origin"):
                    self.sub_group_origin = value
                    self.sub_group_origin.value_namespace = name_space
                    self.sub_group_origin.value_namespace_prefix = name_space_prefix
                if(value_path == "vrf-name"):
                    self.vrf_name = value
                    self.vrf_name.value_namespace = name_space
                    self.vrf_name.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.psb_detailed:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.psb_detailed:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "psb-detaileds" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "psb-detailed"):
                for c in self.psb_detailed:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = Rsvp.PsbDetaileds.PsbDetailed()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.psb_detailed.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "psb-detailed"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class ControllerDetaileds(Entity):
        """
        Table of detailed info about RSVP\-enabled
        controllers
        
        .. attribute:: controller_detailed
        
        	Detailed info about an RSVP\-enabled controller
        	**type**\: list of    :py:class:`ControllerDetailed <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.ControllerDetaileds.ControllerDetailed>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Rsvp.ControllerDetaileds, self).__init__()

            self.yang_name = "controller-detaileds"
            self.yang_parent_name = "rsvp"

            self.controller_detailed = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(Rsvp.ControllerDetaileds, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(Rsvp.ControllerDetaileds, self).__setattr__(name, value)


        class ControllerDetailed(Entity):
            """
            Detailed info about an RSVP\-enabled controller
            
            .. attribute:: controller_name  <key>
            
            	Controller Name
            	**type**\:  str
            
            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
            
            .. attribute:: ack_hold_time
            
            	ACK hold time in msec
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: ack_max_size
            
            	Max size for ACK message
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: bandwidth_information
            
            	Interface bandwidth information
            	**type**\:   :py:class:`BandwidthInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.ControllerDetaileds.ControllerDetailed.BandwidthInformation>`
            
            .. attribute:: bundle_message_max_size
            
            	Max size in bytes of a single Bundle message
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            	**units**\: byte
            
            .. attribute:: expiry_drops_tolerated
            
            	Number of missed messages tolerated
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: expiry_interval
            
            	Expiry interval in msecs
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            	**units**\: millisecond
            
            .. attribute:: expiry_states
            
            	Number of states for expiry check
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: expiry_timer_state
            
            	Expiry timer state
            	**type**\:   :py:class:`RsvpTimerState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpTimerState>`
            
            .. attribute:: flags
            
            	Interface flags
            	**type**\:   :py:class:`Flags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.ControllerDetaileds.ControllerDetailed.Flags>`
            
            .. attribute:: integrity_receive_password
            
            	Integrity receive password
            	**type**\:  str
            
            	**length:** 0..40
            
            .. attribute:: integrity_receive_password_optional
            
            	Integrity recv password optional
            	**type**\:  int
            
            	**range:** 0..255
            
            .. attribute:: integrity_send_password
            
            	Integrity send password
            	**type**\:  str
            
            	**length:** 0..40
            
            .. attribute:: interface_name_xr
            
            	Interface Name
            	**type**\:  str
            
            .. attribute:: neighbor_array
            
            	Neighbor array
            	**type**\: list of    :py:class:`NeighborArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.ControllerDetaileds.ControllerDetailed.NeighborArray>`
            
            .. attribute:: out_of_band_expiry_drops_tolerated
            
            	Number of out\-of\-band missed messages tolerated
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: out_of_band_refresh_interval
            
            	Out\-of\-band Refresh interval in msecs
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            	**units**\: millisecond
            
            .. attribute:: pacing_interval
            
            	Pacing interval in msecs
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            	**units**\: millisecond
            
            .. attribute:: pacing_message_rate
            
            	No. of messages per interval
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: pacing_messages
            
            	Number of messages deferred for pacing
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: pacing_timer_state
            
            	State of pacing timer
            	**type**\:   :py:class:`RsvpTimerState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpTimerState>`
            
            .. attribute:: refresh_interval
            
            	Refresh interval in msecs
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            	**units**\: millisecond
            
            .. attribute:: refresh_timer_state
            
            	Refresh timer state
            	**type**\:   :py:class:`RsvpTimerState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpTimerState>`
            
            .. attribute:: retransmit_time
            
            	Retransmit time in msec
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: signalling_ip_tos
            
            	IP TOS (precedence/DSCP) to use in signalling messages
            	**type**\:  int
            
            	**range:** 0..255
            
            .. attribute:: summary_refresh_max_size
            
            	Max size in bytes of a single SRefresh
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            	**units**\: byte
            
            .. attribute:: summary_refresh_timer_state
            
            	Summary refresh timer state
            	**type**\:   :py:class:`RsvpTimerState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpTimerState>`
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Rsvp.ControllerDetaileds.ControllerDetailed, self).__init__()

                self.yang_name = "controller-detailed"
                self.yang_parent_name = "controller-detaileds"

                self.controller_name = YLeaf(YType.str, "controller-name")

                self.ack_hold_time = YLeaf(YType.uint32, "ack-hold-time")

                self.ack_max_size = YLeaf(YType.uint32, "ack-max-size")

                self.bundle_message_max_size = YLeaf(YType.uint32, "bundle-message-max-size")

                self.expiry_drops_tolerated = YLeaf(YType.int32, "expiry-drops-tolerated")

                self.expiry_interval = YLeaf(YType.int32, "expiry-interval")

                self.expiry_states = YLeaf(YType.int32, "expiry-states")

                self.expiry_timer_state = YLeaf(YType.enumeration, "expiry-timer-state")

                self.integrity_receive_password = YLeaf(YType.str, "integrity-receive-password")

                self.integrity_receive_password_optional = YLeaf(YType.uint8, "integrity-receive-password-optional")

                self.integrity_send_password = YLeaf(YType.str, "integrity-send-password")

                self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                self.out_of_band_expiry_drops_tolerated = YLeaf(YType.uint32, "out-of-band-expiry-drops-tolerated")

                self.out_of_band_refresh_interval = YLeaf(YType.uint32, "out-of-band-refresh-interval")

                self.pacing_interval = YLeaf(YType.uint32, "pacing-interval")

                self.pacing_message_rate = YLeaf(YType.uint32, "pacing-message-rate")

                self.pacing_messages = YLeaf(YType.int32, "pacing-messages")

                self.pacing_timer_state = YLeaf(YType.enumeration, "pacing-timer-state")

                self.refresh_interval = YLeaf(YType.int32, "refresh-interval")

                self.refresh_timer_state = YLeaf(YType.enumeration, "refresh-timer-state")

                self.retransmit_time = YLeaf(YType.uint32, "retransmit-time")

                self.signalling_ip_tos = YLeaf(YType.uint8, "signalling-ip-tos")

                self.summary_refresh_max_size = YLeaf(YType.uint32, "summary-refresh-max-size")

                self.summary_refresh_timer_state = YLeaf(YType.enumeration, "summary-refresh-timer-state")

                self.bandwidth_information = Rsvp.ControllerDetaileds.ControllerDetailed.BandwidthInformation()
                self.bandwidth_information.parent = self
                self._children_name_map["bandwidth_information"] = "bandwidth-information"
                self._children_yang_names.add("bandwidth-information")

                self.flags = Rsvp.ControllerDetaileds.ControllerDetailed.Flags()
                self.flags.parent = self
                self._children_name_map["flags"] = "flags"
                self._children_yang_names.add("flags")

                self.neighbor_array = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("controller_name",
                                "ack_hold_time",
                                "ack_max_size",
                                "bundle_message_max_size",
                                "expiry_drops_tolerated",
                                "expiry_interval",
                                "expiry_states",
                                "expiry_timer_state",
                                "integrity_receive_password",
                                "integrity_receive_password_optional",
                                "integrity_send_password",
                                "interface_name_xr",
                                "out_of_band_expiry_drops_tolerated",
                                "out_of_band_refresh_interval",
                                "pacing_interval",
                                "pacing_message_rate",
                                "pacing_messages",
                                "pacing_timer_state",
                                "refresh_interval",
                                "refresh_timer_state",
                                "retransmit_time",
                                "signalling_ip_tos",
                                "summary_refresh_max_size",
                                "summary_refresh_timer_state") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Rsvp.ControllerDetaileds.ControllerDetailed, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Rsvp.ControllerDetaileds.ControllerDetailed, self).__setattr__(name, value)


            class BandwidthInformation(Entity):
                """
                Interface bandwidth information
                
                .. attribute:: dste_mode
                
                	DSTEMode
                	**type**\:   :py:class:`RsvpMgmtDsteModes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtDsteModes>`
                
                .. attribute:: pre_standard_dste_interface
                
                	Prestandard DSTE interface information
                	**type**\:   :py:class:`PreStandardDsteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.ControllerDetaileds.ControllerDetailed.BandwidthInformation.PreStandardDsteInterface>`
                
                .. attribute:: standard_dste_interface
                
                	Standard DSTE interface information
                	**type**\:   :py:class:`StandardDsteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.ControllerDetaileds.ControllerDetailed.BandwidthInformation.StandardDsteInterface>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.ControllerDetaileds.ControllerDetailed.BandwidthInformation, self).__init__()

                    self.yang_name = "bandwidth-information"
                    self.yang_parent_name = "controller-detailed"

                    self.dste_mode = YLeaf(YType.enumeration, "dste-mode")

                    self.pre_standard_dste_interface = Rsvp.ControllerDetaileds.ControllerDetailed.BandwidthInformation.PreStandardDsteInterface()
                    self.pre_standard_dste_interface.parent = self
                    self._children_name_map["pre_standard_dste_interface"] = "pre-standard-dste-interface"
                    self._children_yang_names.add("pre-standard-dste-interface")

                    self.standard_dste_interface = Rsvp.ControllerDetaileds.ControllerDetailed.BandwidthInformation.StandardDsteInterface()
                    self.standard_dste_interface.parent = self
                    self._children_name_map["standard_dste_interface"] = "standard-dste-interface"
                    self._children_yang_names.add("standard-dste-interface")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("dste_mode") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.ControllerDetaileds.ControllerDetailed.BandwidthInformation, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.ControllerDetaileds.ControllerDetailed.BandwidthInformation, self).__setattr__(name, value)


                class PreStandardDsteInterface(Entity):
                    """
                    Prestandard DSTE interface information
                    
                    .. attribute:: allocated_bit_rate
                    
                    	Bandwidth (bits per second) now allocated
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: is_max_bandwidth_absolute
                    
                    	True if the Max B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: is_max_subpool_bandwidth_absolute
                    
                    	True if the Max sub\-pool B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: max_bandwidth
                    
                    	Max bandwidth (bits per second) allowed
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_flow_bandwidth
                    
                    	Max bandwidth (bits per second) allowed per flow
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_subpool_bandwidth
                    
                    	Max bandwidth (bits per second) allowed in subpool
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.ControllerDetaileds.ControllerDetailed.BandwidthInformation.PreStandardDsteInterface, self).__init__()

                        self.yang_name = "pre-standard-dste-interface"
                        self.yang_parent_name = "bandwidth-information"

                        self.allocated_bit_rate = YLeaf(YType.uint64, "allocated-bit-rate")

                        self.is_max_bandwidth_absolute = YLeaf(YType.boolean, "is-max-bandwidth-absolute")

                        self.is_max_subpool_bandwidth_absolute = YLeaf(YType.boolean, "is-max-subpool-bandwidth-absolute")

                        self.max_bandwidth = YLeaf(YType.uint64, "max-bandwidth")

                        self.max_flow_bandwidth = YLeaf(YType.uint64, "max-flow-bandwidth")

                        self.max_subpool_bandwidth = YLeaf(YType.uint64, "max-subpool-bandwidth")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("allocated_bit_rate",
                                        "is_max_bandwidth_absolute",
                                        "is_max_subpool_bandwidth_absolute",
                                        "max_bandwidth",
                                        "max_flow_bandwidth",
                                        "max_subpool_bandwidth") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.ControllerDetaileds.ControllerDetailed.BandwidthInformation.PreStandardDsteInterface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.ControllerDetaileds.ControllerDetailed.BandwidthInformation.PreStandardDsteInterface, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.allocated_bit_rate.is_set or
                            self.is_max_bandwidth_absolute.is_set or
                            self.is_max_subpool_bandwidth_absolute.is_set or
                            self.max_bandwidth.is_set or
                            self.max_flow_bandwidth.is_set or
                            self.max_subpool_bandwidth.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.allocated_bit_rate.yfilter != YFilter.not_set or
                            self.is_max_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.is_max_subpool_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.max_bandwidth.yfilter != YFilter.not_set or
                            self.max_flow_bandwidth.yfilter != YFilter.not_set or
                            self.max_subpool_bandwidth.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "pre-standard-dste-interface" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.allocated_bit_rate.is_set or self.allocated_bit_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.allocated_bit_rate.get_name_leafdata())
                        if (self.is_max_bandwidth_absolute.is_set or self.is_max_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_bandwidth_absolute.get_name_leafdata())
                        if (self.is_max_subpool_bandwidth_absolute.is_set or self.is_max_subpool_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_subpool_bandwidth_absolute.get_name_leafdata())
                        if (self.max_bandwidth.is_set or self.max_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_bandwidth.get_name_leafdata())
                        if (self.max_flow_bandwidth.is_set or self.max_flow_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_flow_bandwidth.get_name_leafdata())
                        if (self.max_subpool_bandwidth.is_set or self.max_subpool_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_subpool_bandwidth.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "allocated-bit-rate" or name == "is-max-bandwidth-absolute" or name == "is-max-subpool-bandwidth-absolute" or name == "max-bandwidth" or name == "max-flow-bandwidth" or name == "max-subpool-bandwidth"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "allocated-bit-rate"):
                            self.allocated_bit_rate = value
                            self.allocated_bit_rate.value_namespace = name_space
                            self.allocated_bit_rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-bandwidth-absolute"):
                            self.is_max_bandwidth_absolute = value
                            self.is_max_bandwidth_absolute.value_namespace = name_space
                            self.is_max_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-subpool-bandwidth-absolute"):
                            self.is_max_subpool_bandwidth_absolute = value
                            self.is_max_subpool_bandwidth_absolute.value_namespace = name_space
                            self.is_max_subpool_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-bandwidth"):
                            self.max_bandwidth = value
                            self.max_bandwidth.value_namespace = name_space
                            self.max_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-flow-bandwidth"):
                            self.max_flow_bandwidth = value
                            self.max_flow_bandwidth.value_namespace = name_space
                            self.max_flow_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-subpool-bandwidth"):
                            self.max_subpool_bandwidth = value
                            self.max_subpool_bandwidth.value_namespace = name_space
                            self.max_subpool_bandwidth.value_namespace_prefix = name_space_prefix


                class StandardDsteInterface(Entity):
                    """
                    Standard DSTE interface information
                    
                    .. attribute:: allocated_bit_rate
                    
                    	Bandwidth (bits per second) now allocated
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: is_max_bandwidth_absolute
                    
                    	True if the Max B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: is_max_bc0_bandwidth_absolute
                    
                    	True if the Max BC0 B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: is_max_bc1_bandwidth_absolute
                    
                    	True if the Max BC1 sub\-pool B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: max_bandwidth
                    
                    	Max bandwidth (bits per second) allowed
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_flow_bandwidth
                    
                    	Max bandwidth (bits per second) allowed per flow
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_pool0_bandwidth
                    
                    	Max bandwidth (bits per second) allowed in BC0 pool
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_pool1_bandwidth
                    
                    	Max bandwidth (bits per second) allowed in BC1 pool
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.ControllerDetaileds.ControllerDetailed.BandwidthInformation.StandardDsteInterface, self).__init__()

                        self.yang_name = "standard-dste-interface"
                        self.yang_parent_name = "bandwidth-information"

                        self.allocated_bit_rate = YLeaf(YType.uint64, "allocated-bit-rate")

                        self.is_max_bandwidth_absolute = YLeaf(YType.boolean, "is-max-bandwidth-absolute")

                        self.is_max_bc0_bandwidth_absolute = YLeaf(YType.boolean, "is-max-bc0-bandwidth-absolute")

                        self.is_max_bc1_bandwidth_absolute = YLeaf(YType.boolean, "is-max-bc1-bandwidth-absolute")

                        self.max_bandwidth = YLeaf(YType.uint64, "max-bandwidth")

                        self.max_flow_bandwidth = YLeaf(YType.uint64, "max-flow-bandwidth")

                        self.max_pool0_bandwidth = YLeaf(YType.uint64, "max-pool0-bandwidth")

                        self.max_pool1_bandwidth = YLeaf(YType.uint64, "max-pool1-bandwidth")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("allocated_bit_rate",
                                        "is_max_bandwidth_absolute",
                                        "is_max_bc0_bandwidth_absolute",
                                        "is_max_bc1_bandwidth_absolute",
                                        "max_bandwidth",
                                        "max_flow_bandwidth",
                                        "max_pool0_bandwidth",
                                        "max_pool1_bandwidth") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.ControllerDetaileds.ControllerDetailed.BandwidthInformation.StandardDsteInterface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.ControllerDetaileds.ControllerDetailed.BandwidthInformation.StandardDsteInterface, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.allocated_bit_rate.is_set or
                            self.is_max_bandwidth_absolute.is_set or
                            self.is_max_bc0_bandwidth_absolute.is_set or
                            self.is_max_bc1_bandwidth_absolute.is_set or
                            self.max_bandwidth.is_set or
                            self.max_flow_bandwidth.is_set or
                            self.max_pool0_bandwidth.is_set or
                            self.max_pool1_bandwidth.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.allocated_bit_rate.yfilter != YFilter.not_set or
                            self.is_max_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.is_max_bc0_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.is_max_bc1_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.max_bandwidth.yfilter != YFilter.not_set or
                            self.max_flow_bandwidth.yfilter != YFilter.not_set or
                            self.max_pool0_bandwidth.yfilter != YFilter.not_set or
                            self.max_pool1_bandwidth.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "standard-dste-interface" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.allocated_bit_rate.is_set or self.allocated_bit_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.allocated_bit_rate.get_name_leafdata())
                        if (self.is_max_bandwidth_absolute.is_set or self.is_max_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_bandwidth_absolute.get_name_leafdata())
                        if (self.is_max_bc0_bandwidth_absolute.is_set or self.is_max_bc0_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_bc0_bandwidth_absolute.get_name_leafdata())
                        if (self.is_max_bc1_bandwidth_absolute.is_set or self.is_max_bc1_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_bc1_bandwidth_absolute.get_name_leafdata())
                        if (self.max_bandwidth.is_set or self.max_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_bandwidth.get_name_leafdata())
                        if (self.max_flow_bandwidth.is_set or self.max_flow_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_flow_bandwidth.get_name_leafdata())
                        if (self.max_pool0_bandwidth.is_set or self.max_pool0_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_pool0_bandwidth.get_name_leafdata())
                        if (self.max_pool1_bandwidth.is_set or self.max_pool1_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_pool1_bandwidth.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "allocated-bit-rate" or name == "is-max-bandwidth-absolute" or name == "is-max-bc0-bandwidth-absolute" or name == "is-max-bc1-bandwidth-absolute" or name == "max-bandwidth" or name == "max-flow-bandwidth" or name == "max-pool0-bandwidth" or name == "max-pool1-bandwidth"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "allocated-bit-rate"):
                            self.allocated_bit_rate = value
                            self.allocated_bit_rate.value_namespace = name_space
                            self.allocated_bit_rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-bandwidth-absolute"):
                            self.is_max_bandwidth_absolute = value
                            self.is_max_bandwidth_absolute.value_namespace = name_space
                            self.is_max_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-bc0-bandwidth-absolute"):
                            self.is_max_bc0_bandwidth_absolute = value
                            self.is_max_bc0_bandwidth_absolute.value_namespace = name_space
                            self.is_max_bc0_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-bc1-bandwidth-absolute"):
                            self.is_max_bc1_bandwidth_absolute = value
                            self.is_max_bc1_bandwidth_absolute.value_namespace = name_space
                            self.is_max_bc1_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-bandwidth"):
                            self.max_bandwidth = value
                            self.max_bandwidth.value_namespace = name_space
                            self.max_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-flow-bandwidth"):
                            self.max_flow_bandwidth = value
                            self.max_flow_bandwidth.value_namespace = name_space
                            self.max_flow_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-pool0-bandwidth"):
                            self.max_pool0_bandwidth = value
                            self.max_pool0_bandwidth.value_namespace = name_space
                            self.max_pool0_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-pool1-bandwidth"):
                            self.max_pool1_bandwidth = value
                            self.max_pool1_bandwidth.value_namespace = name_space
                            self.max_pool1_bandwidth.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.dste_mode.is_set or
                        (self.pre_standard_dste_interface is not None and self.pre_standard_dste_interface.has_data()) or
                        (self.standard_dste_interface is not None and self.standard_dste_interface.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.dste_mode.yfilter != YFilter.not_set or
                        (self.pre_standard_dste_interface is not None and self.pre_standard_dste_interface.has_operation()) or
                        (self.standard_dste_interface is not None and self.standard_dste_interface.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bandwidth-information" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.dste_mode.is_set or self.dste_mode.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.dste_mode.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "pre-standard-dste-interface"):
                        if (self.pre_standard_dste_interface is None):
                            self.pre_standard_dste_interface = Rsvp.ControllerDetaileds.ControllerDetailed.BandwidthInformation.PreStandardDsteInterface()
                            self.pre_standard_dste_interface.parent = self
                            self._children_name_map["pre_standard_dste_interface"] = "pre-standard-dste-interface"
                        return self.pre_standard_dste_interface

                    if (child_yang_name == "standard-dste-interface"):
                        if (self.standard_dste_interface is None):
                            self.standard_dste_interface = Rsvp.ControllerDetaileds.ControllerDetailed.BandwidthInformation.StandardDsteInterface()
                            self.standard_dste_interface.parent = self
                            self._children_name_map["standard_dste_interface"] = "standard-dste-interface"
                        return self.standard_dste_interface

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "pre-standard-dste-interface" or name == "standard-dste-interface" or name == "dste-mode"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "dste-mode"):
                        self.dste_mode = value
                        self.dste_mode.value_namespace = name_space
                        self.dste_mode.value_namespace_prefix = name_space_prefix


            class Flags(Entity):
                """
                Interface flags
                
                .. attribute:: is_backup_tunnel
                
                	This is backup tunnel
                	**type**\:  bool
                
                .. attribute:: is_interface_created
                
                	Interface is created
                	**type**\:  bool
                
                .. attribute:: is_interface_down
                
                	Interface is DOWN
                	**type**\:  bool
                
                .. attribute:: is_message_bundling_enabled
                
                	Use bundling for outgoing RSVP messages
                	**type**\:  bool
                
                .. attribute:: is_mpls_enabled
                
                	MPLS enabled on interface
                	**type**\:  bool
                
                .. attribute:: is_non_default_vrf
                
                	Interface is defined in non\-Default VRF
                	**type**\:  bool
                
                .. attribute:: is_pacing_enabled
                
                	Message pacing enabled
                	**type**\:  bool
                
                .. attribute:: is_refresh_enabled
                
                	Refresh enabled
                	**type**\:  bool
                
                .. attribute:: is_refresh_reduction_enabled
                
                	Refresh Reduction enabled
                	**type**\:  bool
                
                .. attribute:: is_rel_s_refresh_enabled
                
                	Use reliable xmt for SRefresh
                	**type**\:  bool
                
                .. attribute:: is_rsvp_configured
                
                	RSVP explicitly configured
                	**type**\:  bool
                
                .. attribute:: is_s_refresh_enabled
                
                	Summary Refresh enabled
                	**type**\:  bool
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.ControllerDetaileds.ControllerDetailed.Flags, self).__init__()

                    self.yang_name = "flags"
                    self.yang_parent_name = "controller-detailed"

                    self.is_backup_tunnel = YLeaf(YType.boolean, "is-backup-tunnel")

                    self.is_interface_created = YLeaf(YType.boolean, "is-interface-created")

                    self.is_interface_down = YLeaf(YType.boolean, "is-interface-down")

                    self.is_message_bundling_enabled = YLeaf(YType.boolean, "is-message-bundling-enabled")

                    self.is_mpls_enabled = YLeaf(YType.boolean, "is-mpls-enabled")

                    self.is_non_default_vrf = YLeaf(YType.boolean, "is-non-default-vrf")

                    self.is_pacing_enabled = YLeaf(YType.boolean, "is-pacing-enabled")

                    self.is_refresh_enabled = YLeaf(YType.boolean, "is-refresh-enabled")

                    self.is_refresh_reduction_enabled = YLeaf(YType.boolean, "is-refresh-reduction-enabled")

                    self.is_rel_s_refresh_enabled = YLeaf(YType.boolean, "is-rel-s-refresh-enabled")

                    self.is_rsvp_configured = YLeaf(YType.boolean, "is-rsvp-configured")

                    self.is_s_refresh_enabled = YLeaf(YType.boolean, "is-s-refresh-enabled")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("is_backup_tunnel",
                                    "is_interface_created",
                                    "is_interface_down",
                                    "is_message_bundling_enabled",
                                    "is_mpls_enabled",
                                    "is_non_default_vrf",
                                    "is_pacing_enabled",
                                    "is_refresh_enabled",
                                    "is_refresh_reduction_enabled",
                                    "is_rel_s_refresh_enabled",
                                    "is_rsvp_configured",
                                    "is_s_refresh_enabled") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.ControllerDetaileds.ControllerDetailed.Flags, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.ControllerDetaileds.ControllerDetailed.Flags, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.is_backup_tunnel.is_set or
                        self.is_interface_created.is_set or
                        self.is_interface_down.is_set or
                        self.is_message_bundling_enabled.is_set or
                        self.is_mpls_enabled.is_set or
                        self.is_non_default_vrf.is_set or
                        self.is_pacing_enabled.is_set or
                        self.is_refresh_enabled.is_set or
                        self.is_refresh_reduction_enabled.is_set or
                        self.is_rel_s_refresh_enabled.is_set or
                        self.is_rsvp_configured.is_set or
                        self.is_s_refresh_enabled.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.is_backup_tunnel.yfilter != YFilter.not_set or
                        self.is_interface_created.yfilter != YFilter.not_set or
                        self.is_interface_down.yfilter != YFilter.not_set or
                        self.is_message_bundling_enabled.yfilter != YFilter.not_set or
                        self.is_mpls_enabled.yfilter != YFilter.not_set or
                        self.is_non_default_vrf.yfilter != YFilter.not_set or
                        self.is_pacing_enabled.yfilter != YFilter.not_set or
                        self.is_refresh_enabled.yfilter != YFilter.not_set or
                        self.is_refresh_reduction_enabled.yfilter != YFilter.not_set or
                        self.is_rel_s_refresh_enabled.yfilter != YFilter.not_set or
                        self.is_rsvp_configured.yfilter != YFilter.not_set or
                        self.is_s_refresh_enabled.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "flags" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.is_backup_tunnel.is_set or self.is_backup_tunnel.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_backup_tunnel.get_name_leafdata())
                    if (self.is_interface_created.is_set or self.is_interface_created.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_interface_created.get_name_leafdata())
                    if (self.is_interface_down.is_set or self.is_interface_down.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_interface_down.get_name_leafdata())
                    if (self.is_message_bundling_enabled.is_set or self.is_message_bundling_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_message_bundling_enabled.get_name_leafdata())
                    if (self.is_mpls_enabled.is_set or self.is_mpls_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_mpls_enabled.get_name_leafdata())
                    if (self.is_non_default_vrf.is_set or self.is_non_default_vrf.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_non_default_vrf.get_name_leafdata())
                    if (self.is_pacing_enabled.is_set or self.is_pacing_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_pacing_enabled.get_name_leafdata())
                    if (self.is_refresh_enabled.is_set or self.is_refresh_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_refresh_enabled.get_name_leafdata())
                    if (self.is_refresh_reduction_enabled.is_set or self.is_refresh_reduction_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_refresh_reduction_enabled.get_name_leafdata())
                    if (self.is_rel_s_refresh_enabled.is_set or self.is_rel_s_refresh_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_rel_s_refresh_enabled.get_name_leafdata())
                    if (self.is_rsvp_configured.is_set or self.is_rsvp_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_rsvp_configured.get_name_leafdata())
                    if (self.is_s_refresh_enabled.is_set or self.is_s_refresh_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_s_refresh_enabled.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "is-backup-tunnel" or name == "is-interface-created" or name == "is-interface-down" or name == "is-message-bundling-enabled" or name == "is-mpls-enabled" or name == "is-non-default-vrf" or name == "is-pacing-enabled" or name == "is-refresh-enabled" or name == "is-refresh-reduction-enabled" or name == "is-rel-s-refresh-enabled" or name == "is-rsvp-configured" or name == "is-s-refresh-enabled"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "is-backup-tunnel"):
                        self.is_backup_tunnel = value
                        self.is_backup_tunnel.value_namespace = name_space
                        self.is_backup_tunnel.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-interface-created"):
                        self.is_interface_created = value
                        self.is_interface_created.value_namespace = name_space
                        self.is_interface_created.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-interface-down"):
                        self.is_interface_down = value
                        self.is_interface_down.value_namespace = name_space
                        self.is_interface_down.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-message-bundling-enabled"):
                        self.is_message_bundling_enabled = value
                        self.is_message_bundling_enabled.value_namespace = name_space
                        self.is_message_bundling_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-mpls-enabled"):
                        self.is_mpls_enabled = value
                        self.is_mpls_enabled.value_namespace = name_space
                        self.is_mpls_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-non-default-vrf"):
                        self.is_non_default_vrf = value
                        self.is_non_default_vrf.value_namespace = name_space
                        self.is_non_default_vrf.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-pacing-enabled"):
                        self.is_pacing_enabled = value
                        self.is_pacing_enabled.value_namespace = name_space
                        self.is_pacing_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-refresh-enabled"):
                        self.is_refresh_enabled = value
                        self.is_refresh_enabled.value_namespace = name_space
                        self.is_refresh_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-refresh-reduction-enabled"):
                        self.is_refresh_reduction_enabled = value
                        self.is_refresh_reduction_enabled.value_namespace = name_space
                        self.is_refresh_reduction_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-rel-s-refresh-enabled"):
                        self.is_rel_s_refresh_enabled = value
                        self.is_rel_s_refresh_enabled.value_namespace = name_space
                        self.is_rel_s_refresh_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-rsvp-configured"):
                        self.is_rsvp_configured = value
                        self.is_rsvp_configured.value_namespace = name_space
                        self.is_rsvp_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-s-refresh-enabled"):
                        self.is_s_refresh_enabled = value
                        self.is_s_refresh_enabled.value_namespace = name_space
                        self.is_s_refresh_enabled.value_namespace_prefix = name_space_prefix


            class NeighborArray(Entity):
                """
                Neighbor array
                
                .. attribute:: expiry_time
                
                	Expiry time
                	**type**\:   :py:class:`ExpiryTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.ControllerDetaileds.ControllerDetailed.NeighborArray.ExpiryTime>`
                
                .. attribute:: is_neighbor_refresh_reduction_capable
                
                	Is neighbor capable of Refresh Reduction
                	**type**\:  bool
                
                .. attribute:: message_ids
                
                	Number of MessageIDs
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: neighbor_address
                
                	IP address of the neighbor
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: neighbor_message_id
                
                	List of Neighbor MessageIDs
                	**type**\: list of    :py:class:`NeighborMessageId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.ControllerDetaileds.ControllerDetailed.NeighborArray.NeighborMessageId>`
                
                .. attribute:: outgoing_states
                
                	Number of outgoing states to the neighbour
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.ControllerDetaileds.ControllerDetailed.NeighborArray, self).__init__()

                    self.yang_name = "neighbor-array"
                    self.yang_parent_name = "controller-detailed"

                    self.is_neighbor_refresh_reduction_capable = YLeaf(YType.boolean, "is-neighbor-refresh-reduction-capable")

                    self.message_ids = YLeaf(YType.uint32, "message-ids")

                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                    self.outgoing_states = YLeaf(YType.int32, "outgoing-states")

                    self.expiry_time = Rsvp.ControllerDetaileds.ControllerDetailed.NeighborArray.ExpiryTime()
                    self.expiry_time.parent = self
                    self._children_name_map["expiry_time"] = "expiry-time"
                    self._children_yang_names.add("expiry-time")

                    self.neighbor_message_id = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("is_neighbor_refresh_reduction_capable",
                                    "message_ids",
                                    "neighbor_address",
                                    "outgoing_states") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.ControllerDetaileds.ControllerDetailed.NeighborArray, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.ControllerDetaileds.ControllerDetailed.NeighborArray, self).__setattr__(name, value)


                class ExpiryTime(Entity):
                    """
                    Expiry time
                    
                    .. attribute:: nanoseconds
                    
                    	Time Value in Nano\-seconds
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: nanosecond
                    
                    .. attribute:: seconds
                    
                    	Time Value in Seconds
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.ControllerDetaileds.ControllerDetailed.NeighborArray.ExpiryTime, self).__init__()

                        self.yang_name = "expiry-time"
                        self.yang_parent_name = "neighbor-array"

                        self.nanoseconds = YLeaf(YType.int32, "nanoseconds")

                        self.seconds = YLeaf(YType.int32, "seconds")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("nanoseconds",
                                        "seconds") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.ControllerDetaileds.ControllerDetailed.NeighborArray.ExpiryTime, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.ControllerDetaileds.ControllerDetailed.NeighborArray.ExpiryTime, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.nanoseconds.is_set or
                            self.seconds.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.nanoseconds.yfilter != YFilter.not_set or
                            self.seconds.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "expiry-time" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.nanoseconds.is_set or self.nanoseconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.nanoseconds.get_name_leafdata())
                        if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.seconds.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "nanoseconds" or name == "seconds"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "nanoseconds"):
                            self.nanoseconds = value
                            self.nanoseconds.value_namespace = name_space
                            self.nanoseconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "seconds"):
                            self.seconds = value
                            self.seconds.value_namespace = name_space
                            self.seconds.value_namespace_prefix = name_space_prefix


                class NeighborMessageId(Entity):
                    """
                    List of Neighbor MessageIDs
                    
                    .. attribute:: message_id
                    
                    	Message ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.ControllerDetaileds.ControllerDetailed.NeighborArray.NeighborMessageId, self).__init__()

                        self.yang_name = "neighbor-message-id"
                        self.yang_parent_name = "neighbor-array"

                        self.message_id = YLeaf(YType.uint32, "message-id")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("message_id") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.ControllerDetaileds.ControllerDetailed.NeighborArray.NeighborMessageId, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.ControllerDetaileds.ControllerDetailed.NeighborArray.NeighborMessageId, self).__setattr__(name, value)

                    def has_data(self):
                        return self.message_id.is_set

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.message_id.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "neighbor-message-id" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.message_id.is_set or self.message_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.message_id.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "message-id"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "message-id"):
                            self.message_id = value
                            self.message_id.value_namespace = name_space
                            self.message_id.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.neighbor_message_id:
                        if (c.has_data()):
                            return True
                    return (
                        self.is_neighbor_refresh_reduction_capable.is_set or
                        self.message_ids.is_set or
                        self.neighbor_address.is_set or
                        self.outgoing_states.is_set or
                        (self.expiry_time is not None and self.expiry_time.has_data()))

                def has_operation(self):
                    for c in self.neighbor_message_id:
                        if (c.has_operation()):
                            return True
                    return (
                        self.yfilter != YFilter.not_set or
                        self.is_neighbor_refresh_reduction_capable.yfilter != YFilter.not_set or
                        self.message_ids.yfilter != YFilter.not_set or
                        self.neighbor_address.yfilter != YFilter.not_set or
                        self.outgoing_states.yfilter != YFilter.not_set or
                        (self.expiry_time is not None and self.expiry_time.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "neighbor-array" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.is_neighbor_refresh_reduction_capable.is_set or self.is_neighbor_refresh_reduction_capable.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_neighbor_refresh_reduction_capable.get_name_leafdata())
                    if (self.message_ids.is_set or self.message_ids.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.message_ids.get_name_leafdata())
                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                    if (self.outgoing_states.is_set or self.outgoing_states.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.outgoing_states.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "expiry-time"):
                        if (self.expiry_time is None):
                            self.expiry_time = Rsvp.ControllerDetaileds.ControllerDetailed.NeighborArray.ExpiryTime()
                            self.expiry_time.parent = self
                            self._children_name_map["expiry_time"] = "expiry-time"
                        return self.expiry_time

                    if (child_yang_name == "neighbor-message-id"):
                        for c in self.neighbor_message_id:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Rsvp.ControllerDetaileds.ControllerDetailed.NeighborArray.NeighborMessageId()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.neighbor_message_id.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "expiry-time" or name == "neighbor-message-id" or name == "is-neighbor-refresh-reduction-capable" or name == "message-ids" or name == "neighbor-address" or name == "outgoing-states"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "is-neighbor-refresh-reduction-capable"):
                        self.is_neighbor_refresh_reduction_capable = value
                        self.is_neighbor_refresh_reduction_capable.value_namespace = name_space
                        self.is_neighbor_refresh_reduction_capable.value_namespace_prefix = name_space_prefix
                    if(value_path == "message-ids"):
                        self.message_ids = value
                        self.message_ids.value_namespace = name_space
                        self.message_ids.value_namespace_prefix = name_space_prefix
                    if(value_path == "neighbor-address"):
                        self.neighbor_address = value
                        self.neighbor_address.value_namespace = name_space
                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "outgoing-states"):
                        self.outgoing_states = value
                        self.outgoing_states.value_namespace = name_space
                        self.outgoing_states.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.neighbor_array:
                    if (c.has_data()):
                        return True
                return (
                    self.controller_name.is_set or
                    self.ack_hold_time.is_set or
                    self.ack_max_size.is_set or
                    self.bundle_message_max_size.is_set or
                    self.expiry_drops_tolerated.is_set or
                    self.expiry_interval.is_set or
                    self.expiry_states.is_set or
                    self.expiry_timer_state.is_set or
                    self.integrity_receive_password.is_set or
                    self.integrity_receive_password_optional.is_set or
                    self.integrity_send_password.is_set or
                    self.interface_name_xr.is_set or
                    self.out_of_band_expiry_drops_tolerated.is_set or
                    self.out_of_band_refresh_interval.is_set or
                    self.pacing_interval.is_set or
                    self.pacing_message_rate.is_set or
                    self.pacing_messages.is_set or
                    self.pacing_timer_state.is_set or
                    self.refresh_interval.is_set or
                    self.refresh_timer_state.is_set or
                    self.retransmit_time.is_set or
                    self.signalling_ip_tos.is_set or
                    self.summary_refresh_max_size.is_set or
                    self.summary_refresh_timer_state.is_set or
                    (self.bandwidth_information is not None and self.bandwidth_information.has_data()) or
                    (self.flags is not None and self.flags.has_data()))

            def has_operation(self):
                for c in self.neighbor_array:
                    if (c.has_operation()):
                        return True
                return (
                    self.yfilter != YFilter.not_set or
                    self.controller_name.yfilter != YFilter.not_set or
                    self.ack_hold_time.yfilter != YFilter.not_set or
                    self.ack_max_size.yfilter != YFilter.not_set or
                    self.bundle_message_max_size.yfilter != YFilter.not_set or
                    self.expiry_drops_tolerated.yfilter != YFilter.not_set or
                    self.expiry_interval.yfilter != YFilter.not_set or
                    self.expiry_states.yfilter != YFilter.not_set or
                    self.expiry_timer_state.yfilter != YFilter.not_set or
                    self.integrity_receive_password.yfilter != YFilter.not_set or
                    self.integrity_receive_password_optional.yfilter != YFilter.not_set or
                    self.integrity_send_password.yfilter != YFilter.not_set or
                    self.interface_name_xr.yfilter != YFilter.not_set or
                    self.out_of_band_expiry_drops_tolerated.yfilter != YFilter.not_set or
                    self.out_of_band_refresh_interval.yfilter != YFilter.not_set or
                    self.pacing_interval.yfilter != YFilter.not_set or
                    self.pacing_message_rate.yfilter != YFilter.not_set or
                    self.pacing_messages.yfilter != YFilter.not_set or
                    self.pacing_timer_state.yfilter != YFilter.not_set or
                    self.refresh_interval.yfilter != YFilter.not_set or
                    self.refresh_timer_state.yfilter != YFilter.not_set or
                    self.retransmit_time.yfilter != YFilter.not_set or
                    self.signalling_ip_tos.yfilter != YFilter.not_set or
                    self.summary_refresh_max_size.yfilter != YFilter.not_set or
                    self.summary_refresh_timer_state.yfilter != YFilter.not_set or
                    (self.bandwidth_information is not None and self.bandwidth_information.has_operation()) or
                    (self.flags is not None and self.flags.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "controller-detailed" + "[controller-name='" + self.controller_name.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/controller-detaileds/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.controller_name.is_set or self.controller_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.controller_name.get_name_leafdata())
                if (self.ack_hold_time.is_set or self.ack_hold_time.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.ack_hold_time.get_name_leafdata())
                if (self.ack_max_size.is_set or self.ack_max_size.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.ack_max_size.get_name_leafdata())
                if (self.bundle_message_max_size.is_set or self.bundle_message_max_size.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.bundle_message_max_size.get_name_leafdata())
                if (self.expiry_drops_tolerated.is_set or self.expiry_drops_tolerated.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.expiry_drops_tolerated.get_name_leafdata())
                if (self.expiry_interval.is_set or self.expiry_interval.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.expiry_interval.get_name_leafdata())
                if (self.expiry_states.is_set or self.expiry_states.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.expiry_states.get_name_leafdata())
                if (self.expiry_timer_state.is_set or self.expiry_timer_state.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.expiry_timer_state.get_name_leafdata())
                if (self.integrity_receive_password.is_set or self.integrity_receive_password.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.integrity_receive_password.get_name_leafdata())
                if (self.integrity_receive_password_optional.is_set or self.integrity_receive_password_optional.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.integrity_receive_password_optional.get_name_leafdata())
                if (self.integrity_send_password.is_set or self.integrity_send_password.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.integrity_send_password.get_name_leafdata())
                if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                if (self.out_of_band_expiry_drops_tolerated.is_set or self.out_of_band_expiry_drops_tolerated.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.out_of_band_expiry_drops_tolerated.get_name_leafdata())
                if (self.out_of_band_refresh_interval.is_set or self.out_of_band_refresh_interval.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.out_of_band_refresh_interval.get_name_leafdata())
                if (self.pacing_interval.is_set or self.pacing_interval.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.pacing_interval.get_name_leafdata())
                if (self.pacing_message_rate.is_set or self.pacing_message_rate.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.pacing_message_rate.get_name_leafdata())
                if (self.pacing_messages.is_set or self.pacing_messages.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.pacing_messages.get_name_leafdata())
                if (self.pacing_timer_state.is_set or self.pacing_timer_state.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.pacing_timer_state.get_name_leafdata())
                if (self.refresh_interval.is_set or self.refresh_interval.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.refresh_interval.get_name_leafdata())
                if (self.refresh_timer_state.is_set or self.refresh_timer_state.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.refresh_timer_state.get_name_leafdata())
                if (self.retransmit_time.is_set or self.retransmit_time.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.retransmit_time.get_name_leafdata())
                if (self.signalling_ip_tos.is_set or self.signalling_ip_tos.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.signalling_ip_tos.get_name_leafdata())
                if (self.summary_refresh_max_size.is_set or self.summary_refresh_max_size.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.summary_refresh_max_size.get_name_leafdata())
                if (self.summary_refresh_timer_state.is_set or self.summary_refresh_timer_state.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.summary_refresh_timer_state.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "bandwidth-information"):
                    if (self.bandwidth_information is None):
                        self.bandwidth_information = Rsvp.ControllerDetaileds.ControllerDetailed.BandwidthInformation()
                        self.bandwidth_information.parent = self
                        self._children_name_map["bandwidth_information"] = "bandwidth-information"
                    return self.bandwidth_information

                if (child_yang_name == "flags"):
                    if (self.flags is None):
                        self.flags = Rsvp.ControllerDetaileds.ControllerDetailed.Flags()
                        self.flags.parent = self
                        self._children_name_map["flags"] = "flags"
                    return self.flags

                if (child_yang_name == "neighbor-array"):
                    for c in self.neighbor_array:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = Rsvp.ControllerDetaileds.ControllerDetailed.NeighborArray()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.neighbor_array.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "bandwidth-information" or name == "flags" or name == "neighbor-array" or name == "controller-name" or name == "ack-hold-time" or name == "ack-max-size" or name == "bundle-message-max-size" or name == "expiry-drops-tolerated" or name == "expiry-interval" or name == "expiry-states" or name == "expiry-timer-state" or name == "integrity-receive-password" or name == "integrity-receive-password-optional" or name == "integrity-send-password" or name == "interface-name-xr" or name == "out-of-band-expiry-drops-tolerated" or name == "out-of-band-refresh-interval" or name == "pacing-interval" or name == "pacing-message-rate" or name == "pacing-messages" or name == "pacing-timer-state" or name == "refresh-interval" or name == "refresh-timer-state" or name == "retransmit-time" or name == "signalling-ip-tos" or name == "summary-refresh-max-size" or name == "summary-refresh-timer-state"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "controller-name"):
                    self.controller_name = value
                    self.controller_name.value_namespace = name_space
                    self.controller_name.value_namespace_prefix = name_space_prefix
                if(value_path == "ack-hold-time"):
                    self.ack_hold_time = value
                    self.ack_hold_time.value_namespace = name_space
                    self.ack_hold_time.value_namespace_prefix = name_space_prefix
                if(value_path == "ack-max-size"):
                    self.ack_max_size = value
                    self.ack_max_size.value_namespace = name_space
                    self.ack_max_size.value_namespace_prefix = name_space_prefix
                if(value_path == "bundle-message-max-size"):
                    self.bundle_message_max_size = value
                    self.bundle_message_max_size.value_namespace = name_space
                    self.bundle_message_max_size.value_namespace_prefix = name_space_prefix
                if(value_path == "expiry-drops-tolerated"):
                    self.expiry_drops_tolerated = value
                    self.expiry_drops_tolerated.value_namespace = name_space
                    self.expiry_drops_tolerated.value_namespace_prefix = name_space_prefix
                if(value_path == "expiry-interval"):
                    self.expiry_interval = value
                    self.expiry_interval.value_namespace = name_space
                    self.expiry_interval.value_namespace_prefix = name_space_prefix
                if(value_path == "expiry-states"):
                    self.expiry_states = value
                    self.expiry_states.value_namespace = name_space
                    self.expiry_states.value_namespace_prefix = name_space_prefix
                if(value_path == "expiry-timer-state"):
                    self.expiry_timer_state = value
                    self.expiry_timer_state.value_namespace = name_space
                    self.expiry_timer_state.value_namespace_prefix = name_space_prefix
                if(value_path == "integrity-receive-password"):
                    self.integrity_receive_password = value
                    self.integrity_receive_password.value_namespace = name_space
                    self.integrity_receive_password.value_namespace_prefix = name_space_prefix
                if(value_path == "integrity-receive-password-optional"):
                    self.integrity_receive_password_optional = value
                    self.integrity_receive_password_optional.value_namespace = name_space
                    self.integrity_receive_password_optional.value_namespace_prefix = name_space_prefix
                if(value_path == "integrity-send-password"):
                    self.integrity_send_password = value
                    self.integrity_send_password.value_namespace = name_space
                    self.integrity_send_password.value_namespace_prefix = name_space_prefix
                if(value_path == "interface-name-xr"):
                    self.interface_name_xr = value
                    self.interface_name_xr.value_namespace = name_space
                    self.interface_name_xr.value_namespace_prefix = name_space_prefix
                if(value_path == "out-of-band-expiry-drops-tolerated"):
                    self.out_of_band_expiry_drops_tolerated = value
                    self.out_of_band_expiry_drops_tolerated.value_namespace = name_space
                    self.out_of_band_expiry_drops_tolerated.value_namespace_prefix = name_space_prefix
                if(value_path == "out-of-band-refresh-interval"):
                    self.out_of_band_refresh_interval = value
                    self.out_of_band_refresh_interval.value_namespace = name_space
                    self.out_of_band_refresh_interval.value_namespace_prefix = name_space_prefix
                if(value_path == "pacing-interval"):
                    self.pacing_interval = value
                    self.pacing_interval.value_namespace = name_space
                    self.pacing_interval.value_namespace_prefix = name_space_prefix
                if(value_path == "pacing-message-rate"):
                    self.pacing_message_rate = value
                    self.pacing_message_rate.value_namespace = name_space
                    self.pacing_message_rate.value_namespace_prefix = name_space_prefix
                if(value_path == "pacing-messages"):
                    self.pacing_messages = value
                    self.pacing_messages.value_namespace = name_space
                    self.pacing_messages.value_namespace_prefix = name_space_prefix
                if(value_path == "pacing-timer-state"):
                    self.pacing_timer_state = value
                    self.pacing_timer_state.value_namespace = name_space
                    self.pacing_timer_state.value_namespace_prefix = name_space_prefix
                if(value_path == "refresh-interval"):
                    self.refresh_interval = value
                    self.refresh_interval.value_namespace = name_space
                    self.refresh_interval.value_namespace_prefix = name_space_prefix
                if(value_path == "refresh-timer-state"):
                    self.refresh_timer_state = value
                    self.refresh_timer_state.value_namespace = name_space
                    self.refresh_timer_state.value_namespace_prefix = name_space_prefix
                if(value_path == "retransmit-time"):
                    self.retransmit_time = value
                    self.retransmit_time.value_namespace = name_space
                    self.retransmit_time.value_namespace_prefix = name_space_prefix
                if(value_path == "signalling-ip-tos"):
                    self.signalling_ip_tos = value
                    self.signalling_ip_tos.value_namespace = name_space
                    self.signalling_ip_tos.value_namespace_prefix = name_space_prefix
                if(value_path == "summary-refresh-max-size"):
                    self.summary_refresh_max_size = value
                    self.summary_refresh_max_size.value_namespace = name_space
                    self.summary_refresh_max_size.value_namespace_prefix = name_space_prefix
                if(value_path == "summary-refresh-timer-state"):
                    self.summary_refresh_timer_state = value
                    self.summary_refresh_timer_state.value_namespace = name_space
                    self.summary_refresh_timer_state.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.controller_detailed:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.controller_detailed:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "controller-detaileds" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "controller-detailed"):
                for c in self.controller_detailed:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = Rsvp.ControllerDetaileds.ControllerDetailed()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.controller_detailed.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "controller-detailed"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class FrrSummary(Entity):
        """
        Fast Re\-Route Summary State Information
        
        .. attribute:: path_states
        
        	Path state counters
        	**type**\:   :py:class:`PathStates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.FrrSummary.PathStates>`
        
        .. attribute:: reservation_states
        
        	Rerservation state counters
        	**type**\:   :py:class:`ReservationStates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.FrrSummary.ReservationStates>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Rsvp.FrrSummary, self).__init__()

            self.yang_name = "frr-summary"
            self.yang_parent_name = "rsvp"

            self.path_states = Rsvp.FrrSummary.PathStates()
            self.path_states.parent = self
            self._children_name_map["path_states"] = "path-states"
            self._children_yang_names.add("path-states")

            self.reservation_states = Rsvp.FrrSummary.ReservationStates()
            self.reservation_states.parent = self
            self._children_name_map["reservation_states"] = "reservation-states"
            self._children_yang_names.add("reservation-states")


        class PathStates(Entity):
            """
            Path state counters
            
            .. attribute:: active_instances
            
            	Number of active instances of this state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: active_wait_instances
            
            	Number of instances of this state awaiting Path messages to be sent out or Resv messages to be received
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: ready_instances
            
            	Number of ready instances of this state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: total
            
            	Total number of instances of this state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Rsvp.FrrSummary.PathStates, self).__init__()

                self.yang_name = "path-states"
                self.yang_parent_name = "frr-summary"

                self.active_instances = YLeaf(YType.uint32, "active-instances")

                self.active_wait_instances = YLeaf(YType.uint32, "active-wait-instances")

                self.ready_instances = YLeaf(YType.uint32, "ready-instances")

                self.total = YLeaf(YType.uint32, "total")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("active_instances",
                                "active_wait_instances",
                                "ready_instances",
                                "total") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Rsvp.FrrSummary.PathStates, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Rsvp.FrrSummary.PathStates, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.active_instances.is_set or
                    self.active_wait_instances.is_set or
                    self.ready_instances.is_set or
                    self.total.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.active_instances.yfilter != YFilter.not_set or
                    self.active_wait_instances.yfilter != YFilter.not_set or
                    self.ready_instances.yfilter != YFilter.not_set or
                    self.total.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "path-states" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/frr-summary/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.active_instances.is_set or self.active_instances.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.active_instances.get_name_leafdata())
                if (self.active_wait_instances.is_set or self.active_wait_instances.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.active_wait_instances.get_name_leafdata())
                if (self.ready_instances.is_set or self.ready_instances.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.ready_instances.get_name_leafdata())
                if (self.total.is_set or self.total.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.total.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "active-instances" or name == "active-wait-instances" or name == "ready-instances" or name == "total"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "active-instances"):
                    self.active_instances = value
                    self.active_instances.value_namespace = name_space
                    self.active_instances.value_namespace_prefix = name_space_prefix
                if(value_path == "active-wait-instances"):
                    self.active_wait_instances = value
                    self.active_wait_instances.value_namespace = name_space
                    self.active_wait_instances.value_namespace_prefix = name_space_prefix
                if(value_path == "ready-instances"):
                    self.ready_instances = value
                    self.ready_instances.value_namespace = name_space
                    self.ready_instances.value_namespace_prefix = name_space_prefix
                if(value_path == "total"):
                    self.total = value
                    self.total.value_namespace = name_space
                    self.total.value_namespace_prefix = name_space_prefix


        class ReservationStates(Entity):
            """
            Rerservation state counters
            
            .. attribute:: active_instances
            
            	Number of active instances of this state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: active_wait_instances
            
            	Number of instances of this state awaiting Path messages to be sent out or Resv messages to be received
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: ready_instances
            
            	Number of ready instances of this state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: total
            
            	Total number of instances of this state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Rsvp.FrrSummary.ReservationStates, self).__init__()

                self.yang_name = "reservation-states"
                self.yang_parent_name = "frr-summary"

                self.active_instances = YLeaf(YType.uint32, "active-instances")

                self.active_wait_instances = YLeaf(YType.uint32, "active-wait-instances")

                self.ready_instances = YLeaf(YType.uint32, "ready-instances")

                self.total = YLeaf(YType.uint32, "total")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("active_instances",
                                "active_wait_instances",
                                "ready_instances",
                                "total") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Rsvp.FrrSummary.ReservationStates, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Rsvp.FrrSummary.ReservationStates, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.active_instances.is_set or
                    self.active_wait_instances.is_set or
                    self.ready_instances.is_set or
                    self.total.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.active_instances.yfilter != YFilter.not_set or
                    self.active_wait_instances.yfilter != YFilter.not_set or
                    self.ready_instances.yfilter != YFilter.not_set or
                    self.total.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "reservation-states" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/frr-summary/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.active_instances.is_set or self.active_instances.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.active_instances.get_name_leafdata())
                if (self.active_wait_instances.is_set or self.active_wait_instances.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.active_wait_instances.get_name_leafdata())
                if (self.ready_instances.is_set or self.ready_instances.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.ready_instances.get_name_leafdata())
                if (self.total.is_set or self.total.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.total.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "active-instances" or name == "active-wait-instances" or name == "ready-instances" or name == "total"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "active-instances"):
                    self.active_instances = value
                    self.active_instances.value_namespace = name_space
                    self.active_instances.value_namespace_prefix = name_space_prefix
                if(value_path == "active-wait-instances"):
                    self.active_wait_instances = value
                    self.active_wait_instances.value_namespace = name_space
                    self.active_wait_instances.value_namespace_prefix = name_space_prefix
                if(value_path == "ready-instances"):
                    self.ready_instances = value
                    self.ready_instances.value_namespace = name_space
                    self.ready_instances.value_namespace_prefix = name_space_prefix
                if(value_path == "total"):
                    self.total = value
                    self.total.value_namespace = name_space
                    self.total.value_namespace_prefix = name_space_prefix

        def has_data(self):
            return (
                (self.path_states is not None and self.path_states.has_data()) or
                (self.reservation_states is not None and self.reservation_states.has_data()))

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.path_states is not None and self.path_states.has_operation()) or
                (self.reservation_states is not None and self.reservation_states.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "frr-summary" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "path-states"):
                if (self.path_states is None):
                    self.path_states = Rsvp.FrrSummary.PathStates()
                    self.path_states.parent = self
                    self._children_name_map["path_states"] = "path-states"
                return self.path_states

            if (child_yang_name == "reservation-states"):
                if (self.reservation_states is None):
                    self.reservation_states = Rsvp.FrrSummary.ReservationStates()
                    self.reservation_states.parent = self
                    self._children_name_map["reservation_states"] = "reservation-states"
                return self.reservation_states

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "path-states" or name == "reservation-states"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class RsbDetaileds(Entity):
        """
        Table of detailed info about reservation state
        blocks
        
        .. attribute:: rsb_detailed
        
        	Detailed info for a single reservation state block
        	**type**\: list of    :py:class:`RsbDetailed <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RsbDetaileds.RsbDetailed>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Rsvp.RsbDetaileds, self).__init__()

            self.yang_name = "rsb-detaileds"
            self.yang_parent_name = "rsvp"

            self.rsb_detailed = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(Rsvp.RsbDetaileds, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(Rsvp.RsbDetaileds, self).__setattr__(name, value)


        class RsbDetailed(Entity):
            """
            Detailed info for a single reservation state
            block
            
            .. attribute:: destination_address
            
            	Destination Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: destination_port
            
            	Destination Port
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: expiry_time
            
            	Expiry Time
            	**type**\:   :py:class:`ExpiryTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RsbDetaileds.RsbDetailed.ExpiryTime>`
            
            .. attribute:: extended_tunnel_id
            
            	Extended Tunnel ID
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: filter
            
            	RSVP Filter
            	**type**\:   :py:class:`Filter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RsbDetaileds.RsbDetailed.Filter>`
            
            .. attribute:: flow_spec
            
            	Flow Spec Information
            	**type**\:   :py:class:`FlowSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RsbDetaileds.RsbDetailed.FlowSpec>`
            
            .. attribute:: generic_flow_spec
            
            	Generic Flow Spec Information
            	**type**\:   :py:class:`GenericFlowSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RsbDetaileds.RsbDetailed.GenericFlowSpec>`
            
            .. attribute:: header
            
            	RSVP Header Information
            	**type**\:   :py:class:`Header <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RsbDetaileds.RsbDetailed.Header>`
            
            .. attribute:: hop
            
            	Hop Infomation
            	**type**\:   :py:class:`Hop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RsbDetaileds.RsbDetailed.Hop>`
            
            .. attribute:: input_adjusted_interface
            
            	Input Adjusted Interface
            	**type**\:  str
            
            .. attribute:: input_physical_interface
            
            	Input Physical Interface
            	**type**\:  str
            
            .. attribute:: label_info
            
            	Label Information
            	**type**\:   :py:class:`LabelInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RsbDetaileds.RsbDetailed.LabelInfo>`
            
            .. attribute:: p2mp_id
            
            	P2MP ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: policy_flags
            
            	RSVP Policy Flags
            	**type**\:   :py:class:`PolicyFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RsbDetaileds.RsbDetailed.PolicyFlags>`
            
            .. attribute:: policy_query_flags
            
            	RSVP Query Flags
            	**type**\:   :py:class:`PolicyQueryFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RsbDetaileds.RsbDetailed.PolicyQueryFlags>`
            
            .. attribute:: policy_sources
            
            	RSVP Policy Sources
            	**type**\:   :py:class:`PolicySources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RsbDetaileds.RsbDetailed.PolicySources>`
            
            .. attribute:: protocol
            
            	Protocol
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: rsb_flags
            
            	Reservation State Block Flags
            	**type**\:   :py:class:`RsbFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RsbDetaileds.RsbDetailed.RsbFlags>`
            
            .. attribute:: s2l_sub_lsp
            
            	RSVP S2L Sub\-LSP information
            	**type**\:   :py:class:`S2LSubLsp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RsbDetaileds.RsbDetailed.S2LSubLsp>`
            
            .. attribute:: session
            
            	RSVP Session Information
            	**type**\:   :py:class:`Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RsbDetaileds.RsbDetailed.Session>`
            
            .. attribute:: session_type
            
            	Session Type
            	**type**\:   :py:class:`RsvpSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpSession>`
            
            .. attribute:: source_address
            
            	Source Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: source_port
            
            	Source Port 
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: style
            
            	RSVP Style
            	**type**\:   :py:class:`Style <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RsbDetaileds.RsbDetailed.Style>`
            
            .. attribute:: sub_group_id
            
            	Subgroup ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: sub_group_origin
            
            	Subgroup Origin
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: vrf_name
            
            	VRF Name
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Rsvp.RsbDetaileds.RsbDetailed, self).__init__()

                self.yang_name = "rsb-detailed"
                self.yang_parent_name = "rsb-detaileds"

                self.destination_address = YLeaf(YType.str, "destination-address")

                self.destination_port = YLeaf(YType.int32, "destination-port")

                self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                self.input_adjusted_interface = YLeaf(YType.str, "input-adjusted-interface")

                self.input_physical_interface = YLeaf(YType.str, "input-physical-interface")

                self.p2mp_id = YLeaf(YType.int32, "p2mp-id")

                self.protocol = YLeaf(YType.int32, "protocol")

                self.session_type = YLeaf(YType.enumeration, "session-type")

                self.source_address = YLeaf(YType.str, "source-address")

                self.source_port = YLeaf(YType.int32, "source-port")

                self.sub_group_id = YLeaf(YType.int32, "sub-group-id")

                self.sub_group_origin = YLeaf(YType.str, "sub-group-origin")

                self.vrf_name = YLeaf(YType.str, "vrf-name")

                self.expiry_time = Rsvp.RsbDetaileds.RsbDetailed.ExpiryTime()
                self.expiry_time.parent = self
                self._children_name_map["expiry_time"] = "expiry-time"
                self._children_yang_names.add("expiry-time")

                self.filter = Rsvp.RsbDetaileds.RsbDetailed.Filter()
                self.filter.parent = self
                self._children_name_map["filter"] = "filter"
                self._children_yang_names.add("filter")

                self.flow_spec = Rsvp.RsbDetaileds.RsbDetailed.FlowSpec()
                self.flow_spec.parent = self
                self._children_name_map["flow_spec"] = "flow-spec"
                self._children_yang_names.add("flow-spec")

                self.generic_flow_spec = Rsvp.RsbDetaileds.RsbDetailed.GenericFlowSpec()
                self.generic_flow_spec.parent = self
                self._children_name_map["generic_flow_spec"] = "generic-flow-spec"
                self._children_yang_names.add("generic-flow-spec")

                self.header = Rsvp.RsbDetaileds.RsbDetailed.Header()
                self.header.parent = self
                self._children_name_map["header"] = "header"
                self._children_yang_names.add("header")

                self.hop = Rsvp.RsbDetaileds.RsbDetailed.Hop()
                self.hop.parent = self
                self._children_name_map["hop"] = "hop"
                self._children_yang_names.add("hop")

                self.label_info = Rsvp.RsbDetaileds.RsbDetailed.LabelInfo()
                self.label_info.parent = self
                self._children_name_map["label_info"] = "label-info"
                self._children_yang_names.add("label-info")

                self.policy_flags = Rsvp.RsbDetaileds.RsbDetailed.PolicyFlags()
                self.policy_flags.parent = self
                self._children_name_map["policy_flags"] = "policy-flags"
                self._children_yang_names.add("policy-flags")

                self.policy_query_flags = Rsvp.RsbDetaileds.RsbDetailed.PolicyQueryFlags()
                self.policy_query_flags.parent = self
                self._children_name_map["policy_query_flags"] = "policy-query-flags"
                self._children_yang_names.add("policy-query-flags")

                self.policy_sources = Rsvp.RsbDetaileds.RsbDetailed.PolicySources()
                self.policy_sources.parent = self
                self._children_name_map["policy_sources"] = "policy-sources"
                self._children_yang_names.add("policy-sources")

                self.rsb_flags = Rsvp.RsbDetaileds.RsbDetailed.RsbFlags()
                self.rsb_flags.parent = self
                self._children_name_map["rsb_flags"] = "rsb-flags"
                self._children_yang_names.add("rsb-flags")

                self.s2l_sub_lsp = Rsvp.RsbDetaileds.RsbDetailed.S2LSubLsp()
                self.s2l_sub_lsp.parent = self
                self._children_name_map["s2l_sub_lsp"] = "s2l-sub-lsp"
                self._children_yang_names.add("s2l-sub-lsp")

                self.session = Rsvp.RsbDetaileds.RsbDetailed.Session()
                self.session.parent = self
                self._children_name_map["session"] = "session"
                self._children_yang_names.add("session")

                self.style = Rsvp.RsbDetaileds.RsbDetailed.Style()
                self.style.parent = self
                self._children_name_map["style"] = "style"
                self._children_yang_names.add("style")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("destination_address",
                                "destination_port",
                                "extended_tunnel_id",
                                "input_adjusted_interface",
                                "input_physical_interface",
                                "p2mp_id",
                                "protocol",
                                "session_type",
                                "source_address",
                                "source_port",
                                "sub_group_id",
                                "sub_group_origin",
                                "vrf_name") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Rsvp.RsbDetaileds.RsbDetailed, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Rsvp.RsbDetaileds.RsbDetailed, self).__setattr__(name, value)


            class FlowSpec(Entity):
                """
                Flow Spec Information
                
                .. attribute:: flow_average_rate
                
                	The Flow Average Rate in bytes per second
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: byte/s
                
                .. attribute:: flow_max_burst
                
                	The Flow Maximum Burst
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: flow_max_unit
                
                	The Flow Maximum Unit
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: flow_min_unit
                
                	The Flow Minimum Unit
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: flow_peak_rate
                
                	The Flow Peak Rate in bytes per second
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: byte/s
                
                .. attribute:: flow_qos
                
                	The Flow Quality of Service
                	**type**\:   :py:class:`RsvpMgmtQosServiceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtQosServiceEnum>`
                
                .. attribute:: flow_requested_rate
                
                	The Flow Requested Rate in bytes per second
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: byte/s
                
                .. attribute:: flow_slack
                
                	The Flow Slack
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.RsbDetaileds.RsbDetailed.FlowSpec, self).__init__()

                    self.yang_name = "flow-spec"
                    self.yang_parent_name = "rsb-detailed"

                    self.flow_average_rate = YLeaf(YType.uint64, "flow-average-rate")

                    self.flow_max_burst = YLeaf(YType.uint64, "flow-max-burst")

                    self.flow_max_unit = YLeaf(YType.uint32, "flow-max-unit")

                    self.flow_min_unit = YLeaf(YType.uint32, "flow-min-unit")

                    self.flow_peak_rate = YLeaf(YType.uint64, "flow-peak-rate")

                    self.flow_qos = YLeaf(YType.enumeration, "flow-qos")

                    self.flow_requested_rate = YLeaf(YType.uint64, "flow-requested-rate")

                    self.flow_slack = YLeaf(YType.uint32, "flow-slack")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("flow_average_rate",
                                    "flow_max_burst",
                                    "flow_max_unit",
                                    "flow_min_unit",
                                    "flow_peak_rate",
                                    "flow_qos",
                                    "flow_requested_rate",
                                    "flow_slack") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.RsbDetaileds.RsbDetailed.FlowSpec, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.RsbDetaileds.RsbDetailed.FlowSpec, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.flow_average_rate.is_set or
                        self.flow_max_burst.is_set or
                        self.flow_max_unit.is_set or
                        self.flow_min_unit.is_set or
                        self.flow_peak_rate.is_set or
                        self.flow_qos.is_set or
                        self.flow_requested_rate.is_set or
                        self.flow_slack.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.flow_average_rate.yfilter != YFilter.not_set or
                        self.flow_max_burst.yfilter != YFilter.not_set or
                        self.flow_max_unit.yfilter != YFilter.not_set or
                        self.flow_min_unit.yfilter != YFilter.not_set or
                        self.flow_peak_rate.yfilter != YFilter.not_set or
                        self.flow_qos.yfilter != YFilter.not_set or
                        self.flow_requested_rate.yfilter != YFilter.not_set or
                        self.flow_slack.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "flow-spec" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rsb-detaileds/rsb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.flow_average_rate.is_set or self.flow_average_rate.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_average_rate.get_name_leafdata())
                    if (self.flow_max_burst.is_set or self.flow_max_burst.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_max_burst.get_name_leafdata())
                    if (self.flow_max_unit.is_set or self.flow_max_unit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_max_unit.get_name_leafdata())
                    if (self.flow_min_unit.is_set or self.flow_min_unit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_min_unit.get_name_leafdata())
                    if (self.flow_peak_rate.is_set or self.flow_peak_rate.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_peak_rate.get_name_leafdata())
                    if (self.flow_qos.is_set or self.flow_qos.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_qos.get_name_leafdata())
                    if (self.flow_requested_rate.is_set or self.flow_requested_rate.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_requested_rate.get_name_leafdata())
                    if (self.flow_slack.is_set or self.flow_slack.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_slack.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "flow-average-rate" or name == "flow-max-burst" or name == "flow-max-unit" or name == "flow-min-unit" or name == "flow-peak-rate" or name == "flow-qos" or name == "flow-requested-rate" or name == "flow-slack"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "flow-average-rate"):
                        self.flow_average_rate = value
                        self.flow_average_rate.value_namespace = name_space
                        self.flow_average_rate.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-max-burst"):
                        self.flow_max_burst = value
                        self.flow_max_burst.value_namespace = name_space
                        self.flow_max_burst.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-max-unit"):
                        self.flow_max_unit = value
                        self.flow_max_unit.value_namespace = name_space
                        self.flow_max_unit.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-min-unit"):
                        self.flow_min_unit = value
                        self.flow_min_unit.value_namespace = name_space
                        self.flow_min_unit.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-peak-rate"):
                        self.flow_peak_rate = value
                        self.flow_peak_rate.value_namespace = name_space
                        self.flow_peak_rate.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-qos"):
                        self.flow_qos = value
                        self.flow_qos.value_namespace = name_space
                        self.flow_qos.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-requested-rate"):
                        self.flow_requested_rate = value
                        self.flow_requested_rate.value_namespace = name_space
                        self.flow_requested_rate.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-slack"):
                        self.flow_slack = value
                        self.flow_slack.value_namespace = name_space
                        self.flow_slack.value_namespace_prefix = name_space_prefix


            class GenericFlowSpec(Entity):
                """
                Generic Flow Spec Information
                
                .. attribute:: flow_spec_type
                
                	FlowSpecType
                	**type**\:   :py:class:`RsvpMgmtFlowSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtFlowSpec>`
                
                .. attribute:: g709otn_flow_spec
                
                	G709 OTN FlowSpec
                	**type**\:   :py:class:`G709OtnFlowSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RsbDetaileds.RsbDetailed.GenericFlowSpec.G709OtnFlowSpec>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.RsbDetaileds.RsbDetailed.GenericFlowSpec, self).__init__()

                    self.yang_name = "generic-flow-spec"
                    self.yang_parent_name = "rsb-detailed"

                    self.flow_spec_type = YLeaf(YType.enumeration, "flow-spec-type")

                    self.g709otn_flow_spec = Rsvp.RsbDetaileds.RsbDetailed.GenericFlowSpec.G709OtnFlowSpec()
                    self.g709otn_flow_spec.parent = self
                    self._children_name_map["g709otn_flow_spec"] = "g709otn-flow-spec"
                    self._children_yang_names.add("g709otn-flow-spec")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("flow_spec_type") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.RsbDetaileds.RsbDetailed.GenericFlowSpec, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.RsbDetaileds.RsbDetailed.GenericFlowSpec, self).__setattr__(name, value)


                class G709OtnFlowSpec(Entity):
                    """
                    G709 OTN FlowSpec
                    
                    .. attribute:: flow_bit_rate
                    
                    	G709 OTN Flow Bit Rate
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: flow_multiplier
                    
                    	G709 OTN Flow Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: flow_nvc
                    
                    	G709 OTN Flow NVC
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: flow_signal_type
                    
                    	G709 OTN Flow Signal Type (Refer G709 v3)
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.RsbDetaileds.RsbDetailed.GenericFlowSpec.G709OtnFlowSpec, self).__init__()

                        self.yang_name = "g709otn-flow-spec"
                        self.yang_parent_name = "generic-flow-spec"

                        self.flow_bit_rate = YLeaf(YType.uint64, "flow-bit-rate")

                        self.flow_multiplier = YLeaf(YType.uint16, "flow-multiplier")

                        self.flow_nvc = YLeaf(YType.uint16, "flow-nvc")

                        self.flow_signal_type = YLeaf(YType.uint8, "flow-signal-type")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("flow_bit_rate",
                                        "flow_multiplier",
                                        "flow_nvc",
                                        "flow_signal_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.RsbDetaileds.RsbDetailed.GenericFlowSpec.G709OtnFlowSpec, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.RsbDetaileds.RsbDetailed.GenericFlowSpec.G709OtnFlowSpec, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.flow_bit_rate.is_set or
                            self.flow_multiplier.is_set or
                            self.flow_nvc.is_set or
                            self.flow_signal_type.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.flow_bit_rate.yfilter != YFilter.not_set or
                            self.flow_multiplier.yfilter != YFilter.not_set or
                            self.flow_nvc.yfilter != YFilter.not_set or
                            self.flow_signal_type.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "g709otn-flow-spec" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rsb-detaileds/rsb-detailed/generic-flow-spec/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.flow_bit_rate.is_set or self.flow_bit_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.flow_bit_rate.get_name_leafdata())
                        if (self.flow_multiplier.is_set or self.flow_multiplier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.flow_multiplier.get_name_leafdata())
                        if (self.flow_nvc.is_set or self.flow_nvc.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.flow_nvc.get_name_leafdata())
                        if (self.flow_signal_type.is_set or self.flow_signal_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.flow_signal_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "flow-bit-rate" or name == "flow-multiplier" or name == "flow-nvc" or name == "flow-signal-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "flow-bit-rate"):
                            self.flow_bit_rate = value
                            self.flow_bit_rate.value_namespace = name_space
                            self.flow_bit_rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "flow-multiplier"):
                            self.flow_multiplier = value
                            self.flow_multiplier.value_namespace = name_space
                            self.flow_multiplier.value_namespace_prefix = name_space_prefix
                        if(value_path == "flow-nvc"):
                            self.flow_nvc = value
                            self.flow_nvc.value_namespace = name_space
                            self.flow_nvc.value_namespace_prefix = name_space_prefix
                        if(value_path == "flow-signal-type"):
                            self.flow_signal_type = value
                            self.flow_signal_type.value_namespace = name_space
                            self.flow_signal_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.flow_spec_type.is_set or
                        (self.g709otn_flow_spec is not None and self.g709otn_flow_spec.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.flow_spec_type.yfilter != YFilter.not_set or
                        (self.g709otn_flow_spec is not None and self.g709otn_flow_spec.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "generic-flow-spec" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rsb-detaileds/rsb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.flow_spec_type.is_set or self.flow_spec_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_spec_type.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "g709otn-flow-spec"):
                        if (self.g709otn_flow_spec is None):
                            self.g709otn_flow_spec = Rsvp.RsbDetaileds.RsbDetailed.GenericFlowSpec.G709OtnFlowSpec()
                            self.g709otn_flow_spec.parent = self
                            self._children_name_map["g709otn_flow_spec"] = "g709otn-flow-spec"
                        return self.g709otn_flow_spec

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "g709otn-flow-spec" or name == "flow-spec-type"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "flow-spec-type"):
                        self.flow_spec_type = value
                        self.flow_spec_type.value_namespace = name_space
                        self.flow_spec_type.value_namespace_prefix = name_space_prefix


            class Session(Entity):
                """
                RSVP Session Information
                
                .. attribute:: rsvp_session
                
                	RSVP Session
                	**type**\:   :py:class:`RsvpSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RsbDetaileds.RsbDetailed.Session.RsvpSession>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.RsbDetaileds.RsbDetailed.Session, self).__init__()

                    self.yang_name = "session"
                    self.yang_parent_name = "rsb-detailed"

                    self.rsvp_session = Rsvp.RsbDetaileds.RsbDetailed.Session.RsvpSession()
                    self.rsvp_session.parent = self
                    self._children_name_map["rsvp_session"] = "rsvp-session"
                    self._children_yang_names.add("rsvp-session")


                class RsvpSession(Entity):
                    """
                    RSVP Session
                    
                    .. attribute:: ipv4
                    
                    	UDP IPv4 session
                    	**type**\:   :py:class:`Ipv4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RsbDetaileds.RsbDetailed.Session.RsvpSession.Ipv4>`
                    
                    .. attribute:: ipv4_lsp_session
                    
                    	IPv4 LSP session
                    	**type**\:   :py:class:`Ipv4LspSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RsbDetaileds.RsbDetailed.Session.RsvpSession.Ipv4LspSession>`
                    
                    .. attribute:: ipv4_p2mp_lsp_session
                    
                    	IPv4 P2MP LSP session
                    	**type**\:   :py:class:`Ipv4P2MpLspSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RsbDetaileds.RsbDetailed.Session.RsvpSession.Ipv4P2MpLspSession>`
                    
                    .. attribute:: ipv4_uni_session
                    
                    	IPv4 UNI session
                    	**type**\:   :py:class:`Ipv4UniSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RsbDetaileds.RsbDetailed.Session.RsvpSession.Ipv4UniSession>`
                    
                    .. attribute:: session_type
                    
                    	SessionType
                    	**type**\:   :py:class:`RsvpMgmtSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtSession>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.RsbDetaileds.RsbDetailed.Session.RsvpSession, self).__init__()

                        self.yang_name = "rsvp-session"
                        self.yang_parent_name = "session"

                        self.session_type = YLeaf(YType.enumeration, "session-type")

                        self.ipv4 = Rsvp.RsbDetaileds.RsbDetailed.Session.RsvpSession.Ipv4()
                        self.ipv4.parent = self
                        self._children_name_map["ipv4"] = "ipv4"
                        self._children_yang_names.add("ipv4")

                        self.ipv4_lsp_session = Rsvp.RsbDetaileds.RsbDetailed.Session.RsvpSession.Ipv4LspSession()
                        self.ipv4_lsp_session.parent = self
                        self._children_name_map["ipv4_lsp_session"] = "ipv4-lsp-session"
                        self._children_yang_names.add("ipv4-lsp-session")

                        self.ipv4_p2mp_lsp_session = Rsvp.RsbDetaileds.RsbDetailed.Session.RsvpSession.Ipv4P2MpLspSession()
                        self.ipv4_p2mp_lsp_session.parent = self
                        self._children_name_map["ipv4_p2mp_lsp_session"] = "ipv4-p2mp-lsp-session"
                        self._children_yang_names.add("ipv4-p2mp-lsp-session")

                        self.ipv4_uni_session = Rsvp.RsbDetaileds.RsbDetailed.Session.RsvpSession.Ipv4UniSession()
                        self.ipv4_uni_session.parent = self
                        self._children_name_map["ipv4_uni_session"] = "ipv4-uni-session"
                        self._children_yang_names.add("ipv4-uni-session")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("session_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.RsbDetaileds.RsbDetailed.Session.RsvpSession, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.RsbDetaileds.RsbDetailed.Session.RsvpSession, self).__setattr__(name, value)


                    class Ipv4(Entity):
                        """
                        UDP IPv4 session
                        
                        .. attribute:: destination_address
                        
                        	Destination address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: destination_port
                        
                        	The Session Destination Port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: protocol
                        
                        	Protocol type (originally defined in RFC 790, further values in subsequent RFCs)
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.RsbDetaileds.RsbDetailed.Session.RsvpSession.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "rsvp-session"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.destination_port = YLeaf(YType.uint16, "destination-port")

                            self.protocol = YLeaf(YType.uint8, "protocol")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "destination_port",
                                            "protocol") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.RsbDetaileds.RsbDetailed.Session.RsvpSession.Ipv4, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.RsbDetaileds.RsbDetailed.Session.RsvpSession.Ipv4, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination_address.is_set or
                                self.destination_port.is_set or
                                self.protocol.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.destination_port.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rsb-detaileds/rsb-detailed/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.destination_port.is_set or self.destination_port.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_port.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "destination-port" or name == "protocol"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "destination-port"):
                                self.destination_port = value
                                self.destination_port.value_namespace = name_space
                                self.destination_port.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix


                    class Ipv4LspSession(Entity):
                        """
                        IPv4 LSP session
                        
                        .. attribute:: destination_address
                        
                        	Destination address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: extended_tunnel_id
                        
                        	The Session Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: tunnel_id
                        
                        	The Session Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.RsbDetaileds.RsbDetailed.Session.RsvpSession.Ipv4LspSession, self).__init__()

                            self.yang_name = "ipv4-lsp-session"
                            self.yang_parent_name = "rsvp-session"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                            self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "extended_tunnel_id",
                                            "tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.RsbDetaileds.RsbDetailed.Session.RsvpSession.Ipv4LspSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.RsbDetaileds.RsbDetailed.Session.RsvpSession.Ipv4LspSession, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination_address.is_set or
                                self.extended_tunnel_id.is_set or
                                self.tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.extended_tunnel_id.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-lsp-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rsb-detaileds/rsb-detailed/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "extended-tunnel-id" or name == "tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "extended-tunnel-id"):
                                self.extended_tunnel_id = value
                                self.extended_tunnel_id.value_namespace = name_space
                                self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix


                    class Ipv4UniSession(Entity):
                        """
                        IPv4 UNI session
                        
                        .. attribute:: destination_address
                        
                        	Destination address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: extended_address
                        
                        	The Session Extended Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: tunnel_id
                        
                        	The Session Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.RsbDetaileds.RsbDetailed.Session.RsvpSession.Ipv4UniSession, self).__init__()

                            self.yang_name = "ipv4-uni-session"
                            self.yang_parent_name = "rsvp-session"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.extended_address = YLeaf(YType.str, "extended-address")

                            self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "extended_address",
                                            "tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.RsbDetaileds.RsbDetailed.Session.RsvpSession.Ipv4UniSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.RsbDetaileds.RsbDetailed.Session.RsvpSession.Ipv4UniSession, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination_address.is_set or
                                self.extended_address.is_set or
                                self.tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.extended_address.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-uni-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rsb-detaileds/rsb-detailed/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.extended_address.is_set or self.extended_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_address.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "extended-address" or name == "tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "extended-address"):
                                self.extended_address = value
                                self.extended_address.value_namespace = name_space
                                self.extended_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix


                    class Ipv4P2MpLspSession(Entity):
                        """
                        IPv4 P2MP LSP session
                        
                        .. attribute:: extended_tunnel_id
                        
                        	The Session Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: p2mp_id
                        
                        	The Point to Multipoint ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tunnel_id
                        
                        	The Session Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.RsbDetaileds.RsbDetailed.Session.RsvpSession.Ipv4P2MpLspSession, self).__init__()

                            self.yang_name = "ipv4-p2mp-lsp-session"
                            self.yang_parent_name = "rsvp-session"

                            self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                            self.p2mp_id = YLeaf(YType.uint32, "p2mp-id")

                            self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("extended_tunnel_id",
                                            "p2mp_id",
                                            "tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.RsbDetaileds.RsbDetailed.Session.RsvpSession.Ipv4P2MpLspSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.RsbDetaileds.RsbDetailed.Session.RsvpSession.Ipv4P2MpLspSession, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.extended_tunnel_id.is_set or
                                self.p2mp_id.is_set or
                                self.tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.extended_tunnel_id.yfilter != YFilter.not_set or
                                self.p2mp_id.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-p2mp-lsp-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rsb-detaileds/rsb-detailed/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                            if (self.p2mp_id.is_set or self.p2mp_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.p2mp_id.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "extended-tunnel-id" or name == "p2mp-id" or name == "tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "extended-tunnel-id"):
                                self.extended_tunnel_id = value
                                self.extended_tunnel_id.value_namespace = name_space
                                self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "p2mp-id"):
                                self.p2mp_id = value
                                self.p2mp_id.value_namespace = name_space
                                self.p2mp_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.session_type.is_set or
                            (self.ipv4 is not None and self.ipv4.has_data()) or
                            (self.ipv4_lsp_session is not None and self.ipv4_lsp_session.has_data()) or
                            (self.ipv4_p2mp_lsp_session is not None and self.ipv4_p2mp_lsp_session.has_data()) or
                            (self.ipv4_uni_session is not None and self.ipv4_uni_session.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.session_type.yfilter != YFilter.not_set or
                            (self.ipv4 is not None and self.ipv4.has_operation()) or
                            (self.ipv4_lsp_session is not None and self.ipv4_lsp_session.has_operation()) or
                            (self.ipv4_p2mp_lsp_session is not None and self.ipv4_p2mp_lsp_session.has_operation()) or
                            (self.ipv4_uni_session is not None and self.ipv4_uni_session.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rsvp-session" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rsb-detaileds/rsb-detailed/session/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.session_type.is_set or self.session_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.session_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "ipv4"):
                            if (self.ipv4 is None):
                                self.ipv4 = Rsvp.RsbDetaileds.RsbDetailed.Session.RsvpSession.Ipv4()
                                self.ipv4.parent = self
                                self._children_name_map["ipv4"] = "ipv4"
                            return self.ipv4

                        if (child_yang_name == "ipv4-lsp-session"):
                            if (self.ipv4_lsp_session is None):
                                self.ipv4_lsp_session = Rsvp.RsbDetaileds.RsbDetailed.Session.RsvpSession.Ipv4LspSession()
                                self.ipv4_lsp_session.parent = self
                                self._children_name_map["ipv4_lsp_session"] = "ipv4-lsp-session"
                            return self.ipv4_lsp_session

                        if (child_yang_name == "ipv4-p2mp-lsp-session"):
                            if (self.ipv4_p2mp_lsp_session is None):
                                self.ipv4_p2mp_lsp_session = Rsvp.RsbDetaileds.RsbDetailed.Session.RsvpSession.Ipv4P2MpLspSession()
                                self.ipv4_p2mp_lsp_session.parent = self
                                self._children_name_map["ipv4_p2mp_lsp_session"] = "ipv4-p2mp-lsp-session"
                            return self.ipv4_p2mp_lsp_session

                        if (child_yang_name == "ipv4-uni-session"):
                            if (self.ipv4_uni_session is None):
                                self.ipv4_uni_session = Rsvp.RsbDetaileds.RsbDetailed.Session.RsvpSession.Ipv4UniSession()
                                self.ipv4_uni_session.parent = self
                                self._children_name_map["ipv4_uni_session"] = "ipv4-uni-session"
                            return self.ipv4_uni_session

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ipv4" or name == "ipv4-lsp-session" or name == "ipv4-p2mp-lsp-session" or name == "ipv4-uni-session" or name == "session-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "session-type"):
                            self.session_type = value
                            self.session_type.value_namespace = name_space
                            self.session_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (self.rsvp_session is not None and self.rsvp_session.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.rsvp_session is not None and self.rsvp_session.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "session" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rsb-detaileds/rsb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "rsvp-session"):
                        if (self.rsvp_session is None):
                            self.rsvp_session = Rsvp.RsbDetaileds.RsbDetailed.Session.RsvpSession()
                            self.rsvp_session.parent = self
                            self._children_name_map["rsvp_session"] = "rsvp-session"
                        return self.rsvp_session

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "rsvp-session"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class S2LSubLsp(Entity):
                """
                RSVP S2L Sub\-LSP information
                
                .. attribute:: s2l_destination_address
                
                	S2L Sub\-LSP Destination Address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.RsbDetaileds.RsbDetailed.S2LSubLsp, self).__init__()

                    self.yang_name = "s2l-sub-lsp"
                    self.yang_parent_name = "rsb-detailed"

                    self.s2l_destination_address = YLeaf(YType.str, "s2l-destination-address")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("s2l_destination_address") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.RsbDetaileds.RsbDetailed.S2LSubLsp, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.RsbDetaileds.RsbDetailed.S2LSubLsp, self).__setattr__(name, value)

                def has_data(self):
                    return self.s2l_destination_address.is_set

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.s2l_destination_address.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "s2l-sub-lsp" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rsb-detaileds/rsb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.s2l_destination_address.is_set or self.s2l_destination_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.s2l_destination_address.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "s2l-destination-address"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "s2l-destination-address"):
                        self.s2l_destination_address = value
                        self.s2l_destination_address.value_namespace = name_space
                        self.s2l_destination_address.value_namespace_prefix = name_space_prefix


            class Style(Entity):
                """
                RSVP Style
                
                .. attribute:: reservation_type
                
                	The Reservation Type\: WF, SE or FF
                	**type**\:   :py:class:`RsvpMgmtReservationTypeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtReservationTypeEnum>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.RsbDetaileds.RsbDetailed.Style, self).__init__()

                    self.yang_name = "style"
                    self.yang_parent_name = "rsb-detailed"

                    self.reservation_type = YLeaf(YType.enumeration, "reservation-type")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("reservation_type") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.RsbDetaileds.RsbDetailed.Style, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.RsbDetaileds.RsbDetailed.Style, self).__setattr__(name, value)

                def has_data(self):
                    return self.reservation_type.is_set

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.reservation_type.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "style" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rsb-detaileds/rsb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.reservation_type.is_set or self.reservation_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reservation_type.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "reservation-type"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "reservation-type"):
                        self.reservation_type = value
                        self.reservation_type.value_namespace = name_space
                        self.reservation_type.value_namespace_prefix = name_space_prefix


            class Filter(Entity):
                """
                RSVP Filter
                
                .. attribute:: rsvp_filter
                
                	RSVP Filter
                	**type**\:   :py:class:`RsvpFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RsbDetaileds.RsbDetailed.Filter.RsvpFilter>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.RsbDetaileds.RsbDetailed.Filter, self).__init__()

                    self.yang_name = "filter"
                    self.yang_parent_name = "rsb-detailed"

                    self.rsvp_filter = Rsvp.RsbDetaileds.RsbDetailed.Filter.RsvpFilter()
                    self.rsvp_filter.parent = self
                    self._children_name_map["rsvp_filter"] = "rsvp-filter"
                    self._children_yang_names.add("rsvp-filter")


                class RsvpFilter(Entity):
                    """
                    RSVP Filter
                    
                    .. attribute:: filter_type
                    
                    	FilterType
                    	**type**\:   :py:class:`RsvpMgmtFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtFilter>`
                    
                    .. attribute:: p2mp_ipv4_session
                    
                    	IPv4 P2MP LSP FilterSpec
                    	**type**\:   :py:class:`P2MpIpv4Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RsbDetaileds.RsbDetailed.Filter.RsvpFilter.P2MpIpv4Session>`
                    
                    .. attribute:: udp_ipv4_session
                    
                    	UDP IPV4 FilterSpec
                    	**type**\:   :py:class:`UdpIpv4Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RsbDetaileds.RsbDetailed.Filter.RsvpFilter.UdpIpv4Session>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.RsbDetaileds.RsbDetailed.Filter.RsvpFilter, self).__init__()

                        self.yang_name = "rsvp-filter"
                        self.yang_parent_name = "filter"

                        self.filter_type = YLeaf(YType.enumeration, "filter-type")

                        self.p2mp_ipv4_session = Rsvp.RsbDetaileds.RsbDetailed.Filter.RsvpFilter.P2MpIpv4Session()
                        self.p2mp_ipv4_session.parent = self
                        self._children_name_map["p2mp_ipv4_session"] = "p2mp-ipv4-session"
                        self._children_yang_names.add("p2mp-ipv4-session")

                        self.udp_ipv4_session = Rsvp.RsbDetaileds.RsbDetailed.Filter.RsvpFilter.UdpIpv4Session()
                        self.udp_ipv4_session.parent = self
                        self._children_name_map["udp_ipv4_session"] = "udp-ipv4-session"
                        self._children_yang_names.add("udp-ipv4-session")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("filter_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.RsbDetaileds.RsbDetailed.Filter.RsvpFilter, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.RsbDetaileds.RsbDetailed.Filter.RsvpFilter, self).__setattr__(name, value)


                    class UdpIpv4Session(Entity):
                        """
                        UDP IPV4 FilterSpec
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source_port
                        
                        	Source Port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.RsbDetaileds.RsbDetailed.Filter.RsvpFilter.UdpIpv4Session, self).__init__()

                            self.yang_name = "udp-ipv4-session"
                            self.yang_parent_name = "rsvp-filter"

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.source_port = YLeaf(YType.uint16, "source-port")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("source_address",
                                            "source_port") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.RsbDetaileds.RsbDetailed.Filter.RsvpFilter.UdpIpv4Session, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.RsbDetaileds.RsbDetailed.Filter.RsvpFilter.UdpIpv4Session, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.source_address.is_set or
                                self.source_port.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                self.source_port.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "udp-ipv4-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rsb-detaileds/rsb-detailed/filter/rsvp-filter/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())
                            if (self.source_port.is_set or self.source_port.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_port.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "source-address" or name == "source-port"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-port"):
                                self.source_port = value
                                self.source_port.value_namespace = name_space
                                self.source_port.value_namespace_prefix = name_space_prefix


                    class P2MpIpv4Session(Entity):
                        """
                        IPv4 P2MP LSP FilterSpec
                        
                        .. attribute:: p2mp_sub_group_origin
                        
                        	Point to Multipoint SubGroup Origin
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source_port
                        
                        	Source Port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: sub_group_id
                        
                        	Point to Multipoint Subgroup ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.RsbDetaileds.RsbDetailed.Filter.RsvpFilter.P2MpIpv4Session, self).__init__()

                            self.yang_name = "p2mp-ipv4-session"
                            self.yang_parent_name = "rsvp-filter"

                            self.p2mp_sub_group_origin = YLeaf(YType.str, "p2mp-sub-group-origin")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.source_port = YLeaf(YType.uint16, "source-port")

                            self.sub_group_id = YLeaf(YType.uint16, "sub-group-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("p2mp_sub_group_origin",
                                            "source_address",
                                            "source_port",
                                            "sub_group_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.RsbDetaileds.RsbDetailed.Filter.RsvpFilter.P2MpIpv4Session, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.RsbDetaileds.RsbDetailed.Filter.RsvpFilter.P2MpIpv4Session, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.p2mp_sub_group_origin.is_set or
                                self.source_address.is_set or
                                self.source_port.is_set or
                                self.sub_group_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.p2mp_sub_group_origin.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                self.source_port.yfilter != YFilter.not_set or
                                self.sub_group_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "p2mp-ipv4-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rsb-detaileds/rsb-detailed/filter/rsvp-filter/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.p2mp_sub_group_origin.is_set or self.p2mp_sub_group_origin.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.p2mp_sub_group_origin.get_name_leafdata())
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())
                            if (self.source_port.is_set or self.source_port.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_port.get_name_leafdata())
                            if (self.sub_group_id.is_set or self.sub_group_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sub_group_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "p2mp-sub-group-origin" or name == "source-address" or name == "source-port" or name == "sub-group-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "p2mp-sub-group-origin"):
                                self.p2mp_sub_group_origin = value
                                self.p2mp_sub_group_origin.value_namespace = name_space
                                self.p2mp_sub_group_origin.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-port"):
                                self.source_port = value
                                self.source_port.value_namespace = name_space
                                self.source_port.value_namespace_prefix = name_space_prefix
                            if(value_path == "sub-group-id"):
                                self.sub_group_id = value
                                self.sub_group_id.value_namespace = name_space
                                self.sub_group_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.filter_type.is_set or
                            (self.p2mp_ipv4_session is not None and self.p2mp_ipv4_session.has_data()) or
                            (self.udp_ipv4_session is not None and self.udp_ipv4_session.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.filter_type.yfilter != YFilter.not_set or
                            (self.p2mp_ipv4_session is not None and self.p2mp_ipv4_session.has_operation()) or
                            (self.udp_ipv4_session is not None and self.udp_ipv4_session.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rsvp-filter" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rsb-detaileds/rsb-detailed/filter/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.filter_type.is_set or self.filter_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.filter_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "p2mp-ipv4-session"):
                            if (self.p2mp_ipv4_session is None):
                                self.p2mp_ipv4_session = Rsvp.RsbDetaileds.RsbDetailed.Filter.RsvpFilter.P2MpIpv4Session()
                                self.p2mp_ipv4_session.parent = self
                                self._children_name_map["p2mp_ipv4_session"] = "p2mp-ipv4-session"
                            return self.p2mp_ipv4_session

                        if (child_yang_name == "udp-ipv4-session"):
                            if (self.udp_ipv4_session is None):
                                self.udp_ipv4_session = Rsvp.RsbDetaileds.RsbDetailed.Filter.RsvpFilter.UdpIpv4Session()
                                self.udp_ipv4_session.parent = self
                                self._children_name_map["udp_ipv4_session"] = "udp-ipv4-session"
                            return self.udp_ipv4_session

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "p2mp-ipv4-session" or name == "udp-ipv4-session" or name == "filter-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "filter-type"):
                            self.filter_type = value
                            self.filter_type.value_namespace = name_space
                            self.filter_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (self.rsvp_filter is not None and self.rsvp_filter.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.rsvp_filter is not None and self.rsvp_filter.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "filter" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rsb-detaileds/rsb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "rsvp-filter"):
                        if (self.rsvp_filter is None):
                            self.rsvp_filter = Rsvp.RsbDetaileds.RsbDetailed.Filter.RsvpFilter()
                            self.rsvp_filter.parent = self
                            self._children_name_map["rsvp_filter"] = "rsvp-filter"
                        return self.rsvp_filter

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "rsvp-filter"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class RsbFlags(Entity):
                """
                Reservation State Block Flags
                
                .. attribute:: is_local_receiver
                
                	Local Receiver
                	**type**\:  bool
                
                .. attribute:: is_local_repair
                
                	Rerouted
                	**type**\:  bool
                
                .. attribute:: is_lockout
                
                	Locked Out
                	**type**\:  bool
                
                .. attribute:: is_merge_point
                
                	Is node a Merge Point
                	**type**\:  bool
                
                .. attribute:: is_message_id_valid
                
                	MessageID Valid
                	**type**\:  bool
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.RsbDetaileds.RsbDetailed.RsbFlags, self).__init__()

                    self.yang_name = "rsb-flags"
                    self.yang_parent_name = "rsb-detailed"

                    self.is_local_receiver = YLeaf(YType.boolean, "is-local-receiver")

                    self.is_local_repair = YLeaf(YType.boolean, "is-local-repair")

                    self.is_lockout = YLeaf(YType.boolean, "is-lockout")

                    self.is_merge_point = YLeaf(YType.boolean, "is-merge-point")

                    self.is_message_id_valid = YLeaf(YType.boolean, "is-message-id-valid")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("is_local_receiver",
                                    "is_local_repair",
                                    "is_lockout",
                                    "is_merge_point",
                                    "is_message_id_valid") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.RsbDetaileds.RsbDetailed.RsbFlags, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.RsbDetaileds.RsbDetailed.RsbFlags, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.is_local_receiver.is_set or
                        self.is_local_repair.is_set or
                        self.is_lockout.is_set or
                        self.is_merge_point.is_set or
                        self.is_message_id_valid.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.is_local_receiver.yfilter != YFilter.not_set or
                        self.is_local_repair.yfilter != YFilter.not_set or
                        self.is_lockout.yfilter != YFilter.not_set or
                        self.is_merge_point.yfilter != YFilter.not_set or
                        self.is_message_id_valid.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "rsb-flags" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rsb-detaileds/rsb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.is_local_receiver.is_set or self.is_local_receiver.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_local_receiver.get_name_leafdata())
                    if (self.is_local_repair.is_set or self.is_local_repair.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_local_repair.get_name_leafdata())
                    if (self.is_lockout.is_set or self.is_lockout.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_lockout.get_name_leafdata())
                    if (self.is_merge_point.is_set or self.is_merge_point.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_merge_point.get_name_leafdata())
                    if (self.is_message_id_valid.is_set or self.is_message_id_valid.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_message_id_valid.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "is-local-receiver" or name == "is-local-repair" or name == "is-lockout" or name == "is-merge-point" or name == "is-message-id-valid"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "is-local-receiver"):
                        self.is_local_receiver = value
                        self.is_local_receiver.value_namespace = name_space
                        self.is_local_receiver.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-local-repair"):
                        self.is_local_repair = value
                        self.is_local_repair.value_namespace = name_space
                        self.is_local_repair.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-lockout"):
                        self.is_lockout = value
                        self.is_lockout.value_namespace = name_space
                        self.is_lockout.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-merge-point"):
                        self.is_merge_point = value
                        self.is_merge_point.value_namespace = name_space
                        self.is_merge_point.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-message-id-valid"):
                        self.is_message_id_valid = value
                        self.is_message_id_valid.value_namespace = name_space
                        self.is_message_id_valid.value_namespace_prefix = name_space_prefix


            class Hop(Entity):
                """
                Hop Infomation
                
                .. attribute:: neighbor_address
                
                	IP address of the neighbor
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: neighbor_logical_interface_name
                
                	Neighbor Logical Interface Name
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.RsbDetaileds.RsbDetailed.Hop, self).__init__()

                    self.yang_name = "hop"
                    self.yang_parent_name = "rsb-detailed"

                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                    self.neighbor_logical_interface_name = YLeaf(YType.str, "neighbor-logical-interface-name")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("neighbor_address",
                                    "neighbor_logical_interface_name") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.RsbDetaileds.RsbDetailed.Hop, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.RsbDetaileds.RsbDetailed.Hop, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.neighbor_address.is_set or
                        self.neighbor_logical_interface_name.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.neighbor_address.yfilter != YFilter.not_set or
                        self.neighbor_logical_interface_name.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "hop" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rsb-detaileds/rsb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                    if (self.neighbor_logical_interface_name.is_set or self.neighbor_logical_interface_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.neighbor_logical_interface_name.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "neighbor-address" or name == "neighbor-logical-interface-name"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "neighbor-address"):
                        self.neighbor_address = value
                        self.neighbor_address.value_namespace = name_space
                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "neighbor-logical-interface-name"):
                        self.neighbor_logical_interface_name = value
                        self.neighbor_logical_interface_name.value_namespace = name_space
                        self.neighbor_logical_interface_name.value_namespace_prefix = name_space_prefix


            class PolicySources(Entity):
                """
                RSVP Policy Sources
                
                .. attribute:: is_cable
                
                	Policy Source is Cable
                	**type**\:  bool
                
                .. attribute:: is_cops
                
                	Policy Source is COPS
                	**type**\:  bool
                
                .. attribute:: is_default
                
                	Policy Source is Default
                	**type**\:  bool
                
                .. attribute:: is_local
                
                	Policy Source is Local
                	**type**\:  bool
                
                .. attribute:: is_te_link
                
                	Policy Source is TE Link
                	**type**\:  bool
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.RsbDetaileds.RsbDetailed.PolicySources, self).__init__()

                    self.yang_name = "policy-sources"
                    self.yang_parent_name = "rsb-detailed"

                    self.is_cable = YLeaf(YType.boolean, "is-cable")

                    self.is_cops = YLeaf(YType.boolean, "is-cops")

                    self.is_default = YLeaf(YType.boolean, "is-default")

                    self.is_local = YLeaf(YType.boolean, "is-local")

                    self.is_te_link = YLeaf(YType.boolean, "is-te-link")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("is_cable",
                                    "is_cops",
                                    "is_default",
                                    "is_local",
                                    "is_te_link") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.RsbDetaileds.RsbDetailed.PolicySources, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.RsbDetaileds.RsbDetailed.PolicySources, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.is_cable.is_set or
                        self.is_cops.is_set or
                        self.is_default.is_set or
                        self.is_local.is_set or
                        self.is_te_link.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.is_cable.yfilter != YFilter.not_set or
                        self.is_cops.yfilter != YFilter.not_set or
                        self.is_default.yfilter != YFilter.not_set or
                        self.is_local.yfilter != YFilter.not_set or
                        self.is_te_link.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "policy-sources" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rsb-detaileds/rsb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.is_cable.is_set or self.is_cable.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_cable.get_name_leafdata())
                    if (self.is_cops.is_set or self.is_cops.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_cops.get_name_leafdata())
                    if (self.is_default.is_set or self.is_default.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_default.get_name_leafdata())
                    if (self.is_local.is_set or self.is_local.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_local.get_name_leafdata())
                    if (self.is_te_link.is_set or self.is_te_link.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_te_link.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "is-cable" or name == "is-cops" or name == "is-default" or name == "is-local" or name == "is-te-link"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "is-cable"):
                        self.is_cable = value
                        self.is_cable.value_namespace = name_space
                        self.is_cable.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-cops"):
                        self.is_cops = value
                        self.is_cops.value_namespace = name_space
                        self.is_cops.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-default"):
                        self.is_default = value
                        self.is_default.value_namespace = name_space
                        self.is_default.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-local"):
                        self.is_local = value
                        self.is_local.value_namespace = name_space
                        self.is_local.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-te-link"):
                        self.is_te_link = value
                        self.is_te_link.value_namespace = name_space
                        self.is_te_link.value_namespace_prefix = name_space_prefix


            class Header(Entity):
                """
                RSVP Header Information
                
                .. attribute:: ip_source_address
                
                	IP Source Address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: ip_tos
                
                	IP Type of Service
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: ip_ttl
                
                	IP TTL
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: rsvp_header_flags
                
                	RSVP Header Flags (defined in RFC2205 Section 3 .1.1)
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: rsvp_message_type
                
                	RSVP Message Type
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: rsvp_ttl
                
                	RSVP TTL
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: rsvp_version
                
                	RSVP Version
                	**type**\:  int
                
                	**range:** 0..255
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.RsbDetaileds.RsbDetailed.Header, self).__init__()

                    self.yang_name = "header"
                    self.yang_parent_name = "rsb-detailed"

                    self.ip_source_address = YLeaf(YType.str, "ip-source-address")

                    self.ip_tos = YLeaf(YType.uint8, "ip-tos")

                    self.ip_ttl = YLeaf(YType.uint8, "ip-ttl")

                    self.rsvp_header_flags = YLeaf(YType.uint8, "rsvp-header-flags")

                    self.rsvp_message_type = YLeaf(YType.uint8, "rsvp-message-type")

                    self.rsvp_ttl = YLeaf(YType.uint8, "rsvp-ttl")

                    self.rsvp_version = YLeaf(YType.uint8, "rsvp-version")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("ip_source_address",
                                    "ip_tos",
                                    "ip_ttl",
                                    "rsvp_header_flags",
                                    "rsvp_message_type",
                                    "rsvp_ttl",
                                    "rsvp_version") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.RsbDetaileds.RsbDetailed.Header, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.RsbDetaileds.RsbDetailed.Header, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.ip_source_address.is_set or
                        self.ip_tos.is_set or
                        self.ip_ttl.is_set or
                        self.rsvp_header_flags.is_set or
                        self.rsvp_message_type.is_set or
                        self.rsvp_ttl.is_set or
                        self.rsvp_version.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.ip_source_address.yfilter != YFilter.not_set or
                        self.ip_tos.yfilter != YFilter.not_set or
                        self.ip_ttl.yfilter != YFilter.not_set or
                        self.rsvp_header_flags.yfilter != YFilter.not_set or
                        self.rsvp_message_type.yfilter != YFilter.not_set or
                        self.rsvp_ttl.yfilter != YFilter.not_set or
                        self.rsvp_version.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "header" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rsb-detaileds/rsb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.ip_source_address.is_set or self.ip_source_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ip_source_address.get_name_leafdata())
                    if (self.ip_tos.is_set or self.ip_tos.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ip_tos.get_name_leafdata())
                    if (self.ip_ttl.is_set or self.ip_ttl.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ip_ttl.get_name_leafdata())
                    if (self.rsvp_header_flags.is_set or self.rsvp_header_flags.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_header_flags.get_name_leafdata())
                    if (self.rsvp_message_type.is_set or self.rsvp_message_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_message_type.get_name_leafdata())
                    if (self.rsvp_ttl.is_set or self.rsvp_ttl.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_ttl.get_name_leafdata())
                    if (self.rsvp_version.is_set or self.rsvp_version.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_version.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ip-source-address" or name == "ip-tos" or name == "ip-ttl" or name == "rsvp-header-flags" or name == "rsvp-message-type" or name == "rsvp-ttl" or name == "rsvp-version"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "ip-source-address"):
                        self.ip_source_address = value
                        self.ip_source_address.value_namespace = name_space
                        self.ip_source_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "ip-tos"):
                        self.ip_tos = value
                        self.ip_tos.value_namespace = name_space
                        self.ip_tos.value_namespace_prefix = name_space_prefix
                    if(value_path == "ip-ttl"):
                        self.ip_ttl = value
                        self.ip_ttl.value_namespace = name_space
                        self.ip_ttl.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-header-flags"):
                        self.rsvp_header_flags = value
                        self.rsvp_header_flags.value_namespace = name_space
                        self.rsvp_header_flags.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-message-type"):
                        self.rsvp_message_type = value
                        self.rsvp_message_type.value_namespace = name_space
                        self.rsvp_message_type.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-ttl"):
                        self.rsvp_ttl = value
                        self.rsvp_ttl.value_namespace = name_space
                        self.rsvp_ttl.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-version"):
                        self.rsvp_version = value
                        self.rsvp_version.value_namespace = name_space
                        self.rsvp_version.value_namespace_prefix = name_space_prefix


            class PolicyFlags(Entity):
                """
                RSVP Policy Flags
                
                .. attribute:: is_accepted
                
                	Accepted
                	**type**\:  bool
                
                .. attribute:: is_forwarding
                
                	Forwarding
                	**type**\:  bool
                
                .. attribute:: is_installed
                
                	Installed
                	**type**\:  bool
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.RsbDetaileds.RsbDetailed.PolicyFlags, self).__init__()

                    self.yang_name = "policy-flags"
                    self.yang_parent_name = "rsb-detailed"

                    self.is_accepted = YLeaf(YType.boolean, "is-accepted")

                    self.is_forwarding = YLeaf(YType.boolean, "is-forwarding")

                    self.is_installed = YLeaf(YType.boolean, "is-installed")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("is_accepted",
                                    "is_forwarding",
                                    "is_installed") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.RsbDetaileds.RsbDetailed.PolicyFlags, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.RsbDetaileds.RsbDetailed.PolicyFlags, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.is_accepted.is_set or
                        self.is_forwarding.is_set or
                        self.is_installed.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.is_accepted.yfilter != YFilter.not_set or
                        self.is_forwarding.yfilter != YFilter.not_set or
                        self.is_installed.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "policy-flags" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rsb-detaileds/rsb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.is_accepted.is_set or self.is_accepted.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_accepted.get_name_leafdata())
                    if (self.is_forwarding.is_set or self.is_forwarding.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_forwarding.get_name_leafdata())
                    if (self.is_installed.is_set or self.is_installed.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_installed.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "is-accepted" or name == "is-forwarding" or name == "is-installed"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "is-accepted"):
                        self.is_accepted = value
                        self.is_accepted.value_namespace = name_space
                        self.is_accepted.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-forwarding"):
                        self.is_forwarding = value
                        self.is_forwarding.value_namespace = name_space
                        self.is_forwarding.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-installed"):
                        self.is_installed = value
                        self.is_installed.value_namespace = name_space
                        self.is_installed.value_namespace_prefix = name_space_prefix


            class ExpiryTime(Entity):
                """
                Expiry Time
                
                .. attribute:: nanoseconds
                
                	Time Value in Nano\-seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: nanosecond
                
                .. attribute:: seconds
                
                	Time Value in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.RsbDetaileds.RsbDetailed.ExpiryTime, self).__init__()

                    self.yang_name = "expiry-time"
                    self.yang_parent_name = "rsb-detailed"

                    self.nanoseconds = YLeaf(YType.int32, "nanoseconds")

                    self.seconds = YLeaf(YType.int32, "seconds")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("nanoseconds",
                                    "seconds") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.RsbDetaileds.RsbDetailed.ExpiryTime, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.RsbDetaileds.RsbDetailed.ExpiryTime, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.nanoseconds.is_set or
                        self.seconds.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.nanoseconds.yfilter != YFilter.not_set or
                        self.seconds.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "expiry-time" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rsb-detaileds/rsb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.nanoseconds.is_set or self.nanoseconds.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.nanoseconds.get_name_leafdata())
                    if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.seconds.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "nanoseconds" or name == "seconds"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "nanoseconds"):
                        self.nanoseconds = value
                        self.nanoseconds.value_namespace = name_space
                        self.nanoseconds.value_namespace_prefix = name_space_prefix
                    if(value_path == "seconds"):
                        self.seconds = value
                        self.seconds.value_namespace = name_space
                        self.seconds.value_namespace_prefix = name_space_prefix


            class PolicyQueryFlags(Entity):
                """
                RSVP Query Flags
                
                .. attribute:: is_bypass
                
                	Bypass
                	**type**\:  bool
                
                .. attribute:: is_needed
                
                	Needed
                	**type**\:  bool
                
                .. attribute:: is_report_required
                
                	Report Required
                	**type**\:  bool
                
                .. attribute:: is_resync
                
                	Resynchronization
                	**type**\:  bool
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.RsbDetaileds.RsbDetailed.PolicyQueryFlags, self).__init__()

                    self.yang_name = "policy-query-flags"
                    self.yang_parent_name = "rsb-detailed"

                    self.is_bypass = YLeaf(YType.boolean, "is-bypass")

                    self.is_needed = YLeaf(YType.boolean, "is-needed")

                    self.is_report_required = YLeaf(YType.boolean, "is-report-required")

                    self.is_resync = YLeaf(YType.boolean, "is-resync")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("is_bypass",
                                    "is_needed",
                                    "is_report_required",
                                    "is_resync") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.RsbDetaileds.RsbDetailed.PolicyQueryFlags, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.RsbDetaileds.RsbDetailed.PolicyQueryFlags, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.is_bypass.is_set or
                        self.is_needed.is_set or
                        self.is_report_required.is_set or
                        self.is_resync.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.is_bypass.yfilter != YFilter.not_set or
                        self.is_needed.yfilter != YFilter.not_set or
                        self.is_report_required.yfilter != YFilter.not_set or
                        self.is_resync.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "policy-query-flags" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rsb-detaileds/rsb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.is_bypass.is_set or self.is_bypass.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_bypass.get_name_leafdata())
                    if (self.is_needed.is_set or self.is_needed.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_needed.get_name_leafdata())
                    if (self.is_report_required.is_set or self.is_report_required.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_report_required.get_name_leafdata())
                    if (self.is_resync.is_set or self.is_resync.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_resync.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "is-bypass" or name == "is-needed" or name == "is-report-required" or name == "is-resync"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "is-bypass"):
                        self.is_bypass = value
                        self.is_bypass.value_namespace = name_space
                        self.is_bypass.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-needed"):
                        self.is_needed = value
                        self.is_needed.value_namespace = name_space
                        self.is_needed.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-report-required"):
                        self.is_report_required = value
                        self.is_report_required.value_namespace = name_space
                        self.is_report_required.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-resync"):
                        self.is_resync = value
                        self.is_resync.value_namespace = name_space
                        self.is_resync.value_namespace_prefix = name_space_prefix


            class LabelInfo(Entity):
                """
                Label Information
                
                .. attribute:: generic_local_downstream_label
                
                	Generic Local Downstream Label
                	**type**\:   :py:class:`GenericLocalDownstreamLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericLocalDownstreamLabel>`
                
                .. attribute:: generic_local_upstream_label
                
                	Generic Local Upstream Label
                	**type**\:   :py:class:`GenericLocalUpstreamLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericLocalUpstreamLabel>`
                
                .. attribute:: generic_merge_point_label
                
                	Generic MergePoint Label
                	**type**\:   :py:class:`GenericMergePointLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericMergePointLabel>`
                
                .. attribute:: generic_outgoing_downstream_label
                
                	Generic Outgoing Downstream Label
                	**type**\:   :py:class:`GenericOutgoingDownstreamLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericOutgoingDownstreamLabel>`
                
                .. attribute:: generic_outgoing_upstream_label
                
                	Generic Outgoing Upstream Label
                	**type**\:   :py:class:`GenericOutgoingUpstreamLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericOutgoingUpstreamLabel>`
                
                .. attribute:: generic_recovery_label
                
                	Generic Recovery Label
                	**type**\:   :py:class:`GenericRecoveryLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericRecoveryLabel>`
                
                .. attribute:: is_valid
                
                	Is the label information valid
                	**type**\:  bool
                
                .. attribute:: local_downstream_label
                
                	Local Downstream Label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: local_upstream_label
                
                	Local Upstream Label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: lsp_wrap_label
                
                	LSP Wrap Label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: merge_point_label
                
                	MergePoint Label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: outgoing_downstream_label
                
                	Outgoing Downstream Label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: outgoing_upstream_label
                
                	Outgoing Upstream Label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: recovery_label
                
                	Recovery Label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.RsbDetaileds.RsbDetailed.LabelInfo, self).__init__()

                    self.yang_name = "label-info"
                    self.yang_parent_name = "rsb-detailed"

                    self.is_valid = YLeaf(YType.boolean, "is-valid")

                    self.local_downstream_label = YLeaf(YType.uint32, "local-downstream-label")

                    self.local_upstream_label = YLeaf(YType.uint32, "local-upstream-label")

                    self.lsp_wrap_label = YLeaf(YType.uint32, "lsp-wrap-label")

                    self.merge_point_label = YLeaf(YType.uint32, "merge-point-label")

                    self.outgoing_downstream_label = YLeaf(YType.uint32, "outgoing-downstream-label")

                    self.outgoing_upstream_label = YLeaf(YType.uint32, "outgoing-upstream-label")

                    self.recovery_label = YLeaf(YType.uint32, "recovery-label")

                    self.generic_local_downstream_label = Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericLocalDownstreamLabel()
                    self.generic_local_downstream_label.parent = self
                    self._children_name_map["generic_local_downstream_label"] = "generic-local-downstream-label"
                    self._children_yang_names.add("generic-local-downstream-label")

                    self.generic_local_upstream_label = Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericLocalUpstreamLabel()
                    self.generic_local_upstream_label.parent = self
                    self._children_name_map["generic_local_upstream_label"] = "generic-local-upstream-label"
                    self._children_yang_names.add("generic-local-upstream-label")

                    self.generic_merge_point_label = Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericMergePointLabel()
                    self.generic_merge_point_label.parent = self
                    self._children_name_map["generic_merge_point_label"] = "generic-merge-point-label"
                    self._children_yang_names.add("generic-merge-point-label")

                    self.generic_outgoing_downstream_label = Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericOutgoingDownstreamLabel()
                    self.generic_outgoing_downstream_label.parent = self
                    self._children_name_map["generic_outgoing_downstream_label"] = "generic-outgoing-downstream-label"
                    self._children_yang_names.add("generic-outgoing-downstream-label")

                    self.generic_outgoing_upstream_label = Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericOutgoingUpstreamLabel()
                    self.generic_outgoing_upstream_label.parent = self
                    self._children_name_map["generic_outgoing_upstream_label"] = "generic-outgoing-upstream-label"
                    self._children_yang_names.add("generic-outgoing-upstream-label")

                    self.generic_recovery_label = Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericRecoveryLabel()
                    self.generic_recovery_label.parent = self
                    self._children_name_map["generic_recovery_label"] = "generic-recovery-label"
                    self._children_yang_names.add("generic-recovery-label")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("is_valid",
                                    "local_downstream_label",
                                    "local_upstream_label",
                                    "lsp_wrap_label",
                                    "merge_point_label",
                                    "outgoing_downstream_label",
                                    "outgoing_upstream_label",
                                    "recovery_label") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.RsbDetaileds.RsbDetailed.LabelInfo, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.RsbDetaileds.RsbDetailed.LabelInfo, self).__setattr__(name, value)


                class GenericLocalDownstreamLabel(Entity):
                    """
                    Generic Local Downstream Label
                    
                    .. attribute:: generalized_label
                    
                    	Generalized Label
                    	**type**\:   :py:class:`GeneralizedLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericLocalDownstreamLabel.GeneralizedLabel>`
                    
                    .. attribute:: generic_label_type
                    
                    	GenericLabelType
                    	**type**\:   :py:class:`RsvpMgmtGenericLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtGenericLabel>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericLocalDownstreamLabel, self).__init__()

                        self.yang_name = "generic-local-downstream-label"
                        self.yang_parent_name = "label-info"

                        self.generic_label_type = YLeaf(YType.enumeration, "generic-label-type")

                        self.generalized_label = Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericLocalDownstreamLabel.GeneralizedLabel()
                        self.generalized_label.parent = self
                        self._children_name_map["generalized_label"] = "generalized-label"
                        self._children_yang_names.add("generalized-label")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("generic_label_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericLocalDownstreamLabel, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericLocalDownstreamLabel, self).__setattr__(name, value)


                    class GeneralizedLabel(Entity):
                        """
                        Generalized Label
                        
                        .. attribute:: value
                        
                        	Generalized Label Value
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericLocalDownstreamLabel.GeneralizedLabel, self).__init__()

                            self.yang_name = "generalized-label"
                            self.yang_parent_name = "generic-local-downstream-label"

                            self.value = YLeafList(YType.uint32, "value")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("value") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericLocalDownstreamLabel.GeneralizedLabel, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericLocalDownstreamLabel.GeneralizedLabel, self).__setattr__(name, value)

                        def has_data(self):
                            for leaf in self.value.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            return False

                        def has_operation(self):
                            for leaf in self.value.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.value.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "generalized-label" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rsb-detaileds/rsb-detailed/label-info/generic-local-downstream-label/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            leaf_name_data.extend(self.value.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "value"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "value"):
                                self.value.append(value)

                    def has_data(self):
                        return (
                            self.generic_label_type.is_set or
                            (self.generalized_label is not None and self.generalized_label.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.generic_label_type.yfilter != YFilter.not_set or
                            (self.generalized_label is not None and self.generalized_label.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "generic-local-downstream-label" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rsb-detaileds/rsb-detailed/label-info/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.generic_label_type.is_set or self.generic_label_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.generic_label_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "generalized-label"):
                            if (self.generalized_label is None):
                                self.generalized_label = Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericLocalDownstreamLabel.GeneralizedLabel()
                                self.generalized_label.parent = self
                                self._children_name_map["generalized_label"] = "generalized-label"
                            return self.generalized_label

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "generalized-label" or name == "generic-label-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "generic-label-type"):
                            self.generic_label_type = value
                            self.generic_label_type.value_namespace = name_space
                            self.generic_label_type.value_namespace_prefix = name_space_prefix


                class GenericOutgoingDownstreamLabel(Entity):
                    """
                    Generic Outgoing Downstream Label
                    
                    .. attribute:: generalized_label
                    
                    	Generalized Label
                    	**type**\:   :py:class:`GeneralizedLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericOutgoingDownstreamLabel.GeneralizedLabel>`
                    
                    .. attribute:: generic_label_type
                    
                    	GenericLabelType
                    	**type**\:   :py:class:`RsvpMgmtGenericLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtGenericLabel>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericOutgoingDownstreamLabel, self).__init__()

                        self.yang_name = "generic-outgoing-downstream-label"
                        self.yang_parent_name = "label-info"

                        self.generic_label_type = YLeaf(YType.enumeration, "generic-label-type")

                        self.generalized_label = Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericOutgoingDownstreamLabel.GeneralizedLabel()
                        self.generalized_label.parent = self
                        self._children_name_map["generalized_label"] = "generalized-label"
                        self._children_yang_names.add("generalized-label")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("generic_label_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericOutgoingDownstreamLabel, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericOutgoingDownstreamLabel, self).__setattr__(name, value)


                    class GeneralizedLabel(Entity):
                        """
                        Generalized Label
                        
                        .. attribute:: value
                        
                        	Generalized Label Value
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericOutgoingDownstreamLabel.GeneralizedLabel, self).__init__()

                            self.yang_name = "generalized-label"
                            self.yang_parent_name = "generic-outgoing-downstream-label"

                            self.value = YLeafList(YType.uint32, "value")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("value") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericOutgoingDownstreamLabel.GeneralizedLabel, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericOutgoingDownstreamLabel.GeneralizedLabel, self).__setattr__(name, value)

                        def has_data(self):
                            for leaf in self.value.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            return False

                        def has_operation(self):
                            for leaf in self.value.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.value.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "generalized-label" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rsb-detaileds/rsb-detailed/label-info/generic-outgoing-downstream-label/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            leaf_name_data.extend(self.value.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "value"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "value"):
                                self.value.append(value)

                    def has_data(self):
                        return (
                            self.generic_label_type.is_set or
                            (self.generalized_label is not None and self.generalized_label.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.generic_label_type.yfilter != YFilter.not_set or
                            (self.generalized_label is not None and self.generalized_label.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "generic-outgoing-downstream-label" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rsb-detaileds/rsb-detailed/label-info/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.generic_label_type.is_set or self.generic_label_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.generic_label_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "generalized-label"):
                            if (self.generalized_label is None):
                                self.generalized_label = Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericOutgoingDownstreamLabel.GeneralizedLabel()
                                self.generalized_label.parent = self
                                self._children_name_map["generalized_label"] = "generalized-label"
                            return self.generalized_label

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "generalized-label" or name == "generic-label-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "generic-label-type"):
                            self.generic_label_type = value
                            self.generic_label_type.value_namespace = name_space
                            self.generic_label_type.value_namespace_prefix = name_space_prefix


                class GenericMergePointLabel(Entity):
                    """
                    Generic MergePoint Label
                    
                    .. attribute:: generalized_label
                    
                    	Generalized Label
                    	**type**\:   :py:class:`GeneralizedLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericMergePointLabel.GeneralizedLabel>`
                    
                    .. attribute:: generic_label_type
                    
                    	GenericLabelType
                    	**type**\:   :py:class:`RsvpMgmtGenericLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtGenericLabel>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericMergePointLabel, self).__init__()

                        self.yang_name = "generic-merge-point-label"
                        self.yang_parent_name = "label-info"

                        self.generic_label_type = YLeaf(YType.enumeration, "generic-label-type")

                        self.generalized_label = Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericMergePointLabel.GeneralizedLabel()
                        self.generalized_label.parent = self
                        self._children_name_map["generalized_label"] = "generalized-label"
                        self._children_yang_names.add("generalized-label")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("generic_label_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericMergePointLabel, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericMergePointLabel, self).__setattr__(name, value)


                    class GeneralizedLabel(Entity):
                        """
                        Generalized Label
                        
                        .. attribute:: value
                        
                        	Generalized Label Value
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericMergePointLabel.GeneralizedLabel, self).__init__()

                            self.yang_name = "generalized-label"
                            self.yang_parent_name = "generic-merge-point-label"

                            self.value = YLeafList(YType.uint32, "value")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("value") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericMergePointLabel.GeneralizedLabel, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericMergePointLabel.GeneralizedLabel, self).__setattr__(name, value)

                        def has_data(self):
                            for leaf in self.value.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            return False

                        def has_operation(self):
                            for leaf in self.value.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.value.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "generalized-label" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rsb-detaileds/rsb-detailed/label-info/generic-merge-point-label/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            leaf_name_data.extend(self.value.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "value"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "value"):
                                self.value.append(value)

                    def has_data(self):
                        return (
                            self.generic_label_type.is_set or
                            (self.generalized_label is not None and self.generalized_label.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.generic_label_type.yfilter != YFilter.not_set or
                            (self.generalized_label is not None and self.generalized_label.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "generic-merge-point-label" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rsb-detaileds/rsb-detailed/label-info/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.generic_label_type.is_set or self.generic_label_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.generic_label_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "generalized-label"):
                            if (self.generalized_label is None):
                                self.generalized_label = Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericMergePointLabel.GeneralizedLabel()
                                self.generalized_label.parent = self
                                self._children_name_map["generalized_label"] = "generalized-label"
                            return self.generalized_label

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "generalized-label" or name == "generic-label-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "generic-label-type"):
                            self.generic_label_type = value
                            self.generic_label_type.value_namespace = name_space
                            self.generic_label_type.value_namespace_prefix = name_space_prefix


                class GenericOutgoingUpstreamLabel(Entity):
                    """
                    Generic Outgoing Upstream Label
                    
                    .. attribute:: generalized_label
                    
                    	Generalized Label
                    	**type**\:   :py:class:`GeneralizedLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericOutgoingUpstreamLabel.GeneralizedLabel>`
                    
                    .. attribute:: generic_label_type
                    
                    	GenericLabelType
                    	**type**\:   :py:class:`RsvpMgmtGenericLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtGenericLabel>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericOutgoingUpstreamLabel, self).__init__()

                        self.yang_name = "generic-outgoing-upstream-label"
                        self.yang_parent_name = "label-info"

                        self.generic_label_type = YLeaf(YType.enumeration, "generic-label-type")

                        self.generalized_label = Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericOutgoingUpstreamLabel.GeneralizedLabel()
                        self.generalized_label.parent = self
                        self._children_name_map["generalized_label"] = "generalized-label"
                        self._children_yang_names.add("generalized-label")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("generic_label_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericOutgoingUpstreamLabel, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericOutgoingUpstreamLabel, self).__setattr__(name, value)


                    class GeneralizedLabel(Entity):
                        """
                        Generalized Label
                        
                        .. attribute:: value
                        
                        	Generalized Label Value
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericOutgoingUpstreamLabel.GeneralizedLabel, self).__init__()

                            self.yang_name = "generalized-label"
                            self.yang_parent_name = "generic-outgoing-upstream-label"

                            self.value = YLeafList(YType.uint32, "value")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("value") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericOutgoingUpstreamLabel.GeneralizedLabel, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericOutgoingUpstreamLabel.GeneralizedLabel, self).__setattr__(name, value)

                        def has_data(self):
                            for leaf in self.value.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            return False

                        def has_operation(self):
                            for leaf in self.value.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.value.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "generalized-label" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rsb-detaileds/rsb-detailed/label-info/generic-outgoing-upstream-label/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            leaf_name_data.extend(self.value.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "value"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "value"):
                                self.value.append(value)

                    def has_data(self):
                        return (
                            self.generic_label_type.is_set or
                            (self.generalized_label is not None and self.generalized_label.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.generic_label_type.yfilter != YFilter.not_set or
                            (self.generalized_label is not None and self.generalized_label.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "generic-outgoing-upstream-label" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rsb-detaileds/rsb-detailed/label-info/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.generic_label_type.is_set or self.generic_label_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.generic_label_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "generalized-label"):
                            if (self.generalized_label is None):
                                self.generalized_label = Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericOutgoingUpstreamLabel.GeneralizedLabel()
                                self.generalized_label.parent = self
                                self._children_name_map["generalized_label"] = "generalized-label"
                            return self.generalized_label

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "generalized-label" or name == "generic-label-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "generic-label-type"):
                            self.generic_label_type = value
                            self.generic_label_type.value_namespace = name_space
                            self.generic_label_type.value_namespace_prefix = name_space_prefix


                class GenericLocalUpstreamLabel(Entity):
                    """
                    Generic Local Upstream Label
                    
                    .. attribute:: generalized_label
                    
                    	Generalized Label
                    	**type**\:   :py:class:`GeneralizedLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericLocalUpstreamLabel.GeneralizedLabel>`
                    
                    .. attribute:: generic_label_type
                    
                    	GenericLabelType
                    	**type**\:   :py:class:`RsvpMgmtGenericLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtGenericLabel>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericLocalUpstreamLabel, self).__init__()

                        self.yang_name = "generic-local-upstream-label"
                        self.yang_parent_name = "label-info"

                        self.generic_label_type = YLeaf(YType.enumeration, "generic-label-type")

                        self.generalized_label = Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericLocalUpstreamLabel.GeneralizedLabel()
                        self.generalized_label.parent = self
                        self._children_name_map["generalized_label"] = "generalized-label"
                        self._children_yang_names.add("generalized-label")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("generic_label_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericLocalUpstreamLabel, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericLocalUpstreamLabel, self).__setattr__(name, value)


                    class GeneralizedLabel(Entity):
                        """
                        Generalized Label
                        
                        .. attribute:: value
                        
                        	Generalized Label Value
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericLocalUpstreamLabel.GeneralizedLabel, self).__init__()

                            self.yang_name = "generalized-label"
                            self.yang_parent_name = "generic-local-upstream-label"

                            self.value = YLeafList(YType.uint32, "value")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("value") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericLocalUpstreamLabel.GeneralizedLabel, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericLocalUpstreamLabel.GeneralizedLabel, self).__setattr__(name, value)

                        def has_data(self):
                            for leaf in self.value.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            return False

                        def has_operation(self):
                            for leaf in self.value.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.value.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "generalized-label" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rsb-detaileds/rsb-detailed/label-info/generic-local-upstream-label/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            leaf_name_data.extend(self.value.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "value"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "value"):
                                self.value.append(value)

                    def has_data(self):
                        return (
                            self.generic_label_type.is_set or
                            (self.generalized_label is not None and self.generalized_label.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.generic_label_type.yfilter != YFilter.not_set or
                            (self.generalized_label is not None and self.generalized_label.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "generic-local-upstream-label" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rsb-detaileds/rsb-detailed/label-info/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.generic_label_type.is_set or self.generic_label_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.generic_label_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "generalized-label"):
                            if (self.generalized_label is None):
                                self.generalized_label = Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericLocalUpstreamLabel.GeneralizedLabel()
                                self.generalized_label.parent = self
                                self._children_name_map["generalized_label"] = "generalized-label"
                            return self.generalized_label

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "generalized-label" or name == "generic-label-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "generic-label-type"):
                            self.generic_label_type = value
                            self.generic_label_type.value_namespace = name_space
                            self.generic_label_type.value_namespace_prefix = name_space_prefix


                class GenericRecoveryLabel(Entity):
                    """
                    Generic Recovery Label
                    
                    .. attribute:: generalized_label
                    
                    	Generalized Label
                    	**type**\:   :py:class:`GeneralizedLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericRecoveryLabel.GeneralizedLabel>`
                    
                    .. attribute:: generic_label_type
                    
                    	GenericLabelType
                    	**type**\:   :py:class:`RsvpMgmtGenericLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtGenericLabel>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericRecoveryLabel, self).__init__()

                        self.yang_name = "generic-recovery-label"
                        self.yang_parent_name = "label-info"

                        self.generic_label_type = YLeaf(YType.enumeration, "generic-label-type")

                        self.generalized_label = Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericRecoveryLabel.GeneralizedLabel()
                        self.generalized_label.parent = self
                        self._children_name_map["generalized_label"] = "generalized-label"
                        self._children_yang_names.add("generalized-label")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("generic_label_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericRecoveryLabel, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericRecoveryLabel, self).__setattr__(name, value)


                    class GeneralizedLabel(Entity):
                        """
                        Generalized Label
                        
                        .. attribute:: value
                        
                        	Generalized Label Value
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericRecoveryLabel.GeneralizedLabel, self).__init__()

                            self.yang_name = "generalized-label"
                            self.yang_parent_name = "generic-recovery-label"

                            self.value = YLeafList(YType.uint32, "value")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("value") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericRecoveryLabel.GeneralizedLabel, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericRecoveryLabel.GeneralizedLabel, self).__setattr__(name, value)

                        def has_data(self):
                            for leaf in self.value.getYLeafs():
                                if (leaf.yfilter != YFilter.not_set):
                                    return True
                            return False

                        def has_operation(self):
                            for leaf in self.value.getYLeafs():
                                if (leaf.is_set):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                self.value.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "generalized-label" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rsb-detaileds/rsb-detailed/label-info/generic-recovery-label/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            leaf_name_data.extend(self.value.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "value"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "value"):
                                self.value.append(value)

                    def has_data(self):
                        return (
                            self.generic_label_type.is_set or
                            (self.generalized_label is not None and self.generalized_label.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.generic_label_type.yfilter != YFilter.not_set or
                            (self.generalized_label is not None and self.generalized_label.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "generic-recovery-label" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rsb-detaileds/rsb-detailed/label-info/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.generic_label_type.is_set or self.generic_label_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.generic_label_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "generalized-label"):
                            if (self.generalized_label is None):
                                self.generalized_label = Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericRecoveryLabel.GeneralizedLabel()
                                self.generalized_label.parent = self
                                self._children_name_map["generalized_label"] = "generalized-label"
                            return self.generalized_label

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "generalized-label" or name == "generic-label-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "generic-label-type"):
                            self.generic_label_type = value
                            self.generic_label_type.value_namespace = name_space
                            self.generic_label_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.is_valid.is_set or
                        self.local_downstream_label.is_set or
                        self.local_upstream_label.is_set or
                        self.lsp_wrap_label.is_set or
                        self.merge_point_label.is_set or
                        self.outgoing_downstream_label.is_set or
                        self.outgoing_upstream_label.is_set or
                        self.recovery_label.is_set or
                        (self.generic_local_downstream_label is not None and self.generic_local_downstream_label.has_data()) or
                        (self.generic_local_upstream_label is not None and self.generic_local_upstream_label.has_data()) or
                        (self.generic_merge_point_label is not None and self.generic_merge_point_label.has_data()) or
                        (self.generic_outgoing_downstream_label is not None and self.generic_outgoing_downstream_label.has_data()) or
                        (self.generic_outgoing_upstream_label is not None and self.generic_outgoing_upstream_label.has_data()) or
                        (self.generic_recovery_label is not None and self.generic_recovery_label.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.is_valid.yfilter != YFilter.not_set or
                        self.local_downstream_label.yfilter != YFilter.not_set or
                        self.local_upstream_label.yfilter != YFilter.not_set or
                        self.lsp_wrap_label.yfilter != YFilter.not_set or
                        self.merge_point_label.yfilter != YFilter.not_set or
                        self.outgoing_downstream_label.yfilter != YFilter.not_set or
                        self.outgoing_upstream_label.yfilter != YFilter.not_set or
                        self.recovery_label.yfilter != YFilter.not_set or
                        (self.generic_local_downstream_label is not None and self.generic_local_downstream_label.has_operation()) or
                        (self.generic_local_upstream_label is not None and self.generic_local_upstream_label.has_operation()) or
                        (self.generic_merge_point_label is not None and self.generic_merge_point_label.has_operation()) or
                        (self.generic_outgoing_downstream_label is not None and self.generic_outgoing_downstream_label.has_operation()) or
                        (self.generic_outgoing_upstream_label is not None and self.generic_outgoing_upstream_label.has_operation()) or
                        (self.generic_recovery_label is not None and self.generic_recovery_label.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "label-info" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rsb-detaileds/rsb-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_valid.get_name_leafdata())
                    if (self.local_downstream_label.is_set or self.local_downstream_label.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.local_downstream_label.get_name_leafdata())
                    if (self.local_upstream_label.is_set or self.local_upstream_label.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.local_upstream_label.get_name_leafdata())
                    if (self.lsp_wrap_label.is_set or self.lsp_wrap_label.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.lsp_wrap_label.get_name_leafdata())
                    if (self.merge_point_label.is_set or self.merge_point_label.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.merge_point_label.get_name_leafdata())
                    if (self.outgoing_downstream_label.is_set or self.outgoing_downstream_label.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.outgoing_downstream_label.get_name_leafdata())
                    if (self.outgoing_upstream_label.is_set or self.outgoing_upstream_label.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.outgoing_upstream_label.get_name_leafdata())
                    if (self.recovery_label.is_set or self.recovery_label.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.recovery_label.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "generic-local-downstream-label"):
                        if (self.generic_local_downstream_label is None):
                            self.generic_local_downstream_label = Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericLocalDownstreamLabel()
                            self.generic_local_downstream_label.parent = self
                            self._children_name_map["generic_local_downstream_label"] = "generic-local-downstream-label"
                        return self.generic_local_downstream_label

                    if (child_yang_name == "generic-local-upstream-label"):
                        if (self.generic_local_upstream_label is None):
                            self.generic_local_upstream_label = Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericLocalUpstreamLabel()
                            self.generic_local_upstream_label.parent = self
                            self._children_name_map["generic_local_upstream_label"] = "generic-local-upstream-label"
                        return self.generic_local_upstream_label

                    if (child_yang_name == "generic-merge-point-label"):
                        if (self.generic_merge_point_label is None):
                            self.generic_merge_point_label = Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericMergePointLabel()
                            self.generic_merge_point_label.parent = self
                            self._children_name_map["generic_merge_point_label"] = "generic-merge-point-label"
                        return self.generic_merge_point_label

                    if (child_yang_name == "generic-outgoing-downstream-label"):
                        if (self.generic_outgoing_downstream_label is None):
                            self.generic_outgoing_downstream_label = Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericOutgoingDownstreamLabel()
                            self.generic_outgoing_downstream_label.parent = self
                            self._children_name_map["generic_outgoing_downstream_label"] = "generic-outgoing-downstream-label"
                        return self.generic_outgoing_downstream_label

                    if (child_yang_name == "generic-outgoing-upstream-label"):
                        if (self.generic_outgoing_upstream_label is None):
                            self.generic_outgoing_upstream_label = Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericOutgoingUpstreamLabel()
                            self.generic_outgoing_upstream_label.parent = self
                            self._children_name_map["generic_outgoing_upstream_label"] = "generic-outgoing-upstream-label"
                        return self.generic_outgoing_upstream_label

                    if (child_yang_name == "generic-recovery-label"):
                        if (self.generic_recovery_label is None):
                            self.generic_recovery_label = Rsvp.RsbDetaileds.RsbDetailed.LabelInfo.GenericRecoveryLabel()
                            self.generic_recovery_label.parent = self
                            self._children_name_map["generic_recovery_label"] = "generic-recovery-label"
                        return self.generic_recovery_label

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "generic-local-downstream-label" or name == "generic-local-upstream-label" or name == "generic-merge-point-label" or name == "generic-outgoing-downstream-label" or name == "generic-outgoing-upstream-label" or name == "generic-recovery-label" or name == "is-valid" or name == "local-downstream-label" or name == "local-upstream-label" or name == "lsp-wrap-label" or name == "merge-point-label" or name == "outgoing-downstream-label" or name == "outgoing-upstream-label" or name == "recovery-label"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "is-valid"):
                        self.is_valid = value
                        self.is_valid.value_namespace = name_space
                        self.is_valid.value_namespace_prefix = name_space_prefix
                    if(value_path == "local-downstream-label"):
                        self.local_downstream_label = value
                        self.local_downstream_label.value_namespace = name_space
                        self.local_downstream_label.value_namespace_prefix = name_space_prefix
                    if(value_path == "local-upstream-label"):
                        self.local_upstream_label = value
                        self.local_upstream_label.value_namespace = name_space
                        self.local_upstream_label.value_namespace_prefix = name_space_prefix
                    if(value_path == "lsp-wrap-label"):
                        self.lsp_wrap_label = value
                        self.lsp_wrap_label.value_namespace = name_space
                        self.lsp_wrap_label.value_namespace_prefix = name_space_prefix
                    if(value_path == "merge-point-label"):
                        self.merge_point_label = value
                        self.merge_point_label.value_namespace = name_space
                        self.merge_point_label.value_namespace_prefix = name_space_prefix
                    if(value_path == "outgoing-downstream-label"):
                        self.outgoing_downstream_label = value
                        self.outgoing_downstream_label.value_namespace = name_space
                        self.outgoing_downstream_label.value_namespace_prefix = name_space_prefix
                    if(value_path == "outgoing-upstream-label"):
                        self.outgoing_upstream_label = value
                        self.outgoing_upstream_label.value_namespace = name_space
                        self.outgoing_upstream_label.value_namespace_prefix = name_space_prefix
                    if(value_path == "recovery-label"):
                        self.recovery_label = value
                        self.recovery_label.value_namespace = name_space
                        self.recovery_label.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.destination_address.is_set or
                    self.destination_port.is_set or
                    self.extended_tunnel_id.is_set or
                    self.input_adjusted_interface.is_set or
                    self.input_physical_interface.is_set or
                    self.p2mp_id.is_set or
                    self.protocol.is_set or
                    self.session_type.is_set or
                    self.source_address.is_set or
                    self.source_port.is_set or
                    self.sub_group_id.is_set or
                    self.sub_group_origin.is_set or
                    self.vrf_name.is_set or
                    (self.expiry_time is not None and self.expiry_time.has_data()) or
                    (self.filter is not None and self.filter.has_data()) or
                    (self.flow_spec is not None and self.flow_spec.has_data()) or
                    (self.generic_flow_spec is not None and self.generic_flow_spec.has_data()) or
                    (self.header is not None and self.header.has_data()) or
                    (self.hop is not None and self.hop.has_data()) or
                    (self.label_info is not None and self.label_info.has_data()) or
                    (self.policy_flags is not None and self.policy_flags.has_data()) or
                    (self.policy_query_flags is not None and self.policy_query_flags.has_data()) or
                    (self.policy_sources is not None and self.policy_sources.has_data()) or
                    (self.rsb_flags is not None and self.rsb_flags.has_data()) or
                    (self.s2l_sub_lsp is not None and self.s2l_sub_lsp.has_data()) or
                    (self.session is not None and self.session.has_data()) or
                    (self.style is not None and self.style.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.destination_address.yfilter != YFilter.not_set or
                    self.destination_port.yfilter != YFilter.not_set or
                    self.extended_tunnel_id.yfilter != YFilter.not_set or
                    self.input_adjusted_interface.yfilter != YFilter.not_set or
                    self.input_physical_interface.yfilter != YFilter.not_set or
                    self.p2mp_id.yfilter != YFilter.not_set or
                    self.protocol.yfilter != YFilter.not_set or
                    self.session_type.yfilter != YFilter.not_set or
                    self.source_address.yfilter != YFilter.not_set or
                    self.source_port.yfilter != YFilter.not_set or
                    self.sub_group_id.yfilter != YFilter.not_set or
                    self.sub_group_origin.yfilter != YFilter.not_set or
                    self.vrf_name.yfilter != YFilter.not_set or
                    (self.expiry_time is not None and self.expiry_time.has_operation()) or
                    (self.filter is not None and self.filter.has_operation()) or
                    (self.flow_spec is not None and self.flow_spec.has_operation()) or
                    (self.generic_flow_spec is not None and self.generic_flow_spec.has_operation()) or
                    (self.header is not None and self.header.has_operation()) or
                    (self.hop is not None and self.hop.has_operation()) or
                    (self.label_info is not None and self.label_info.has_operation()) or
                    (self.policy_flags is not None and self.policy_flags.has_operation()) or
                    (self.policy_query_flags is not None and self.policy_query_flags.has_operation()) or
                    (self.policy_sources is not None and self.policy_sources.has_operation()) or
                    (self.rsb_flags is not None and self.rsb_flags.has_operation()) or
                    (self.s2l_sub_lsp is not None and self.s2l_sub_lsp.has_operation()) or
                    (self.session is not None and self.session.has_operation()) or
                    (self.style is not None and self.style.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "rsb-detailed" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rsb-detaileds/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_address.get_name_leafdata())
                if (self.destination_port.is_set or self.destination_port.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_port.get_name_leafdata())
                if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                if (self.input_adjusted_interface.is_set or self.input_adjusted_interface.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.input_adjusted_interface.get_name_leafdata())
                if (self.input_physical_interface.is_set or self.input_physical_interface.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.input_physical_interface.get_name_leafdata())
                if (self.p2mp_id.is_set or self.p2mp_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.p2mp_id.get_name_leafdata())
                if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.protocol.get_name_leafdata())
                if (self.session_type.is_set or self.session_type.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.session_type.get_name_leafdata())
                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_address.get_name_leafdata())
                if (self.source_port.is_set or self.source_port.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_port.get_name_leafdata())
                if (self.sub_group_id.is_set or self.sub_group_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.sub_group_id.get_name_leafdata())
                if (self.sub_group_origin.is_set or self.sub_group_origin.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.sub_group_origin.get_name_leafdata())
                if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.vrf_name.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "expiry-time"):
                    if (self.expiry_time is None):
                        self.expiry_time = Rsvp.RsbDetaileds.RsbDetailed.ExpiryTime()
                        self.expiry_time.parent = self
                        self._children_name_map["expiry_time"] = "expiry-time"
                    return self.expiry_time

                if (child_yang_name == "filter"):
                    if (self.filter is None):
                        self.filter = Rsvp.RsbDetaileds.RsbDetailed.Filter()
                        self.filter.parent = self
                        self._children_name_map["filter"] = "filter"
                    return self.filter

                if (child_yang_name == "flow-spec"):
                    if (self.flow_spec is None):
                        self.flow_spec = Rsvp.RsbDetaileds.RsbDetailed.FlowSpec()
                        self.flow_spec.parent = self
                        self._children_name_map["flow_spec"] = "flow-spec"
                    return self.flow_spec

                if (child_yang_name == "generic-flow-spec"):
                    if (self.generic_flow_spec is None):
                        self.generic_flow_spec = Rsvp.RsbDetaileds.RsbDetailed.GenericFlowSpec()
                        self.generic_flow_spec.parent = self
                        self._children_name_map["generic_flow_spec"] = "generic-flow-spec"
                    return self.generic_flow_spec

                if (child_yang_name == "header"):
                    if (self.header is None):
                        self.header = Rsvp.RsbDetaileds.RsbDetailed.Header()
                        self.header.parent = self
                        self._children_name_map["header"] = "header"
                    return self.header

                if (child_yang_name == "hop"):
                    if (self.hop is None):
                        self.hop = Rsvp.RsbDetaileds.RsbDetailed.Hop()
                        self.hop.parent = self
                        self._children_name_map["hop"] = "hop"
                    return self.hop

                if (child_yang_name == "label-info"):
                    if (self.label_info is None):
                        self.label_info = Rsvp.RsbDetaileds.RsbDetailed.LabelInfo()
                        self.label_info.parent = self
                        self._children_name_map["label_info"] = "label-info"
                    return self.label_info

                if (child_yang_name == "policy-flags"):
                    if (self.policy_flags is None):
                        self.policy_flags = Rsvp.RsbDetaileds.RsbDetailed.PolicyFlags()
                        self.policy_flags.parent = self
                        self._children_name_map["policy_flags"] = "policy-flags"
                    return self.policy_flags

                if (child_yang_name == "policy-query-flags"):
                    if (self.policy_query_flags is None):
                        self.policy_query_flags = Rsvp.RsbDetaileds.RsbDetailed.PolicyQueryFlags()
                        self.policy_query_flags.parent = self
                        self._children_name_map["policy_query_flags"] = "policy-query-flags"
                    return self.policy_query_flags

                if (child_yang_name == "policy-sources"):
                    if (self.policy_sources is None):
                        self.policy_sources = Rsvp.RsbDetaileds.RsbDetailed.PolicySources()
                        self.policy_sources.parent = self
                        self._children_name_map["policy_sources"] = "policy-sources"
                    return self.policy_sources

                if (child_yang_name == "rsb-flags"):
                    if (self.rsb_flags is None):
                        self.rsb_flags = Rsvp.RsbDetaileds.RsbDetailed.RsbFlags()
                        self.rsb_flags.parent = self
                        self._children_name_map["rsb_flags"] = "rsb-flags"
                    return self.rsb_flags

                if (child_yang_name == "s2l-sub-lsp"):
                    if (self.s2l_sub_lsp is None):
                        self.s2l_sub_lsp = Rsvp.RsbDetaileds.RsbDetailed.S2LSubLsp()
                        self.s2l_sub_lsp.parent = self
                        self._children_name_map["s2l_sub_lsp"] = "s2l-sub-lsp"
                    return self.s2l_sub_lsp

                if (child_yang_name == "session"):
                    if (self.session is None):
                        self.session = Rsvp.RsbDetaileds.RsbDetailed.Session()
                        self.session.parent = self
                        self._children_name_map["session"] = "session"
                    return self.session

                if (child_yang_name == "style"):
                    if (self.style is None):
                        self.style = Rsvp.RsbDetaileds.RsbDetailed.Style()
                        self.style.parent = self
                        self._children_name_map["style"] = "style"
                    return self.style

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "expiry-time" or name == "filter" or name == "flow-spec" or name == "generic-flow-spec" or name == "header" or name == "hop" or name == "label-info" or name == "policy-flags" or name == "policy-query-flags" or name == "policy-sources" or name == "rsb-flags" or name == "s2l-sub-lsp" or name == "session" or name == "style" or name == "destination-address" or name == "destination-port" or name == "extended-tunnel-id" or name == "input-adjusted-interface" or name == "input-physical-interface" or name == "p2mp-id" or name == "protocol" or name == "session-type" or name == "source-address" or name == "source-port" or name == "sub-group-id" or name == "sub-group-origin" or name == "vrf-name"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "destination-address"):
                    self.destination_address = value
                    self.destination_address.value_namespace = name_space
                    self.destination_address.value_namespace_prefix = name_space_prefix
                if(value_path == "destination-port"):
                    self.destination_port = value
                    self.destination_port.value_namespace = name_space
                    self.destination_port.value_namespace_prefix = name_space_prefix
                if(value_path == "extended-tunnel-id"):
                    self.extended_tunnel_id = value
                    self.extended_tunnel_id.value_namespace = name_space
                    self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                if(value_path == "input-adjusted-interface"):
                    self.input_adjusted_interface = value
                    self.input_adjusted_interface.value_namespace = name_space
                    self.input_adjusted_interface.value_namespace_prefix = name_space_prefix
                if(value_path == "input-physical-interface"):
                    self.input_physical_interface = value
                    self.input_physical_interface.value_namespace = name_space
                    self.input_physical_interface.value_namespace_prefix = name_space_prefix
                if(value_path == "p2mp-id"):
                    self.p2mp_id = value
                    self.p2mp_id.value_namespace = name_space
                    self.p2mp_id.value_namespace_prefix = name_space_prefix
                if(value_path == "protocol"):
                    self.protocol = value
                    self.protocol.value_namespace = name_space
                    self.protocol.value_namespace_prefix = name_space_prefix
                if(value_path == "session-type"):
                    self.session_type = value
                    self.session_type.value_namespace = name_space
                    self.session_type.value_namespace_prefix = name_space_prefix
                if(value_path == "source-address"):
                    self.source_address = value
                    self.source_address.value_namespace = name_space
                    self.source_address.value_namespace_prefix = name_space_prefix
                if(value_path == "source-port"):
                    self.source_port = value
                    self.source_port.value_namespace = name_space
                    self.source_port.value_namespace_prefix = name_space_prefix
                if(value_path == "sub-group-id"):
                    self.sub_group_id = value
                    self.sub_group_id.value_namespace = name_space
                    self.sub_group_id.value_namespace_prefix = name_space_prefix
                if(value_path == "sub-group-origin"):
                    self.sub_group_origin = value
                    self.sub_group_origin.value_namespace = name_space
                    self.sub_group_origin.value_namespace_prefix = name_space_prefix
                if(value_path == "vrf-name"):
                    self.vrf_name = value
                    self.vrf_name.value_namespace = name_space
                    self.vrf_name.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.rsb_detailed:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.rsb_detailed:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "rsb-detaileds" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "rsb-detailed"):
                for c in self.rsb_detailed:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = Rsvp.RsbDetaileds.RsbDetailed()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.rsb_detailed.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "rsb-detailed"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class InterfaceSummaries(Entity):
        """
        Table of summary info about RSVP\-enabled
        interfaces
        
        .. attribute:: interface_summary
        
        	Summary info about an RSVP\-enabled interface
        	**type**\: list of    :py:class:`InterfaceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.InterfaceSummaries.InterfaceSummary>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Rsvp.InterfaceSummaries, self).__init__()

            self.yang_name = "interface-summaries"
            self.yang_parent_name = "rsvp"

            self.interface_summary = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(Rsvp.InterfaceSummaries, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(Rsvp.InterfaceSummaries, self).__setattr__(name, value)


        class InterfaceSummary(Entity):
            """
            Summary info about an RSVP\-enabled interface
            
            .. attribute:: interface_name  <key>
            
            	Interface Name
            	**type**\:  str
            
            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
            
            .. attribute:: bandwidth_information
            
            	Interface bandwidth information
            	**type**\:   :py:class:`BandwidthInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.InterfaceSummaries.InterfaceSummary.BandwidthInformation>`
            
            .. attribute:: interface_name_xr
            
            	Interface Name
            	**type**\:  str
            
            .. attribute:: paths_in
            
            	Number of locally created and incoming path states
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: paths_out
            
            	Number of outgoing path states
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: reservations_in
            
            	Number of locally created and incoming reservation states
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: reservations_out
            
            	Number of outgoing reservation states
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Rsvp.InterfaceSummaries.InterfaceSummary, self).__init__()

                self.yang_name = "interface-summary"
                self.yang_parent_name = "interface-summaries"

                self.interface_name = YLeaf(YType.str, "interface-name")

                self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                self.paths_in = YLeaf(YType.uint32, "paths-in")

                self.paths_out = YLeaf(YType.uint32, "paths-out")

                self.reservations_in = YLeaf(YType.uint32, "reservations-in")

                self.reservations_out = YLeaf(YType.uint32, "reservations-out")

                self.bandwidth_information = Rsvp.InterfaceSummaries.InterfaceSummary.BandwidthInformation()
                self.bandwidth_information.parent = self
                self._children_name_map["bandwidth_information"] = "bandwidth-information"
                self._children_yang_names.add("bandwidth-information")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("interface_name",
                                "interface_name_xr",
                                "paths_in",
                                "paths_out",
                                "reservations_in",
                                "reservations_out") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Rsvp.InterfaceSummaries.InterfaceSummary, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Rsvp.InterfaceSummaries.InterfaceSummary, self).__setattr__(name, value)


            class BandwidthInformation(Entity):
                """
                Interface bandwidth information
                
                .. attribute:: dste_mode
                
                	DSTEMode
                	**type**\:   :py:class:`RsvpMgmtDsteModes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtDsteModes>`
                
                .. attribute:: pre_standard_dste_interface
                
                	Prestandard DSTE interface information
                	**type**\:   :py:class:`PreStandardDsteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.InterfaceSummaries.InterfaceSummary.BandwidthInformation.PreStandardDsteInterface>`
                
                .. attribute:: standard_dste_interface
                
                	Standard DSTE interface information
                	**type**\:   :py:class:`StandardDsteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.InterfaceSummaries.InterfaceSummary.BandwidthInformation.StandardDsteInterface>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.InterfaceSummaries.InterfaceSummary.BandwidthInformation, self).__init__()

                    self.yang_name = "bandwidth-information"
                    self.yang_parent_name = "interface-summary"

                    self.dste_mode = YLeaf(YType.enumeration, "dste-mode")

                    self.pre_standard_dste_interface = Rsvp.InterfaceSummaries.InterfaceSummary.BandwidthInformation.PreStandardDsteInterface()
                    self.pre_standard_dste_interface.parent = self
                    self._children_name_map["pre_standard_dste_interface"] = "pre-standard-dste-interface"
                    self._children_yang_names.add("pre-standard-dste-interface")

                    self.standard_dste_interface = Rsvp.InterfaceSummaries.InterfaceSummary.BandwidthInformation.StandardDsteInterface()
                    self.standard_dste_interface.parent = self
                    self._children_name_map["standard_dste_interface"] = "standard-dste-interface"
                    self._children_yang_names.add("standard-dste-interface")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("dste_mode") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.InterfaceSummaries.InterfaceSummary.BandwidthInformation, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.InterfaceSummaries.InterfaceSummary.BandwidthInformation, self).__setattr__(name, value)


                class PreStandardDsteInterface(Entity):
                    """
                    Prestandard DSTE interface information
                    
                    .. attribute:: allocated_bit_rate
                    
                    	Bandwidth (bits per second) now allocated
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: is_max_bandwidth_absolute
                    
                    	True if the Max B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: is_max_subpool_bandwidth_absolute
                    
                    	True if the Max sub\-pool B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: max_bandwidth
                    
                    	Max bandwidth (bits per second) allowed
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_flow_bandwidth
                    
                    	Max bandwidth (bits per second) allowed per flow
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_subpool_bandwidth
                    
                    	Max bandwidth (bits per second) allowed in subpool
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.InterfaceSummaries.InterfaceSummary.BandwidthInformation.PreStandardDsteInterface, self).__init__()

                        self.yang_name = "pre-standard-dste-interface"
                        self.yang_parent_name = "bandwidth-information"

                        self.allocated_bit_rate = YLeaf(YType.uint64, "allocated-bit-rate")

                        self.is_max_bandwidth_absolute = YLeaf(YType.boolean, "is-max-bandwidth-absolute")

                        self.is_max_subpool_bandwidth_absolute = YLeaf(YType.boolean, "is-max-subpool-bandwidth-absolute")

                        self.max_bandwidth = YLeaf(YType.uint64, "max-bandwidth")

                        self.max_flow_bandwidth = YLeaf(YType.uint64, "max-flow-bandwidth")

                        self.max_subpool_bandwidth = YLeaf(YType.uint64, "max-subpool-bandwidth")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("allocated_bit_rate",
                                        "is_max_bandwidth_absolute",
                                        "is_max_subpool_bandwidth_absolute",
                                        "max_bandwidth",
                                        "max_flow_bandwidth",
                                        "max_subpool_bandwidth") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.InterfaceSummaries.InterfaceSummary.BandwidthInformation.PreStandardDsteInterface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.InterfaceSummaries.InterfaceSummary.BandwidthInformation.PreStandardDsteInterface, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.allocated_bit_rate.is_set or
                            self.is_max_bandwidth_absolute.is_set or
                            self.is_max_subpool_bandwidth_absolute.is_set or
                            self.max_bandwidth.is_set or
                            self.max_flow_bandwidth.is_set or
                            self.max_subpool_bandwidth.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.allocated_bit_rate.yfilter != YFilter.not_set or
                            self.is_max_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.is_max_subpool_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.max_bandwidth.yfilter != YFilter.not_set or
                            self.max_flow_bandwidth.yfilter != YFilter.not_set or
                            self.max_subpool_bandwidth.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "pre-standard-dste-interface" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.allocated_bit_rate.is_set or self.allocated_bit_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.allocated_bit_rate.get_name_leafdata())
                        if (self.is_max_bandwidth_absolute.is_set or self.is_max_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_bandwidth_absolute.get_name_leafdata())
                        if (self.is_max_subpool_bandwidth_absolute.is_set or self.is_max_subpool_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_subpool_bandwidth_absolute.get_name_leafdata())
                        if (self.max_bandwidth.is_set or self.max_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_bandwidth.get_name_leafdata())
                        if (self.max_flow_bandwidth.is_set or self.max_flow_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_flow_bandwidth.get_name_leafdata())
                        if (self.max_subpool_bandwidth.is_set or self.max_subpool_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_subpool_bandwidth.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "allocated-bit-rate" or name == "is-max-bandwidth-absolute" or name == "is-max-subpool-bandwidth-absolute" or name == "max-bandwidth" or name == "max-flow-bandwidth" or name == "max-subpool-bandwidth"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "allocated-bit-rate"):
                            self.allocated_bit_rate = value
                            self.allocated_bit_rate.value_namespace = name_space
                            self.allocated_bit_rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-bandwidth-absolute"):
                            self.is_max_bandwidth_absolute = value
                            self.is_max_bandwidth_absolute.value_namespace = name_space
                            self.is_max_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-subpool-bandwidth-absolute"):
                            self.is_max_subpool_bandwidth_absolute = value
                            self.is_max_subpool_bandwidth_absolute.value_namespace = name_space
                            self.is_max_subpool_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-bandwidth"):
                            self.max_bandwidth = value
                            self.max_bandwidth.value_namespace = name_space
                            self.max_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-flow-bandwidth"):
                            self.max_flow_bandwidth = value
                            self.max_flow_bandwidth.value_namespace = name_space
                            self.max_flow_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-subpool-bandwidth"):
                            self.max_subpool_bandwidth = value
                            self.max_subpool_bandwidth.value_namespace = name_space
                            self.max_subpool_bandwidth.value_namespace_prefix = name_space_prefix


                class StandardDsteInterface(Entity):
                    """
                    Standard DSTE interface information
                    
                    .. attribute:: allocated_bit_rate
                    
                    	Bandwidth (bits per second) now allocated
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: is_max_bandwidth_absolute
                    
                    	True if the Max B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: is_max_bc0_bandwidth_absolute
                    
                    	True if the Max BC0 B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: is_max_bc1_bandwidth_absolute
                    
                    	True if the Max BC1 sub\-pool B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: max_bandwidth
                    
                    	Max bandwidth (bits per second) allowed
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_flow_bandwidth
                    
                    	Max bandwidth (bits per second) allowed per flow
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_pool0_bandwidth
                    
                    	Max bandwidth (bits per second) allowed in BC0 pool
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_pool1_bandwidth
                    
                    	Max bandwidth (bits per second) allowed in BC1 pool
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.InterfaceSummaries.InterfaceSummary.BandwidthInformation.StandardDsteInterface, self).__init__()

                        self.yang_name = "standard-dste-interface"
                        self.yang_parent_name = "bandwidth-information"

                        self.allocated_bit_rate = YLeaf(YType.uint64, "allocated-bit-rate")

                        self.is_max_bandwidth_absolute = YLeaf(YType.boolean, "is-max-bandwidth-absolute")

                        self.is_max_bc0_bandwidth_absolute = YLeaf(YType.boolean, "is-max-bc0-bandwidth-absolute")

                        self.is_max_bc1_bandwidth_absolute = YLeaf(YType.boolean, "is-max-bc1-bandwidth-absolute")

                        self.max_bandwidth = YLeaf(YType.uint64, "max-bandwidth")

                        self.max_flow_bandwidth = YLeaf(YType.uint64, "max-flow-bandwidth")

                        self.max_pool0_bandwidth = YLeaf(YType.uint64, "max-pool0-bandwidth")

                        self.max_pool1_bandwidth = YLeaf(YType.uint64, "max-pool1-bandwidth")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("allocated_bit_rate",
                                        "is_max_bandwidth_absolute",
                                        "is_max_bc0_bandwidth_absolute",
                                        "is_max_bc1_bandwidth_absolute",
                                        "max_bandwidth",
                                        "max_flow_bandwidth",
                                        "max_pool0_bandwidth",
                                        "max_pool1_bandwidth") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.InterfaceSummaries.InterfaceSummary.BandwidthInformation.StandardDsteInterface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.InterfaceSummaries.InterfaceSummary.BandwidthInformation.StandardDsteInterface, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.allocated_bit_rate.is_set or
                            self.is_max_bandwidth_absolute.is_set or
                            self.is_max_bc0_bandwidth_absolute.is_set or
                            self.is_max_bc1_bandwidth_absolute.is_set or
                            self.max_bandwidth.is_set or
                            self.max_flow_bandwidth.is_set or
                            self.max_pool0_bandwidth.is_set or
                            self.max_pool1_bandwidth.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.allocated_bit_rate.yfilter != YFilter.not_set or
                            self.is_max_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.is_max_bc0_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.is_max_bc1_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.max_bandwidth.yfilter != YFilter.not_set or
                            self.max_flow_bandwidth.yfilter != YFilter.not_set or
                            self.max_pool0_bandwidth.yfilter != YFilter.not_set or
                            self.max_pool1_bandwidth.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "standard-dste-interface" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.allocated_bit_rate.is_set or self.allocated_bit_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.allocated_bit_rate.get_name_leafdata())
                        if (self.is_max_bandwidth_absolute.is_set or self.is_max_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_bandwidth_absolute.get_name_leafdata())
                        if (self.is_max_bc0_bandwidth_absolute.is_set or self.is_max_bc0_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_bc0_bandwidth_absolute.get_name_leafdata())
                        if (self.is_max_bc1_bandwidth_absolute.is_set or self.is_max_bc1_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_bc1_bandwidth_absolute.get_name_leafdata())
                        if (self.max_bandwidth.is_set or self.max_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_bandwidth.get_name_leafdata())
                        if (self.max_flow_bandwidth.is_set or self.max_flow_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_flow_bandwidth.get_name_leafdata())
                        if (self.max_pool0_bandwidth.is_set or self.max_pool0_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_pool0_bandwidth.get_name_leafdata())
                        if (self.max_pool1_bandwidth.is_set or self.max_pool1_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_pool1_bandwidth.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "allocated-bit-rate" or name == "is-max-bandwidth-absolute" or name == "is-max-bc0-bandwidth-absolute" or name == "is-max-bc1-bandwidth-absolute" or name == "max-bandwidth" or name == "max-flow-bandwidth" or name == "max-pool0-bandwidth" or name == "max-pool1-bandwidth"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "allocated-bit-rate"):
                            self.allocated_bit_rate = value
                            self.allocated_bit_rate.value_namespace = name_space
                            self.allocated_bit_rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-bandwidth-absolute"):
                            self.is_max_bandwidth_absolute = value
                            self.is_max_bandwidth_absolute.value_namespace = name_space
                            self.is_max_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-bc0-bandwidth-absolute"):
                            self.is_max_bc0_bandwidth_absolute = value
                            self.is_max_bc0_bandwidth_absolute.value_namespace = name_space
                            self.is_max_bc0_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-bc1-bandwidth-absolute"):
                            self.is_max_bc1_bandwidth_absolute = value
                            self.is_max_bc1_bandwidth_absolute.value_namespace = name_space
                            self.is_max_bc1_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-bandwidth"):
                            self.max_bandwidth = value
                            self.max_bandwidth.value_namespace = name_space
                            self.max_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-flow-bandwidth"):
                            self.max_flow_bandwidth = value
                            self.max_flow_bandwidth.value_namespace = name_space
                            self.max_flow_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-pool0-bandwidth"):
                            self.max_pool0_bandwidth = value
                            self.max_pool0_bandwidth.value_namespace = name_space
                            self.max_pool0_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-pool1-bandwidth"):
                            self.max_pool1_bandwidth = value
                            self.max_pool1_bandwidth.value_namespace = name_space
                            self.max_pool1_bandwidth.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.dste_mode.is_set or
                        (self.pre_standard_dste_interface is not None and self.pre_standard_dste_interface.has_data()) or
                        (self.standard_dste_interface is not None and self.standard_dste_interface.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.dste_mode.yfilter != YFilter.not_set or
                        (self.pre_standard_dste_interface is not None and self.pre_standard_dste_interface.has_operation()) or
                        (self.standard_dste_interface is not None and self.standard_dste_interface.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bandwidth-information" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.dste_mode.is_set or self.dste_mode.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.dste_mode.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "pre-standard-dste-interface"):
                        if (self.pre_standard_dste_interface is None):
                            self.pre_standard_dste_interface = Rsvp.InterfaceSummaries.InterfaceSummary.BandwidthInformation.PreStandardDsteInterface()
                            self.pre_standard_dste_interface.parent = self
                            self._children_name_map["pre_standard_dste_interface"] = "pre-standard-dste-interface"
                        return self.pre_standard_dste_interface

                    if (child_yang_name == "standard-dste-interface"):
                        if (self.standard_dste_interface is None):
                            self.standard_dste_interface = Rsvp.InterfaceSummaries.InterfaceSummary.BandwidthInformation.StandardDsteInterface()
                            self.standard_dste_interface.parent = self
                            self._children_name_map["standard_dste_interface"] = "standard-dste-interface"
                        return self.standard_dste_interface

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "pre-standard-dste-interface" or name == "standard-dste-interface" or name == "dste-mode"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "dste-mode"):
                        self.dste_mode = value
                        self.dste_mode.value_namespace = name_space
                        self.dste_mode.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.interface_name.is_set or
                    self.interface_name_xr.is_set or
                    self.paths_in.is_set or
                    self.paths_out.is_set or
                    self.reservations_in.is_set or
                    self.reservations_out.is_set or
                    (self.bandwidth_information is not None and self.bandwidth_information.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.interface_name.yfilter != YFilter.not_set or
                    self.interface_name_xr.yfilter != YFilter.not_set or
                    self.paths_in.yfilter != YFilter.not_set or
                    self.paths_out.yfilter != YFilter.not_set or
                    self.reservations_in.yfilter != YFilter.not_set or
                    self.reservations_out.yfilter != YFilter.not_set or
                    (self.bandwidth_information is not None and self.bandwidth_information.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "interface-summary" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/interface-summaries/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                if (self.paths_in.is_set or self.paths_in.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.paths_in.get_name_leafdata())
                if (self.paths_out.is_set or self.paths_out.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.paths_out.get_name_leafdata())
                if (self.reservations_in.is_set or self.reservations_in.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.reservations_in.get_name_leafdata())
                if (self.reservations_out.is_set or self.reservations_out.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.reservations_out.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "bandwidth-information"):
                    if (self.bandwidth_information is None):
                        self.bandwidth_information = Rsvp.InterfaceSummaries.InterfaceSummary.BandwidthInformation()
                        self.bandwidth_information.parent = self
                        self._children_name_map["bandwidth_information"] = "bandwidth-information"
                    return self.bandwidth_information

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "bandwidth-information" or name == "interface-name" or name == "interface-name-xr" or name == "paths-in" or name == "paths-out" or name == "reservations-in" or name == "reservations-out"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "interface-name"):
                    self.interface_name = value
                    self.interface_name.value_namespace = name_space
                    self.interface_name.value_namespace_prefix = name_space_prefix
                if(value_path == "interface-name-xr"):
                    self.interface_name_xr = value
                    self.interface_name_xr.value_namespace = name_space
                    self.interface_name_xr.value_namespace_prefix = name_space_prefix
                if(value_path == "paths-in"):
                    self.paths_in = value
                    self.paths_in.value_namespace = name_space
                    self.paths_in.value_namespace_prefix = name_space_prefix
                if(value_path == "paths-out"):
                    self.paths_out = value
                    self.paths_out.value_namespace = name_space
                    self.paths_out.value_namespace_prefix = name_space_prefix
                if(value_path == "reservations-in"):
                    self.reservations_in = value
                    self.reservations_in.value_namespace = name_space
                    self.reservations_in.value_namespace_prefix = name_space_prefix
                if(value_path == "reservations-out"):
                    self.reservations_out = value
                    self.reservations_out.value_namespace = name_space
                    self.reservations_out.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.interface_summary:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.interface_summary:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "interface-summaries" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "interface-summary"):
                for c in self.interface_summary:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = Rsvp.InterfaceSummaries.InterfaceSummary()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.interface_summary.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "interface-summary"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class HelloInstanceBriefs(Entity):
        """
        Table of brief info about hello instances
        
        .. attribute:: hello_instance_brief
        
        	Brief info for a single hello instance
        	**type**\: list of    :py:class:`HelloInstanceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.HelloInstanceBriefs.HelloInstanceBrief>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Rsvp.HelloInstanceBriefs, self).__init__()

            self.yang_name = "hello-instance-briefs"
            self.yang_parent_name = "rsvp"

            self.hello_instance_brief = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(Rsvp.HelloInstanceBriefs, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(Rsvp.HelloInstanceBriefs, self).__setattr__(name, value)


        class HelloInstanceBrief(Entity):
            """
            Brief info for a single hello instance
            
            .. attribute:: source_address  <key>
            
            	Source Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: destination_address  <key>
            
            	Destination Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: destination_address_xr
            
            	Destination address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: hello_interface
            
            	Interface to use
            	**type**\:  str
            
            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
            
            .. attribute:: instance_type
            
            	Hello instance type
            	**type**\:   :py:class:`RsvpMgmtHelloInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtHelloInstance>`
            
            .. attribute:: lost_communication_total
            
            	Total number of times communication got lost
            	**type**\:  int
            
            	**range:** 0..65535
            
            .. attribute:: neighbor_hello_state
            
            	Neighbor Hello state
            	**type**\:   :py:class:`RsvpMgmtHelloState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtHelloState>`
            
            .. attribute:: source_address_xr
            
            	Source address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Rsvp.HelloInstanceBriefs.HelloInstanceBrief, self).__init__()

                self.yang_name = "hello-instance-brief"
                self.yang_parent_name = "hello-instance-briefs"

                self.source_address = YLeaf(YType.str, "source-address")

                self.destination_address = YLeaf(YType.str, "destination-address")

                self.destination_address_xr = YLeaf(YType.str, "destination-address-xr")

                self.hello_interface = YLeaf(YType.str, "hello-interface")

                self.instance_type = YLeaf(YType.enumeration, "instance-type")

                self.lost_communication_total = YLeaf(YType.uint16, "lost-communication-total")

                self.neighbor_hello_state = YLeaf(YType.enumeration, "neighbor-hello-state")

                self.source_address_xr = YLeaf(YType.str, "source-address-xr")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("source_address",
                                "destination_address",
                                "destination_address_xr",
                                "hello_interface",
                                "instance_type",
                                "lost_communication_total",
                                "neighbor_hello_state",
                                "source_address_xr") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Rsvp.HelloInstanceBriefs.HelloInstanceBrief, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Rsvp.HelloInstanceBriefs.HelloInstanceBrief, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.source_address.is_set or
                    self.destination_address.is_set or
                    self.destination_address_xr.is_set or
                    self.hello_interface.is_set or
                    self.instance_type.is_set or
                    self.lost_communication_total.is_set or
                    self.neighbor_hello_state.is_set or
                    self.source_address_xr.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.source_address.yfilter != YFilter.not_set or
                    self.destination_address.yfilter != YFilter.not_set or
                    self.destination_address_xr.yfilter != YFilter.not_set or
                    self.hello_interface.yfilter != YFilter.not_set or
                    self.instance_type.yfilter != YFilter.not_set or
                    self.lost_communication_total.yfilter != YFilter.not_set or
                    self.neighbor_hello_state.yfilter != YFilter.not_set or
                    self.source_address_xr.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "hello-instance-brief" + "[source-address='" + self.source_address.get() + "']" + "[destination-address='" + self.destination_address.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/hello-instance-briefs/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_address.get_name_leafdata())
                if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_address.get_name_leafdata())
                if (self.destination_address_xr.is_set or self.destination_address_xr.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_address_xr.get_name_leafdata())
                if (self.hello_interface.is_set or self.hello_interface.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.hello_interface.get_name_leafdata())
                if (self.instance_type.is_set or self.instance_type.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.instance_type.get_name_leafdata())
                if (self.lost_communication_total.is_set or self.lost_communication_total.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.lost_communication_total.get_name_leafdata())
                if (self.neighbor_hello_state.is_set or self.neighbor_hello_state.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.neighbor_hello_state.get_name_leafdata())
                if (self.source_address_xr.is_set or self.source_address_xr.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_address_xr.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "source-address" or name == "destination-address" or name == "destination-address-xr" or name == "hello-interface" or name == "instance-type" or name == "lost-communication-total" or name == "neighbor-hello-state" or name == "source-address-xr"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "source-address"):
                    self.source_address = value
                    self.source_address.value_namespace = name_space
                    self.source_address.value_namespace_prefix = name_space_prefix
                if(value_path == "destination-address"):
                    self.destination_address = value
                    self.destination_address.value_namespace = name_space
                    self.destination_address.value_namespace_prefix = name_space_prefix
                if(value_path == "destination-address-xr"):
                    self.destination_address_xr = value
                    self.destination_address_xr.value_namespace = name_space
                    self.destination_address_xr.value_namespace_prefix = name_space_prefix
                if(value_path == "hello-interface"):
                    self.hello_interface = value
                    self.hello_interface.value_namespace = name_space
                    self.hello_interface.value_namespace_prefix = name_space_prefix
                if(value_path == "instance-type"):
                    self.instance_type = value
                    self.instance_type.value_namespace = name_space
                    self.instance_type.value_namespace_prefix = name_space_prefix
                if(value_path == "lost-communication-total"):
                    self.lost_communication_total = value
                    self.lost_communication_total.value_namespace = name_space
                    self.lost_communication_total.value_namespace_prefix = name_space_prefix
                if(value_path == "neighbor-hello-state"):
                    self.neighbor_hello_state = value
                    self.neighbor_hello_state.value_namespace = name_space
                    self.neighbor_hello_state.value_namespace_prefix = name_space_prefix
                if(value_path == "source-address-xr"):
                    self.source_address_xr = value
                    self.source_address_xr.value_namespace = name_space
                    self.source_address_xr.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.hello_instance_brief:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.hello_instance_brief:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "hello-instance-briefs" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "hello-instance-brief"):
                for c in self.hello_instance_brief:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = Rsvp.HelloInstanceBriefs.HelloInstanceBrief()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.hello_instance_brief.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "hello-instance-brief"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class AuthenticationDetails(Entity):
        """
        Table for detailed authentication related
        information
        
        .. attribute:: authentication_detail
        
        	Brief Authentication information
        	**type**\: list of    :py:class:`AuthenticationDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.AuthenticationDetails.AuthenticationDetail>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Rsvp.AuthenticationDetails, self).__init__()

            self.yang_name = "authentication-details"
            self.yang_parent_name = "rsvp"

            self.authentication_detail = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(Rsvp.AuthenticationDetails, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(Rsvp.AuthenticationDetails, self).__setattr__(name, value)


        class AuthenticationDetail(Entity):
            """
            Brief Authentication information
            
            .. attribute:: source_address  <key>
            
            	Source Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: destination_address  <key>
            
            	Destination Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: mode_id  <key>
            
            	Mode (Tx or Rx)
            	**type**\:   :py:class:`RsvpMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMode>`
            
            .. attribute:: interface_name  <key>
            
            	InterfaceName
            	**type**\:  str
            
            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
            
            .. attribute:: auth_compact
            
            	Basic authentication data
            	**type**\:   :py:class:`AuthCompact <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.AuthenticationDetails.AuthenticationDetail.AuthCompact>`
            
            .. attribute:: challenge_status
            
            	Challenge status
            	**type**\:   :py:class:`RsvpMgmtAuthChallengeStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtAuthChallengeStatus>`
            
            .. attribute:: direction_info
            
            	direction info
            	**type**\:   :py:class:`DirectionInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.AuthenticationDetails.AuthenticationDetail.DirectionInfo>`
            
            .. attribute:: key_digest_info
            
            	Direction
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: key_status
            
            	Key status
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: lifetime
            
            	Lifetime (seconds)
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            	**units**\: second
            
            .. attribute:: lifetime_left
            
            	Remaining lifetime (seconds)
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            	**units**\: second
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Rsvp.AuthenticationDetails.AuthenticationDetail, self).__init__()

                self.yang_name = "authentication-detail"
                self.yang_parent_name = "authentication-details"

                self.source_address = YLeaf(YType.str, "source-address")

                self.destination_address = YLeaf(YType.str, "destination-address")

                self.mode_id = YLeaf(YType.enumeration, "mode-id")

                self.interface_name = YLeaf(YType.str, "interface-name")

                self.challenge_status = YLeaf(YType.enumeration, "challenge-status")

                self.key_digest_info = YLeaf(YType.uint32, "key-digest-info")

                self.key_status = YLeaf(YType.uint32, "key-status")

                self.lifetime = YLeaf(YType.uint32, "lifetime")

                self.lifetime_left = YLeaf(YType.uint32, "lifetime-left")

                self.auth_compact = Rsvp.AuthenticationDetails.AuthenticationDetail.AuthCompact()
                self.auth_compact.parent = self
                self._children_name_map["auth_compact"] = "auth-compact"
                self._children_yang_names.add("auth-compact")

                self.direction_info = Rsvp.AuthenticationDetails.AuthenticationDetail.DirectionInfo()
                self.direction_info.parent = self
                self._children_name_map["direction_info"] = "direction-info"
                self._children_yang_names.add("direction-info")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("source_address",
                                "destination_address",
                                "mode_id",
                                "interface_name",
                                "challenge_status",
                                "key_digest_info",
                                "key_status",
                                "lifetime",
                                "lifetime_left") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Rsvp.AuthenticationDetails.AuthenticationDetail, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Rsvp.AuthenticationDetails.AuthenticationDetail, self).__setattr__(name, value)


            class AuthCompact(Entity):
                """
                Basic authentication data
                
                .. attribute:: destination_address_xr
                
                	Destination address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: direction
                
                	Direction
                	**type**\:   :py:class:`RsvpMgmtAuthDirection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtAuthDirection>`
                
                .. attribute:: key_id
                
                	Key ID
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: key_id_valid
                
                	Key validity
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: key_source
                
                	Key source
                	**type**\:  str
                
                .. attribute:: key_type
                
                	Key type
                	**type**\:   :py:class:`RsvpMgmtAuthKi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtAuthKi>`
                
                .. attribute:: neighbor_address
                
                	Neighbor address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: source_address_xr
                
                	Source address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.AuthenticationDetails.AuthenticationDetail.AuthCompact, self).__init__()

                    self.yang_name = "auth-compact"
                    self.yang_parent_name = "authentication-detail"

                    self.destination_address_xr = YLeaf(YType.str, "destination-address-xr")

                    self.direction = YLeaf(YType.enumeration, "direction")

                    self.key_id = YLeaf(YType.uint64, "key-id")

                    self.key_id_valid = YLeaf(YType.uint32, "key-id-valid")

                    self.key_source = YLeaf(YType.str, "key-source")

                    self.key_type = YLeaf(YType.enumeration, "key-type")

                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                    self.source_address_xr = YLeaf(YType.str, "source-address-xr")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("destination_address_xr",
                                    "direction",
                                    "key_id",
                                    "key_id_valid",
                                    "key_source",
                                    "key_type",
                                    "neighbor_address",
                                    "source_address_xr") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.AuthenticationDetails.AuthenticationDetail.AuthCompact, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.AuthenticationDetails.AuthenticationDetail.AuthCompact, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.destination_address_xr.is_set or
                        self.direction.is_set or
                        self.key_id.is_set or
                        self.key_id_valid.is_set or
                        self.key_source.is_set or
                        self.key_type.is_set or
                        self.neighbor_address.is_set or
                        self.source_address_xr.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.destination_address_xr.yfilter != YFilter.not_set or
                        self.direction.yfilter != YFilter.not_set or
                        self.key_id.yfilter != YFilter.not_set or
                        self.key_id_valid.yfilter != YFilter.not_set or
                        self.key_source.yfilter != YFilter.not_set or
                        self.key_type.yfilter != YFilter.not_set or
                        self.neighbor_address.yfilter != YFilter.not_set or
                        self.source_address_xr.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "auth-compact" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.destination_address_xr.is_set or self.destination_address_xr.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.destination_address_xr.get_name_leafdata())
                    if (self.direction.is_set or self.direction.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.direction.get_name_leafdata())
                    if (self.key_id.is_set or self.key_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.key_id.get_name_leafdata())
                    if (self.key_id_valid.is_set or self.key_id_valid.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.key_id_valid.get_name_leafdata())
                    if (self.key_source.is_set or self.key_source.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.key_source.get_name_leafdata())
                    if (self.key_type.is_set or self.key_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.key_type.get_name_leafdata())
                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                    if (self.source_address_xr.is_set or self.source_address_xr.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.source_address_xr.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "destination-address-xr" or name == "direction" or name == "key-id" or name == "key-id-valid" or name == "key-source" or name == "key-type" or name == "neighbor-address" or name == "source-address-xr"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "destination-address-xr"):
                        self.destination_address_xr = value
                        self.destination_address_xr.value_namespace = name_space
                        self.destination_address_xr.value_namespace_prefix = name_space_prefix
                    if(value_path == "direction"):
                        self.direction = value
                        self.direction.value_namespace = name_space
                        self.direction.value_namespace_prefix = name_space_prefix
                    if(value_path == "key-id"):
                        self.key_id = value
                        self.key_id.value_namespace = name_space
                        self.key_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "key-id-valid"):
                        self.key_id_valid = value
                        self.key_id_valid.value_namespace = name_space
                        self.key_id_valid.value_namespace_prefix = name_space_prefix
                    if(value_path == "key-source"):
                        self.key_source = value
                        self.key_source.value_namespace = name_space
                        self.key_source.value_namespace_prefix = name_space_prefix
                    if(value_path == "key-type"):
                        self.key_type = value
                        self.key_type.value_namespace = name_space
                        self.key_type.value_namespace_prefix = name_space_prefix
                    if(value_path == "neighbor-address"):
                        self.neighbor_address = value
                        self.neighbor_address.value_namespace = name_space
                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "source-address-xr"):
                        self.source_address_xr = value
                        self.source_address_xr.value_namespace = name_space
                        self.source_address_xr.value_namespace_prefix = name_space_prefix


            class DirectionInfo(Entity):
                """
                direction info
                
                .. attribute:: auth_direction
                
                	AuthDirection
                	**type**\:   :py:class:`RsvpMgmtAuthDirection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtAuthDirection>`
                
                .. attribute:: receive_info
                
                	receive info
                	**type**\:   :py:class:`ReceiveInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.AuthenticationDetails.AuthenticationDetail.DirectionInfo.ReceiveInfo>`
                
                .. attribute:: send_info
                
                	send info
                	**type**\:   :py:class:`SendInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.AuthenticationDetails.AuthenticationDetail.DirectionInfo.SendInfo>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.AuthenticationDetails.AuthenticationDetail.DirectionInfo, self).__init__()

                    self.yang_name = "direction-info"
                    self.yang_parent_name = "authentication-detail"

                    self.auth_direction = YLeaf(YType.enumeration, "auth-direction")

                    self.receive_info = Rsvp.AuthenticationDetails.AuthenticationDetail.DirectionInfo.ReceiveInfo()
                    self.receive_info.parent = self
                    self._children_name_map["receive_info"] = "receive-info"
                    self._children_yang_names.add("receive-info")

                    self.send_info = Rsvp.AuthenticationDetails.AuthenticationDetail.DirectionInfo.SendInfo()
                    self.send_info.parent = self
                    self._children_name_map["send_info"] = "send-info"
                    self._children_yang_names.add("send-info")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("auth_direction") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.AuthenticationDetails.AuthenticationDetail.DirectionInfo, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.AuthenticationDetails.AuthenticationDetail.DirectionInfo, self).__setattr__(name, value)


                class SendInfo(Entity):
                    """
                    send info
                    
                    .. attribute:: counters
                    
                    	Counters
                    	**type**\:   :py:class:`Counters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.AuthenticationDetails.AuthenticationDetail.DirectionInfo.SendInfo.Counters>`
                    
                    .. attribute:: sequence
                    
                    	Sequence number
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.AuthenticationDetails.AuthenticationDetail.DirectionInfo.SendInfo, self).__init__()

                        self.yang_name = "send-info"
                        self.yang_parent_name = "direction-info"

                        self.sequence = YLeaf(YType.uint64, "sequence")

                        self.counters = Rsvp.AuthenticationDetails.AuthenticationDetail.DirectionInfo.SendInfo.Counters()
                        self.counters.parent = self
                        self._children_name_map["counters"] = "counters"
                        self._children_yang_names.add("counters")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("sequence") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.AuthenticationDetails.AuthenticationDetail.DirectionInfo.SendInfo, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.AuthenticationDetails.AuthenticationDetail.DirectionInfo.SendInfo, self).__setattr__(name, value)


                    class Counters(Entity):
                        """
                        Counters
                        
                        .. attribute:: authentication_challenge_responses_sent
                        
                        	Challenge responses sent
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: authentication_failures
                        
                        	Failures
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: authentication_send_challenges_received
                        
                        	Challenges received
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: authentication_sent
                        
                        	Messages sent
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.AuthenticationDetails.AuthenticationDetail.DirectionInfo.SendInfo.Counters, self).__init__()

                            self.yang_name = "counters"
                            self.yang_parent_name = "send-info"

                            self.authentication_challenge_responses_sent = YLeaf(YType.uint32, "authentication-challenge-responses-sent")

                            self.authentication_failures = YLeaf(YType.uint32, "authentication-failures")

                            self.authentication_send_challenges_received = YLeaf(YType.uint32, "authentication-send-challenges-received")

                            self.authentication_sent = YLeaf(YType.uint32, "authentication-sent")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("authentication_challenge_responses_sent",
                                            "authentication_failures",
                                            "authentication_send_challenges_received",
                                            "authentication_sent") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.AuthenticationDetails.AuthenticationDetail.DirectionInfo.SendInfo.Counters, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.AuthenticationDetails.AuthenticationDetail.DirectionInfo.SendInfo.Counters, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.authentication_challenge_responses_sent.is_set or
                                self.authentication_failures.is_set or
                                self.authentication_send_challenges_received.is_set or
                                self.authentication_sent.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.authentication_challenge_responses_sent.yfilter != YFilter.not_set or
                                self.authentication_failures.yfilter != YFilter.not_set or
                                self.authentication_send_challenges_received.yfilter != YFilter.not_set or
                                self.authentication_sent.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "counters" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.authentication_challenge_responses_sent.is_set or self.authentication_challenge_responses_sent.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.authentication_challenge_responses_sent.get_name_leafdata())
                            if (self.authentication_failures.is_set or self.authentication_failures.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.authentication_failures.get_name_leafdata())
                            if (self.authentication_send_challenges_received.is_set or self.authentication_send_challenges_received.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.authentication_send_challenges_received.get_name_leafdata())
                            if (self.authentication_sent.is_set or self.authentication_sent.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.authentication_sent.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "authentication-challenge-responses-sent" or name == "authentication-failures" or name == "authentication-send-challenges-received" or name == "authentication-sent"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "authentication-challenge-responses-sent"):
                                self.authentication_challenge_responses_sent = value
                                self.authentication_challenge_responses_sent.value_namespace = name_space
                                self.authentication_challenge_responses_sent.value_namespace_prefix = name_space_prefix
                            if(value_path == "authentication-failures"):
                                self.authentication_failures = value
                                self.authentication_failures.value_namespace = name_space
                                self.authentication_failures.value_namespace_prefix = name_space_prefix
                            if(value_path == "authentication-send-challenges-received"):
                                self.authentication_send_challenges_received = value
                                self.authentication_send_challenges_received.value_namespace = name_space
                                self.authentication_send_challenges_received.value_namespace_prefix = name_space_prefix
                            if(value_path == "authentication-sent"):
                                self.authentication_sent = value
                                self.authentication_sent.value_namespace = name_space
                                self.authentication_sent.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.sequence.is_set or
                            (self.counters is not None and self.counters.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.sequence.yfilter != YFilter.not_set or
                            (self.counters is not None and self.counters.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "send-info" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.sequence.is_set or self.sequence.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sequence.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "counters"):
                            if (self.counters is None):
                                self.counters = Rsvp.AuthenticationDetails.AuthenticationDetail.DirectionInfo.SendInfo.Counters()
                                self.counters.parent = self
                                self._children_name_map["counters"] = "counters"
                            return self.counters

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "counters" or name == "sequence"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "sequence"):
                            self.sequence = value
                            self.sequence.value_namespace = name_space
                            self.sequence.value_namespace_prefix = name_space_prefix


                class ReceiveInfo(Entity):
                    """
                    receive info
                    
                    .. attribute:: counters
                    
                    	Counters
                    	**type**\:   :py:class:`Counters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.AuthenticationDetails.AuthenticationDetail.DirectionInfo.ReceiveInfo.Counters>`
                    
                    .. attribute:: sequence
                    
                    	Sequence number
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: sequence_window
                    
                    	Sequence window
                    	**type**\:  list of int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: sequence_window_count
                    
                    	Sequence window count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sequence_window_size
                    
                    	Sequence window size
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.AuthenticationDetails.AuthenticationDetail.DirectionInfo.ReceiveInfo, self).__init__()

                        self.yang_name = "receive-info"
                        self.yang_parent_name = "direction-info"

                        self.sequence = YLeaf(YType.uint64, "sequence")

                        self.sequence_window = YLeafList(YType.uint64, "sequence-window")

                        self.sequence_window_count = YLeaf(YType.uint32, "sequence-window-count")

                        self.sequence_window_size = YLeaf(YType.uint32, "sequence-window-size")

                        self.counters = Rsvp.AuthenticationDetails.AuthenticationDetail.DirectionInfo.ReceiveInfo.Counters()
                        self.counters.parent = self
                        self._children_name_map["counters"] = "counters"
                        self._children_yang_names.add("counters")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("sequence",
                                        "sequence_window",
                                        "sequence_window_count",
                                        "sequence_window_size") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.AuthenticationDetails.AuthenticationDetail.DirectionInfo.ReceiveInfo, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.AuthenticationDetails.AuthenticationDetail.DirectionInfo.ReceiveInfo, self).__setattr__(name, value)


                    class Counters(Entity):
                        """
                        Counters
                        
                        .. attribute:: authentication_received_bad_digest
                        
                        	Authentication received with bad digest
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: authentication_received_bad_message_format
                        
                        	Authentication received with bad mesage format
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: authentication_received_challenge_response
                        
                        	Challenge responses received
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: authentication_received_challenge_timeouts
                        
                        	Challenge timeouts
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: authentication_received_challenges_resent
                        
                        	Challenges resent
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: authentication_received_challenges_response_duplicate
                        
                        	Duplicate challenge responses received
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: authentication_received_challenges_sent
                        
                        	Challenges sent
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: authentication_received_during_challenge
                        
                        	Authentication received during challenge
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: authentication_received_incomplete
                        
                        	Authentication received incomplete
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: authentication_received_no_integrity
                        
                        	Authentication received with no integrity
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: authentication_received_response_late
                        
                        	Challenge responses received late
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: authentication_received_sequence_number_duplicate
                        
                        	Authentication received with duplicate sequence number
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: authentication_received_sequence_number_outof_range
                        
                        	Authentication received with sequence number out of range
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: authentication_received_valid_messages
                        
                        	Valid messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: authentication_received_wrong_challenges_response
                        
                        	Incorect challenge responses received
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: authentication_received_wrong_digest_type
                        
                        	Authentication received with wrong digest type
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.AuthenticationDetails.AuthenticationDetail.DirectionInfo.ReceiveInfo.Counters, self).__init__()

                            self.yang_name = "counters"
                            self.yang_parent_name = "receive-info"

                            self.authentication_received_bad_digest = YLeaf(YType.uint32, "authentication-received-bad-digest")

                            self.authentication_received_bad_message_format = YLeaf(YType.uint32, "authentication-received-bad-message-format")

                            self.authentication_received_challenge_response = YLeaf(YType.uint32, "authentication-received-challenge-response")

                            self.authentication_received_challenge_timeouts = YLeaf(YType.uint32, "authentication-received-challenge-timeouts")

                            self.authentication_received_challenges_resent = YLeaf(YType.uint32, "authentication-received-challenges-resent")

                            self.authentication_received_challenges_response_duplicate = YLeaf(YType.uint32, "authentication-received-challenges-response-duplicate")

                            self.authentication_received_challenges_sent = YLeaf(YType.uint32, "authentication-received-challenges-sent")

                            self.authentication_received_during_challenge = YLeaf(YType.uint32, "authentication-received-during-challenge")

                            self.authentication_received_incomplete = YLeaf(YType.uint32, "authentication-received-incomplete")

                            self.authentication_received_no_integrity = YLeaf(YType.uint32, "authentication-received-no-integrity")

                            self.authentication_received_response_late = YLeaf(YType.uint32, "authentication-received-response-late")

                            self.authentication_received_sequence_number_duplicate = YLeaf(YType.uint32, "authentication-received-sequence-number-duplicate")

                            self.authentication_received_sequence_number_outof_range = YLeaf(YType.uint32, "authentication-received-sequence-number-outof-range")

                            self.authentication_received_valid_messages = YLeaf(YType.uint32, "authentication-received-valid-messages")

                            self.authentication_received_wrong_challenges_response = YLeaf(YType.uint32, "authentication-received-wrong-challenges-response")

                            self.authentication_received_wrong_digest_type = YLeaf(YType.uint32, "authentication-received-wrong-digest-type")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("authentication_received_bad_digest",
                                            "authentication_received_bad_message_format",
                                            "authentication_received_challenge_response",
                                            "authentication_received_challenge_timeouts",
                                            "authentication_received_challenges_resent",
                                            "authentication_received_challenges_response_duplicate",
                                            "authentication_received_challenges_sent",
                                            "authentication_received_during_challenge",
                                            "authentication_received_incomplete",
                                            "authentication_received_no_integrity",
                                            "authentication_received_response_late",
                                            "authentication_received_sequence_number_duplicate",
                                            "authentication_received_sequence_number_outof_range",
                                            "authentication_received_valid_messages",
                                            "authentication_received_wrong_challenges_response",
                                            "authentication_received_wrong_digest_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.AuthenticationDetails.AuthenticationDetail.DirectionInfo.ReceiveInfo.Counters, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.AuthenticationDetails.AuthenticationDetail.DirectionInfo.ReceiveInfo.Counters, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.authentication_received_bad_digest.is_set or
                                self.authentication_received_bad_message_format.is_set or
                                self.authentication_received_challenge_response.is_set or
                                self.authentication_received_challenge_timeouts.is_set or
                                self.authentication_received_challenges_resent.is_set or
                                self.authentication_received_challenges_response_duplicate.is_set or
                                self.authentication_received_challenges_sent.is_set or
                                self.authentication_received_during_challenge.is_set or
                                self.authentication_received_incomplete.is_set or
                                self.authentication_received_no_integrity.is_set or
                                self.authentication_received_response_late.is_set or
                                self.authentication_received_sequence_number_duplicate.is_set or
                                self.authentication_received_sequence_number_outof_range.is_set or
                                self.authentication_received_valid_messages.is_set or
                                self.authentication_received_wrong_challenges_response.is_set or
                                self.authentication_received_wrong_digest_type.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.authentication_received_bad_digest.yfilter != YFilter.not_set or
                                self.authentication_received_bad_message_format.yfilter != YFilter.not_set or
                                self.authentication_received_challenge_response.yfilter != YFilter.not_set or
                                self.authentication_received_challenge_timeouts.yfilter != YFilter.not_set or
                                self.authentication_received_challenges_resent.yfilter != YFilter.not_set or
                                self.authentication_received_challenges_response_duplicate.yfilter != YFilter.not_set or
                                self.authentication_received_challenges_sent.yfilter != YFilter.not_set or
                                self.authentication_received_during_challenge.yfilter != YFilter.not_set or
                                self.authentication_received_incomplete.yfilter != YFilter.not_set or
                                self.authentication_received_no_integrity.yfilter != YFilter.not_set or
                                self.authentication_received_response_late.yfilter != YFilter.not_set or
                                self.authentication_received_sequence_number_duplicate.yfilter != YFilter.not_set or
                                self.authentication_received_sequence_number_outof_range.yfilter != YFilter.not_set or
                                self.authentication_received_valid_messages.yfilter != YFilter.not_set or
                                self.authentication_received_wrong_challenges_response.yfilter != YFilter.not_set or
                                self.authentication_received_wrong_digest_type.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "counters" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.authentication_received_bad_digest.is_set or self.authentication_received_bad_digest.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.authentication_received_bad_digest.get_name_leafdata())
                            if (self.authentication_received_bad_message_format.is_set or self.authentication_received_bad_message_format.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.authentication_received_bad_message_format.get_name_leafdata())
                            if (self.authentication_received_challenge_response.is_set or self.authentication_received_challenge_response.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.authentication_received_challenge_response.get_name_leafdata())
                            if (self.authentication_received_challenge_timeouts.is_set or self.authentication_received_challenge_timeouts.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.authentication_received_challenge_timeouts.get_name_leafdata())
                            if (self.authentication_received_challenges_resent.is_set or self.authentication_received_challenges_resent.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.authentication_received_challenges_resent.get_name_leafdata())
                            if (self.authentication_received_challenges_response_duplicate.is_set or self.authentication_received_challenges_response_duplicate.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.authentication_received_challenges_response_duplicate.get_name_leafdata())
                            if (self.authentication_received_challenges_sent.is_set or self.authentication_received_challenges_sent.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.authentication_received_challenges_sent.get_name_leafdata())
                            if (self.authentication_received_during_challenge.is_set or self.authentication_received_during_challenge.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.authentication_received_during_challenge.get_name_leafdata())
                            if (self.authentication_received_incomplete.is_set or self.authentication_received_incomplete.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.authentication_received_incomplete.get_name_leafdata())
                            if (self.authentication_received_no_integrity.is_set or self.authentication_received_no_integrity.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.authentication_received_no_integrity.get_name_leafdata())
                            if (self.authentication_received_response_late.is_set or self.authentication_received_response_late.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.authentication_received_response_late.get_name_leafdata())
                            if (self.authentication_received_sequence_number_duplicate.is_set or self.authentication_received_sequence_number_duplicate.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.authentication_received_sequence_number_duplicate.get_name_leafdata())
                            if (self.authentication_received_sequence_number_outof_range.is_set or self.authentication_received_sequence_number_outof_range.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.authentication_received_sequence_number_outof_range.get_name_leafdata())
                            if (self.authentication_received_valid_messages.is_set or self.authentication_received_valid_messages.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.authentication_received_valid_messages.get_name_leafdata())
                            if (self.authentication_received_wrong_challenges_response.is_set or self.authentication_received_wrong_challenges_response.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.authentication_received_wrong_challenges_response.get_name_leafdata())
                            if (self.authentication_received_wrong_digest_type.is_set or self.authentication_received_wrong_digest_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.authentication_received_wrong_digest_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "authentication-received-bad-digest" or name == "authentication-received-bad-message-format" or name == "authentication-received-challenge-response" or name == "authentication-received-challenge-timeouts" or name == "authentication-received-challenges-resent" or name == "authentication-received-challenges-response-duplicate" or name == "authentication-received-challenges-sent" or name == "authentication-received-during-challenge" or name == "authentication-received-incomplete" or name == "authentication-received-no-integrity" or name == "authentication-received-response-late" or name == "authentication-received-sequence-number-duplicate" or name == "authentication-received-sequence-number-outof-range" or name == "authentication-received-valid-messages" or name == "authentication-received-wrong-challenges-response" or name == "authentication-received-wrong-digest-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "authentication-received-bad-digest"):
                                self.authentication_received_bad_digest = value
                                self.authentication_received_bad_digest.value_namespace = name_space
                                self.authentication_received_bad_digest.value_namespace_prefix = name_space_prefix
                            if(value_path == "authentication-received-bad-message-format"):
                                self.authentication_received_bad_message_format = value
                                self.authentication_received_bad_message_format.value_namespace = name_space
                                self.authentication_received_bad_message_format.value_namespace_prefix = name_space_prefix
                            if(value_path == "authentication-received-challenge-response"):
                                self.authentication_received_challenge_response = value
                                self.authentication_received_challenge_response.value_namespace = name_space
                                self.authentication_received_challenge_response.value_namespace_prefix = name_space_prefix
                            if(value_path == "authentication-received-challenge-timeouts"):
                                self.authentication_received_challenge_timeouts = value
                                self.authentication_received_challenge_timeouts.value_namespace = name_space
                                self.authentication_received_challenge_timeouts.value_namespace_prefix = name_space_prefix
                            if(value_path == "authentication-received-challenges-resent"):
                                self.authentication_received_challenges_resent = value
                                self.authentication_received_challenges_resent.value_namespace = name_space
                                self.authentication_received_challenges_resent.value_namespace_prefix = name_space_prefix
                            if(value_path == "authentication-received-challenges-response-duplicate"):
                                self.authentication_received_challenges_response_duplicate = value
                                self.authentication_received_challenges_response_duplicate.value_namespace = name_space
                                self.authentication_received_challenges_response_duplicate.value_namespace_prefix = name_space_prefix
                            if(value_path == "authentication-received-challenges-sent"):
                                self.authentication_received_challenges_sent = value
                                self.authentication_received_challenges_sent.value_namespace = name_space
                                self.authentication_received_challenges_sent.value_namespace_prefix = name_space_prefix
                            if(value_path == "authentication-received-during-challenge"):
                                self.authentication_received_during_challenge = value
                                self.authentication_received_during_challenge.value_namespace = name_space
                                self.authentication_received_during_challenge.value_namespace_prefix = name_space_prefix
                            if(value_path == "authentication-received-incomplete"):
                                self.authentication_received_incomplete = value
                                self.authentication_received_incomplete.value_namespace = name_space
                                self.authentication_received_incomplete.value_namespace_prefix = name_space_prefix
                            if(value_path == "authentication-received-no-integrity"):
                                self.authentication_received_no_integrity = value
                                self.authentication_received_no_integrity.value_namespace = name_space
                                self.authentication_received_no_integrity.value_namespace_prefix = name_space_prefix
                            if(value_path == "authentication-received-response-late"):
                                self.authentication_received_response_late = value
                                self.authentication_received_response_late.value_namespace = name_space
                                self.authentication_received_response_late.value_namespace_prefix = name_space_prefix
                            if(value_path == "authentication-received-sequence-number-duplicate"):
                                self.authentication_received_sequence_number_duplicate = value
                                self.authentication_received_sequence_number_duplicate.value_namespace = name_space
                                self.authentication_received_sequence_number_duplicate.value_namespace_prefix = name_space_prefix
                            if(value_path == "authentication-received-sequence-number-outof-range"):
                                self.authentication_received_sequence_number_outof_range = value
                                self.authentication_received_sequence_number_outof_range.value_namespace = name_space
                                self.authentication_received_sequence_number_outof_range.value_namespace_prefix = name_space_prefix
                            if(value_path == "authentication-received-valid-messages"):
                                self.authentication_received_valid_messages = value
                                self.authentication_received_valid_messages.value_namespace = name_space
                                self.authentication_received_valid_messages.value_namespace_prefix = name_space_prefix
                            if(value_path == "authentication-received-wrong-challenges-response"):
                                self.authentication_received_wrong_challenges_response = value
                                self.authentication_received_wrong_challenges_response.value_namespace = name_space
                                self.authentication_received_wrong_challenges_response.value_namespace_prefix = name_space_prefix
                            if(value_path == "authentication-received-wrong-digest-type"):
                                self.authentication_received_wrong_digest_type = value
                                self.authentication_received_wrong_digest_type.value_namespace = name_space
                                self.authentication_received_wrong_digest_type.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for leaf in self.sequence_window.getYLeafs():
                            if (leaf.yfilter != YFilter.not_set):
                                return True
                        return (
                            self.sequence.is_set or
                            self.sequence_window_count.is_set or
                            self.sequence_window_size.is_set or
                            (self.counters is not None and self.counters.has_data()))

                    def has_operation(self):
                        for leaf in self.sequence_window.getYLeafs():
                            if (leaf.is_set):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.sequence.yfilter != YFilter.not_set or
                            self.sequence_window.yfilter != YFilter.not_set or
                            self.sequence_window_count.yfilter != YFilter.not_set or
                            self.sequence_window_size.yfilter != YFilter.not_set or
                            (self.counters is not None and self.counters.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "receive-info" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.sequence.is_set or self.sequence.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sequence.get_name_leafdata())
                        if (self.sequence_window_count.is_set or self.sequence_window_count.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sequence_window_count.get_name_leafdata())
                        if (self.sequence_window_size.is_set or self.sequence_window_size.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sequence_window_size.get_name_leafdata())

                        leaf_name_data.extend(self.sequence_window.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "counters"):
                            if (self.counters is None):
                                self.counters = Rsvp.AuthenticationDetails.AuthenticationDetail.DirectionInfo.ReceiveInfo.Counters()
                                self.counters.parent = self
                                self._children_name_map["counters"] = "counters"
                            return self.counters

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "counters" or name == "sequence" or name == "sequence-window" or name == "sequence-window-count" or name == "sequence-window-size"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "sequence"):
                            self.sequence = value
                            self.sequence.value_namespace = name_space
                            self.sequence.value_namespace_prefix = name_space_prefix
                        if(value_path == "sequence-window"):
                            self.sequence_window.append(value)
                        if(value_path == "sequence-window-count"):
                            self.sequence_window_count = value
                            self.sequence_window_count.value_namespace = name_space
                            self.sequence_window_count.value_namespace_prefix = name_space_prefix
                        if(value_path == "sequence-window-size"):
                            self.sequence_window_size = value
                            self.sequence_window_size.value_namespace = name_space
                            self.sequence_window_size.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.auth_direction.is_set or
                        (self.receive_info is not None and self.receive_info.has_data()) or
                        (self.send_info is not None and self.send_info.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.auth_direction.yfilter != YFilter.not_set or
                        (self.receive_info is not None and self.receive_info.has_operation()) or
                        (self.send_info is not None and self.send_info.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "direction-info" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.auth_direction.is_set or self.auth_direction.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.auth_direction.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "receive-info"):
                        if (self.receive_info is None):
                            self.receive_info = Rsvp.AuthenticationDetails.AuthenticationDetail.DirectionInfo.ReceiveInfo()
                            self.receive_info.parent = self
                            self._children_name_map["receive_info"] = "receive-info"
                        return self.receive_info

                    if (child_yang_name == "send-info"):
                        if (self.send_info is None):
                            self.send_info = Rsvp.AuthenticationDetails.AuthenticationDetail.DirectionInfo.SendInfo()
                            self.send_info.parent = self
                            self._children_name_map["send_info"] = "send-info"
                        return self.send_info

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "receive-info" or name == "send-info" or name == "auth-direction"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "auth-direction"):
                        self.auth_direction = value
                        self.auth_direction.value_namespace = name_space
                        self.auth_direction.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.source_address.is_set or
                    self.destination_address.is_set or
                    self.mode_id.is_set or
                    self.interface_name.is_set or
                    self.challenge_status.is_set or
                    self.key_digest_info.is_set or
                    self.key_status.is_set or
                    self.lifetime.is_set or
                    self.lifetime_left.is_set or
                    (self.auth_compact is not None and self.auth_compact.has_data()) or
                    (self.direction_info is not None and self.direction_info.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.source_address.yfilter != YFilter.not_set or
                    self.destination_address.yfilter != YFilter.not_set or
                    self.mode_id.yfilter != YFilter.not_set or
                    self.interface_name.yfilter != YFilter.not_set or
                    self.challenge_status.yfilter != YFilter.not_set or
                    self.key_digest_info.yfilter != YFilter.not_set or
                    self.key_status.yfilter != YFilter.not_set or
                    self.lifetime.yfilter != YFilter.not_set or
                    self.lifetime_left.yfilter != YFilter.not_set or
                    (self.auth_compact is not None and self.auth_compact.has_operation()) or
                    (self.direction_info is not None and self.direction_info.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "authentication-detail" + "[source-address='" + self.source_address.get() + "']" + "[destination-address='" + self.destination_address.get() + "']" + "[mode-id='" + self.mode_id.get() + "']" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/authentication-details/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_address.get_name_leafdata())
                if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_address.get_name_leafdata())
                if (self.mode_id.is_set or self.mode_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.mode_id.get_name_leafdata())
                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                if (self.challenge_status.is_set or self.challenge_status.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.challenge_status.get_name_leafdata())
                if (self.key_digest_info.is_set or self.key_digest_info.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.key_digest_info.get_name_leafdata())
                if (self.key_status.is_set or self.key_status.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.key_status.get_name_leafdata())
                if (self.lifetime.is_set or self.lifetime.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.lifetime.get_name_leafdata())
                if (self.lifetime_left.is_set or self.lifetime_left.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.lifetime_left.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "auth-compact"):
                    if (self.auth_compact is None):
                        self.auth_compact = Rsvp.AuthenticationDetails.AuthenticationDetail.AuthCompact()
                        self.auth_compact.parent = self
                        self._children_name_map["auth_compact"] = "auth-compact"
                    return self.auth_compact

                if (child_yang_name == "direction-info"):
                    if (self.direction_info is None):
                        self.direction_info = Rsvp.AuthenticationDetails.AuthenticationDetail.DirectionInfo()
                        self.direction_info.parent = self
                        self._children_name_map["direction_info"] = "direction-info"
                    return self.direction_info

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "auth-compact" or name == "direction-info" or name == "source-address" or name == "destination-address" or name == "mode-id" or name == "interface-name" or name == "challenge-status" or name == "key-digest-info" or name == "key-status" or name == "lifetime" or name == "lifetime-left"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "source-address"):
                    self.source_address = value
                    self.source_address.value_namespace = name_space
                    self.source_address.value_namespace_prefix = name_space_prefix
                if(value_path == "destination-address"):
                    self.destination_address = value
                    self.destination_address.value_namespace = name_space
                    self.destination_address.value_namespace_prefix = name_space_prefix
                if(value_path == "mode-id"):
                    self.mode_id = value
                    self.mode_id.value_namespace = name_space
                    self.mode_id.value_namespace_prefix = name_space_prefix
                if(value_path == "interface-name"):
                    self.interface_name = value
                    self.interface_name.value_namespace = name_space
                    self.interface_name.value_namespace_prefix = name_space_prefix
                if(value_path == "challenge-status"):
                    self.challenge_status = value
                    self.challenge_status.value_namespace = name_space
                    self.challenge_status.value_namespace_prefix = name_space_prefix
                if(value_path == "key-digest-info"):
                    self.key_digest_info = value
                    self.key_digest_info.value_namespace = name_space
                    self.key_digest_info.value_namespace_prefix = name_space_prefix
                if(value_path == "key-status"):
                    self.key_status = value
                    self.key_status.value_namespace = name_space
                    self.key_status.value_namespace_prefix = name_space_prefix
                if(value_path == "lifetime"):
                    self.lifetime = value
                    self.lifetime.value_namespace = name_space
                    self.lifetime.value_namespace_prefix = name_space_prefix
                if(value_path == "lifetime-left"):
                    self.lifetime_left = value
                    self.lifetime_left.value_namespace = name_space
                    self.lifetime_left.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.authentication_detail:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.authentication_detail:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "authentication-details" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "authentication-detail"):
                for c in self.authentication_detail:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = Rsvp.AuthenticationDetails.AuthenticationDetail()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.authentication_detail.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "authentication-detail"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class RsbBriefs(Entity):
        """
        Table of brief info about reservation state
        blocks
        
        .. attribute:: rsb_brief
        
        	Brief info for a single reservation state block
        	**type**\: list of    :py:class:`RsbBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RsbBriefs.RsbBrief>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Rsvp.RsbBriefs, self).__init__()

            self.yang_name = "rsb-briefs"
            self.yang_parent_name = "rsvp"

            self.rsb_brief = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(Rsvp.RsbBriefs, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(Rsvp.RsbBriefs, self).__setattr__(name, value)


        class RsbBrief(Entity):
            """
            Brief info for a single reservation state block
            
            .. attribute:: destination_address
            
            	Destination Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: destination_port
            
            	Destination Port
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: extended_tunnel_id
            
            	Extended Tunnel ID
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: filter
            
            	RSVP Filter
            	**type**\:   :py:class:`Filter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RsbBriefs.RsbBrief.Filter>`
            
            .. attribute:: flow_spec
            
            	Flow Spec Information
            	**type**\:   :py:class:`FlowSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RsbBriefs.RsbBrief.FlowSpec>`
            
            .. attribute:: generic_flow_spec
            
            	Generic Flow Spec Info
            	**type**\:   :py:class:`GenericFlowSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RsbBriefs.RsbBrief.GenericFlowSpec>`
            
            .. attribute:: input_interface
            
            	Reservation Input Interface
            	**type**\:  str
            
            .. attribute:: p2mp_id
            
            	P2MP ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: protocol
            
            	Protocol
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: s2l_sub_lsp
            
            	RSVP S2L Sub\-LSP information
            	**type**\:   :py:class:`S2LSubLsp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RsbBriefs.RsbBrief.S2LSubLsp>`
            
            .. attribute:: session
            
            	RSVP Session Information
            	**type**\:   :py:class:`Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RsbBriefs.RsbBrief.Session>`
            
            .. attribute:: session_type
            
            	Session Type
            	**type**\:   :py:class:`RsvpSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpSession>`
            
            .. attribute:: source_address
            
            	Source Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: source_port
            
            	Source Port 
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: style
            
            	RSVP Style
            	**type**\:   :py:class:`Style <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RsbBriefs.RsbBrief.Style>`
            
            .. attribute:: sub_group_id
            
            	Subgroup ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: sub_group_origin
            
            	Subgroup Origin
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: vrf_name
            
            	VRF Name
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Rsvp.RsbBriefs.RsbBrief, self).__init__()

                self.yang_name = "rsb-brief"
                self.yang_parent_name = "rsb-briefs"

                self.destination_address = YLeaf(YType.str, "destination-address")

                self.destination_port = YLeaf(YType.int32, "destination-port")

                self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                self.input_interface = YLeaf(YType.str, "input-interface")

                self.p2mp_id = YLeaf(YType.int32, "p2mp-id")

                self.protocol = YLeaf(YType.int32, "protocol")

                self.session_type = YLeaf(YType.enumeration, "session-type")

                self.source_address = YLeaf(YType.str, "source-address")

                self.source_port = YLeaf(YType.int32, "source-port")

                self.sub_group_id = YLeaf(YType.int32, "sub-group-id")

                self.sub_group_origin = YLeaf(YType.str, "sub-group-origin")

                self.vrf_name = YLeaf(YType.str, "vrf-name")

                self.filter = Rsvp.RsbBriefs.RsbBrief.Filter()
                self.filter.parent = self
                self._children_name_map["filter"] = "filter"
                self._children_yang_names.add("filter")

                self.flow_spec = Rsvp.RsbBriefs.RsbBrief.FlowSpec()
                self.flow_spec.parent = self
                self._children_name_map["flow_spec"] = "flow-spec"
                self._children_yang_names.add("flow-spec")

                self.generic_flow_spec = Rsvp.RsbBriefs.RsbBrief.GenericFlowSpec()
                self.generic_flow_spec.parent = self
                self._children_name_map["generic_flow_spec"] = "generic-flow-spec"
                self._children_yang_names.add("generic-flow-spec")

                self.s2l_sub_lsp = Rsvp.RsbBriefs.RsbBrief.S2LSubLsp()
                self.s2l_sub_lsp.parent = self
                self._children_name_map["s2l_sub_lsp"] = "s2l-sub-lsp"
                self._children_yang_names.add("s2l-sub-lsp")

                self.session = Rsvp.RsbBriefs.RsbBrief.Session()
                self.session.parent = self
                self._children_name_map["session"] = "session"
                self._children_yang_names.add("session")

                self.style = Rsvp.RsbBriefs.RsbBrief.Style()
                self.style.parent = self
                self._children_name_map["style"] = "style"
                self._children_yang_names.add("style")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("destination_address",
                                "destination_port",
                                "extended_tunnel_id",
                                "input_interface",
                                "p2mp_id",
                                "protocol",
                                "session_type",
                                "source_address",
                                "source_port",
                                "sub_group_id",
                                "sub_group_origin",
                                "vrf_name") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Rsvp.RsbBriefs.RsbBrief, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Rsvp.RsbBriefs.RsbBrief, self).__setattr__(name, value)


            class Session(Entity):
                """
                RSVP Session Information
                
                .. attribute:: rsvp_session
                
                	RSVP Session
                	**type**\:   :py:class:`RsvpSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RsbBriefs.RsbBrief.Session.RsvpSession>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.RsbBriefs.RsbBrief.Session, self).__init__()

                    self.yang_name = "session"
                    self.yang_parent_name = "rsb-brief"

                    self.rsvp_session = Rsvp.RsbBriefs.RsbBrief.Session.RsvpSession()
                    self.rsvp_session.parent = self
                    self._children_name_map["rsvp_session"] = "rsvp-session"
                    self._children_yang_names.add("rsvp-session")


                class RsvpSession(Entity):
                    """
                    RSVP Session
                    
                    .. attribute:: ipv4
                    
                    	UDP IPv4 session
                    	**type**\:   :py:class:`Ipv4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RsbBriefs.RsbBrief.Session.RsvpSession.Ipv4>`
                    
                    .. attribute:: ipv4_lsp_session
                    
                    	IPv4 LSP session
                    	**type**\:   :py:class:`Ipv4LspSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RsbBriefs.RsbBrief.Session.RsvpSession.Ipv4LspSession>`
                    
                    .. attribute:: ipv4_p2mp_lsp_session
                    
                    	IPv4 P2MP LSP session
                    	**type**\:   :py:class:`Ipv4P2MpLspSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RsbBriefs.RsbBrief.Session.RsvpSession.Ipv4P2MpLspSession>`
                    
                    .. attribute:: ipv4_uni_session
                    
                    	IPv4 UNI session
                    	**type**\:   :py:class:`Ipv4UniSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RsbBriefs.RsbBrief.Session.RsvpSession.Ipv4UniSession>`
                    
                    .. attribute:: session_type
                    
                    	SessionType
                    	**type**\:   :py:class:`RsvpMgmtSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtSession>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.RsbBriefs.RsbBrief.Session.RsvpSession, self).__init__()

                        self.yang_name = "rsvp-session"
                        self.yang_parent_name = "session"

                        self.session_type = YLeaf(YType.enumeration, "session-type")

                        self.ipv4 = Rsvp.RsbBriefs.RsbBrief.Session.RsvpSession.Ipv4()
                        self.ipv4.parent = self
                        self._children_name_map["ipv4"] = "ipv4"
                        self._children_yang_names.add("ipv4")

                        self.ipv4_lsp_session = Rsvp.RsbBriefs.RsbBrief.Session.RsvpSession.Ipv4LspSession()
                        self.ipv4_lsp_session.parent = self
                        self._children_name_map["ipv4_lsp_session"] = "ipv4-lsp-session"
                        self._children_yang_names.add("ipv4-lsp-session")

                        self.ipv4_p2mp_lsp_session = Rsvp.RsbBriefs.RsbBrief.Session.RsvpSession.Ipv4P2MpLspSession()
                        self.ipv4_p2mp_lsp_session.parent = self
                        self._children_name_map["ipv4_p2mp_lsp_session"] = "ipv4-p2mp-lsp-session"
                        self._children_yang_names.add("ipv4-p2mp-lsp-session")

                        self.ipv4_uni_session = Rsvp.RsbBriefs.RsbBrief.Session.RsvpSession.Ipv4UniSession()
                        self.ipv4_uni_session.parent = self
                        self._children_name_map["ipv4_uni_session"] = "ipv4-uni-session"
                        self._children_yang_names.add("ipv4-uni-session")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("session_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.RsbBriefs.RsbBrief.Session.RsvpSession, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.RsbBriefs.RsbBrief.Session.RsvpSession, self).__setattr__(name, value)


                    class Ipv4(Entity):
                        """
                        UDP IPv4 session
                        
                        .. attribute:: destination_address
                        
                        	Destination address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: destination_port
                        
                        	The Session Destination Port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: protocol
                        
                        	Protocol type (originally defined in RFC 790, further values in subsequent RFCs)
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.RsbBriefs.RsbBrief.Session.RsvpSession.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "rsvp-session"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.destination_port = YLeaf(YType.uint16, "destination-port")

                            self.protocol = YLeaf(YType.uint8, "protocol")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "destination_port",
                                            "protocol") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.RsbBriefs.RsbBrief.Session.RsvpSession.Ipv4, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.RsbBriefs.RsbBrief.Session.RsvpSession.Ipv4, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination_address.is_set or
                                self.destination_port.is_set or
                                self.protocol.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.destination_port.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rsb-briefs/rsb-brief/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.destination_port.is_set or self.destination_port.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_port.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "destination-port" or name == "protocol"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "destination-port"):
                                self.destination_port = value
                                self.destination_port.value_namespace = name_space
                                self.destination_port.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix


                    class Ipv4LspSession(Entity):
                        """
                        IPv4 LSP session
                        
                        .. attribute:: destination_address
                        
                        	Destination address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: extended_tunnel_id
                        
                        	The Session Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: tunnel_id
                        
                        	The Session Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.RsbBriefs.RsbBrief.Session.RsvpSession.Ipv4LspSession, self).__init__()

                            self.yang_name = "ipv4-lsp-session"
                            self.yang_parent_name = "rsvp-session"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                            self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "extended_tunnel_id",
                                            "tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.RsbBriefs.RsbBrief.Session.RsvpSession.Ipv4LspSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.RsbBriefs.RsbBrief.Session.RsvpSession.Ipv4LspSession, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination_address.is_set or
                                self.extended_tunnel_id.is_set or
                                self.tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.extended_tunnel_id.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-lsp-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rsb-briefs/rsb-brief/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "extended-tunnel-id" or name == "tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "extended-tunnel-id"):
                                self.extended_tunnel_id = value
                                self.extended_tunnel_id.value_namespace = name_space
                                self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix


                    class Ipv4UniSession(Entity):
                        """
                        IPv4 UNI session
                        
                        .. attribute:: destination_address
                        
                        	Destination address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: extended_address
                        
                        	The Session Extended Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: tunnel_id
                        
                        	The Session Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.RsbBriefs.RsbBrief.Session.RsvpSession.Ipv4UniSession, self).__init__()

                            self.yang_name = "ipv4-uni-session"
                            self.yang_parent_name = "rsvp-session"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.extended_address = YLeaf(YType.str, "extended-address")

                            self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "extended_address",
                                            "tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.RsbBriefs.RsbBrief.Session.RsvpSession.Ipv4UniSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.RsbBriefs.RsbBrief.Session.RsvpSession.Ipv4UniSession, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination_address.is_set or
                                self.extended_address.is_set or
                                self.tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.extended_address.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-uni-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rsb-briefs/rsb-brief/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.extended_address.is_set or self.extended_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_address.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "extended-address" or name == "tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "extended-address"):
                                self.extended_address = value
                                self.extended_address.value_namespace = name_space
                                self.extended_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix


                    class Ipv4P2MpLspSession(Entity):
                        """
                        IPv4 P2MP LSP session
                        
                        .. attribute:: extended_tunnel_id
                        
                        	The Session Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: p2mp_id
                        
                        	The Point to Multipoint ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tunnel_id
                        
                        	The Session Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.RsbBriefs.RsbBrief.Session.RsvpSession.Ipv4P2MpLspSession, self).__init__()

                            self.yang_name = "ipv4-p2mp-lsp-session"
                            self.yang_parent_name = "rsvp-session"

                            self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                            self.p2mp_id = YLeaf(YType.uint32, "p2mp-id")

                            self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("extended_tunnel_id",
                                            "p2mp_id",
                                            "tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.RsbBriefs.RsbBrief.Session.RsvpSession.Ipv4P2MpLspSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.RsbBriefs.RsbBrief.Session.RsvpSession.Ipv4P2MpLspSession, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.extended_tunnel_id.is_set or
                                self.p2mp_id.is_set or
                                self.tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.extended_tunnel_id.yfilter != YFilter.not_set or
                                self.p2mp_id.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-p2mp-lsp-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rsb-briefs/rsb-brief/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                            if (self.p2mp_id.is_set or self.p2mp_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.p2mp_id.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "extended-tunnel-id" or name == "p2mp-id" or name == "tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "extended-tunnel-id"):
                                self.extended_tunnel_id = value
                                self.extended_tunnel_id.value_namespace = name_space
                                self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "p2mp-id"):
                                self.p2mp_id = value
                                self.p2mp_id.value_namespace = name_space
                                self.p2mp_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.session_type.is_set or
                            (self.ipv4 is not None and self.ipv4.has_data()) or
                            (self.ipv4_lsp_session is not None and self.ipv4_lsp_session.has_data()) or
                            (self.ipv4_p2mp_lsp_session is not None and self.ipv4_p2mp_lsp_session.has_data()) or
                            (self.ipv4_uni_session is not None and self.ipv4_uni_session.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.session_type.yfilter != YFilter.not_set or
                            (self.ipv4 is not None and self.ipv4.has_operation()) or
                            (self.ipv4_lsp_session is not None and self.ipv4_lsp_session.has_operation()) or
                            (self.ipv4_p2mp_lsp_session is not None and self.ipv4_p2mp_lsp_session.has_operation()) or
                            (self.ipv4_uni_session is not None and self.ipv4_uni_session.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rsvp-session" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rsb-briefs/rsb-brief/session/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.session_type.is_set or self.session_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.session_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "ipv4"):
                            if (self.ipv4 is None):
                                self.ipv4 = Rsvp.RsbBriefs.RsbBrief.Session.RsvpSession.Ipv4()
                                self.ipv4.parent = self
                                self._children_name_map["ipv4"] = "ipv4"
                            return self.ipv4

                        if (child_yang_name == "ipv4-lsp-session"):
                            if (self.ipv4_lsp_session is None):
                                self.ipv4_lsp_session = Rsvp.RsbBriefs.RsbBrief.Session.RsvpSession.Ipv4LspSession()
                                self.ipv4_lsp_session.parent = self
                                self._children_name_map["ipv4_lsp_session"] = "ipv4-lsp-session"
                            return self.ipv4_lsp_session

                        if (child_yang_name == "ipv4-p2mp-lsp-session"):
                            if (self.ipv4_p2mp_lsp_session is None):
                                self.ipv4_p2mp_lsp_session = Rsvp.RsbBriefs.RsbBrief.Session.RsvpSession.Ipv4P2MpLspSession()
                                self.ipv4_p2mp_lsp_session.parent = self
                                self._children_name_map["ipv4_p2mp_lsp_session"] = "ipv4-p2mp-lsp-session"
                            return self.ipv4_p2mp_lsp_session

                        if (child_yang_name == "ipv4-uni-session"):
                            if (self.ipv4_uni_session is None):
                                self.ipv4_uni_session = Rsvp.RsbBriefs.RsbBrief.Session.RsvpSession.Ipv4UniSession()
                                self.ipv4_uni_session.parent = self
                                self._children_name_map["ipv4_uni_session"] = "ipv4-uni-session"
                            return self.ipv4_uni_session

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ipv4" or name == "ipv4-lsp-session" or name == "ipv4-p2mp-lsp-session" or name == "ipv4-uni-session" or name == "session-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "session-type"):
                            self.session_type = value
                            self.session_type.value_namespace = name_space
                            self.session_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (self.rsvp_session is not None and self.rsvp_session.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.rsvp_session is not None and self.rsvp_session.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "session" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rsb-briefs/rsb-brief/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "rsvp-session"):
                        if (self.rsvp_session is None):
                            self.rsvp_session = Rsvp.RsbBriefs.RsbBrief.Session.RsvpSession()
                            self.rsvp_session.parent = self
                            self._children_name_map["rsvp_session"] = "rsvp-session"
                        return self.rsvp_session

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "rsvp-session"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class S2LSubLsp(Entity):
                """
                RSVP S2L Sub\-LSP information
                
                .. attribute:: s2l_destination_address
                
                	S2L Sub\-LSP Destination Address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.RsbBriefs.RsbBrief.S2LSubLsp, self).__init__()

                    self.yang_name = "s2l-sub-lsp"
                    self.yang_parent_name = "rsb-brief"

                    self.s2l_destination_address = YLeaf(YType.str, "s2l-destination-address")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("s2l_destination_address") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.RsbBriefs.RsbBrief.S2LSubLsp, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.RsbBriefs.RsbBrief.S2LSubLsp, self).__setattr__(name, value)

                def has_data(self):
                    return self.s2l_destination_address.is_set

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.s2l_destination_address.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "s2l-sub-lsp" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rsb-briefs/rsb-brief/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.s2l_destination_address.is_set or self.s2l_destination_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.s2l_destination_address.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "s2l-destination-address"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "s2l-destination-address"):
                        self.s2l_destination_address = value
                        self.s2l_destination_address.value_namespace = name_space
                        self.s2l_destination_address.value_namespace_prefix = name_space_prefix


            class FlowSpec(Entity):
                """
                Flow Spec Information
                
                .. attribute:: flow_average_rate
                
                	The Flow Average Rate in bytes per second
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: byte/s
                
                .. attribute:: flow_max_burst
                
                	The Flow Maximum Burst
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: flow_max_unit
                
                	The Flow Maximum Unit
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: flow_min_unit
                
                	The Flow Minimum Unit
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: flow_peak_rate
                
                	The Flow Peak Rate in bytes per second
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: byte/s
                
                .. attribute:: flow_qos
                
                	The Flow Quality of Service
                	**type**\:   :py:class:`RsvpMgmtQosServiceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtQosServiceEnum>`
                
                .. attribute:: flow_requested_rate
                
                	The Flow Requested Rate in bytes per second
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: byte/s
                
                .. attribute:: flow_slack
                
                	The Flow Slack
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.RsbBriefs.RsbBrief.FlowSpec, self).__init__()

                    self.yang_name = "flow-spec"
                    self.yang_parent_name = "rsb-brief"

                    self.flow_average_rate = YLeaf(YType.uint64, "flow-average-rate")

                    self.flow_max_burst = YLeaf(YType.uint64, "flow-max-burst")

                    self.flow_max_unit = YLeaf(YType.uint32, "flow-max-unit")

                    self.flow_min_unit = YLeaf(YType.uint32, "flow-min-unit")

                    self.flow_peak_rate = YLeaf(YType.uint64, "flow-peak-rate")

                    self.flow_qos = YLeaf(YType.enumeration, "flow-qos")

                    self.flow_requested_rate = YLeaf(YType.uint64, "flow-requested-rate")

                    self.flow_slack = YLeaf(YType.uint32, "flow-slack")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("flow_average_rate",
                                    "flow_max_burst",
                                    "flow_max_unit",
                                    "flow_min_unit",
                                    "flow_peak_rate",
                                    "flow_qos",
                                    "flow_requested_rate",
                                    "flow_slack") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.RsbBriefs.RsbBrief.FlowSpec, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.RsbBriefs.RsbBrief.FlowSpec, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.flow_average_rate.is_set or
                        self.flow_max_burst.is_set or
                        self.flow_max_unit.is_set or
                        self.flow_min_unit.is_set or
                        self.flow_peak_rate.is_set or
                        self.flow_qos.is_set or
                        self.flow_requested_rate.is_set or
                        self.flow_slack.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.flow_average_rate.yfilter != YFilter.not_set or
                        self.flow_max_burst.yfilter != YFilter.not_set or
                        self.flow_max_unit.yfilter != YFilter.not_set or
                        self.flow_min_unit.yfilter != YFilter.not_set or
                        self.flow_peak_rate.yfilter != YFilter.not_set or
                        self.flow_qos.yfilter != YFilter.not_set or
                        self.flow_requested_rate.yfilter != YFilter.not_set or
                        self.flow_slack.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "flow-spec" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rsb-briefs/rsb-brief/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.flow_average_rate.is_set or self.flow_average_rate.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_average_rate.get_name_leafdata())
                    if (self.flow_max_burst.is_set or self.flow_max_burst.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_max_burst.get_name_leafdata())
                    if (self.flow_max_unit.is_set or self.flow_max_unit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_max_unit.get_name_leafdata())
                    if (self.flow_min_unit.is_set or self.flow_min_unit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_min_unit.get_name_leafdata())
                    if (self.flow_peak_rate.is_set or self.flow_peak_rate.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_peak_rate.get_name_leafdata())
                    if (self.flow_qos.is_set or self.flow_qos.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_qos.get_name_leafdata())
                    if (self.flow_requested_rate.is_set or self.flow_requested_rate.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_requested_rate.get_name_leafdata())
                    if (self.flow_slack.is_set or self.flow_slack.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_slack.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "flow-average-rate" or name == "flow-max-burst" or name == "flow-max-unit" or name == "flow-min-unit" or name == "flow-peak-rate" or name == "flow-qos" or name == "flow-requested-rate" or name == "flow-slack"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "flow-average-rate"):
                        self.flow_average_rate = value
                        self.flow_average_rate.value_namespace = name_space
                        self.flow_average_rate.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-max-burst"):
                        self.flow_max_burst = value
                        self.flow_max_burst.value_namespace = name_space
                        self.flow_max_burst.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-max-unit"):
                        self.flow_max_unit = value
                        self.flow_max_unit.value_namespace = name_space
                        self.flow_max_unit.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-min-unit"):
                        self.flow_min_unit = value
                        self.flow_min_unit.value_namespace = name_space
                        self.flow_min_unit.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-peak-rate"):
                        self.flow_peak_rate = value
                        self.flow_peak_rate.value_namespace = name_space
                        self.flow_peak_rate.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-qos"):
                        self.flow_qos = value
                        self.flow_qos.value_namespace = name_space
                        self.flow_qos.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-requested-rate"):
                        self.flow_requested_rate = value
                        self.flow_requested_rate.value_namespace = name_space
                        self.flow_requested_rate.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-slack"):
                        self.flow_slack = value
                        self.flow_slack.value_namespace = name_space
                        self.flow_slack.value_namespace_prefix = name_space_prefix


            class GenericFlowSpec(Entity):
                """
                Generic Flow Spec Info
                
                .. attribute:: flow_spec_type
                
                	FlowSpecType
                	**type**\:   :py:class:`RsvpMgmtFlowSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtFlowSpec>`
                
                .. attribute:: g709otn_flow_spec
                
                	G709 OTN FlowSpec
                	**type**\:   :py:class:`G709OtnFlowSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RsbBriefs.RsbBrief.GenericFlowSpec.G709OtnFlowSpec>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.RsbBriefs.RsbBrief.GenericFlowSpec, self).__init__()

                    self.yang_name = "generic-flow-spec"
                    self.yang_parent_name = "rsb-brief"

                    self.flow_spec_type = YLeaf(YType.enumeration, "flow-spec-type")

                    self.g709otn_flow_spec = Rsvp.RsbBriefs.RsbBrief.GenericFlowSpec.G709OtnFlowSpec()
                    self.g709otn_flow_spec.parent = self
                    self._children_name_map["g709otn_flow_spec"] = "g709otn-flow-spec"
                    self._children_yang_names.add("g709otn-flow-spec")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("flow_spec_type") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.RsbBriefs.RsbBrief.GenericFlowSpec, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.RsbBriefs.RsbBrief.GenericFlowSpec, self).__setattr__(name, value)


                class G709OtnFlowSpec(Entity):
                    """
                    G709 OTN FlowSpec
                    
                    .. attribute:: flow_bit_rate
                    
                    	G709 OTN Flow Bit Rate
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: flow_multiplier
                    
                    	G709 OTN Flow Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: flow_nvc
                    
                    	G709 OTN Flow NVC
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: flow_signal_type
                    
                    	G709 OTN Flow Signal Type (Refer G709 v3)
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.RsbBriefs.RsbBrief.GenericFlowSpec.G709OtnFlowSpec, self).__init__()

                        self.yang_name = "g709otn-flow-spec"
                        self.yang_parent_name = "generic-flow-spec"

                        self.flow_bit_rate = YLeaf(YType.uint64, "flow-bit-rate")

                        self.flow_multiplier = YLeaf(YType.uint16, "flow-multiplier")

                        self.flow_nvc = YLeaf(YType.uint16, "flow-nvc")

                        self.flow_signal_type = YLeaf(YType.uint8, "flow-signal-type")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("flow_bit_rate",
                                        "flow_multiplier",
                                        "flow_nvc",
                                        "flow_signal_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.RsbBriefs.RsbBrief.GenericFlowSpec.G709OtnFlowSpec, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.RsbBriefs.RsbBrief.GenericFlowSpec.G709OtnFlowSpec, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.flow_bit_rate.is_set or
                            self.flow_multiplier.is_set or
                            self.flow_nvc.is_set or
                            self.flow_signal_type.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.flow_bit_rate.yfilter != YFilter.not_set or
                            self.flow_multiplier.yfilter != YFilter.not_set or
                            self.flow_nvc.yfilter != YFilter.not_set or
                            self.flow_signal_type.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "g709otn-flow-spec" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rsb-briefs/rsb-brief/generic-flow-spec/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.flow_bit_rate.is_set or self.flow_bit_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.flow_bit_rate.get_name_leafdata())
                        if (self.flow_multiplier.is_set or self.flow_multiplier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.flow_multiplier.get_name_leafdata())
                        if (self.flow_nvc.is_set or self.flow_nvc.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.flow_nvc.get_name_leafdata())
                        if (self.flow_signal_type.is_set or self.flow_signal_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.flow_signal_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "flow-bit-rate" or name == "flow-multiplier" or name == "flow-nvc" or name == "flow-signal-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "flow-bit-rate"):
                            self.flow_bit_rate = value
                            self.flow_bit_rate.value_namespace = name_space
                            self.flow_bit_rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "flow-multiplier"):
                            self.flow_multiplier = value
                            self.flow_multiplier.value_namespace = name_space
                            self.flow_multiplier.value_namespace_prefix = name_space_prefix
                        if(value_path == "flow-nvc"):
                            self.flow_nvc = value
                            self.flow_nvc.value_namespace = name_space
                            self.flow_nvc.value_namespace_prefix = name_space_prefix
                        if(value_path == "flow-signal-type"):
                            self.flow_signal_type = value
                            self.flow_signal_type.value_namespace = name_space
                            self.flow_signal_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.flow_spec_type.is_set or
                        (self.g709otn_flow_spec is not None and self.g709otn_flow_spec.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.flow_spec_type.yfilter != YFilter.not_set or
                        (self.g709otn_flow_spec is not None and self.g709otn_flow_spec.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "generic-flow-spec" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rsb-briefs/rsb-brief/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.flow_spec_type.is_set or self.flow_spec_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_spec_type.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "g709otn-flow-spec"):
                        if (self.g709otn_flow_spec is None):
                            self.g709otn_flow_spec = Rsvp.RsbBriefs.RsbBrief.GenericFlowSpec.G709OtnFlowSpec()
                            self.g709otn_flow_spec.parent = self
                            self._children_name_map["g709otn_flow_spec"] = "g709otn-flow-spec"
                        return self.g709otn_flow_spec

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "g709otn-flow-spec" or name == "flow-spec-type"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "flow-spec-type"):
                        self.flow_spec_type = value
                        self.flow_spec_type.value_namespace = name_space
                        self.flow_spec_type.value_namespace_prefix = name_space_prefix


            class Style(Entity):
                """
                RSVP Style
                
                .. attribute:: reservation_type
                
                	The Reservation Type\: WF, SE or FF
                	**type**\:   :py:class:`RsvpMgmtReservationTypeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtReservationTypeEnum>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.RsbBriefs.RsbBrief.Style, self).__init__()

                    self.yang_name = "style"
                    self.yang_parent_name = "rsb-brief"

                    self.reservation_type = YLeaf(YType.enumeration, "reservation-type")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("reservation_type") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.RsbBriefs.RsbBrief.Style, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.RsbBriefs.RsbBrief.Style, self).__setattr__(name, value)

                def has_data(self):
                    return self.reservation_type.is_set

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.reservation_type.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "style" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rsb-briefs/rsb-brief/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.reservation_type.is_set or self.reservation_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reservation_type.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "reservation-type"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "reservation-type"):
                        self.reservation_type = value
                        self.reservation_type.value_namespace = name_space
                        self.reservation_type.value_namespace_prefix = name_space_prefix


            class Filter(Entity):
                """
                RSVP Filter
                
                .. attribute:: rsvp_filter
                
                	RSVP Filter
                	**type**\:   :py:class:`RsvpFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RsbBriefs.RsbBrief.Filter.RsvpFilter>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.RsbBriefs.RsbBrief.Filter, self).__init__()

                    self.yang_name = "filter"
                    self.yang_parent_name = "rsb-brief"

                    self.rsvp_filter = Rsvp.RsbBriefs.RsbBrief.Filter.RsvpFilter()
                    self.rsvp_filter.parent = self
                    self._children_name_map["rsvp_filter"] = "rsvp-filter"
                    self._children_yang_names.add("rsvp-filter")


                class RsvpFilter(Entity):
                    """
                    RSVP Filter
                    
                    .. attribute:: filter_type
                    
                    	FilterType
                    	**type**\:   :py:class:`RsvpMgmtFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtFilter>`
                    
                    .. attribute:: p2mp_ipv4_session
                    
                    	IPv4 P2MP LSP FilterSpec
                    	**type**\:   :py:class:`P2MpIpv4Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RsbBriefs.RsbBrief.Filter.RsvpFilter.P2MpIpv4Session>`
                    
                    .. attribute:: udp_ipv4_session
                    
                    	UDP IPV4 FilterSpec
                    	**type**\:   :py:class:`UdpIpv4Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RsbBriefs.RsbBrief.Filter.RsvpFilter.UdpIpv4Session>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.RsbBriefs.RsbBrief.Filter.RsvpFilter, self).__init__()

                        self.yang_name = "rsvp-filter"
                        self.yang_parent_name = "filter"

                        self.filter_type = YLeaf(YType.enumeration, "filter-type")

                        self.p2mp_ipv4_session = Rsvp.RsbBriefs.RsbBrief.Filter.RsvpFilter.P2MpIpv4Session()
                        self.p2mp_ipv4_session.parent = self
                        self._children_name_map["p2mp_ipv4_session"] = "p2mp-ipv4-session"
                        self._children_yang_names.add("p2mp-ipv4-session")

                        self.udp_ipv4_session = Rsvp.RsbBriefs.RsbBrief.Filter.RsvpFilter.UdpIpv4Session()
                        self.udp_ipv4_session.parent = self
                        self._children_name_map["udp_ipv4_session"] = "udp-ipv4-session"
                        self._children_yang_names.add("udp-ipv4-session")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("filter_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.RsbBriefs.RsbBrief.Filter.RsvpFilter, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.RsbBriefs.RsbBrief.Filter.RsvpFilter, self).__setattr__(name, value)


                    class UdpIpv4Session(Entity):
                        """
                        UDP IPV4 FilterSpec
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source_port
                        
                        	Source Port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.RsbBriefs.RsbBrief.Filter.RsvpFilter.UdpIpv4Session, self).__init__()

                            self.yang_name = "udp-ipv4-session"
                            self.yang_parent_name = "rsvp-filter"

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.source_port = YLeaf(YType.uint16, "source-port")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("source_address",
                                            "source_port") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.RsbBriefs.RsbBrief.Filter.RsvpFilter.UdpIpv4Session, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.RsbBriefs.RsbBrief.Filter.RsvpFilter.UdpIpv4Session, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.source_address.is_set or
                                self.source_port.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                self.source_port.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "udp-ipv4-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rsb-briefs/rsb-brief/filter/rsvp-filter/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())
                            if (self.source_port.is_set or self.source_port.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_port.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "source-address" or name == "source-port"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-port"):
                                self.source_port = value
                                self.source_port.value_namespace = name_space
                                self.source_port.value_namespace_prefix = name_space_prefix


                    class P2MpIpv4Session(Entity):
                        """
                        IPv4 P2MP LSP FilterSpec
                        
                        .. attribute:: p2mp_sub_group_origin
                        
                        	Point to Multipoint SubGroup Origin
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source_port
                        
                        	Source Port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: sub_group_id
                        
                        	Point to Multipoint Subgroup ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.RsbBriefs.RsbBrief.Filter.RsvpFilter.P2MpIpv4Session, self).__init__()

                            self.yang_name = "p2mp-ipv4-session"
                            self.yang_parent_name = "rsvp-filter"

                            self.p2mp_sub_group_origin = YLeaf(YType.str, "p2mp-sub-group-origin")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.source_port = YLeaf(YType.uint16, "source-port")

                            self.sub_group_id = YLeaf(YType.uint16, "sub-group-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("p2mp_sub_group_origin",
                                            "source_address",
                                            "source_port",
                                            "sub_group_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.RsbBriefs.RsbBrief.Filter.RsvpFilter.P2MpIpv4Session, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.RsbBriefs.RsbBrief.Filter.RsvpFilter.P2MpIpv4Session, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.p2mp_sub_group_origin.is_set or
                                self.source_address.is_set or
                                self.source_port.is_set or
                                self.sub_group_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.p2mp_sub_group_origin.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                self.source_port.yfilter != YFilter.not_set or
                                self.sub_group_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "p2mp-ipv4-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rsb-briefs/rsb-brief/filter/rsvp-filter/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.p2mp_sub_group_origin.is_set or self.p2mp_sub_group_origin.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.p2mp_sub_group_origin.get_name_leafdata())
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())
                            if (self.source_port.is_set or self.source_port.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_port.get_name_leafdata())
                            if (self.sub_group_id.is_set or self.sub_group_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sub_group_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "p2mp-sub-group-origin" or name == "source-address" or name == "source-port" or name == "sub-group-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "p2mp-sub-group-origin"):
                                self.p2mp_sub_group_origin = value
                                self.p2mp_sub_group_origin.value_namespace = name_space
                                self.p2mp_sub_group_origin.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-port"):
                                self.source_port = value
                                self.source_port.value_namespace = name_space
                                self.source_port.value_namespace_prefix = name_space_prefix
                            if(value_path == "sub-group-id"):
                                self.sub_group_id = value
                                self.sub_group_id.value_namespace = name_space
                                self.sub_group_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.filter_type.is_set or
                            (self.p2mp_ipv4_session is not None and self.p2mp_ipv4_session.has_data()) or
                            (self.udp_ipv4_session is not None and self.udp_ipv4_session.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.filter_type.yfilter != YFilter.not_set or
                            (self.p2mp_ipv4_session is not None and self.p2mp_ipv4_session.has_operation()) or
                            (self.udp_ipv4_session is not None and self.udp_ipv4_session.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rsvp-filter" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rsb-briefs/rsb-brief/filter/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.filter_type.is_set or self.filter_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.filter_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "p2mp-ipv4-session"):
                            if (self.p2mp_ipv4_session is None):
                                self.p2mp_ipv4_session = Rsvp.RsbBriefs.RsbBrief.Filter.RsvpFilter.P2MpIpv4Session()
                                self.p2mp_ipv4_session.parent = self
                                self._children_name_map["p2mp_ipv4_session"] = "p2mp-ipv4-session"
                            return self.p2mp_ipv4_session

                        if (child_yang_name == "udp-ipv4-session"):
                            if (self.udp_ipv4_session is None):
                                self.udp_ipv4_session = Rsvp.RsbBriefs.RsbBrief.Filter.RsvpFilter.UdpIpv4Session()
                                self.udp_ipv4_session.parent = self
                                self._children_name_map["udp_ipv4_session"] = "udp-ipv4-session"
                            return self.udp_ipv4_session

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "p2mp-ipv4-session" or name == "udp-ipv4-session" or name == "filter-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "filter-type"):
                            self.filter_type = value
                            self.filter_type.value_namespace = name_space
                            self.filter_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (self.rsvp_filter is not None and self.rsvp_filter.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.rsvp_filter is not None and self.rsvp_filter.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "filter" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rsb-briefs/rsb-brief/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "rsvp-filter"):
                        if (self.rsvp_filter is None):
                            self.rsvp_filter = Rsvp.RsbBriefs.RsbBrief.Filter.RsvpFilter()
                            self.rsvp_filter.parent = self
                            self._children_name_map["rsvp_filter"] = "rsvp-filter"
                        return self.rsvp_filter

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "rsvp-filter"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (
                    self.destination_address.is_set or
                    self.destination_port.is_set or
                    self.extended_tunnel_id.is_set or
                    self.input_interface.is_set or
                    self.p2mp_id.is_set or
                    self.protocol.is_set or
                    self.session_type.is_set or
                    self.source_address.is_set or
                    self.source_port.is_set or
                    self.sub_group_id.is_set or
                    self.sub_group_origin.is_set or
                    self.vrf_name.is_set or
                    (self.filter is not None and self.filter.has_data()) or
                    (self.flow_spec is not None and self.flow_spec.has_data()) or
                    (self.generic_flow_spec is not None and self.generic_flow_spec.has_data()) or
                    (self.s2l_sub_lsp is not None and self.s2l_sub_lsp.has_data()) or
                    (self.session is not None and self.session.has_data()) or
                    (self.style is not None and self.style.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.destination_address.yfilter != YFilter.not_set or
                    self.destination_port.yfilter != YFilter.not_set or
                    self.extended_tunnel_id.yfilter != YFilter.not_set or
                    self.input_interface.yfilter != YFilter.not_set or
                    self.p2mp_id.yfilter != YFilter.not_set or
                    self.protocol.yfilter != YFilter.not_set or
                    self.session_type.yfilter != YFilter.not_set or
                    self.source_address.yfilter != YFilter.not_set or
                    self.source_port.yfilter != YFilter.not_set or
                    self.sub_group_id.yfilter != YFilter.not_set or
                    self.sub_group_origin.yfilter != YFilter.not_set or
                    self.vrf_name.yfilter != YFilter.not_set or
                    (self.filter is not None and self.filter.has_operation()) or
                    (self.flow_spec is not None and self.flow_spec.has_operation()) or
                    (self.generic_flow_spec is not None and self.generic_flow_spec.has_operation()) or
                    (self.s2l_sub_lsp is not None and self.s2l_sub_lsp.has_operation()) or
                    (self.session is not None and self.session.has_operation()) or
                    (self.style is not None and self.style.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "rsb-brief" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/rsb-briefs/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_address.get_name_leafdata())
                if (self.destination_port.is_set or self.destination_port.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_port.get_name_leafdata())
                if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                if (self.input_interface.is_set or self.input_interface.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.input_interface.get_name_leafdata())
                if (self.p2mp_id.is_set or self.p2mp_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.p2mp_id.get_name_leafdata())
                if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.protocol.get_name_leafdata())
                if (self.session_type.is_set or self.session_type.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.session_type.get_name_leafdata())
                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_address.get_name_leafdata())
                if (self.source_port.is_set or self.source_port.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_port.get_name_leafdata())
                if (self.sub_group_id.is_set or self.sub_group_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.sub_group_id.get_name_leafdata())
                if (self.sub_group_origin.is_set or self.sub_group_origin.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.sub_group_origin.get_name_leafdata())
                if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.vrf_name.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "filter"):
                    if (self.filter is None):
                        self.filter = Rsvp.RsbBriefs.RsbBrief.Filter()
                        self.filter.parent = self
                        self._children_name_map["filter"] = "filter"
                    return self.filter

                if (child_yang_name == "flow-spec"):
                    if (self.flow_spec is None):
                        self.flow_spec = Rsvp.RsbBriefs.RsbBrief.FlowSpec()
                        self.flow_spec.parent = self
                        self._children_name_map["flow_spec"] = "flow-spec"
                    return self.flow_spec

                if (child_yang_name == "generic-flow-spec"):
                    if (self.generic_flow_spec is None):
                        self.generic_flow_spec = Rsvp.RsbBriefs.RsbBrief.GenericFlowSpec()
                        self.generic_flow_spec.parent = self
                        self._children_name_map["generic_flow_spec"] = "generic-flow-spec"
                    return self.generic_flow_spec

                if (child_yang_name == "s2l-sub-lsp"):
                    if (self.s2l_sub_lsp is None):
                        self.s2l_sub_lsp = Rsvp.RsbBriefs.RsbBrief.S2LSubLsp()
                        self.s2l_sub_lsp.parent = self
                        self._children_name_map["s2l_sub_lsp"] = "s2l-sub-lsp"
                    return self.s2l_sub_lsp

                if (child_yang_name == "session"):
                    if (self.session is None):
                        self.session = Rsvp.RsbBriefs.RsbBrief.Session()
                        self.session.parent = self
                        self._children_name_map["session"] = "session"
                    return self.session

                if (child_yang_name == "style"):
                    if (self.style is None):
                        self.style = Rsvp.RsbBriefs.RsbBrief.Style()
                        self.style.parent = self
                        self._children_name_map["style"] = "style"
                    return self.style

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "filter" or name == "flow-spec" or name == "generic-flow-spec" or name == "s2l-sub-lsp" or name == "session" or name == "style" or name == "destination-address" or name == "destination-port" or name == "extended-tunnel-id" or name == "input-interface" or name == "p2mp-id" or name == "protocol" or name == "session-type" or name == "source-address" or name == "source-port" or name == "sub-group-id" or name == "sub-group-origin" or name == "vrf-name"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "destination-address"):
                    self.destination_address = value
                    self.destination_address.value_namespace = name_space
                    self.destination_address.value_namespace_prefix = name_space_prefix
                if(value_path == "destination-port"):
                    self.destination_port = value
                    self.destination_port.value_namespace = name_space
                    self.destination_port.value_namespace_prefix = name_space_prefix
                if(value_path == "extended-tunnel-id"):
                    self.extended_tunnel_id = value
                    self.extended_tunnel_id.value_namespace = name_space
                    self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                if(value_path == "input-interface"):
                    self.input_interface = value
                    self.input_interface.value_namespace = name_space
                    self.input_interface.value_namespace_prefix = name_space_prefix
                if(value_path == "p2mp-id"):
                    self.p2mp_id = value
                    self.p2mp_id.value_namespace = name_space
                    self.p2mp_id.value_namespace_prefix = name_space_prefix
                if(value_path == "protocol"):
                    self.protocol = value
                    self.protocol.value_namespace = name_space
                    self.protocol.value_namespace_prefix = name_space_prefix
                if(value_path == "session-type"):
                    self.session_type = value
                    self.session_type.value_namespace = name_space
                    self.session_type.value_namespace_prefix = name_space_prefix
                if(value_path == "source-address"):
                    self.source_address = value
                    self.source_address.value_namespace = name_space
                    self.source_address.value_namespace_prefix = name_space_prefix
                if(value_path == "source-port"):
                    self.source_port = value
                    self.source_port.value_namespace = name_space
                    self.source_port.value_namespace_prefix = name_space_prefix
                if(value_path == "sub-group-id"):
                    self.sub_group_id = value
                    self.sub_group_id.value_namespace = name_space
                    self.sub_group_id.value_namespace_prefix = name_space_prefix
                if(value_path == "sub-group-origin"):
                    self.sub_group_origin = value
                    self.sub_group_origin.value_namespace = name_space
                    self.sub_group_origin.value_namespace_prefix = name_space_prefix
                if(value_path == "vrf-name"):
                    self.vrf_name = value
                    self.vrf_name.value_namespace = name_space
                    self.vrf_name.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.rsb_brief:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.rsb_brief:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "rsb-briefs" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "rsb-brief"):
                for c in self.rsb_brief:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = Rsvp.RsbBriefs.RsbBrief()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.rsb_brief.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "rsb-brief"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class OpenConfig(Entity):
        """
        OpenConfig info
        
        .. attribute:: global_counters
        
        	Platform wide RSVP statistics and counters
        	**type**\:   :py:class:`GlobalCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.OpenConfig.GlobalCounters>`
        
        .. attribute:: interface_counters
        
        	Table of info about RSVP\-enabled interface counters for OpenConfig
        	**type**\:   :py:class:`InterfaceCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.OpenConfig.InterfaceCounters>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Rsvp.OpenConfig, self).__init__()

            self.yang_name = "open-config"
            self.yang_parent_name = "rsvp"

            self.global_counters = Rsvp.OpenConfig.GlobalCounters()
            self.global_counters.parent = self
            self._children_name_map["global_counters"] = "global-counters"
            self._children_yang_names.add("global-counters")

            self.interface_counters = Rsvp.OpenConfig.InterfaceCounters()
            self.interface_counters.parent = self
            self._children_name_map["interface_counters"] = "interface-counters"
            self._children_yang_names.add("interface-counters")


        class GlobalCounters(Entity):
            """
            Platform wide RSVP statistics and counters
            
            .. attribute:: in_ack_messages
            
            	Global count of ack messages received
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: in_hello_messages
            
            	Global count of hello messages received
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: in_path_error_messages
            
            	Global count of path error messages received
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: in_path_messages
            
            	Global count of path messages received
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: in_path_tear_messages
            
            	Global count of path tear messages received
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: in_reservation_error_messages
            
            	Global count of reservation error messages received
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: in_reservation_messages
            
            	Global count of reservation messages received
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: in_reservation_tear_messages
            
            	Global count of reservation tear messages received
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: in_srefresh_messages
            
            	Global count of srefresh messages received
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: out_ack_messages
            
            	Global count of ack messages send
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: out_hello_messages
            
            	Global count of hello messages send
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: out_path_error_messages
            
            	Global count of path error messages send
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: out_path_messages
            
            	Global count of path messages send
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: out_path_tear_messages
            
            	Global count of path tear messages send
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: out_reservation_error_messages
            
            	Global count of reservation error messages send
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: out_reservation_messages
            
            	Global count of reservation messages send
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: out_reservation_tear_messages
            
            	Global count of reservation tear messages send
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: out_srefresh_messages
            
            	Global count of srefresh messages send
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: path_timeouts
            
            	Global count of Path Timeouts
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: rate_limited_messages
            
            	Global count of rate limited messages
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: reservation_timeouts
            
            	Global count of reservation timeouts
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Rsvp.OpenConfig.GlobalCounters, self).__init__()

                self.yang_name = "global-counters"
                self.yang_parent_name = "open-config"

                self.in_ack_messages = YLeaf(YType.uint64, "in-ack-messages")

                self.in_hello_messages = YLeaf(YType.uint64, "in-hello-messages")

                self.in_path_error_messages = YLeaf(YType.uint64, "in-path-error-messages")

                self.in_path_messages = YLeaf(YType.uint64, "in-path-messages")

                self.in_path_tear_messages = YLeaf(YType.uint64, "in-path-tear-messages")

                self.in_reservation_error_messages = YLeaf(YType.uint64, "in-reservation-error-messages")

                self.in_reservation_messages = YLeaf(YType.uint64, "in-reservation-messages")

                self.in_reservation_tear_messages = YLeaf(YType.uint64, "in-reservation-tear-messages")

                self.in_srefresh_messages = YLeaf(YType.uint64, "in-srefresh-messages")

                self.out_ack_messages = YLeaf(YType.uint64, "out-ack-messages")

                self.out_hello_messages = YLeaf(YType.uint64, "out-hello-messages")

                self.out_path_error_messages = YLeaf(YType.uint64, "out-path-error-messages")

                self.out_path_messages = YLeaf(YType.uint64, "out-path-messages")

                self.out_path_tear_messages = YLeaf(YType.uint64, "out-path-tear-messages")

                self.out_reservation_error_messages = YLeaf(YType.uint64, "out-reservation-error-messages")

                self.out_reservation_messages = YLeaf(YType.uint64, "out-reservation-messages")

                self.out_reservation_tear_messages = YLeaf(YType.uint64, "out-reservation-tear-messages")

                self.out_srefresh_messages = YLeaf(YType.uint64, "out-srefresh-messages")

                self.path_timeouts = YLeaf(YType.uint64, "path-timeouts")

                self.rate_limited_messages = YLeaf(YType.uint64, "rate-limited-messages")

                self.reservation_timeouts = YLeaf(YType.uint64, "reservation-timeouts")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("in_ack_messages",
                                "in_hello_messages",
                                "in_path_error_messages",
                                "in_path_messages",
                                "in_path_tear_messages",
                                "in_reservation_error_messages",
                                "in_reservation_messages",
                                "in_reservation_tear_messages",
                                "in_srefresh_messages",
                                "out_ack_messages",
                                "out_hello_messages",
                                "out_path_error_messages",
                                "out_path_messages",
                                "out_path_tear_messages",
                                "out_reservation_error_messages",
                                "out_reservation_messages",
                                "out_reservation_tear_messages",
                                "out_srefresh_messages",
                                "path_timeouts",
                                "rate_limited_messages",
                                "reservation_timeouts") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Rsvp.OpenConfig.GlobalCounters, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Rsvp.OpenConfig.GlobalCounters, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.in_ack_messages.is_set or
                    self.in_hello_messages.is_set or
                    self.in_path_error_messages.is_set or
                    self.in_path_messages.is_set or
                    self.in_path_tear_messages.is_set or
                    self.in_reservation_error_messages.is_set or
                    self.in_reservation_messages.is_set or
                    self.in_reservation_tear_messages.is_set or
                    self.in_srefresh_messages.is_set or
                    self.out_ack_messages.is_set or
                    self.out_hello_messages.is_set or
                    self.out_path_error_messages.is_set or
                    self.out_path_messages.is_set or
                    self.out_path_tear_messages.is_set or
                    self.out_reservation_error_messages.is_set or
                    self.out_reservation_messages.is_set or
                    self.out_reservation_tear_messages.is_set or
                    self.out_srefresh_messages.is_set or
                    self.path_timeouts.is_set or
                    self.rate_limited_messages.is_set or
                    self.reservation_timeouts.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.in_ack_messages.yfilter != YFilter.not_set or
                    self.in_hello_messages.yfilter != YFilter.not_set or
                    self.in_path_error_messages.yfilter != YFilter.not_set or
                    self.in_path_messages.yfilter != YFilter.not_set or
                    self.in_path_tear_messages.yfilter != YFilter.not_set or
                    self.in_reservation_error_messages.yfilter != YFilter.not_set or
                    self.in_reservation_messages.yfilter != YFilter.not_set or
                    self.in_reservation_tear_messages.yfilter != YFilter.not_set or
                    self.in_srefresh_messages.yfilter != YFilter.not_set or
                    self.out_ack_messages.yfilter != YFilter.not_set or
                    self.out_hello_messages.yfilter != YFilter.not_set or
                    self.out_path_error_messages.yfilter != YFilter.not_set or
                    self.out_path_messages.yfilter != YFilter.not_set or
                    self.out_path_tear_messages.yfilter != YFilter.not_set or
                    self.out_reservation_error_messages.yfilter != YFilter.not_set or
                    self.out_reservation_messages.yfilter != YFilter.not_set or
                    self.out_reservation_tear_messages.yfilter != YFilter.not_set or
                    self.out_srefresh_messages.yfilter != YFilter.not_set or
                    self.path_timeouts.yfilter != YFilter.not_set or
                    self.rate_limited_messages.yfilter != YFilter.not_set or
                    self.reservation_timeouts.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "global-counters" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/open-config/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.in_ack_messages.is_set or self.in_ack_messages.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.in_ack_messages.get_name_leafdata())
                if (self.in_hello_messages.is_set or self.in_hello_messages.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.in_hello_messages.get_name_leafdata())
                if (self.in_path_error_messages.is_set or self.in_path_error_messages.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.in_path_error_messages.get_name_leafdata())
                if (self.in_path_messages.is_set or self.in_path_messages.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.in_path_messages.get_name_leafdata())
                if (self.in_path_tear_messages.is_set or self.in_path_tear_messages.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.in_path_tear_messages.get_name_leafdata())
                if (self.in_reservation_error_messages.is_set or self.in_reservation_error_messages.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.in_reservation_error_messages.get_name_leafdata())
                if (self.in_reservation_messages.is_set or self.in_reservation_messages.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.in_reservation_messages.get_name_leafdata())
                if (self.in_reservation_tear_messages.is_set or self.in_reservation_tear_messages.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.in_reservation_tear_messages.get_name_leafdata())
                if (self.in_srefresh_messages.is_set or self.in_srefresh_messages.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.in_srefresh_messages.get_name_leafdata())
                if (self.out_ack_messages.is_set or self.out_ack_messages.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.out_ack_messages.get_name_leafdata())
                if (self.out_hello_messages.is_set or self.out_hello_messages.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.out_hello_messages.get_name_leafdata())
                if (self.out_path_error_messages.is_set or self.out_path_error_messages.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.out_path_error_messages.get_name_leafdata())
                if (self.out_path_messages.is_set or self.out_path_messages.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.out_path_messages.get_name_leafdata())
                if (self.out_path_tear_messages.is_set or self.out_path_tear_messages.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.out_path_tear_messages.get_name_leafdata())
                if (self.out_reservation_error_messages.is_set or self.out_reservation_error_messages.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.out_reservation_error_messages.get_name_leafdata())
                if (self.out_reservation_messages.is_set or self.out_reservation_messages.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.out_reservation_messages.get_name_leafdata())
                if (self.out_reservation_tear_messages.is_set or self.out_reservation_tear_messages.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.out_reservation_tear_messages.get_name_leafdata())
                if (self.out_srefresh_messages.is_set or self.out_srefresh_messages.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.out_srefresh_messages.get_name_leafdata())
                if (self.path_timeouts.is_set or self.path_timeouts.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.path_timeouts.get_name_leafdata())
                if (self.rate_limited_messages.is_set or self.rate_limited_messages.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.rate_limited_messages.get_name_leafdata())
                if (self.reservation_timeouts.is_set or self.reservation_timeouts.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.reservation_timeouts.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "in-ack-messages" or name == "in-hello-messages" or name == "in-path-error-messages" or name == "in-path-messages" or name == "in-path-tear-messages" or name == "in-reservation-error-messages" or name == "in-reservation-messages" or name == "in-reservation-tear-messages" or name == "in-srefresh-messages" or name == "out-ack-messages" or name == "out-hello-messages" or name == "out-path-error-messages" or name == "out-path-messages" or name == "out-path-tear-messages" or name == "out-reservation-error-messages" or name == "out-reservation-messages" or name == "out-reservation-tear-messages" or name == "out-srefresh-messages" or name == "path-timeouts" or name == "rate-limited-messages" or name == "reservation-timeouts"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "in-ack-messages"):
                    self.in_ack_messages = value
                    self.in_ack_messages.value_namespace = name_space
                    self.in_ack_messages.value_namespace_prefix = name_space_prefix
                if(value_path == "in-hello-messages"):
                    self.in_hello_messages = value
                    self.in_hello_messages.value_namespace = name_space
                    self.in_hello_messages.value_namespace_prefix = name_space_prefix
                if(value_path == "in-path-error-messages"):
                    self.in_path_error_messages = value
                    self.in_path_error_messages.value_namespace = name_space
                    self.in_path_error_messages.value_namespace_prefix = name_space_prefix
                if(value_path == "in-path-messages"):
                    self.in_path_messages = value
                    self.in_path_messages.value_namespace = name_space
                    self.in_path_messages.value_namespace_prefix = name_space_prefix
                if(value_path == "in-path-tear-messages"):
                    self.in_path_tear_messages = value
                    self.in_path_tear_messages.value_namespace = name_space
                    self.in_path_tear_messages.value_namespace_prefix = name_space_prefix
                if(value_path == "in-reservation-error-messages"):
                    self.in_reservation_error_messages = value
                    self.in_reservation_error_messages.value_namespace = name_space
                    self.in_reservation_error_messages.value_namespace_prefix = name_space_prefix
                if(value_path == "in-reservation-messages"):
                    self.in_reservation_messages = value
                    self.in_reservation_messages.value_namespace = name_space
                    self.in_reservation_messages.value_namespace_prefix = name_space_prefix
                if(value_path == "in-reservation-tear-messages"):
                    self.in_reservation_tear_messages = value
                    self.in_reservation_tear_messages.value_namespace = name_space
                    self.in_reservation_tear_messages.value_namespace_prefix = name_space_prefix
                if(value_path == "in-srefresh-messages"):
                    self.in_srefresh_messages = value
                    self.in_srefresh_messages.value_namespace = name_space
                    self.in_srefresh_messages.value_namespace_prefix = name_space_prefix
                if(value_path == "out-ack-messages"):
                    self.out_ack_messages = value
                    self.out_ack_messages.value_namespace = name_space
                    self.out_ack_messages.value_namespace_prefix = name_space_prefix
                if(value_path == "out-hello-messages"):
                    self.out_hello_messages = value
                    self.out_hello_messages.value_namespace = name_space
                    self.out_hello_messages.value_namespace_prefix = name_space_prefix
                if(value_path == "out-path-error-messages"):
                    self.out_path_error_messages = value
                    self.out_path_error_messages.value_namespace = name_space
                    self.out_path_error_messages.value_namespace_prefix = name_space_prefix
                if(value_path == "out-path-messages"):
                    self.out_path_messages = value
                    self.out_path_messages.value_namespace = name_space
                    self.out_path_messages.value_namespace_prefix = name_space_prefix
                if(value_path == "out-path-tear-messages"):
                    self.out_path_tear_messages = value
                    self.out_path_tear_messages.value_namespace = name_space
                    self.out_path_tear_messages.value_namespace_prefix = name_space_prefix
                if(value_path == "out-reservation-error-messages"):
                    self.out_reservation_error_messages = value
                    self.out_reservation_error_messages.value_namespace = name_space
                    self.out_reservation_error_messages.value_namespace_prefix = name_space_prefix
                if(value_path == "out-reservation-messages"):
                    self.out_reservation_messages = value
                    self.out_reservation_messages.value_namespace = name_space
                    self.out_reservation_messages.value_namespace_prefix = name_space_prefix
                if(value_path == "out-reservation-tear-messages"):
                    self.out_reservation_tear_messages = value
                    self.out_reservation_tear_messages.value_namespace = name_space
                    self.out_reservation_tear_messages.value_namespace_prefix = name_space_prefix
                if(value_path == "out-srefresh-messages"):
                    self.out_srefresh_messages = value
                    self.out_srefresh_messages.value_namespace = name_space
                    self.out_srefresh_messages.value_namespace_prefix = name_space_prefix
                if(value_path == "path-timeouts"):
                    self.path_timeouts = value
                    self.path_timeouts.value_namespace = name_space
                    self.path_timeouts.value_namespace_prefix = name_space_prefix
                if(value_path == "rate-limited-messages"):
                    self.rate_limited_messages = value
                    self.rate_limited_messages.value_namespace = name_space
                    self.rate_limited_messages.value_namespace_prefix = name_space_prefix
                if(value_path == "reservation-timeouts"):
                    self.reservation_timeouts = value
                    self.reservation_timeouts.value_namespace = name_space
                    self.reservation_timeouts.value_namespace_prefix = name_space_prefix


        class InterfaceCounters(Entity):
            """
            Table of info about RSVP\-enabled interface
            counters for OpenConfig
            
            .. attribute:: interface_counter
            
            	Info about an RSVP\-enabled interface counters
            	**type**\: list of    :py:class:`InterfaceCounter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.OpenConfig.InterfaceCounters.InterfaceCounter>`
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Rsvp.OpenConfig.InterfaceCounters, self).__init__()

                self.yang_name = "interface-counters"
                self.yang_parent_name = "open-config"

                self.interface_counter = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Rsvp.OpenConfig.InterfaceCounters, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Rsvp.OpenConfig.InterfaceCounters, self).__setattr__(name, value)


            class InterfaceCounter(Entity):
                """
                Info about an RSVP\-enabled interface counters
                
                .. attribute:: interface_name  <key>
                
                	Interface name
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: in_ack_messages
                
                	Per interface count of ack messages received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: in_hello_messages
                
                	Per interface count of hello messages received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: in_path_error_messages
                
                	Per interface count of path error messages received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: in_path_messages
                
                	Per interface count of path messages received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: in_path_tear_messages
                
                	Per interface count of path tear messages received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: in_reservation_error_messages
                
                	Per interface count of reservation error messages received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: in_reservation_messages
                
                	Per interface count of reservation messages received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: in_reservation_tear_messages
                
                	Per interface count of reservation tear messages received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: in_srefresh_messages
                
                	Per interface count of srefresh messages received
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: interface_name_xr
                
                	Interface name
                	**type**\:  str
                
                .. attribute:: out_ack_messages
                
                	Per interface count of ack messages send
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: out_hello_messages
                
                	Per interface count of hello messages send
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: out_path_error_messages
                
                	Per interface count of path error messages send
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: out_path_messages
                
                	Per interface count of path messages send
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: out_path_tear_messages
                
                	Per interface count of path tear messages send
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: out_reservation_error_messages
                
                	Per interface count of reservation error messages send
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: out_reservation_messages
                
                	Per interface count of reservation messages send
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: out_reservation_tear_messages
                
                	Per interface count of reservation tear messages send
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: out_srefresh_messages
                
                	Per interface count of srefresh messages send
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.OpenConfig.InterfaceCounters.InterfaceCounter, self).__init__()

                    self.yang_name = "interface-counter"
                    self.yang_parent_name = "interface-counters"

                    self.interface_name = YLeaf(YType.str, "interface-name")

                    self.in_ack_messages = YLeaf(YType.uint64, "in-ack-messages")

                    self.in_hello_messages = YLeaf(YType.uint64, "in-hello-messages")

                    self.in_path_error_messages = YLeaf(YType.uint64, "in-path-error-messages")

                    self.in_path_messages = YLeaf(YType.uint64, "in-path-messages")

                    self.in_path_tear_messages = YLeaf(YType.uint64, "in-path-tear-messages")

                    self.in_reservation_error_messages = YLeaf(YType.uint64, "in-reservation-error-messages")

                    self.in_reservation_messages = YLeaf(YType.uint64, "in-reservation-messages")

                    self.in_reservation_tear_messages = YLeaf(YType.uint64, "in-reservation-tear-messages")

                    self.in_srefresh_messages = YLeaf(YType.uint64, "in-srefresh-messages")

                    self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                    self.out_ack_messages = YLeaf(YType.uint64, "out-ack-messages")

                    self.out_hello_messages = YLeaf(YType.uint64, "out-hello-messages")

                    self.out_path_error_messages = YLeaf(YType.uint64, "out-path-error-messages")

                    self.out_path_messages = YLeaf(YType.uint64, "out-path-messages")

                    self.out_path_tear_messages = YLeaf(YType.uint64, "out-path-tear-messages")

                    self.out_reservation_error_messages = YLeaf(YType.uint64, "out-reservation-error-messages")

                    self.out_reservation_messages = YLeaf(YType.uint64, "out-reservation-messages")

                    self.out_reservation_tear_messages = YLeaf(YType.uint64, "out-reservation-tear-messages")

                    self.out_srefresh_messages = YLeaf(YType.uint64, "out-srefresh-messages")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("interface_name",
                                    "in_ack_messages",
                                    "in_hello_messages",
                                    "in_path_error_messages",
                                    "in_path_messages",
                                    "in_path_tear_messages",
                                    "in_reservation_error_messages",
                                    "in_reservation_messages",
                                    "in_reservation_tear_messages",
                                    "in_srefresh_messages",
                                    "interface_name_xr",
                                    "out_ack_messages",
                                    "out_hello_messages",
                                    "out_path_error_messages",
                                    "out_path_messages",
                                    "out_path_tear_messages",
                                    "out_reservation_error_messages",
                                    "out_reservation_messages",
                                    "out_reservation_tear_messages",
                                    "out_srefresh_messages") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.OpenConfig.InterfaceCounters.InterfaceCounter, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.OpenConfig.InterfaceCounters.InterfaceCounter, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.interface_name.is_set or
                        self.in_ack_messages.is_set or
                        self.in_hello_messages.is_set or
                        self.in_path_error_messages.is_set or
                        self.in_path_messages.is_set or
                        self.in_path_tear_messages.is_set or
                        self.in_reservation_error_messages.is_set or
                        self.in_reservation_messages.is_set or
                        self.in_reservation_tear_messages.is_set or
                        self.in_srefresh_messages.is_set or
                        self.interface_name_xr.is_set or
                        self.out_ack_messages.is_set or
                        self.out_hello_messages.is_set or
                        self.out_path_error_messages.is_set or
                        self.out_path_messages.is_set or
                        self.out_path_tear_messages.is_set or
                        self.out_reservation_error_messages.is_set or
                        self.out_reservation_messages.is_set or
                        self.out_reservation_tear_messages.is_set or
                        self.out_srefresh_messages.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.interface_name.yfilter != YFilter.not_set or
                        self.in_ack_messages.yfilter != YFilter.not_set or
                        self.in_hello_messages.yfilter != YFilter.not_set or
                        self.in_path_error_messages.yfilter != YFilter.not_set or
                        self.in_path_messages.yfilter != YFilter.not_set or
                        self.in_path_tear_messages.yfilter != YFilter.not_set or
                        self.in_reservation_error_messages.yfilter != YFilter.not_set or
                        self.in_reservation_messages.yfilter != YFilter.not_set or
                        self.in_reservation_tear_messages.yfilter != YFilter.not_set or
                        self.in_srefresh_messages.yfilter != YFilter.not_set or
                        self.interface_name_xr.yfilter != YFilter.not_set or
                        self.out_ack_messages.yfilter != YFilter.not_set or
                        self.out_hello_messages.yfilter != YFilter.not_set or
                        self.out_path_error_messages.yfilter != YFilter.not_set or
                        self.out_path_messages.yfilter != YFilter.not_set or
                        self.out_path_tear_messages.yfilter != YFilter.not_set or
                        self.out_reservation_error_messages.yfilter != YFilter.not_set or
                        self.out_reservation_messages.yfilter != YFilter.not_set or
                        self.out_reservation_tear_messages.yfilter != YFilter.not_set or
                        self.out_srefresh_messages.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "interface-counter" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/open-config/interface-counters/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                    if (self.in_ack_messages.is_set or self.in_ack_messages.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_ack_messages.get_name_leafdata())
                    if (self.in_hello_messages.is_set or self.in_hello_messages.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_hello_messages.get_name_leafdata())
                    if (self.in_path_error_messages.is_set or self.in_path_error_messages.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_path_error_messages.get_name_leafdata())
                    if (self.in_path_messages.is_set or self.in_path_messages.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_path_messages.get_name_leafdata())
                    if (self.in_path_tear_messages.is_set or self.in_path_tear_messages.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_path_tear_messages.get_name_leafdata())
                    if (self.in_reservation_error_messages.is_set or self.in_reservation_error_messages.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_reservation_error_messages.get_name_leafdata())
                    if (self.in_reservation_messages.is_set or self.in_reservation_messages.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_reservation_messages.get_name_leafdata())
                    if (self.in_reservation_tear_messages.is_set or self.in_reservation_tear_messages.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_reservation_tear_messages.get_name_leafdata())
                    if (self.in_srefresh_messages.is_set or self.in_srefresh_messages.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.in_srefresh_messages.get_name_leafdata())
                    if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                    if (self.out_ack_messages.is_set or self.out_ack_messages.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.out_ack_messages.get_name_leafdata())
                    if (self.out_hello_messages.is_set or self.out_hello_messages.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.out_hello_messages.get_name_leafdata())
                    if (self.out_path_error_messages.is_set or self.out_path_error_messages.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.out_path_error_messages.get_name_leafdata())
                    if (self.out_path_messages.is_set or self.out_path_messages.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.out_path_messages.get_name_leafdata())
                    if (self.out_path_tear_messages.is_set or self.out_path_tear_messages.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.out_path_tear_messages.get_name_leafdata())
                    if (self.out_reservation_error_messages.is_set or self.out_reservation_error_messages.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.out_reservation_error_messages.get_name_leafdata())
                    if (self.out_reservation_messages.is_set or self.out_reservation_messages.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.out_reservation_messages.get_name_leafdata())
                    if (self.out_reservation_tear_messages.is_set or self.out_reservation_tear_messages.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.out_reservation_tear_messages.get_name_leafdata())
                    if (self.out_srefresh_messages.is_set or self.out_srefresh_messages.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.out_srefresh_messages.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface-name" or name == "in-ack-messages" or name == "in-hello-messages" or name == "in-path-error-messages" or name == "in-path-messages" or name == "in-path-tear-messages" or name == "in-reservation-error-messages" or name == "in-reservation-messages" or name == "in-reservation-tear-messages" or name == "in-srefresh-messages" or name == "interface-name-xr" or name == "out-ack-messages" or name == "out-hello-messages" or name == "out-path-error-messages" or name == "out-path-messages" or name == "out-path-tear-messages" or name == "out-reservation-error-messages" or name == "out-reservation-messages" or name == "out-reservation-tear-messages" or name == "out-srefresh-messages"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "interface-name"):
                        self.interface_name = value
                        self.interface_name.value_namespace = name_space
                        self.interface_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "in-ack-messages"):
                        self.in_ack_messages = value
                        self.in_ack_messages.value_namespace = name_space
                        self.in_ack_messages.value_namespace_prefix = name_space_prefix
                    if(value_path == "in-hello-messages"):
                        self.in_hello_messages = value
                        self.in_hello_messages.value_namespace = name_space
                        self.in_hello_messages.value_namespace_prefix = name_space_prefix
                    if(value_path == "in-path-error-messages"):
                        self.in_path_error_messages = value
                        self.in_path_error_messages.value_namespace = name_space
                        self.in_path_error_messages.value_namespace_prefix = name_space_prefix
                    if(value_path == "in-path-messages"):
                        self.in_path_messages = value
                        self.in_path_messages.value_namespace = name_space
                        self.in_path_messages.value_namespace_prefix = name_space_prefix
                    if(value_path == "in-path-tear-messages"):
                        self.in_path_tear_messages = value
                        self.in_path_tear_messages.value_namespace = name_space
                        self.in_path_tear_messages.value_namespace_prefix = name_space_prefix
                    if(value_path == "in-reservation-error-messages"):
                        self.in_reservation_error_messages = value
                        self.in_reservation_error_messages.value_namespace = name_space
                        self.in_reservation_error_messages.value_namespace_prefix = name_space_prefix
                    if(value_path == "in-reservation-messages"):
                        self.in_reservation_messages = value
                        self.in_reservation_messages.value_namespace = name_space
                        self.in_reservation_messages.value_namespace_prefix = name_space_prefix
                    if(value_path == "in-reservation-tear-messages"):
                        self.in_reservation_tear_messages = value
                        self.in_reservation_tear_messages.value_namespace = name_space
                        self.in_reservation_tear_messages.value_namespace_prefix = name_space_prefix
                    if(value_path == "in-srefresh-messages"):
                        self.in_srefresh_messages = value
                        self.in_srefresh_messages.value_namespace = name_space
                        self.in_srefresh_messages.value_namespace_prefix = name_space_prefix
                    if(value_path == "interface-name-xr"):
                        self.interface_name_xr = value
                        self.interface_name_xr.value_namespace = name_space
                        self.interface_name_xr.value_namespace_prefix = name_space_prefix
                    if(value_path == "out-ack-messages"):
                        self.out_ack_messages = value
                        self.out_ack_messages.value_namespace = name_space
                        self.out_ack_messages.value_namespace_prefix = name_space_prefix
                    if(value_path == "out-hello-messages"):
                        self.out_hello_messages = value
                        self.out_hello_messages.value_namespace = name_space
                        self.out_hello_messages.value_namespace_prefix = name_space_prefix
                    if(value_path == "out-path-error-messages"):
                        self.out_path_error_messages = value
                        self.out_path_error_messages.value_namespace = name_space
                        self.out_path_error_messages.value_namespace_prefix = name_space_prefix
                    if(value_path == "out-path-messages"):
                        self.out_path_messages = value
                        self.out_path_messages.value_namespace = name_space
                        self.out_path_messages.value_namespace_prefix = name_space_prefix
                    if(value_path == "out-path-tear-messages"):
                        self.out_path_tear_messages = value
                        self.out_path_tear_messages.value_namespace = name_space
                        self.out_path_tear_messages.value_namespace_prefix = name_space_prefix
                    if(value_path == "out-reservation-error-messages"):
                        self.out_reservation_error_messages = value
                        self.out_reservation_error_messages.value_namespace = name_space
                        self.out_reservation_error_messages.value_namespace_prefix = name_space_prefix
                    if(value_path == "out-reservation-messages"):
                        self.out_reservation_messages = value
                        self.out_reservation_messages.value_namespace = name_space
                        self.out_reservation_messages.value_namespace_prefix = name_space_prefix
                    if(value_path == "out-reservation-tear-messages"):
                        self.out_reservation_tear_messages = value
                        self.out_reservation_tear_messages.value_namespace = name_space
                        self.out_reservation_tear_messages.value_namespace_prefix = name_space_prefix
                    if(value_path == "out-srefresh-messages"):
                        self.out_srefresh_messages = value
                        self.out_srefresh_messages.value_namespace = name_space
                        self.out_srefresh_messages.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.interface_counter:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.interface_counter:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "interface-counters" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/open-config/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "interface-counter"):
                    for c in self.interface_counter:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = Rsvp.OpenConfig.InterfaceCounters.InterfaceCounter()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.interface_counter.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "interface-counter"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass

        def has_data(self):
            return (
                (self.global_counters is not None and self.global_counters.has_data()) or
                (self.interface_counters is not None and self.interface_counters.has_data()))

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.global_counters is not None and self.global_counters.has_operation()) or
                (self.interface_counters is not None and self.interface_counters.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "open-config" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "global-counters"):
                if (self.global_counters is None):
                    self.global_counters = Rsvp.OpenConfig.GlobalCounters()
                    self.global_counters.parent = self
                    self._children_name_map["global_counters"] = "global-counters"
                return self.global_counters

            if (child_yang_name == "interface-counters"):
                if (self.interface_counters is None):
                    self.interface_counters = Rsvp.OpenConfig.InterfaceCounters()
                    self.interface_counters.parent = self
                    self._children_name_map["interface_counters"] = "interface-counters"
                return self.interface_counters

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "global-counters" or name == "interface-counters"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class Counters(Entity):
        """
        Counters
        
        .. attribute:: database
        
        	Summary information for all RSVP database counters
        	**type**\:   :py:class:`Database <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Counters.Database>`
        
        .. attribute:: event_syncs
        
        	Table containing event sync counters
        	**type**\:   :py:class:`EventSyncs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Counters.EventSyncs>`
        
        .. attribute:: interface_events
        
        	Event counters
        	**type**\:   :py:class:`InterfaceEvents <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Counters.InterfaceEvents>`
        
        .. attribute:: interface_messages
        
        	Table of message counters
        	**type**\:   :py:class:`InterfaceMessages <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Counters.InterfaceMessages>`
        
        .. attribute:: issu
        
        	Summary information for all RSVP ISSU counters
        	**type**\:   :py:class:`Issu <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Counters.Issu>`
        
        .. attribute:: message_summary
        
        	Summary information for all RSVP message counters
        	**type**\:   :py:class:`MessageSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Counters.MessageSummary>`
        
        .. attribute:: nsr
        
        	Summary information for all RSVP NSR counters
        	**type**\:   :py:class:`Nsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Counters.Nsr>`
        
        .. attribute:: out_of_resource
        
        	Out of resource counters
        	**type**\:   :py:class:`OutOfResource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Counters.OutOfResource>`
        
        .. attribute:: prefix_filtering
        
        	Prefix filtering counters
        	**type**\:   :py:class:`PrefixFiltering <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Counters.PrefixFiltering>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Rsvp.Counters, self).__init__()

            self.yang_name = "counters"
            self.yang_parent_name = "rsvp"

            self.database = Rsvp.Counters.Database()
            self.database.parent = self
            self._children_name_map["database"] = "database"
            self._children_yang_names.add("database")

            self.event_syncs = Rsvp.Counters.EventSyncs()
            self.event_syncs.parent = self
            self._children_name_map["event_syncs"] = "event-syncs"
            self._children_yang_names.add("event-syncs")

            self.interface_events = Rsvp.Counters.InterfaceEvents()
            self.interface_events.parent = self
            self._children_name_map["interface_events"] = "interface-events"
            self._children_yang_names.add("interface-events")

            self.interface_messages = Rsvp.Counters.InterfaceMessages()
            self.interface_messages.parent = self
            self._children_name_map["interface_messages"] = "interface-messages"
            self._children_yang_names.add("interface-messages")

            self.issu = Rsvp.Counters.Issu()
            self.issu.parent = self
            self._children_name_map["issu"] = "issu"
            self._children_yang_names.add("issu")

            self.message_summary = Rsvp.Counters.MessageSummary()
            self.message_summary.parent = self
            self._children_name_map["message_summary"] = "message-summary"
            self._children_yang_names.add("message-summary")

            self.nsr = Rsvp.Counters.Nsr()
            self.nsr.parent = self
            self._children_name_map["nsr"] = "nsr"
            self._children_yang_names.add("nsr")

            self.out_of_resource = Rsvp.Counters.OutOfResource()
            self.out_of_resource.parent = self
            self._children_name_map["out_of_resource"] = "out-of-resource"
            self._children_yang_names.add("out-of-resource")

            self.prefix_filtering = Rsvp.Counters.PrefixFiltering()
            self.prefix_filtering.parent = self
            self._children_name_map["prefix_filtering"] = "prefix-filtering"
            self._children_yang_names.add("prefix-filtering")


        class InterfaceMessages(Entity):
            """
            Table of message counters
            
            .. attribute:: interface_message
            
            	Interface message counters
            	**type**\: list of    :py:class:`InterfaceMessage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Counters.InterfaceMessages.InterfaceMessage>`
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Rsvp.Counters.InterfaceMessages, self).__init__()

                self.yang_name = "interface-messages"
                self.yang_parent_name = "counters"

                self.interface_message = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Rsvp.Counters.InterfaceMessages, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Rsvp.Counters.InterfaceMessages, self).__setattr__(name, value)


            class InterfaceMessage(Entity):
                """
                Interface message counters
                
                .. attribute:: interface_name  <key>
                
                	Interface Name. 'None' is used internally where the true interface is unknown (e.g. for routed packets)
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: bundle_received_messages
                
                	Count of Bundle messages received
                	**type**\:   :py:class:`BundleReceivedMessages <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Counters.InterfaceMessages.InterfaceMessage.BundleReceivedMessages>`
                
                .. attribute:: bundle_transmitted_messages
                
                	Count of Bundle messages transmitted
                	**type**\:   :py:class:`BundleTransmittedMessages <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Counters.InterfaceMessages.InterfaceMessage.BundleTransmittedMessages>`
                
                .. attribute:: out_of_order_messages
                
                	Count of Out of Order messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rate_limited_messages
                
                	Count of Rate Limited messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: received_messages
                
                	Count of messages received
                	**type**\:   :py:class:`ReceivedMessages <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Counters.InterfaceMessages.InterfaceMessage.ReceivedMessages>`
                
                .. attribute:: retransmitted_messages
                
                	Count of messages retransmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: transmitted_messages
                
                	Count of messages transmitted
                	**type**\:   :py:class:`TransmittedMessages <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Counters.InterfaceMessages.InterfaceMessage.TransmittedMessages>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.Counters.InterfaceMessages.InterfaceMessage, self).__init__()

                    self.yang_name = "interface-message"
                    self.yang_parent_name = "interface-messages"

                    self.interface_name = YLeaf(YType.str, "interface-name")

                    self.out_of_order_messages = YLeaf(YType.uint32, "out-of-order-messages")

                    self.rate_limited_messages = YLeaf(YType.uint32, "rate-limited-messages")

                    self.retransmitted_messages = YLeaf(YType.uint32, "retransmitted-messages")

                    self.bundle_received_messages = Rsvp.Counters.InterfaceMessages.InterfaceMessage.BundleReceivedMessages()
                    self.bundle_received_messages.parent = self
                    self._children_name_map["bundle_received_messages"] = "bundle-received-messages"
                    self._children_yang_names.add("bundle-received-messages")

                    self.bundle_transmitted_messages = Rsvp.Counters.InterfaceMessages.InterfaceMessage.BundleTransmittedMessages()
                    self.bundle_transmitted_messages.parent = self
                    self._children_name_map["bundle_transmitted_messages"] = "bundle-transmitted-messages"
                    self._children_yang_names.add("bundle-transmitted-messages")

                    self.received_messages = Rsvp.Counters.InterfaceMessages.InterfaceMessage.ReceivedMessages()
                    self.received_messages.parent = self
                    self._children_name_map["received_messages"] = "received-messages"
                    self._children_yang_names.add("received-messages")

                    self.transmitted_messages = Rsvp.Counters.InterfaceMessages.InterfaceMessage.TransmittedMessages()
                    self.transmitted_messages.parent = self
                    self._children_name_map["transmitted_messages"] = "transmitted-messages"
                    self._children_yang_names.add("transmitted-messages")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("interface_name",
                                    "out_of_order_messages",
                                    "rate_limited_messages",
                                    "retransmitted_messages") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.Counters.InterfaceMessages.InterfaceMessage, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.Counters.InterfaceMessages.InterfaceMessage, self).__setattr__(name, value)


                class ReceivedMessages(Entity):
                    """
                    Count of messages received
                    
                    .. attribute:: ack
                    
                    	Count of ACK messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bundle
                    
                    	Count of Bundle messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: challenge
                    
                    	Count of Integrity Challenge messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello
                    
                    	Count of Hello messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: path
                    
                    	Count of Path messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: path_error
                    
                    	Count of PathError messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: path_tear
                    
                    	Count of PathTear messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: reservation
                    
                    	Count of Reservation messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: reservation_confirm
                    
                    	Count of ReservationConfirm messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: reservation_error
                    
                    	Count of ReservationError messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: reservation_tear
                    
                    	Count of ReservationTear messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: response
                    
                    	Count of Integrity Response messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: srefresh
                    
                    	Count of Srefresh messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.Counters.InterfaceMessages.InterfaceMessage.ReceivedMessages, self).__init__()

                        self.yang_name = "received-messages"
                        self.yang_parent_name = "interface-message"

                        self.ack = YLeaf(YType.uint32, "ack")

                        self.bundle = YLeaf(YType.uint32, "bundle")

                        self.challenge = YLeaf(YType.uint32, "challenge")

                        self.hello = YLeaf(YType.uint32, "hello")

                        self.path = YLeaf(YType.uint32, "path")

                        self.path_error = YLeaf(YType.uint32, "path-error")

                        self.path_tear = YLeaf(YType.uint32, "path-tear")

                        self.reservation = YLeaf(YType.uint32, "reservation")

                        self.reservation_confirm = YLeaf(YType.uint32, "reservation-confirm")

                        self.reservation_error = YLeaf(YType.uint32, "reservation-error")

                        self.reservation_tear = YLeaf(YType.uint32, "reservation-tear")

                        self.response = YLeaf(YType.uint32, "response")

                        self.srefresh = YLeaf(YType.uint32, "srefresh")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("ack",
                                        "bundle",
                                        "challenge",
                                        "hello",
                                        "path",
                                        "path_error",
                                        "path_tear",
                                        "reservation",
                                        "reservation_confirm",
                                        "reservation_error",
                                        "reservation_tear",
                                        "response",
                                        "srefresh") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.Counters.InterfaceMessages.InterfaceMessage.ReceivedMessages, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.Counters.InterfaceMessages.InterfaceMessage.ReceivedMessages, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.ack.is_set or
                            self.bundle.is_set or
                            self.challenge.is_set or
                            self.hello.is_set or
                            self.path.is_set or
                            self.path_error.is_set or
                            self.path_tear.is_set or
                            self.reservation.is_set or
                            self.reservation_confirm.is_set or
                            self.reservation_error.is_set or
                            self.reservation_tear.is_set or
                            self.response.is_set or
                            self.srefresh.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.ack.yfilter != YFilter.not_set or
                            self.bundle.yfilter != YFilter.not_set or
                            self.challenge.yfilter != YFilter.not_set or
                            self.hello.yfilter != YFilter.not_set or
                            self.path.yfilter != YFilter.not_set or
                            self.path_error.yfilter != YFilter.not_set or
                            self.path_tear.yfilter != YFilter.not_set or
                            self.reservation.yfilter != YFilter.not_set or
                            self.reservation_confirm.yfilter != YFilter.not_set or
                            self.reservation_error.yfilter != YFilter.not_set or
                            self.reservation_tear.yfilter != YFilter.not_set or
                            self.response.yfilter != YFilter.not_set or
                            self.srefresh.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "received-messages" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.ack.is_set or self.ack.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ack.get_name_leafdata())
                        if (self.bundle.is_set or self.bundle.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bundle.get_name_leafdata())
                        if (self.challenge.is_set or self.challenge.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.challenge.get_name_leafdata())
                        if (self.hello.is_set or self.hello.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.hello.get_name_leafdata())
                        if (self.path.is_set or self.path.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.path.get_name_leafdata())
                        if (self.path_error.is_set or self.path_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.path_error.get_name_leafdata())
                        if (self.path_tear.is_set or self.path_tear.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.path_tear.get_name_leafdata())
                        if (self.reservation.is_set or self.reservation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.reservation.get_name_leafdata())
                        if (self.reservation_confirm.is_set or self.reservation_confirm.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.reservation_confirm.get_name_leafdata())
                        if (self.reservation_error.is_set or self.reservation_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.reservation_error.get_name_leafdata())
                        if (self.reservation_tear.is_set or self.reservation_tear.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.reservation_tear.get_name_leafdata())
                        if (self.response.is_set or self.response.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.response.get_name_leafdata())
                        if (self.srefresh.is_set or self.srefresh.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.srefresh.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ack" or name == "bundle" or name == "challenge" or name == "hello" or name == "path" or name == "path-error" or name == "path-tear" or name == "reservation" or name == "reservation-confirm" or name == "reservation-error" or name == "reservation-tear" or name == "response" or name == "srefresh"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "ack"):
                            self.ack = value
                            self.ack.value_namespace = name_space
                            self.ack.value_namespace_prefix = name_space_prefix
                        if(value_path == "bundle"):
                            self.bundle = value
                            self.bundle.value_namespace = name_space
                            self.bundle.value_namespace_prefix = name_space_prefix
                        if(value_path == "challenge"):
                            self.challenge = value
                            self.challenge.value_namespace = name_space
                            self.challenge.value_namespace_prefix = name_space_prefix
                        if(value_path == "hello"):
                            self.hello = value
                            self.hello.value_namespace = name_space
                            self.hello.value_namespace_prefix = name_space_prefix
                        if(value_path == "path"):
                            self.path = value
                            self.path.value_namespace = name_space
                            self.path.value_namespace_prefix = name_space_prefix
                        if(value_path == "path-error"):
                            self.path_error = value
                            self.path_error.value_namespace = name_space
                            self.path_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "path-tear"):
                            self.path_tear = value
                            self.path_tear.value_namespace = name_space
                            self.path_tear.value_namespace_prefix = name_space_prefix
                        if(value_path == "reservation"):
                            self.reservation = value
                            self.reservation.value_namespace = name_space
                            self.reservation.value_namespace_prefix = name_space_prefix
                        if(value_path == "reservation-confirm"):
                            self.reservation_confirm = value
                            self.reservation_confirm.value_namespace = name_space
                            self.reservation_confirm.value_namespace_prefix = name_space_prefix
                        if(value_path == "reservation-error"):
                            self.reservation_error = value
                            self.reservation_error.value_namespace = name_space
                            self.reservation_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "reservation-tear"):
                            self.reservation_tear = value
                            self.reservation_tear.value_namespace = name_space
                            self.reservation_tear.value_namespace_prefix = name_space_prefix
                        if(value_path == "response"):
                            self.response = value
                            self.response.value_namespace = name_space
                            self.response.value_namespace_prefix = name_space_prefix
                        if(value_path == "srefresh"):
                            self.srefresh = value
                            self.srefresh.value_namespace = name_space
                            self.srefresh.value_namespace_prefix = name_space_prefix


                class TransmittedMessages(Entity):
                    """
                    Count of messages transmitted
                    
                    .. attribute:: ack
                    
                    	Count of ACK messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bundle
                    
                    	Count of Bundle messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: challenge
                    
                    	Count of Integrity Challenge messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello
                    
                    	Count of Hello messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: path
                    
                    	Count of Path messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: path_error
                    
                    	Count of PathError messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: path_tear
                    
                    	Count of PathTear messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: reservation
                    
                    	Count of Reservation messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: reservation_confirm
                    
                    	Count of ReservationConfirm messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: reservation_error
                    
                    	Count of ReservationError messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: reservation_tear
                    
                    	Count of ReservationTear messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: response
                    
                    	Count of Integrity Response messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: srefresh
                    
                    	Count of Srefresh messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.Counters.InterfaceMessages.InterfaceMessage.TransmittedMessages, self).__init__()

                        self.yang_name = "transmitted-messages"
                        self.yang_parent_name = "interface-message"

                        self.ack = YLeaf(YType.uint32, "ack")

                        self.bundle = YLeaf(YType.uint32, "bundle")

                        self.challenge = YLeaf(YType.uint32, "challenge")

                        self.hello = YLeaf(YType.uint32, "hello")

                        self.path = YLeaf(YType.uint32, "path")

                        self.path_error = YLeaf(YType.uint32, "path-error")

                        self.path_tear = YLeaf(YType.uint32, "path-tear")

                        self.reservation = YLeaf(YType.uint32, "reservation")

                        self.reservation_confirm = YLeaf(YType.uint32, "reservation-confirm")

                        self.reservation_error = YLeaf(YType.uint32, "reservation-error")

                        self.reservation_tear = YLeaf(YType.uint32, "reservation-tear")

                        self.response = YLeaf(YType.uint32, "response")

                        self.srefresh = YLeaf(YType.uint32, "srefresh")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("ack",
                                        "bundle",
                                        "challenge",
                                        "hello",
                                        "path",
                                        "path_error",
                                        "path_tear",
                                        "reservation",
                                        "reservation_confirm",
                                        "reservation_error",
                                        "reservation_tear",
                                        "response",
                                        "srefresh") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.Counters.InterfaceMessages.InterfaceMessage.TransmittedMessages, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.Counters.InterfaceMessages.InterfaceMessage.TransmittedMessages, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.ack.is_set or
                            self.bundle.is_set or
                            self.challenge.is_set or
                            self.hello.is_set or
                            self.path.is_set or
                            self.path_error.is_set or
                            self.path_tear.is_set or
                            self.reservation.is_set or
                            self.reservation_confirm.is_set or
                            self.reservation_error.is_set or
                            self.reservation_tear.is_set or
                            self.response.is_set or
                            self.srefresh.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.ack.yfilter != YFilter.not_set or
                            self.bundle.yfilter != YFilter.not_set or
                            self.challenge.yfilter != YFilter.not_set or
                            self.hello.yfilter != YFilter.not_set or
                            self.path.yfilter != YFilter.not_set or
                            self.path_error.yfilter != YFilter.not_set or
                            self.path_tear.yfilter != YFilter.not_set or
                            self.reservation.yfilter != YFilter.not_set or
                            self.reservation_confirm.yfilter != YFilter.not_set or
                            self.reservation_error.yfilter != YFilter.not_set or
                            self.reservation_tear.yfilter != YFilter.not_set or
                            self.response.yfilter != YFilter.not_set or
                            self.srefresh.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "transmitted-messages" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.ack.is_set or self.ack.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ack.get_name_leafdata())
                        if (self.bundle.is_set or self.bundle.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bundle.get_name_leafdata())
                        if (self.challenge.is_set or self.challenge.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.challenge.get_name_leafdata())
                        if (self.hello.is_set or self.hello.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.hello.get_name_leafdata())
                        if (self.path.is_set or self.path.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.path.get_name_leafdata())
                        if (self.path_error.is_set or self.path_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.path_error.get_name_leafdata())
                        if (self.path_tear.is_set or self.path_tear.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.path_tear.get_name_leafdata())
                        if (self.reservation.is_set or self.reservation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.reservation.get_name_leafdata())
                        if (self.reservation_confirm.is_set or self.reservation_confirm.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.reservation_confirm.get_name_leafdata())
                        if (self.reservation_error.is_set or self.reservation_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.reservation_error.get_name_leafdata())
                        if (self.reservation_tear.is_set or self.reservation_tear.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.reservation_tear.get_name_leafdata())
                        if (self.response.is_set or self.response.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.response.get_name_leafdata())
                        if (self.srefresh.is_set or self.srefresh.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.srefresh.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ack" or name == "bundle" or name == "challenge" or name == "hello" or name == "path" or name == "path-error" or name == "path-tear" or name == "reservation" or name == "reservation-confirm" or name == "reservation-error" or name == "reservation-tear" or name == "response" or name == "srefresh"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "ack"):
                            self.ack = value
                            self.ack.value_namespace = name_space
                            self.ack.value_namespace_prefix = name_space_prefix
                        if(value_path == "bundle"):
                            self.bundle = value
                            self.bundle.value_namespace = name_space
                            self.bundle.value_namespace_prefix = name_space_prefix
                        if(value_path == "challenge"):
                            self.challenge = value
                            self.challenge.value_namespace = name_space
                            self.challenge.value_namespace_prefix = name_space_prefix
                        if(value_path == "hello"):
                            self.hello = value
                            self.hello.value_namespace = name_space
                            self.hello.value_namespace_prefix = name_space_prefix
                        if(value_path == "path"):
                            self.path = value
                            self.path.value_namespace = name_space
                            self.path.value_namespace_prefix = name_space_prefix
                        if(value_path == "path-error"):
                            self.path_error = value
                            self.path_error.value_namespace = name_space
                            self.path_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "path-tear"):
                            self.path_tear = value
                            self.path_tear.value_namespace = name_space
                            self.path_tear.value_namespace_prefix = name_space_prefix
                        if(value_path == "reservation"):
                            self.reservation = value
                            self.reservation.value_namespace = name_space
                            self.reservation.value_namespace_prefix = name_space_prefix
                        if(value_path == "reservation-confirm"):
                            self.reservation_confirm = value
                            self.reservation_confirm.value_namespace = name_space
                            self.reservation_confirm.value_namespace_prefix = name_space_prefix
                        if(value_path == "reservation-error"):
                            self.reservation_error = value
                            self.reservation_error.value_namespace = name_space
                            self.reservation_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "reservation-tear"):
                            self.reservation_tear = value
                            self.reservation_tear.value_namespace = name_space
                            self.reservation_tear.value_namespace_prefix = name_space_prefix
                        if(value_path == "response"):
                            self.response = value
                            self.response.value_namespace = name_space
                            self.response.value_namespace_prefix = name_space_prefix
                        if(value_path == "srefresh"):
                            self.srefresh = value
                            self.srefresh.value_namespace = name_space
                            self.srefresh.value_namespace_prefix = name_space_prefix


                class BundleReceivedMessages(Entity):
                    """
                    Count of Bundle messages received
                    
                    .. attribute:: ack
                    
                    	Count of ACK messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bundle
                    
                    	Count of Bundle messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: challenge
                    
                    	Count of Integrity Challenge messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello
                    
                    	Count of Hello messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: path
                    
                    	Count of Path messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: path_error
                    
                    	Count of PathError messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: path_tear
                    
                    	Count of PathTear messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: reservation
                    
                    	Count of Reservation messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: reservation_confirm
                    
                    	Count of ReservationConfirm messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: reservation_error
                    
                    	Count of ReservationError messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: reservation_tear
                    
                    	Count of ReservationTear messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: response
                    
                    	Count of Integrity Response messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: srefresh
                    
                    	Count of Srefresh messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.Counters.InterfaceMessages.InterfaceMessage.BundleReceivedMessages, self).__init__()

                        self.yang_name = "bundle-received-messages"
                        self.yang_parent_name = "interface-message"

                        self.ack = YLeaf(YType.uint32, "ack")

                        self.bundle = YLeaf(YType.uint32, "bundle")

                        self.challenge = YLeaf(YType.uint32, "challenge")

                        self.hello = YLeaf(YType.uint32, "hello")

                        self.path = YLeaf(YType.uint32, "path")

                        self.path_error = YLeaf(YType.uint32, "path-error")

                        self.path_tear = YLeaf(YType.uint32, "path-tear")

                        self.reservation = YLeaf(YType.uint32, "reservation")

                        self.reservation_confirm = YLeaf(YType.uint32, "reservation-confirm")

                        self.reservation_error = YLeaf(YType.uint32, "reservation-error")

                        self.reservation_tear = YLeaf(YType.uint32, "reservation-tear")

                        self.response = YLeaf(YType.uint32, "response")

                        self.srefresh = YLeaf(YType.uint32, "srefresh")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("ack",
                                        "bundle",
                                        "challenge",
                                        "hello",
                                        "path",
                                        "path_error",
                                        "path_tear",
                                        "reservation",
                                        "reservation_confirm",
                                        "reservation_error",
                                        "reservation_tear",
                                        "response",
                                        "srefresh") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.Counters.InterfaceMessages.InterfaceMessage.BundleReceivedMessages, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.Counters.InterfaceMessages.InterfaceMessage.BundleReceivedMessages, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.ack.is_set or
                            self.bundle.is_set or
                            self.challenge.is_set or
                            self.hello.is_set or
                            self.path.is_set or
                            self.path_error.is_set or
                            self.path_tear.is_set or
                            self.reservation.is_set or
                            self.reservation_confirm.is_set or
                            self.reservation_error.is_set or
                            self.reservation_tear.is_set or
                            self.response.is_set or
                            self.srefresh.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.ack.yfilter != YFilter.not_set or
                            self.bundle.yfilter != YFilter.not_set or
                            self.challenge.yfilter != YFilter.not_set or
                            self.hello.yfilter != YFilter.not_set or
                            self.path.yfilter != YFilter.not_set or
                            self.path_error.yfilter != YFilter.not_set or
                            self.path_tear.yfilter != YFilter.not_set or
                            self.reservation.yfilter != YFilter.not_set or
                            self.reservation_confirm.yfilter != YFilter.not_set or
                            self.reservation_error.yfilter != YFilter.not_set or
                            self.reservation_tear.yfilter != YFilter.not_set or
                            self.response.yfilter != YFilter.not_set or
                            self.srefresh.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bundle-received-messages" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.ack.is_set or self.ack.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ack.get_name_leafdata())
                        if (self.bundle.is_set or self.bundle.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bundle.get_name_leafdata())
                        if (self.challenge.is_set or self.challenge.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.challenge.get_name_leafdata())
                        if (self.hello.is_set or self.hello.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.hello.get_name_leafdata())
                        if (self.path.is_set or self.path.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.path.get_name_leafdata())
                        if (self.path_error.is_set or self.path_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.path_error.get_name_leafdata())
                        if (self.path_tear.is_set or self.path_tear.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.path_tear.get_name_leafdata())
                        if (self.reservation.is_set or self.reservation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.reservation.get_name_leafdata())
                        if (self.reservation_confirm.is_set or self.reservation_confirm.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.reservation_confirm.get_name_leafdata())
                        if (self.reservation_error.is_set or self.reservation_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.reservation_error.get_name_leafdata())
                        if (self.reservation_tear.is_set or self.reservation_tear.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.reservation_tear.get_name_leafdata())
                        if (self.response.is_set or self.response.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.response.get_name_leafdata())
                        if (self.srefresh.is_set or self.srefresh.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.srefresh.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ack" or name == "bundle" or name == "challenge" or name == "hello" or name == "path" or name == "path-error" or name == "path-tear" or name == "reservation" or name == "reservation-confirm" or name == "reservation-error" or name == "reservation-tear" or name == "response" or name == "srefresh"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "ack"):
                            self.ack = value
                            self.ack.value_namespace = name_space
                            self.ack.value_namespace_prefix = name_space_prefix
                        if(value_path == "bundle"):
                            self.bundle = value
                            self.bundle.value_namespace = name_space
                            self.bundle.value_namespace_prefix = name_space_prefix
                        if(value_path == "challenge"):
                            self.challenge = value
                            self.challenge.value_namespace = name_space
                            self.challenge.value_namespace_prefix = name_space_prefix
                        if(value_path == "hello"):
                            self.hello = value
                            self.hello.value_namespace = name_space
                            self.hello.value_namespace_prefix = name_space_prefix
                        if(value_path == "path"):
                            self.path = value
                            self.path.value_namespace = name_space
                            self.path.value_namespace_prefix = name_space_prefix
                        if(value_path == "path-error"):
                            self.path_error = value
                            self.path_error.value_namespace = name_space
                            self.path_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "path-tear"):
                            self.path_tear = value
                            self.path_tear.value_namespace = name_space
                            self.path_tear.value_namespace_prefix = name_space_prefix
                        if(value_path == "reservation"):
                            self.reservation = value
                            self.reservation.value_namespace = name_space
                            self.reservation.value_namespace_prefix = name_space_prefix
                        if(value_path == "reservation-confirm"):
                            self.reservation_confirm = value
                            self.reservation_confirm.value_namespace = name_space
                            self.reservation_confirm.value_namespace_prefix = name_space_prefix
                        if(value_path == "reservation-error"):
                            self.reservation_error = value
                            self.reservation_error.value_namespace = name_space
                            self.reservation_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "reservation-tear"):
                            self.reservation_tear = value
                            self.reservation_tear.value_namespace = name_space
                            self.reservation_tear.value_namespace_prefix = name_space_prefix
                        if(value_path == "response"):
                            self.response = value
                            self.response.value_namespace = name_space
                            self.response.value_namespace_prefix = name_space_prefix
                        if(value_path == "srefresh"):
                            self.srefresh = value
                            self.srefresh.value_namespace = name_space
                            self.srefresh.value_namespace_prefix = name_space_prefix


                class BundleTransmittedMessages(Entity):
                    """
                    Count of Bundle messages transmitted
                    
                    .. attribute:: ack
                    
                    	Count of ACK messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bundle
                    
                    	Count of Bundle messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: challenge
                    
                    	Count of Integrity Challenge messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: hello
                    
                    	Count of Hello messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: path
                    
                    	Count of Path messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: path_error
                    
                    	Count of PathError messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: path_tear
                    
                    	Count of PathTear messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: reservation
                    
                    	Count of Reservation messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: reservation_confirm
                    
                    	Count of ReservationConfirm messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: reservation_error
                    
                    	Count of ReservationError messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: reservation_tear
                    
                    	Count of ReservationTear messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: response
                    
                    	Count of Integrity Response messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: srefresh
                    
                    	Count of Srefresh messages
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.Counters.InterfaceMessages.InterfaceMessage.BundleTransmittedMessages, self).__init__()

                        self.yang_name = "bundle-transmitted-messages"
                        self.yang_parent_name = "interface-message"

                        self.ack = YLeaf(YType.uint32, "ack")

                        self.bundle = YLeaf(YType.uint32, "bundle")

                        self.challenge = YLeaf(YType.uint32, "challenge")

                        self.hello = YLeaf(YType.uint32, "hello")

                        self.path = YLeaf(YType.uint32, "path")

                        self.path_error = YLeaf(YType.uint32, "path-error")

                        self.path_tear = YLeaf(YType.uint32, "path-tear")

                        self.reservation = YLeaf(YType.uint32, "reservation")

                        self.reservation_confirm = YLeaf(YType.uint32, "reservation-confirm")

                        self.reservation_error = YLeaf(YType.uint32, "reservation-error")

                        self.reservation_tear = YLeaf(YType.uint32, "reservation-tear")

                        self.response = YLeaf(YType.uint32, "response")

                        self.srefresh = YLeaf(YType.uint32, "srefresh")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("ack",
                                        "bundle",
                                        "challenge",
                                        "hello",
                                        "path",
                                        "path_error",
                                        "path_tear",
                                        "reservation",
                                        "reservation_confirm",
                                        "reservation_error",
                                        "reservation_tear",
                                        "response",
                                        "srefresh") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.Counters.InterfaceMessages.InterfaceMessage.BundleTransmittedMessages, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.Counters.InterfaceMessages.InterfaceMessage.BundleTransmittedMessages, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.ack.is_set or
                            self.bundle.is_set or
                            self.challenge.is_set or
                            self.hello.is_set or
                            self.path.is_set or
                            self.path_error.is_set or
                            self.path_tear.is_set or
                            self.reservation.is_set or
                            self.reservation_confirm.is_set or
                            self.reservation_error.is_set or
                            self.reservation_tear.is_set or
                            self.response.is_set or
                            self.srefresh.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.ack.yfilter != YFilter.not_set or
                            self.bundle.yfilter != YFilter.not_set or
                            self.challenge.yfilter != YFilter.not_set or
                            self.hello.yfilter != YFilter.not_set or
                            self.path.yfilter != YFilter.not_set or
                            self.path_error.yfilter != YFilter.not_set or
                            self.path_tear.yfilter != YFilter.not_set or
                            self.reservation.yfilter != YFilter.not_set or
                            self.reservation_confirm.yfilter != YFilter.not_set or
                            self.reservation_error.yfilter != YFilter.not_set or
                            self.reservation_tear.yfilter != YFilter.not_set or
                            self.response.yfilter != YFilter.not_set or
                            self.srefresh.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "bundle-transmitted-messages" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.ack.is_set or self.ack.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.ack.get_name_leafdata())
                        if (self.bundle.is_set or self.bundle.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.bundle.get_name_leafdata())
                        if (self.challenge.is_set or self.challenge.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.challenge.get_name_leafdata())
                        if (self.hello.is_set or self.hello.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.hello.get_name_leafdata())
                        if (self.path.is_set or self.path.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.path.get_name_leafdata())
                        if (self.path_error.is_set or self.path_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.path_error.get_name_leafdata())
                        if (self.path_tear.is_set or self.path_tear.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.path_tear.get_name_leafdata())
                        if (self.reservation.is_set or self.reservation.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.reservation.get_name_leafdata())
                        if (self.reservation_confirm.is_set or self.reservation_confirm.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.reservation_confirm.get_name_leafdata())
                        if (self.reservation_error.is_set or self.reservation_error.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.reservation_error.get_name_leafdata())
                        if (self.reservation_tear.is_set or self.reservation_tear.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.reservation_tear.get_name_leafdata())
                        if (self.response.is_set or self.response.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.response.get_name_leafdata())
                        if (self.srefresh.is_set or self.srefresh.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.srefresh.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ack" or name == "bundle" or name == "challenge" or name == "hello" or name == "path" or name == "path-error" or name == "path-tear" or name == "reservation" or name == "reservation-confirm" or name == "reservation-error" or name == "reservation-tear" or name == "response" or name == "srefresh"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "ack"):
                            self.ack = value
                            self.ack.value_namespace = name_space
                            self.ack.value_namespace_prefix = name_space_prefix
                        if(value_path == "bundle"):
                            self.bundle = value
                            self.bundle.value_namespace = name_space
                            self.bundle.value_namespace_prefix = name_space_prefix
                        if(value_path == "challenge"):
                            self.challenge = value
                            self.challenge.value_namespace = name_space
                            self.challenge.value_namespace_prefix = name_space_prefix
                        if(value_path == "hello"):
                            self.hello = value
                            self.hello.value_namespace = name_space
                            self.hello.value_namespace_prefix = name_space_prefix
                        if(value_path == "path"):
                            self.path = value
                            self.path.value_namespace = name_space
                            self.path.value_namespace_prefix = name_space_prefix
                        if(value_path == "path-error"):
                            self.path_error = value
                            self.path_error.value_namespace = name_space
                            self.path_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "path-tear"):
                            self.path_tear = value
                            self.path_tear.value_namespace = name_space
                            self.path_tear.value_namespace_prefix = name_space_prefix
                        if(value_path == "reservation"):
                            self.reservation = value
                            self.reservation.value_namespace = name_space
                            self.reservation.value_namespace_prefix = name_space_prefix
                        if(value_path == "reservation-confirm"):
                            self.reservation_confirm = value
                            self.reservation_confirm.value_namespace = name_space
                            self.reservation_confirm.value_namespace_prefix = name_space_prefix
                        if(value_path == "reservation-error"):
                            self.reservation_error = value
                            self.reservation_error.value_namespace = name_space
                            self.reservation_error.value_namespace_prefix = name_space_prefix
                        if(value_path == "reservation-tear"):
                            self.reservation_tear = value
                            self.reservation_tear.value_namespace = name_space
                            self.reservation_tear.value_namespace_prefix = name_space_prefix
                        if(value_path == "response"):
                            self.response = value
                            self.response.value_namespace = name_space
                            self.response.value_namespace_prefix = name_space_prefix
                        if(value_path == "srefresh"):
                            self.srefresh = value
                            self.srefresh.value_namespace = name_space
                            self.srefresh.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.interface_name.is_set or
                        self.out_of_order_messages.is_set or
                        self.rate_limited_messages.is_set or
                        self.retransmitted_messages.is_set or
                        (self.bundle_received_messages is not None and self.bundle_received_messages.has_data()) or
                        (self.bundle_transmitted_messages is not None and self.bundle_transmitted_messages.has_data()) or
                        (self.received_messages is not None and self.received_messages.has_data()) or
                        (self.transmitted_messages is not None and self.transmitted_messages.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.interface_name.yfilter != YFilter.not_set or
                        self.out_of_order_messages.yfilter != YFilter.not_set or
                        self.rate_limited_messages.yfilter != YFilter.not_set or
                        self.retransmitted_messages.yfilter != YFilter.not_set or
                        (self.bundle_received_messages is not None and self.bundle_received_messages.has_operation()) or
                        (self.bundle_transmitted_messages is not None and self.bundle_transmitted_messages.has_operation()) or
                        (self.received_messages is not None and self.received_messages.has_operation()) or
                        (self.transmitted_messages is not None and self.transmitted_messages.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "interface-message" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/counters/interface-messages/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                    if (self.out_of_order_messages.is_set or self.out_of_order_messages.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.out_of_order_messages.get_name_leafdata())
                    if (self.rate_limited_messages.is_set or self.rate_limited_messages.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rate_limited_messages.get_name_leafdata())
                    if (self.retransmitted_messages.is_set or self.retransmitted_messages.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.retransmitted_messages.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "bundle-received-messages"):
                        if (self.bundle_received_messages is None):
                            self.bundle_received_messages = Rsvp.Counters.InterfaceMessages.InterfaceMessage.BundleReceivedMessages()
                            self.bundle_received_messages.parent = self
                            self._children_name_map["bundle_received_messages"] = "bundle-received-messages"
                        return self.bundle_received_messages

                    if (child_yang_name == "bundle-transmitted-messages"):
                        if (self.bundle_transmitted_messages is None):
                            self.bundle_transmitted_messages = Rsvp.Counters.InterfaceMessages.InterfaceMessage.BundleTransmittedMessages()
                            self.bundle_transmitted_messages.parent = self
                            self._children_name_map["bundle_transmitted_messages"] = "bundle-transmitted-messages"
                        return self.bundle_transmitted_messages

                    if (child_yang_name == "received-messages"):
                        if (self.received_messages is None):
                            self.received_messages = Rsvp.Counters.InterfaceMessages.InterfaceMessage.ReceivedMessages()
                            self.received_messages.parent = self
                            self._children_name_map["received_messages"] = "received-messages"
                        return self.received_messages

                    if (child_yang_name == "transmitted-messages"):
                        if (self.transmitted_messages is None):
                            self.transmitted_messages = Rsvp.Counters.InterfaceMessages.InterfaceMessage.TransmittedMessages()
                            self.transmitted_messages.parent = self
                            self._children_name_map["transmitted_messages"] = "transmitted-messages"
                        return self.transmitted_messages

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "bundle-received-messages" or name == "bundle-transmitted-messages" or name == "received-messages" or name == "transmitted-messages" or name == "interface-name" or name == "out-of-order-messages" or name == "rate-limited-messages" or name == "retransmitted-messages"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "interface-name"):
                        self.interface_name = value
                        self.interface_name.value_namespace = name_space
                        self.interface_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "out-of-order-messages"):
                        self.out_of_order_messages = value
                        self.out_of_order_messages.value_namespace = name_space
                        self.out_of_order_messages.value_namespace_prefix = name_space_prefix
                    if(value_path == "rate-limited-messages"):
                        self.rate_limited_messages = value
                        self.rate_limited_messages.value_namespace = name_space
                        self.rate_limited_messages.value_namespace_prefix = name_space_prefix
                    if(value_path == "retransmitted-messages"):
                        self.retransmitted_messages = value
                        self.retransmitted_messages.value_namespace = name_space
                        self.retransmitted_messages.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.interface_message:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.interface_message:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "interface-messages" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/counters/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "interface-message"):
                    for c in self.interface_message:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = Rsvp.Counters.InterfaceMessages.InterfaceMessage()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.interface_message.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "interface-message"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class MessageSummary(Entity):
            """
            Summary information for all RSVP message
            counters
            
            .. attribute:: bundle_received_messages
            
            	Count of Bundle messages received
            	**type**\:   :py:class:`BundleReceivedMessages <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Counters.MessageSummary.BundleReceivedMessages>`
            
            .. attribute:: bundle_transmitted_messages
            
            	Count of Bundle messages transmitted
            	**type**\:   :py:class:`BundleTransmittedMessages <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Counters.MessageSummary.BundleTransmittedMessages>`
            
            .. attribute:: out_of_order_messages
            
            	Count of Out of Order messages
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: rate_limited_messages
            
            	Count of Rate Limited messages
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: received_messages
            
            	Count of messages received
            	**type**\:   :py:class:`ReceivedMessages <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Counters.MessageSummary.ReceivedMessages>`
            
            .. attribute:: retransmitted_messages
            
            	Count of messages retransmitted
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: transmitted_messages
            
            	Count of messages transmitted
            	**type**\:   :py:class:`TransmittedMessages <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Counters.MessageSummary.TransmittedMessages>`
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Rsvp.Counters.MessageSummary, self).__init__()

                self.yang_name = "message-summary"
                self.yang_parent_name = "counters"

                self.out_of_order_messages = YLeaf(YType.uint32, "out-of-order-messages")

                self.rate_limited_messages = YLeaf(YType.uint32, "rate-limited-messages")

                self.retransmitted_messages = YLeaf(YType.uint32, "retransmitted-messages")

                self.bundle_received_messages = Rsvp.Counters.MessageSummary.BundleReceivedMessages()
                self.bundle_received_messages.parent = self
                self._children_name_map["bundle_received_messages"] = "bundle-received-messages"
                self._children_yang_names.add("bundle-received-messages")

                self.bundle_transmitted_messages = Rsvp.Counters.MessageSummary.BundleTransmittedMessages()
                self.bundle_transmitted_messages.parent = self
                self._children_name_map["bundle_transmitted_messages"] = "bundle-transmitted-messages"
                self._children_yang_names.add("bundle-transmitted-messages")

                self.received_messages = Rsvp.Counters.MessageSummary.ReceivedMessages()
                self.received_messages.parent = self
                self._children_name_map["received_messages"] = "received-messages"
                self._children_yang_names.add("received-messages")

                self.transmitted_messages = Rsvp.Counters.MessageSummary.TransmittedMessages()
                self.transmitted_messages.parent = self
                self._children_name_map["transmitted_messages"] = "transmitted-messages"
                self._children_yang_names.add("transmitted-messages")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("out_of_order_messages",
                                "rate_limited_messages",
                                "retransmitted_messages") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Rsvp.Counters.MessageSummary, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Rsvp.Counters.MessageSummary, self).__setattr__(name, value)


            class ReceivedMessages(Entity):
                """
                Count of messages received
                
                .. attribute:: ack
                
                	Count of ACK messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bundle
                
                	Count of Bundle messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: challenge
                
                	Count of Integrity Challenge messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: hello
                
                	Count of Hello messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: path
                
                	Count of Path messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: path_error
                
                	Count of PathError messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: path_tear
                
                	Count of PathTear messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: reservation
                
                	Count of Reservation messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: reservation_confirm
                
                	Count of ReservationConfirm messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: reservation_error
                
                	Count of ReservationError messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: reservation_tear
                
                	Count of ReservationTear messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: response
                
                	Count of Integrity Response messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: srefresh
                
                	Count of Srefresh messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.Counters.MessageSummary.ReceivedMessages, self).__init__()

                    self.yang_name = "received-messages"
                    self.yang_parent_name = "message-summary"

                    self.ack = YLeaf(YType.uint32, "ack")

                    self.bundle = YLeaf(YType.uint32, "bundle")

                    self.challenge = YLeaf(YType.uint32, "challenge")

                    self.hello = YLeaf(YType.uint32, "hello")

                    self.path = YLeaf(YType.uint32, "path")

                    self.path_error = YLeaf(YType.uint32, "path-error")

                    self.path_tear = YLeaf(YType.uint32, "path-tear")

                    self.reservation = YLeaf(YType.uint32, "reservation")

                    self.reservation_confirm = YLeaf(YType.uint32, "reservation-confirm")

                    self.reservation_error = YLeaf(YType.uint32, "reservation-error")

                    self.reservation_tear = YLeaf(YType.uint32, "reservation-tear")

                    self.response = YLeaf(YType.uint32, "response")

                    self.srefresh = YLeaf(YType.uint32, "srefresh")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("ack",
                                    "bundle",
                                    "challenge",
                                    "hello",
                                    "path",
                                    "path_error",
                                    "path_tear",
                                    "reservation",
                                    "reservation_confirm",
                                    "reservation_error",
                                    "reservation_tear",
                                    "response",
                                    "srefresh") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.Counters.MessageSummary.ReceivedMessages, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.Counters.MessageSummary.ReceivedMessages, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.ack.is_set or
                        self.bundle.is_set or
                        self.challenge.is_set or
                        self.hello.is_set or
                        self.path.is_set or
                        self.path_error.is_set or
                        self.path_tear.is_set or
                        self.reservation.is_set or
                        self.reservation_confirm.is_set or
                        self.reservation_error.is_set or
                        self.reservation_tear.is_set or
                        self.response.is_set or
                        self.srefresh.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.ack.yfilter != YFilter.not_set or
                        self.bundle.yfilter != YFilter.not_set or
                        self.challenge.yfilter != YFilter.not_set or
                        self.hello.yfilter != YFilter.not_set or
                        self.path.yfilter != YFilter.not_set or
                        self.path_error.yfilter != YFilter.not_set or
                        self.path_tear.yfilter != YFilter.not_set or
                        self.reservation.yfilter != YFilter.not_set or
                        self.reservation_confirm.yfilter != YFilter.not_set or
                        self.reservation_error.yfilter != YFilter.not_set or
                        self.reservation_tear.yfilter != YFilter.not_set or
                        self.response.yfilter != YFilter.not_set or
                        self.srefresh.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "received-messages" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/counters/message-summary/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.ack.is_set or self.ack.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ack.get_name_leafdata())
                    if (self.bundle.is_set or self.bundle.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bundle.get_name_leafdata())
                    if (self.challenge.is_set or self.challenge.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.challenge.get_name_leafdata())
                    if (self.hello.is_set or self.hello.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.hello.get_name_leafdata())
                    if (self.path.is_set or self.path.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.path.get_name_leafdata())
                    if (self.path_error.is_set or self.path_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.path_error.get_name_leafdata())
                    if (self.path_tear.is_set or self.path_tear.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.path_tear.get_name_leafdata())
                    if (self.reservation.is_set or self.reservation.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reservation.get_name_leafdata())
                    if (self.reservation_confirm.is_set or self.reservation_confirm.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reservation_confirm.get_name_leafdata())
                    if (self.reservation_error.is_set or self.reservation_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reservation_error.get_name_leafdata())
                    if (self.reservation_tear.is_set or self.reservation_tear.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reservation_tear.get_name_leafdata())
                    if (self.response.is_set or self.response.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.response.get_name_leafdata())
                    if (self.srefresh.is_set or self.srefresh.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.srefresh.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ack" or name == "bundle" or name == "challenge" or name == "hello" or name == "path" or name == "path-error" or name == "path-tear" or name == "reservation" or name == "reservation-confirm" or name == "reservation-error" or name == "reservation-tear" or name == "response" or name == "srefresh"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "ack"):
                        self.ack = value
                        self.ack.value_namespace = name_space
                        self.ack.value_namespace_prefix = name_space_prefix
                    if(value_path == "bundle"):
                        self.bundle = value
                        self.bundle.value_namespace = name_space
                        self.bundle.value_namespace_prefix = name_space_prefix
                    if(value_path == "challenge"):
                        self.challenge = value
                        self.challenge.value_namespace = name_space
                        self.challenge.value_namespace_prefix = name_space_prefix
                    if(value_path == "hello"):
                        self.hello = value
                        self.hello.value_namespace = name_space
                        self.hello.value_namespace_prefix = name_space_prefix
                    if(value_path == "path"):
                        self.path = value
                        self.path.value_namespace = name_space
                        self.path.value_namespace_prefix = name_space_prefix
                    if(value_path == "path-error"):
                        self.path_error = value
                        self.path_error.value_namespace = name_space
                        self.path_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "path-tear"):
                        self.path_tear = value
                        self.path_tear.value_namespace = name_space
                        self.path_tear.value_namespace_prefix = name_space_prefix
                    if(value_path == "reservation"):
                        self.reservation = value
                        self.reservation.value_namespace = name_space
                        self.reservation.value_namespace_prefix = name_space_prefix
                    if(value_path == "reservation-confirm"):
                        self.reservation_confirm = value
                        self.reservation_confirm.value_namespace = name_space
                        self.reservation_confirm.value_namespace_prefix = name_space_prefix
                    if(value_path == "reservation-error"):
                        self.reservation_error = value
                        self.reservation_error.value_namespace = name_space
                        self.reservation_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "reservation-tear"):
                        self.reservation_tear = value
                        self.reservation_tear.value_namespace = name_space
                        self.reservation_tear.value_namespace_prefix = name_space_prefix
                    if(value_path == "response"):
                        self.response = value
                        self.response.value_namespace = name_space
                        self.response.value_namespace_prefix = name_space_prefix
                    if(value_path == "srefresh"):
                        self.srefresh = value
                        self.srefresh.value_namespace = name_space
                        self.srefresh.value_namespace_prefix = name_space_prefix


            class TransmittedMessages(Entity):
                """
                Count of messages transmitted
                
                .. attribute:: ack
                
                	Count of ACK messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bundle
                
                	Count of Bundle messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: challenge
                
                	Count of Integrity Challenge messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: hello
                
                	Count of Hello messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: path
                
                	Count of Path messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: path_error
                
                	Count of PathError messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: path_tear
                
                	Count of PathTear messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: reservation
                
                	Count of Reservation messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: reservation_confirm
                
                	Count of ReservationConfirm messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: reservation_error
                
                	Count of ReservationError messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: reservation_tear
                
                	Count of ReservationTear messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: response
                
                	Count of Integrity Response messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: srefresh
                
                	Count of Srefresh messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.Counters.MessageSummary.TransmittedMessages, self).__init__()

                    self.yang_name = "transmitted-messages"
                    self.yang_parent_name = "message-summary"

                    self.ack = YLeaf(YType.uint32, "ack")

                    self.bundle = YLeaf(YType.uint32, "bundle")

                    self.challenge = YLeaf(YType.uint32, "challenge")

                    self.hello = YLeaf(YType.uint32, "hello")

                    self.path = YLeaf(YType.uint32, "path")

                    self.path_error = YLeaf(YType.uint32, "path-error")

                    self.path_tear = YLeaf(YType.uint32, "path-tear")

                    self.reservation = YLeaf(YType.uint32, "reservation")

                    self.reservation_confirm = YLeaf(YType.uint32, "reservation-confirm")

                    self.reservation_error = YLeaf(YType.uint32, "reservation-error")

                    self.reservation_tear = YLeaf(YType.uint32, "reservation-tear")

                    self.response = YLeaf(YType.uint32, "response")

                    self.srefresh = YLeaf(YType.uint32, "srefresh")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("ack",
                                    "bundle",
                                    "challenge",
                                    "hello",
                                    "path",
                                    "path_error",
                                    "path_tear",
                                    "reservation",
                                    "reservation_confirm",
                                    "reservation_error",
                                    "reservation_tear",
                                    "response",
                                    "srefresh") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.Counters.MessageSummary.TransmittedMessages, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.Counters.MessageSummary.TransmittedMessages, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.ack.is_set or
                        self.bundle.is_set or
                        self.challenge.is_set or
                        self.hello.is_set or
                        self.path.is_set or
                        self.path_error.is_set or
                        self.path_tear.is_set or
                        self.reservation.is_set or
                        self.reservation_confirm.is_set or
                        self.reservation_error.is_set or
                        self.reservation_tear.is_set or
                        self.response.is_set or
                        self.srefresh.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.ack.yfilter != YFilter.not_set or
                        self.bundle.yfilter != YFilter.not_set or
                        self.challenge.yfilter != YFilter.not_set or
                        self.hello.yfilter != YFilter.not_set or
                        self.path.yfilter != YFilter.not_set or
                        self.path_error.yfilter != YFilter.not_set or
                        self.path_tear.yfilter != YFilter.not_set or
                        self.reservation.yfilter != YFilter.not_set or
                        self.reservation_confirm.yfilter != YFilter.not_set or
                        self.reservation_error.yfilter != YFilter.not_set or
                        self.reservation_tear.yfilter != YFilter.not_set or
                        self.response.yfilter != YFilter.not_set or
                        self.srefresh.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "transmitted-messages" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/counters/message-summary/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.ack.is_set or self.ack.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ack.get_name_leafdata())
                    if (self.bundle.is_set or self.bundle.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bundle.get_name_leafdata())
                    if (self.challenge.is_set or self.challenge.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.challenge.get_name_leafdata())
                    if (self.hello.is_set or self.hello.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.hello.get_name_leafdata())
                    if (self.path.is_set or self.path.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.path.get_name_leafdata())
                    if (self.path_error.is_set or self.path_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.path_error.get_name_leafdata())
                    if (self.path_tear.is_set or self.path_tear.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.path_tear.get_name_leafdata())
                    if (self.reservation.is_set or self.reservation.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reservation.get_name_leafdata())
                    if (self.reservation_confirm.is_set or self.reservation_confirm.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reservation_confirm.get_name_leafdata())
                    if (self.reservation_error.is_set or self.reservation_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reservation_error.get_name_leafdata())
                    if (self.reservation_tear.is_set or self.reservation_tear.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reservation_tear.get_name_leafdata())
                    if (self.response.is_set or self.response.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.response.get_name_leafdata())
                    if (self.srefresh.is_set or self.srefresh.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.srefresh.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ack" or name == "bundle" or name == "challenge" or name == "hello" or name == "path" or name == "path-error" or name == "path-tear" or name == "reservation" or name == "reservation-confirm" or name == "reservation-error" or name == "reservation-tear" or name == "response" or name == "srefresh"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "ack"):
                        self.ack = value
                        self.ack.value_namespace = name_space
                        self.ack.value_namespace_prefix = name_space_prefix
                    if(value_path == "bundle"):
                        self.bundle = value
                        self.bundle.value_namespace = name_space
                        self.bundle.value_namespace_prefix = name_space_prefix
                    if(value_path == "challenge"):
                        self.challenge = value
                        self.challenge.value_namespace = name_space
                        self.challenge.value_namespace_prefix = name_space_prefix
                    if(value_path == "hello"):
                        self.hello = value
                        self.hello.value_namespace = name_space
                        self.hello.value_namespace_prefix = name_space_prefix
                    if(value_path == "path"):
                        self.path = value
                        self.path.value_namespace = name_space
                        self.path.value_namespace_prefix = name_space_prefix
                    if(value_path == "path-error"):
                        self.path_error = value
                        self.path_error.value_namespace = name_space
                        self.path_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "path-tear"):
                        self.path_tear = value
                        self.path_tear.value_namespace = name_space
                        self.path_tear.value_namespace_prefix = name_space_prefix
                    if(value_path == "reservation"):
                        self.reservation = value
                        self.reservation.value_namespace = name_space
                        self.reservation.value_namespace_prefix = name_space_prefix
                    if(value_path == "reservation-confirm"):
                        self.reservation_confirm = value
                        self.reservation_confirm.value_namespace = name_space
                        self.reservation_confirm.value_namespace_prefix = name_space_prefix
                    if(value_path == "reservation-error"):
                        self.reservation_error = value
                        self.reservation_error.value_namespace = name_space
                        self.reservation_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "reservation-tear"):
                        self.reservation_tear = value
                        self.reservation_tear.value_namespace = name_space
                        self.reservation_tear.value_namespace_prefix = name_space_prefix
                    if(value_path == "response"):
                        self.response = value
                        self.response.value_namespace = name_space
                        self.response.value_namespace_prefix = name_space_prefix
                    if(value_path == "srefresh"):
                        self.srefresh = value
                        self.srefresh.value_namespace = name_space
                        self.srefresh.value_namespace_prefix = name_space_prefix


            class BundleReceivedMessages(Entity):
                """
                Count of Bundle messages received
                
                .. attribute:: ack
                
                	Count of ACK messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bundle
                
                	Count of Bundle messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: challenge
                
                	Count of Integrity Challenge messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: hello
                
                	Count of Hello messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: path
                
                	Count of Path messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: path_error
                
                	Count of PathError messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: path_tear
                
                	Count of PathTear messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: reservation
                
                	Count of Reservation messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: reservation_confirm
                
                	Count of ReservationConfirm messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: reservation_error
                
                	Count of ReservationError messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: reservation_tear
                
                	Count of ReservationTear messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: response
                
                	Count of Integrity Response messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: srefresh
                
                	Count of Srefresh messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.Counters.MessageSummary.BundleReceivedMessages, self).__init__()

                    self.yang_name = "bundle-received-messages"
                    self.yang_parent_name = "message-summary"

                    self.ack = YLeaf(YType.uint32, "ack")

                    self.bundle = YLeaf(YType.uint32, "bundle")

                    self.challenge = YLeaf(YType.uint32, "challenge")

                    self.hello = YLeaf(YType.uint32, "hello")

                    self.path = YLeaf(YType.uint32, "path")

                    self.path_error = YLeaf(YType.uint32, "path-error")

                    self.path_tear = YLeaf(YType.uint32, "path-tear")

                    self.reservation = YLeaf(YType.uint32, "reservation")

                    self.reservation_confirm = YLeaf(YType.uint32, "reservation-confirm")

                    self.reservation_error = YLeaf(YType.uint32, "reservation-error")

                    self.reservation_tear = YLeaf(YType.uint32, "reservation-tear")

                    self.response = YLeaf(YType.uint32, "response")

                    self.srefresh = YLeaf(YType.uint32, "srefresh")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("ack",
                                    "bundle",
                                    "challenge",
                                    "hello",
                                    "path",
                                    "path_error",
                                    "path_tear",
                                    "reservation",
                                    "reservation_confirm",
                                    "reservation_error",
                                    "reservation_tear",
                                    "response",
                                    "srefresh") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.Counters.MessageSummary.BundleReceivedMessages, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.Counters.MessageSummary.BundleReceivedMessages, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.ack.is_set or
                        self.bundle.is_set or
                        self.challenge.is_set or
                        self.hello.is_set or
                        self.path.is_set or
                        self.path_error.is_set or
                        self.path_tear.is_set or
                        self.reservation.is_set or
                        self.reservation_confirm.is_set or
                        self.reservation_error.is_set or
                        self.reservation_tear.is_set or
                        self.response.is_set or
                        self.srefresh.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.ack.yfilter != YFilter.not_set or
                        self.bundle.yfilter != YFilter.not_set or
                        self.challenge.yfilter != YFilter.not_set or
                        self.hello.yfilter != YFilter.not_set or
                        self.path.yfilter != YFilter.not_set or
                        self.path_error.yfilter != YFilter.not_set or
                        self.path_tear.yfilter != YFilter.not_set or
                        self.reservation.yfilter != YFilter.not_set or
                        self.reservation_confirm.yfilter != YFilter.not_set or
                        self.reservation_error.yfilter != YFilter.not_set or
                        self.reservation_tear.yfilter != YFilter.not_set or
                        self.response.yfilter != YFilter.not_set or
                        self.srefresh.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bundle-received-messages" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/counters/message-summary/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.ack.is_set or self.ack.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ack.get_name_leafdata())
                    if (self.bundle.is_set or self.bundle.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bundle.get_name_leafdata())
                    if (self.challenge.is_set or self.challenge.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.challenge.get_name_leafdata())
                    if (self.hello.is_set or self.hello.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.hello.get_name_leafdata())
                    if (self.path.is_set or self.path.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.path.get_name_leafdata())
                    if (self.path_error.is_set or self.path_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.path_error.get_name_leafdata())
                    if (self.path_tear.is_set or self.path_tear.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.path_tear.get_name_leafdata())
                    if (self.reservation.is_set or self.reservation.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reservation.get_name_leafdata())
                    if (self.reservation_confirm.is_set or self.reservation_confirm.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reservation_confirm.get_name_leafdata())
                    if (self.reservation_error.is_set or self.reservation_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reservation_error.get_name_leafdata())
                    if (self.reservation_tear.is_set or self.reservation_tear.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reservation_tear.get_name_leafdata())
                    if (self.response.is_set or self.response.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.response.get_name_leafdata())
                    if (self.srefresh.is_set or self.srefresh.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.srefresh.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ack" or name == "bundle" or name == "challenge" or name == "hello" or name == "path" or name == "path-error" or name == "path-tear" or name == "reservation" or name == "reservation-confirm" or name == "reservation-error" or name == "reservation-tear" or name == "response" or name == "srefresh"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "ack"):
                        self.ack = value
                        self.ack.value_namespace = name_space
                        self.ack.value_namespace_prefix = name_space_prefix
                    if(value_path == "bundle"):
                        self.bundle = value
                        self.bundle.value_namespace = name_space
                        self.bundle.value_namespace_prefix = name_space_prefix
                    if(value_path == "challenge"):
                        self.challenge = value
                        self.challenge.value_namespace = name_space
                        self.challenge.value_namespace_prefix = name_space_prefix
                    if(value_path == "hello"):
                        self.hello = value
                        self.hello.value_namespace = name_space
                        self.hello.value_namespace_prefix = name_space_prefix
                    if(value_path == "path"):
                        self.path = value
                        self.path.value_namespace = name_space
                        self.path.value_namespace_prefix = name_space_prefix
                    if(value_path == "path-error"):
                        self.path_error = value
                        self.path_error.value_namespace = name_space
                        self.path_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "path-tear"):
                        self.path_tear = value
                        self.path_tear.value_namespace = name_space
                        self.path_tear.value_namespace_prefix = name_space_prefix
                    if(value_path == "reservation"):
                        self.reservation = value
                        self.reservation.value_namespace = name_space
                        self.reservation.value_namespace_prefix = name_space_prefix
                    if(value_path == "reservation-confirm"):
                        self.reservation_confirm = value
                        self.reservation_confirm.value_namespace = name_space
                        self.reservation_confirm.value_namespace_prefix = name_space_prefix
                    if(value_path == "reservation-error"):
                        self.reservation_error = value
                        self.reservation_error.value_namespace = name_space
                        self.reservation_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "reservation-tear"):
                        self.reservation_tear = value
                        self.reservation_tear.value_namespace = name_space
                        self.reservation_tear.value_namespace_prefix = name_space_prefix
                    if(value_path == "response"):
                        self.response = value
                        self.response.value_namespace = name_space
                        self.response.value_namespace_prefix = name_space_prefix
                    if(value_path == "srefresh"):
                        self.srefresh = value
                        self.srefresh.value_namespace = name_space
                        self.srefresh.value_namespace_prefix = name_space_prefix


            class BundleTransmittedMessages(Entity):
                """
                Count of Bundle messages transmitted
                
                .. attribute:: ack
                
                	Count of ACK messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bundle
                
                	Count of Bundle messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: challenge
                
                	Count of Integrity Challenge messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: hello
                
                	Count of Hello messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: path
                
                	Count of Path messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: path_error
                
                	Count of PathError messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: path_tear
                
                	Count of PathTear messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: reservation
                
                	Count of Reservation messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: reservation_confirm
                
                	Count of ReservationConfirm messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: reservation_error
                
                	Count of ReservationError messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: reservation_tear
                
                	Count of ReservationTear messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: response
                
                	Count of Integrity Response messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: srefresh
                
                	Count of Srefresh messages
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.Counters.MessageSummary.BundleTransmittedMessages, self).__init__()

                    self.yang_name = "bundle-transmitted-messages"
                    self.yang_parent_name = "message-summary"

                    self.ack = YLeaf(YType.uint32, "ack")

                    self.bundle = YLeaf(YType.uint32, "bundle")

                    self.challenge = YLeaf(YType.uint32, "challenge")

                    self.hello = YLeaf(YType.uint32, "hello")

                    self.path = YLeaf(YType.uint32, "path")

                    self.path_error = YLeaf(YType.uint32, "path-error")

                    self.path_tear = YLeaf(YType.uint32, "path-tear")

                    self.reservation = YLeaf(YType.uint32, "reservation")

                    self.reservation_confirm = YLeaf(YType.uint32, "reservation-confirm")

                    self.reservation_error = YLeaf(YType.uint32, "reservation-error")

                    self.reservation_tear = YLeaf(YType.uint32, "reservation-tear")

                    self.response = YLeaf(YType.uint32, "response")

                    self.srefresh = YLeaf(YType.uint32, "srefresh")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("ack",
                                    "bundle",
                                    "challenge",
                                    "hello",
                                    "path",
                                    "path_error",
                                    "path_tear",
                                    "reservation",
                                    "reservation_confirm",
                                    "reservation_error",
                                    "reservation_tear",
                                    "response",
                                    "srefresh") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.Counters.MessageSummary.BundleTransmittedMessages, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.Counters.MessageSummary.BundleTransmittedMessages, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.ack.is_set or
                        self.bundle.is_set or
                        self.challenge.is_set or
                        self.hello.is_set or
                        self.path.is_set or
                        self.path_error.is_set or
                        self.path_tear.is_set or
                        self.reservation.is_set or
                        self.reservation_confirm.is_set or
                        self.reservation_error.is_set or
                        self.reservation_tear.is_set or
                        self.response.is_set or
                        self.srefresh.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.ack.yfilter != YFilter.not_set or
                        self.bundle.yfilter != YFilter.not_set or
                        self.challenge.yfilter != YFilter.not_set or
                        self.hello.yfilter != YFilter.not_set or
                        self.path.yfilter != YFilter.not_set or
                        self.path_error.yfilter != YFilter.not_set or
                        self.path_tear.yfilter != YFilter.not_set or
                        self.reservation.yfilter != YFilter.not_set or
                        self.reservation_confirm.yfilter != YFilter.not_set or
                        self.reservation_error.yfilter != YFilter.not_set or
                        self.reservation_tear.yfilter != YFilter.not_set or
                        self.response.yfilter != YFilter.not_set or
                        self.srefresh.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bundle-transmitted-messages" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/counters/message-summary/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.ack.is_set or self.ack.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ack.get_name_leafdata())
                    if (self.bundle.is_set or self.bundle.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.bundle.get_name_leafdata())
                    if (self.challenge.is_set or self.challenge.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.challenge.get_name_leafdata())
                    if (self.hello.is_set or self.hello.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.hello.get_name_leafdata())
                    if (self.path.is_set or self.path.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.path.get_name_leafdata())
                    if (self.path_error.is_set or self.path_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.path_error.get_name_leafdata())
                    if (self.path_tear.is_set or self.path_tear.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.path_tear.get_name_leafdata())
                    if (self.reservation.is_set or self.reservation.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reservation.get_name_leafdata())
                    if (self.reservation_confirm.is_set or self.reservation_confirm.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reservation_confirm.get_name_leafdata())
                    if (self.reservation_error.is_set or self.reservation_error.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reservation_error.get_name_leafdata())
                    if (self.reservation_tear.is_set or self.reservation_tear.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reservation_tear.get_name_leafdata())
                    if (self.response.is_set or self.response.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.response.get_name_leafdata())
                    if (self.srefresh.is_set or self.srefresh.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.srefresh.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ack" or name == "bundle" or name == "challenge" or name == "hello" or name == "path" or name == "path-error" or name == "path-tear" or name == "reservation" or name == "reservation-confirm" or name == "reservation-error" or name == "reservation-tear" or name == "response" or name == "srefresh"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "ack"):
                        self.ack = value
                        self.ack.value_namespace = name_space
                        self.ack.value_namespace_prefix = name_space_prefix
                    if(value_path == "bundle"):
                        self.bundle = value
                        self.bundle.value_namespace = name_space
                        self.bundle.value_namespace_prefix = name_space_prefix
                    if(value_path == "challenge"):
                        self.challenge = value
                        self.challenge.value_namespace = name_space
                        self.challenge.value_namespace_prefix = name_space_prefix
                    if(value_path == "hello"):
                        self.hello = value
                        self.hello.value_namespace = name_space
                        self.hello.value_namespace_prefix = name_space_prefix
                    if(value_path == "path"):
                        self.path = value
                        self.path.value_namespace = name_space
                        self.path.value_namespace_prefix = name_space_prefix
                    if(value_path == "path-error"):
                        self.path_error = value
                        self.path_error.value_namespace = name_space
                        self.path_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "path-tear"):
                        self.path_tear = value
                        self.path_tear.value_namespace = name_space
                        self.path_tear.value_namespace_prefix = name_space_prefix
                    if(value_path == "reservation"):
                        self.reservation = value
                        self.reservation.value_namespace = name_space
                        self.reservation.value_namespace_prefix = name_space_prefix
                    if(value_path == "reservation-confirm"):
                        self.reservation_confirm = value
                        self.reservation_confirm.value_namespace = name_space
                        self.reservation_confirm.value_namespace_prefix = name_space_prefix
                    if(value_path == "reservation-error"):
                        self.reservation_error = value
                        self.reservation_error.value_namespace = name_space
                        self.reservation_error.value_namespace_prefix = name_space_prefix
                    if(value_path == "reservation-tear"):
                        self.reservation_tear = value
                        self.reservation_tear.value_namespace = name_space
                        self.reservation_tear.value_namespace_prefix = name_space_prefix
                    if(value_path == "response"):
                        self.response = value
                        self.response.value_namespace = name_space
                        self.response.value_namespace_prefix = name_space_prefix
                    if(value_path == "srefresh"):
                        self.srefresh = value
                        self.srefresh.value_namespace = name_space
                        self.srefresh.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.out_of_order_messages.is_set or
                    self.rate_limited_messages.is_set or
                    self.retransmitted_messages.is_set or
                    (self.bundle_received_messages is not None and self.bundle_received_messages.has_data()) or
                    (self.bundle_transmitted_messages is not None and self.bundle_transmitted_messages.has_data()) or
                    (self.received_messages is not None and self.received_messages.has_data()) or
                    (self.transmitted_messages is not None and self.transmitted_messages.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.out_of_order_messages.yfilter != YFilter.not_set or
                    self.rate_limited_messages.yfilter != YFilter.not_set or
                    self.retransmitted_messages.yfilter != YFilter.not_set or
                    (self.bundle_received_messages is not None and self.bundle_received_messages.has_operation()) or
                    (self.bundle_transmitted_messages is not None and self.bundle_transmitted_messages.has_operation()) or
                    (self.received_messages is not None and self.received_messages.has_operation()) or
                    (self.transmitted_messages is not None and self.transmitted_messages.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "message-summary" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/counters/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.out_of_order_messages.is_set or self.out_of_order_messages.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.out_of_order_messages.get_name_leafdata())
                if (self.rate_limited_messages.is_set or self.rate_limited_messages.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.rate_limited_messages.get_name_leafdata())
                if (self.retransmitted_messages.is_set or self.retransmitted_messages.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.retransmitted_messages.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "bundle-received-messages"):
                    if (self.bundle_received_messages is None):
                        self.bundle_received_messages = Rsvp.Counters.MessageSummary.BundleReceivedMessages()
                        self.bundle_received_messages.parent = self
                        self._children_name_map["bundle_received_messages"] = "bundle-received-messages"
                    return self.bundle_received_messages

                if (child_yang_name == "bundle-transmitted-messages"):
                    if (self.bundle_transmitted_messages is None):
                        self.bundle_transmitted_messages = Rsvp.Counters.MessageSummary.BundleTransmittedMessages()
                        self.bundle_transmitted_messages.parent = self
                        self._children_name_map["bundle_transmitted_messages"] = "bundle-transmitted-messages"
                    return self.bundle_transmitted_messages

                if (child_yang_name == "received-messages"):
                    if (self.received_messages is None):
                        self.received_messages = Rsvp.Counters.MessageSummary.ReceivedMessages()
                        self.received_messages.parent = self
                        self._children_name_map["received_messages"] = "received-messages"
                    return self.received_messages

                if (child_yang_name == "transmitted-messages"):
                    if (self.transmitted_messages is None):
                        self.transmitted_messages = Rsvp.Counters.MessageSummary.TransmittedMessages()
                        self.transmitted_messages.parent = self
                        self._children_name_map["transmitted_messages"] = "transmitted-messages"
                    return self.transmitted_messages

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "bundle-received-messages" or name == "bundle-transmitted-messages" or name == "received-messages" or name == "transmitted-messages" or name == "out-of-order-messages" or name == "rate-limited-messages" or name == "retransmitted-messages"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "out-of-order-messages"):
                    self.out_of_order_messages = value
                    self.out_of_order_messages.value_namespace = name_space
                    self.out_of_order_messages.value_namespace_prefix = name_space_prefix
                if(value_path == "rate-limited-messages"):
                    self.rate_limited_messages = value
                    self.rate_limited_messages.value_namespace = name_space
                    self.rate_limited_messages.value_namespace_prefix = name_space_prefix
                if(value_path == "retransmitted-messages"):
                    self.retransmitted_messages = value
                    self.retransmitted_messages.value_namespace = name_space
                    self.retransmitted_messages.value_namespace_prefix = name_space_prefix


        class PrefixFiltering(Entity):
            """
            Prefix filtering counters
            
            .. attribute:: accesses
            
            	AccessList specific prefix filtering counters
            	**type**\:   :py:class:`Accesses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Counters.PrefixFiltering.Accesses>`
            
            .. attribute:: interfaces
            
            	Interface specific prefix filtering counters
            	**type**\:   :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Counters.PrefixFiltering.Interfaces>`
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Rsvp.Counters.PrefixFiltering, self).__init__()

                self.yang_name = "prefix-filtering"
                self.yang_parent_name = "counters"

                self.accesses = Rsvp.Counters.PrefixFiltering.Accesses()
                self.accesses.parent = self
                self._children_name_map["accesses"] = "accesses"
                self._children_yang_names.add("accesses")

                self.interfaces = Rsvp.Counters.PrefixFiltering.Interfaces()
                self.interfaces.parent = self
                self._children_name_map["interfaces"] = "interfaces"
                self._children_yang_names.add("interfaces")


            class Accesses(Entity):
                """
                AccessList specific prefix filtering counters
                
                .. attribute:: access
                
                	Prefix filtering counters for a specific AccessList
                	**type**\: list of    :py:class:`Access <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Counters.PrefixFiltering.Accesses.Access>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.Counters.PrefixFiltering.Accesses, self).__init__()

                    self.yang_name = "accesses"
                    self.yang_parent_name = "prefix-filtering"

                    self.access = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.Counters.PrefixFiltering.Accesses, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.Counters.PrefixFiltering.Accesses, self).__setattr__(name, value)


                class Access(Entity):
                    """
                    Prefix filtering counters for a specific
                    AccessList
                    
                    .. attribute:: access_list_name  <key>
                    
                    	AccessList Name
                    	**type**\:  str
                    
                    	**length:** 1..65
                    
                    .. attribute:: dropped
                    
                    	Count of messages dropped
                    	**type**\:   :py:class:`Dropped <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Counters.PrefixFiltering.Accesses.Access.Dropped>`
                    
                    .. attribute:: forwarded
                    
                    	Count of messages which got forwarded
                    	**type**\:   :py:class:`Forwarded <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Counters.PrefixFiltering.Accesses.Access.Forwarded>`
                    
                    .. attribute:: locally_destined
                    
                    	Count of locally destined messages
                    	**type**\:   :py:class:`LocallyDestined <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Counters.PrefixFiltering.Accesses.Access.LocallyDestined>`
                    
                    .. attribute:: total
                    
                    	Count of total messages
                    	**type**\:   :py:class:`Total <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Counters.PrefixFiltering.Accesses.Access.Total>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.Counters.PrefixFiltering.Accesses.Access, self).__init__()

                        self.yang_name = "access"
                        self.yang_parent_name = "accesses"

                        self.access_list_name = YLeaf(YType.str, "access-list-name")

                        self.dropped = Rsvp.Counters.PrefixFiltering.Accesses.Access.Dropped()
                        self.dropped.parent = self
                        self._children_name_map["dropped"] = "dropped"
                        self._children_yang_names.add("dropped")

                        self.forwarded = Rsvp.Counters.PrefixFiltering.Accesses.Access.Forwarded()
                        self.forwarded.parent = self
                        self._children_name_map["forwarded"] = "forwarded"
                        self._children_yang_names.add("forwarded")

                        self.locally_destined = Rsvp.Counters.PrefixFiltering.Accesses.Access.LocallyDestined()
                        self.locally_destined.parent = self
                        self._children_name_map["locally_destined"] = "locally-destined"
                        self._children_yang_names.add("locally-destined")

                        self.total = Rsvp.Counters.PrefixFiltering.Accesses.Access.Total()
                        self.total.parent = self
                        self._children_name_map["total"] = "total"
                        self._children_yang_names.add("total")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("access_list_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.Counters.PrefixFiltering.Accesses.Access, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.Counters.PrefixFiltering.Accesses.Access, self).__setattr__(name, value)


                    class Forwarded(Entity):
                        """
                        Count of messages which got forwarded
                        
                        .. attribute:: path
                        
                        	Count of Path messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: path_tear
                        
                        	Count of PathTear messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: reservation_confirm
                        
                        	Count of ReservationConfirm messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total
                        
                        	Total count of messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.Counters.PrefixFiltering.Accesses.Access.Forwarded, self).__init__()

                            self.yang_name = "forwarded"
                            self.yang_parent_name = "access"

                            self.path = YLeaf(YType.uint32, "path")

                            self.path_tear = YLeaf(YType.uint32, "path-tear")

                            self.reservation_confirm = YLeaf(YType.uint32, "reservation-confirm")

                            self.total = YLeaf(YType.uint32, "total")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("path",
                                            "path_tear",
                                            "reservation_confirm",
                                            "total") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.Counters.PrefixFiltering.Accesses.Access.Forwarded, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.Counters.PrefixFiltering.Accesses.Access.Forwarded, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.path.is_set or
                                self.path_tear.is_set or
                                self.reservation_confirm.is_set or
                                self.total.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.path.yfilter != YFilter.not_set or
                                self.path_tear.yfilter != YFilter.not_set or
                                self.reservation_confirm.yfilter != YFilter.not_set or
                                self.total.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "forwarded" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.path.is_set or self.path.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.path.get_name_leafdata())
                            if (self.path_tear.is_set or self.path_tear.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.path_tear.get_name_leafdata())
                            if (self.reservation_confirm.is_set or self.reservation_confirm.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.reservation_confirm.get_name_leafdata())
                            if (self.total.is_set or self.total.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.total.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "path" or name == "path-tear" or name == "reservation-confirm" or name == "total"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "path"):
                                self.path = value
                                self.path.value_namespace = name_space
                                self.path.value_namespace_prefix = name_space_prefix
                            if(value_path == "path-tear"):
                                self.path_tear = value
                                self.path_tear.value_namespace = name_space
                                self.path_tear.value_namespace_prefix = name_space_prefix
                            if(value_path == "reservation-confirm"):
                                self.reservation_confirm = value
                                self.reservation_confirm.value_namespace = name_space
                                self.reservation_confirm.value_namespace_prefix = name_space_prefix
                            if(value_path == "total"):
                                self.total = value
                                self.total.value_namespace = name_space
                                self.total.value_namespace_prefix = name_space_prefix


                    class LocallyDestined(Entity):
                        """
                        Count of locally destined messages
                        
                        .. attribute:: path
                        
                        	Count of Path messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: path_tear
                        
                        	Count of PathTear messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: reservation_confirm
                        
                        	Count of ReservationConfirm messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total
                        
                        	Total count of messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.Counters.PrefixFiltering.Accesses.Access.LocallyDestined, self).__init__()

                            self.yang_name = "locally-destined"
                            self.yang_parent_name = "access"

                            self.path = YLeaf(YType.uint32, "path")

                            self.path_tear = YLeaf(YType.uint32, "path-tear")

                            self.reservation_confirm = YLeaf(YType.uint32, "reservation-confirm")

                            self.total = YLeaf(YType.uint32, "total")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("path",
                                            "path_tear",
                                            "reservation_confirm",
                                            "total") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.Counters.PrefixFiltering.Accesses.Access.LocallyDestined, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.Counters.PrefixFiltering.Accesses.Access.LocallyDestined, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.path.is_set or
                                self.path_tear.is_set or
                                self.reservation_confirm.is_set or
                                self.total.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.path.yfilter != YFilter.not_set or
                                self.path_tear.yfilter != YFilter.not_set or
                                self.reservation_confirm.yfilter != YFilter.not_set or
                                self.total.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "locally-destined" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.path.is_set or self.path.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.path.get_name_leafdata())
                            if (self.path_tear.is_set or self.path_tear.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.path_tear.get_name_leafdata())
                            if (self.reservation_confirm.is_set or self.reservation_confirm.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.reservation_confirm.get_name_leafdata())
                            if (self.total.is_set or self.total.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.total.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "path" or name == "path-tear" or name == "reservation-confirm" or name == "total"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "path"):
                                self.path = value
                                self.path.value_namespace = name_space
                                self.path.value_namespace_prefix = name_space_prefix
                            if(value_path == "path-tear"):
                                self.path_tear = value
                                self.path_tear.value_namespace = name_space
                                self.path_tear.value_namespace_prefix = name_space_prefix
                            if(value_path == "reservation-confirm"):
                                self.reservation_confirm = value
                                self.reservation_confirm.value_namespace = name_space
                                self.reservation_confirm.value_namespace_prefix = name_space_prefix
                            if(value_path == "total"):
                                self.total = value
                                self.total.value_namespace = name_space
                                self.total.value_namespace_prefix = name_space_prefix


                    class Dropped(Entity):
                        """
                        Count of messages dropped
                        
                        .. attribute:: path
                        
                        	Count of Path messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: path_tear
                        
                        	Count of PathTear messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: reservation_confirm
                        
                        	Count of ReservationConfirm messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total
                        
                        	Total count of messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.Counters.PrefixFiltering.Accesses.Access.Dropped, self).__init__()

                            self.yang_name = "dropped"
                            self.yang_parent_name = "access"

                            self.path = YLeaf(YType.uint32, "path")

                            self.path_tear = YLeaf(YType.uint32, "path-tear")

                            self.reservation_confirm = YLeaf(YType.uint32, "reservation-confirm")

                            self.total = YLeaf(YType.uint32, "total")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("path",
                                            "path_tear",
                                            "reservation_confirm",
                                            "total") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.Counters.PrefixFiltering.Accesses.Access.Dropped, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.Counters.PrefixFiltering.Accesses.Access.Dropped, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.path.is_set or
                                self.path_tear.is_set or
                                self.reservation_confirm.is_set or
                                self.total.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.path.yfilter != YFilter.not_set or
                                self.path_tear.yfilter != YFilter.not_set or
                                self.reservation_confirm.yfilter != YFilter.not_set or
                                self.total.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "dropped" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.path.is_set or self.path.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.path.get_name_leafdata())
                            if (self.path_tear.is_set or self.path_tear.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.path_tear.get_name_leafdata())
                            if (self.reservation_confirm.is_set or self.reservation_confirm.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.reservation_confirm.get_name_leafdata())
                            if (self.total.is_set or self.total.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.total.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "path" or name == "path-tear" or name == "reservation-confirm" or name == "total"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "path"):
                                self.path = value
                                self.path.value_namespace = name_space
                                self.path.value_namespace_prefix = name_space_prefix
                            if(value_path == "path-tear"):
                                self.path_tear = value
                                self.path_tear.value_namespace = name_space
                                self.path_tear.value_namespace_prefix = name_space_prefix
                            if(value_path == "reservation-confirm"):
                                self.reservation_confirm = value
                                self.reservation_confirm.value_namespace = name_space
                                self.reservation_confirm.value_namespace_prefix = name_space_prefix
                            if(value_path == "total"):
                                self.total = value
                                self.total.value_namespace = name_space
                                self.total.value_namespace_prefix = name_space_prefix


                    class Total(Entity):
                        """
                        Count of total messages
                        
                        .. attribute:: path
                        
                        	Count of Path messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: path_tear
                        
                        	Count of PathTear messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: reservation_confirm
                        
                        	Count of ReservationConfirm messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total
                        
                        	Total count of messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.Counters.PrefixFiltering.Accesses.Access.Total, self).__init__()

                            self.yang_name = "total"
                            self.yang_parent_name = "access"

                            self.path = YLeaf(YType.uint32, "path")

                            self.path_tear = YLeaf(YType.uint32, "path-tear")

                            self.reservation_confirm = YLeaf(YType.uint32, "reservation-confirm")

                            self.total = YLeaf(YType.uint32, "total")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("path",
                                            "path_tear",
                                            "reservation_confirm",
                                            "total") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.Counters.PrefixFiltering.Accesses.Access.Total, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.Counters.PrefixFiltering.Accesses.Access.Total, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.path.is_set or
                                self.path_tear.is_set or
                                self.reservation_confirm.is_set or
                                self.total.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.path.yfilter != YFilter.not_set or
                                self.path_tear.yfilter != YFilter.not_set or
                                self.reservation_confirm.yfilter != YFilter.not_set or
                                self.total.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "total" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.path.is_set or self.path.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.path.get_name_leafdata())
                            if (self.path_tear.is_set or self.path_tear.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.path_tear.get_name_leafdata())
                            if (self.reservation_confirm.is_set or self.reservation_confirm.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.reservation_confirm.get_name_leafdata())
                            if (self.total.is_set or self.total.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.total.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "path" or name == "path-tear" or name == "reservation-confirm" or name == "total"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "path"):
                                self.path = value
                                self.path.value_namespace = name_space
                                self.path.value_namespace_prefix = name_space_prefix
                            if(value_path == "path-tear"):
                                self.path_tear = value
                                self.path_tear.value_namespace = name_space
                                self.path_tear.value_namespace_prefix = name_space_prefix
                            if(value_path == "reservation-confirm"):
                                self.reservation_confirm = value
                                self.reservation_confirm.value_namespace = name_space
                                self.reservation_confirm.value_namespace_prefix = name_space_prefix
                            if(value_path == "total"):
                                self.total = value
                                self.total.value_namespace = name_space
                                self.total.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.access_list_name.is_set or
                            (self.dropped is not None and self.dropped.has_data()) or
                            (self.forwarded is not None and self.forwarded.has_data()) or
                            (self.locally_destined is not None and self.locally_destined.has_data()) or
                            (self.total is not None and self.total.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.access_list_name.yfilter != YFilter.not_set or
                            (self.dropped is not None and self.dropped.has_operation()) or
                            (self.forwarded is not None and self.forwarded.has_operation()) or
                            (self.locally_destined is not None and self.locally_destined.has_operation()) or
                            (self.total is not None and self.total.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "access" + "[access-list-name='" + self.access_list_name.get() + "']" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/counters/prefix-filtering/accesses/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.access_list_name.is_set or self.access_list_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.access_list_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "dropped"):
                            if (self.dropped is None):
                                self.dropped = Rsvp.Counters.PrefixFiltering.Accesses.Access.Dropped()
                                self.dropped.parent = self
                                self._children_name_map["dropped"] = "dropped"
                            return self.dropped

                        if (child_yang_name == "forwarded"):
                            if (self.forwarded is None):
                                self.forwarded = Rsvp.Counters.PrefixFiltering.Accesses.Access.Forwarded()
                                self.forwarded.parent = self
                                self._children_name_map["forwarded"] = "forwarded"
                            return self.forwarded

                        if (child_yang_name == "locally-destined"):
                            if (self.locally_destined is None):
                                self.locally_destined = Rsvp.Counters.PrefixFiltering.Accesses.Access.LocallyDestined()
                                self.locally_destined.parent = self
                                self._children_name_map["locally_destined"] = "locally-destined"
                            return self.locally_destined

                        if (child_yang_name == "total"):
                            if (self.total is None):
                                self.total = Rsvp.Counters.PrefixFiltering.Accesses.Access.Total()
                                self.total.parent = self
                                self._children_name_map["total"] = "total"
                            return self.total

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "dropped" or name == "forwarded" or name == "locally-destined" or name == "total" or name == "access-list-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "access-list-name"):
                            self.access_list_name = value
                            self.access_list_name.value_namespace = name_space
                            self.access_list_name.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.access:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.access:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "accesses" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/counters/prefix-filtering/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "access"):
                        for c in self.access:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Rsvp.Counters.PrefixFiltering.Accesses.Access()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.access.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "access"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Interfaces(Entity):
                """
                Interface specific prefix filtering counters
                
                .. attribute:: interfaces
                
                	Table of interface specific prefix filtering counters
                	**type**\:   :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Counters.PrefixFiltering.Interfaces.Interfaces>`
                
                .. attribute:: summary
                
                	Summary of prefix filtering counts for all interfaces
                	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Counters.PrefixFiltering.Interfaces.Summary>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.Counters.PrefixFiltering.Interfaces, self).__init__()

                    self.yang_name = "interfaces"
                    self.yang_parent_name = "prefix-filtering"

                    self.interfaces = Rsvp.Counters.PrefixFiltering.Interfaces.Interfaces()
                    self.interfaces.parent = self
                    self._children_name_map["interfaces"] = "interfaces"
                    self._children_yang_names.add("interfaces")

                    self.summary = Rsvp.Counters.PrefixFiltering.Interfaces.Summary()
                    self.summary.parent = self
                    self._children_name_map["summary"] = "summary"
                    self._children_yang_names.add("summary")


                class Summary(Entity):
                    """
                    Summary of prefix filtering counts for all
                    interfaces
                    
                    .. attribute:: default_action_dropped
                    
                    	Count of messages which got dropped due to default ACL action
                    	**type**\:   :py:class:`DefaultActionDropped <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Counters.PrefixFiltering.Interfaces.Summary.DefaultActionDropped>`
                    
                    .. attribute:: default_action_processed
                    
                    	Count of messages which were processed due to default ACL action
                    	**type**\:   :py:class:`DefaultActionProcessed <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Counters.PrefixFiltering.Interfaces.Summary.DefaultActionProcessed>`
                    
                    .. attribute:: dropped
                    
                    	Count of messages dropped
                    	**type**\:   :py:class:`Dropped <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Counters.PrefixFiltering.Interfaces.Summary.Dropped>`
                    
                    .. attribute:: forwarded
                    
                    	Count of messages which got forwarded
                    	**type**\:   :py:class:`Forwarded <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Counters.PrefixFiltering.Interfaces.Summary.Forwarded>`
                    
                    .. attribute:: locally_destined
                    
                    	Count of locally destined messages
                    	**type**\:   :py:class:`LocallyDestined <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Counters.PrefixFiltering.Interfaces.Summary.LocallyDestined>`
                    
                    .. attribute:: total
                    
                    	Count of total messages
                    	**type**\:   :py:class:`Total <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Counters.PrefixFiltering.Interfaces.Summary.Total>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.Counters.PrefixFiltering.Interfaces.Summary, self).__init__()

                        self.yang_name = "summary"
                        self.yang_parent_name = "interfaces"

                        self.default_action_dropped = Rsvp.Counters.PrefixFiltering.Interfaces.Summary.DefaultActionDropped()
                        self.default_action_dropped.parent = self
                        self._children_name_map["default_action_dropped"] = "default-action-dropped"
                        self._children_yang_names.add("default-action-dropped")

                        self.default_action_processed = Rsvp.Counters.PrefixFiltering.Interfaces.Summary.DefaultActionProcessed()
                        self.default_action_processed.parent = self
                        self._children_name_map["default_action_processed"] = "default-action-processed"
                        self._children_yang_names.add("default-action-processed")

                        self.dropped = Rsvp.Counters.PrefixFiltering.Interfaces.Summary.Dropped()
                        self.dropped.parent = self
                        self._children_name_map["dropped"] = "dropped"
                        self._children_yang_names.add("dropped")

                        self.forwarded = Rsvp.Counters.PrefixFiltering.Interfaces.Summary.Forwarded()
                        self.forwarded.parent = self
                        self._children_name_map["forwarded"] = "forwarded"
                        self._children_yang_names.add("forwarded")

                        self.locally_destined = Rsvp.Counters.PrefixFiltering.Interfaces.Summary.LocallyDestined()
                        self.locally_destined.parent = self
                        self._children_name_map["locally_destined"] = "locally-destined"
                        self._children_yang_names.add("locally-destined")

                        self.total = Rsvp.Counters.PrefixFiltering.Interfaces.Summary.Total()
                        self.total.parent = self
                        self._children_name_map["total"] = "total"
                        self._children_yang_names.add("total")


                    class Forwarded(Entity):
                        """
                        Count of messages which got forwarded
                        
                        .. attribute:: path
                        
                        	Count of Path messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: path_tear
                        
                        	Count of PathTear messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: reservation_confirm
                        
                        	Count of ReservationConfirm messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total
                        
                        	Total count of messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.Counters.PrefixFiltering.Interfaces.Summary.Forwarded, self).__init__()

                            self.yang_name = "forwarded"
                            self.yang_parent_name = "summary"

                            self.path = YLeaf(YType.uint32, "path")

                            self.path_tear = YLeaf(YType.uint32, "path-tear")

                            self.reservation_confirm = YLeaf(YType.uint32, "reservation-confirm")

                            self.total = YLeaf(YType.uint32, "total")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("path",
                                            "path_tear",
                                            "reservation_confirm",
                                            "total") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.Counters.PrefixFiltering.Interfaces.Summary.Forwarded, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.Counters.PrefixFiltering.Interfaces.Summary.Forwarded, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.path.is_set or
                                self.path_tear.is_set or
                                self.reservation_confirm.is_set or
                                self.total.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.path.yfilter != YFilter.not_set or
                                self.path_tear.yfilter != YFilter.not_set or
                                self.reservation_confirm.yfilter != YFilter.not_set or
                                self.total.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "forwarded" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/counters/prefix-filtering/interfaces/summary/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.path.is_set or self.path.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.path.get_name_leafdata())
                            if (self.path_tear.is_set or self.path_tear.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.path_tear.get_name_leafdata())
                            if (self.reservation_confirm.is_set or self.reservation_confirm.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.reservation_confirm.get_name_leafdata())
                            if (self.total.is_set or self.total.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.total.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "path" or name == "path-tear" or name == "reservation-confirm" or name == "total"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "path"):
                                self.path = value
                                self.path.value_namespace = name_space
                                self.path.value_namespace_prefix = name_space_prefix
                            if(value_path == "path-tear"):
                                self.path_tear = value
                                self.path_tear.value_namespace = name_space
                                self.path_tear.value_namespace_prefix = name_space_prefix
                            if(value_path == "reservation-confirm"):
                                self.reservation_confirm = value
                                self.reservation_confirm.value_namespace = name_space
                                self.reservation_confirm.value_namespace_prefix = name_space_prefix
                            if(value_path == "total"):
                                self.total = value
                                self.total.value_namespace = name_space
                                self.total.value_namespace_prefix = name_space_prefix


                    class LocallyDestined(Entity):
                        """
                        Count of locally destined messages
                        
                        .. attribute:: path
                        
                        	Count of Path messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: path_tear
                        
                        	Count of PathTear messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: reservation_confirm
                        
                        	Count of ReservationConfirm messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total
                        
                        	Total count of messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.Counters.PrefixFiltering.Interfaces.Summary.LocallyDestined, self).__init__()

                            self.yang_name = "locally-destined"
                            self.yang_parent_name = "summary"

                            self.path = YLeaf(YType.uint32, "path")

                            self.path_tear = YLeaf(YType.uint32, "path-tear")

                            self.reservation_confirm = YLeaf(YType.uint32, "reservation-confirm")

                            self.total = YLeaf(YType.uint32, "total")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("path",
                                            "path_tear",
                                            "reservation_confirm",
                                            "total") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.Counters.PrefixFiltering.Interfaces.Summary.LocallyDestined, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.Counters.PrefixFiltering.Interfaces.Summary.LocallyDestined, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.path.is_set or
                                self.path_tear.is_set or
                                self.reservation_confirm.is_set or
                                self.total.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.path.yfilter != YFilter.not_set or
                                self.path_tear.yfilter != YFilter.not_set or
                                self.reservation_confirm.yfilter != YFilter.not_set or
                                self.total.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "locally-destined" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/counters/prefix-filtering/interfaces/summary/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.path.is_set or self.path.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.path.get_name_leafdata())
                            if (self.path_tear.is_set or self.path_tear.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.path_tear.get_name_leafdata())
                            if (self.reservation_confirm.is_set or self.reservation_confirm.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.reservation_confirm.get_name_leafdata())
                            if (self.total.is_set or self.total.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.total.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "path" or name == "path-tear" or name == "reservation-confirm" or name == "total"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "path"):
                                self.path = value
                                self.path.value_namespace = name_space
                                self.path.value_namespace_prefix = name_space_prefix
                            if(value_path == "path-tear"):
                                self.path_tear = value
                                self.path_tear.value_namespace = name_space
                                self.path_tear.value_namespace_prefix = name_space_prefix
                            if(value_path == "reservation-confirm"):
                                self.reservation_confirm = value
                                self.reservation_confirm.value_namespace = name_space
                                self.reservation_confirm.value_namespace_prefix = name_space_prefix
                            if(value_path == "total"):
                                self.total = value
                                self.total.value_namespace = name_space
                                self.total.value_namespace_prefix = name_space_prefix


                    class Dropped(Entity):
                        """
                        Count of messages dropped
                        
                        .. attribute:: path
                        
                        	Count of Path messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: path_tear
                        
                        	Count of PathTear messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: reservation_confirm
                        
                        	Count of ReservationConfirm messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total
                        
                        	Total count of messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.Counters.PrefixFiltering.Interfaces.Summary.Dropped, self).__init__()

                            self.yang_name = "dropped"
                            self.yang_parent_name = "summary"

                            self.path = YLeaf(YType.uint32, "path")

                            self.path_tear = YLeaf(YType.uint32, "path-tear")

                            self.reservation_confirm = YLeaf(YType.uint32, "reservation-confirm")

                            self.total = YLeaf(YType.uint32, "total")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("path",
                                            "path_tear",
                                            "reservation_confirm",
                                            "total") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.Counters.PrefixFiltering.Interfaces.Summary.Dropped, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.Counters.PrefixFiltering.Interfaces.Summary.Dropped, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.path.is_set or
                                self.path_tear.is_set or
                                self.reservation_confirm.is_set or
                                self.total.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.path.yfilter != YFilter.not_set or
                                self.path_tear.yfilter != YFilter.not_set or
                                self.reservation_confirm.yfilter != YFilter.not_set or
                                self.total.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "dropped" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/counters/prefix-filtering/interfaces/summary/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.path.is_set or self.path.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.path.get_name_leafdata())
                            if (self.path_tear.is_set or self.path_tear.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.path_tear.get_name_leafdata())
                            if (self.reservation_confirm.is_set or self.reservation_confirm.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.reservation_confirm.get_name_leafdata())
                            if (self.total.is_set or self.total.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.total.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "path" or name == "path-tear" or name == "reservation-confirm" or name == "total"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "path"):
                                self.path = value
                                self.path.value_namespace = name_space
                                self.path.value_namespace_prefix = name_space_prefix
                            if(value_path == "path-tear"):
                                self.path_tear = value
                                self.path_tear.value_namespace = name_space
                                self.path_tear.value_namespace_prefix = name_space_prefix
                            if(value_path == "reservation-confirm"):
                                self.reservation_confirm = value
                                self.reservation_confirm.value_namespace = name_space
                                self.reservation_confirm.value_namespace_prefix = name_space_prefix
                            if(value_path == "total"):
                                self.total = value
                                self.total.value_namespace = name_space
                                self.total.value_namespace_prefix = name_space_prefix


                    class DefaultActionDropped(Entity):
                        """
                        Count of messages which got dropped due to
                        default ACL action
                        
                        .. attribute:: path
                        
                        	Count of Path messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: path_tear
                        
                        	Count of PathTear messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: reservation_confirm
                        
                        	Count of ReservationConfirm messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total
                        
                        	Total count of messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.Counters.PrefixFiltering.Interfaces.Summary.DefaultActionDropped, self).__init__()

                            self.yang_name = "default-action-dropped"
                            self.yang_parent_name = "summary"

                            self.path = YLeaf(YType.uint32, "path")

                            self.path_tear = YLeaf(YType.uint32, "path-tear")

                            self.reservation_confirm = YLeaf(YType.uint32, "reservation-confirm")

                            self.total = YLeaf(YType.uint32, "total")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("path",
                                            "path_tear",
                                            "reservation_confirm",
                                            "total") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.Counters.PrefixFiltering.Interfaces.Summary.DefaultActionDropped, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.Counters.PrefixFiltering.Interfaces.Summary.DefaultActionDropped, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.path.is_set or
                                self.path_tear.is_set or
                                self.reservation_confirm.is_set or
                                self.total.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.path.yfilter != YFilter.not_set or
                                self.path_tear.yfilter != YFilter.not_set or
                                self.reservation_confirm.yfilter != YFilter.not_set or
                                self.total.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "default-action-dropped" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/counters/prefix-filtering/interfaces/summary/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.path.is_set or self.path.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.path.get_name_leafdata())
                            if (self.path_tear.is_set or self.path_tear.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.path_tear.get_name_leafdata())
                            if (self.reservation_confirm.is_set or self.reservation_confirm.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.reservation_confirm.get_name_leafdata())
                            if (self.total.is_set or self.total.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.total.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "path" or name == "path-tear" or name == "reservation-confirm" or name == "total"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "path"):
                                self.path = value
                                self.path.value_namespace = name_space
                                self.path.value_namespace_prefix = name_space_prefix
                            if(value_path == "path-tear"):
                                self.path_tear = value
                                self.path_tear.value_namespace = name_space
                                self.path_tear.value_namespace_prefix = name_space_prefix
                            if(value_path == "reservation-confirm"):
                                self.reservation_confirm = value
                                self.reservation_confirm.value_namespace = name_space
                                self.reservation_confirm.value_namespace_prefix = name_space_prefix
                            if(value_path == "total"):
                                self.total = value
                                self.total.value_namespace = name_space
                                self.total.value_namespace_prefix = name_space_prefix


                    class DefaultActionProcessed(Entity):
                        """
                        Count of messages which were processed due to
                        default ACL action
                        
                        .. attribute:: path
                        
                        	Count of Path messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: path_tear
                        
                        	Count of PathTear messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: reservation_confirm
                        
                        	Count of ReservationConfirm messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total
                        
                        	Total count of messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.Counters.PrefixFiltering.Interfaces.Summary.DefaultActionProcessed, self).__init__()

                            self.yang_name = "default-action-processed"
                            self.yang_parent_name = "summary"

                            self.path = YLeaf(YType.uint32, "path")

                            self.path_tear = YLeaf(YType.uint32, "path-tear")

                            self.reservation_confirm = YLeaf(YType.uint32, "reservation-confirm")

                            self.total = YLeaf(YType.uint32, "total")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("path",
                                            "path_tear",
                                            "reservation_confirm",
                                            "total") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.Counters.PrefixFiltering.Interfaces.Summary.DefaultActionProcessed, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.Counters.PrefixFiltering.Interfaces.Summary.DefaultActionProcessed, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.path.is_set or
                                self.path_tear.is_set or
                                self.reservation_confirm.is_set or
                                self.total.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.path.yfilter != YFilter.not_set or
                                self.path_tear.yfilter != YFilter.not_set or
                                self.reservation_confirm.yfilter != YFilter.not_set or
                                self.total.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "default-action-processed" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/counters/prefix-filtering/interfaces/summary/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.path.is_set or self.path.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.path.get_name_leafdata())
                            if (self.path_tear.is_set or self.path_tear.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.path_tear.get_name_leafdata())
                            if (self.reservation_confirm.is_set or self.reservation_confirm.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.reservation_confirm.get_name_leafdata())
                            if (self.total.is_set or self.total.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.total.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "path" or name == "path-tear" or name == "reservation-confirm" or name == "total"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "path"):
                                self.path = value
                                self.path.value_namespace = name_space
                                self.path.value_namespace_prefix = name_space_prefix
                            if(value_path == "path-tear"):
                                self.path_tear = value
                                self.path_tear.value_namespace = name_space
                                self.path_tear.value_namespace_prefix = name_space_prefix
                            if(value_path == "reservation-confirm"):
                                self.reservation_confirm = value
                                self.reservation_confirm.value_namespace = name_space
                                self.reservation_confirm.value_namespace_prefix = name_space_prefix
                            if(value_path == "total"):
                                self.total = value
                                self.total.value_namespace = name_space
                                self.total.value_namespace_prefix = name_space_prefix


                    class Total(Entity):
                        """
                        Count of total messages
                        
                        .. attribute:: path
                        
                        	Count of Path messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: path_tear
                        
                        	Count of PathTear messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: reservation_confirm
                        
                        	Count of ReservationConfirm messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total
                        
                        	Total count of messages
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.Counters.PrefixFiltering.Interfaces.Summary.Total, self).__init__()

                            self.yang_name = "total"
                            self.yang_parent_name = "summary"

                            self.path = YLeaf(YType.uint32, "path")

                            self.path_tear = YLeaf(YType.uint32, "path-tear")

                            self.reservation_confirm = YLeaf(YType.uint32, "reservation-confirm")

                            self.total = YLeaf(YType.uint32, "total")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("path",
                                            "path_tear",
                                            "reservation_confirm",
                                            "total") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.Counters.PrefixFiltering.Interfaces.Summary.Total, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.Counters.PrefixFiltering.Interfaces.Summary.Total, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.path.is_set or
                                self.path_tear.is_set or
                                self.reservation_confirm.is_set or
                                self.total.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.path.yfilter != YFilter.not_set or
                                self.path_tear.yfilter != YFilter.not_set or
                                self.reservation_confirm.yfilter != YFilter.not_set or
                                self.total.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "total" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/counters/prefix-filtering/interfaces/summary/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.path.is_set or self.path.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.path.get_name_leafdata())
                            if (self.path_tear.is_set or self.path_tear.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.path_tear.get_name_leafdata())
                            if (self.reservation_confirm.is_set or self.reservation_confirm.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.reservation_confirm.get_name_leafdata())
                            if (self.total.is_set or self.total.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.total.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "path" or name == "path-tear" or name == "reservation-confirm" or name == "total"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "path"):
                                self.path = value
                                self.path.value_namespace = name_space
                                self.path.value_namespace_prefix = name_space_prefix
                            if(value_path == "path-tear"):
                                self.path_tear = value
                                self.path_tear.value_namespace = name_space
                                self.path_tear.value_namespace_prefix = name_space_prefix
                            if(value_path == "reservation-confirm"):
                                self.reservation_confirm = value
                                self.reservation_confirm.value_namespace = name_space
                                self.reservation_confirm.value_namespace_prefix = name_space_prefix
                            if(value_path == "total"):
                                self.total = value
                                self.total.value_namespace = name_space
                                self.total.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            (self.default_action_dropped is not None and self.default_action_dropped.has_data()) or
                            (self.default_action_processed is not None and self.default_action_processed.has_data()) or
                            (self.dropped is not None and self.dropped.has_data()) or
                            (self.forwarded is not None and self.forwarded.has_data()) or
                            (self.locally_destined is not None and self.locally_destined.has_data()) or
                            (self.total is not None and self.total.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.default_action_dropped is not None and self.default_action_dropped.has_operation()) or
                            (self.default_action_processed is not None and self.default_action_processed.has_operation()) or
                            (self.dropped is not None and self.dropped.has_operation()) or
                            (self.forwarded is not None and self.forwarded.has_operation()) or
                            (self.locally_destined is not None and self.locally_destined.has_operation()) or
                            (self.total is not None and self.total.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "summary" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/counters/prefix-filtering/interfaces/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "default-action-dropped"):
                            if (self.default_action_dropped is None):
                                self.default_action_dropped = Rsvp.Counters.PrefixFiltering.Interfaces.Summary.DefaultActionDropped()
                                self.default_action_dropped.parent = self
                                self._children_name_map["default_action_dropped"] = "default-action-dropped"
                            return self.default_action_dropped

                        if (child_yang_name == "default-action-processed"):
                            if (self.default_action_processed is None):
                                self.default_action_processed = Rsvp.Counters.PrefixFiltering.Interfaces.Summary.DefaultActionProcessed()
                                self.default_action_processed.parent = self
                                self._children_name_map["default_action_processed"] = "default-action-processed"
                            return self.default_action_processed

                        if (child_yang_name == "dropped"):
                            if (self.dropped is None):
                                self.dropped = Rsvp.Counters.PrefixFiltering.Interfaces.Summary.Dropped()
                                self.dropped.parent = self
                                self._children_name_map["dropped"] = "dropped"
                            return self.dropped

                        if (child_yang_name == "forwarded"):
                            if (self.forwarded is None):
                                self.forwarded = Rsvp.Counters.PrefixFiltering.Interfaces.Summary.Forwarded()
                                self.forwarded.parent = self
                                self._children_name_map["forwarded"] = "forwarded"
                            return self.forwarded

                        if (child_yang_name == "locally-destined"):
                            if (self.locally_destined is None):
                                self.locally_destined = Rsvp.Counters.PrefixFiltering.Interfaces.Summary.LocallyDestined()
                                self.locally_destined.parent = self
                                self._children_name_map["locally_destined"] = "locally-destined"
                            return self.locally_destined

                        if (child_yang_name == "total"):
                            if (self.total is None):
                                self.total = Rsvp.Counters.PrefixFiltering.Interfaces.Summary.Total()
                                self.total.parent = self
                                self._children_name_map["total"] = "total"
                            return self.total

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "default-action-dropped" or name == "default-action-processed" or name == "dropped" or name == "forwarded" or name == "locally-destined" or name == "total"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass


                class Interfaces(Entity):
                    """
                    Table of interface specific prefix filtering
                    counters
                    
                    .. attribute:: interface
                    
                    	Prefix filtering counters for a specific interface
                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Counters.PrefixFiltering.Interfaces.Interfaces.Interface>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.Counters.PrefixFiltering.Interfaces.Interfaces, self).__init__()

                        self.yang_name = "interfaces"
                        self.yang_parent_name = "interfaces"

                        self.interface = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.Counters.PrefixFiltering.Interfaces.Interfaces, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.Counters.PrefixFiltering.Interfaces.Interfaces, self).__setattr__(name, value)


                    class Interface(Entity):
                        """
                        Prefix filtering counters for a specific
                        interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface Name. 'None' is used internally where the true interface is unknown (e.g. for routed packets)
                        	**type**\:  str
                        
                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                        
                        .. attribute:: default_action_dropped
                        
                        	Count of messages which got dropped due to default ACL action
                        	**type**\:   :py:class:`DefaultActionDropped <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.DefaultActionDropped>`
                        
                        .. attribute:: default_action_processed
                        
                        	Count of messages which were processed due to default ACL action
                        	**type**\:   :py:class:`DefaultActionProcessed <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.DefaultActionProcessed>`
                        
                        .. attribute:: dropped
                        
                        	Count of messages dropped
                        	**type**\:   :py:class:`Dropped <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.Dropped>`
                        
                        .. attribute:: forwarded
                        
                        	Count of messages which got forwarded
                        	**type**\:   :py:class:`Forwarded <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.Forwarded>`
                        
                        .. attribute:: locally_destined
                        
                        	Count of locally destined messages
                        	**type**\:   :py:class:`LocallyDestined <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.LocallyDestined>`
                        
                        .. attribute:: total
                        
                        	Count of total messages
                        	**type**\:   :py:class:`Total <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.Total>`
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.Counters.PrefixFiltering.Interfaces.Interfaces.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "interfaces"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.default_action_dropped = Rsvp.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.DefaultActionDropped()
                            self.default_action_dropped.parent = self
                            self._children_name_map["default_action_dropped"] = "default-action-dropped"
                            self._children_yang_names.add("default-action-dropped")

                            self.default_action_processed = Rsvp.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.DefaultActionProcessed()
                            self.default_action_processed.parent = self
                            self._children_name_map["default_action_processed"] = "default-action-processed"
                            self._children_yang_names.add("default-action-processed")

                            self.dropped = Rsvp.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.Dropped()
                            self.dropped.parent = self
                            self._children_name_map["dropped"] = "dropped"
                            self._children_yang_names.add("dropped")

                            self.forwarded = Rsvp.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.Forwarded()
                            self.forwarded.parent = self
                            self._children_name_map["forwarded"] = "forwarded"
                            self._children_yang_names.add("forwarded")

                            self.locally_destined = Rsvp.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.LocallyDestined()
                            self.locally_destined.parent = self
                            self._children_name_map["locally_destined"] = "locally-destined"
                            self._children_yang_names.add("locally-destined")

                            self.total = Rsvp.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.Total()
                            self.total.parent = self
                            self._children_name_map["total"] = "total"
                            self._children_yang_names.add("total")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.Counters.PrefixFiltering.Interfaces.Interfaces.Interface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.Counters.PrefixFiltering.Interfaces.Interfaces.Interface, self).__setattr__(name, value)


                        class Forwarded(Entity):
                            """
                            Count of messages which got forwarded
                            
                            .. attribute:: path
                            
                            	Count of Path messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: path_tear
                            
                            	Count of PathTear messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: reservation_confirm
                            
                            	Count of ReservationConfirm messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: total
                            
                            	Total count of messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Rsvp.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.Forwarded, self).__init__()

                                self.yang_name = "forwarded"
                                self.yang_parent_name = "interface"

                                self.path = YLeaf(YType.uint32, "path")

                                self.path_tear = YLeaf(YType.uint32, "path-tear")

                                self.reservation_confirm = YLeaf(YType.uint32, "reservation-confirm")

                                self.total = YLeaf(YType.uint32, "total")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("path",
                                                "path_tear",
                                                "reservation_confirm",
                                                "total") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Rsvp.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.Forwarded, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Rsvp.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.Forwarded, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.path.is_set or
                                    self.path_tear.is_set or
                                    self.reservation_confirm.is_set or
                                    self.total.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.path.yfilter != YFilter.not_set or
                                    self.path_tear.yfilter != YFilter.not_set or
                                    self.reservation_confirm.yfilter != YFilter.not_set or
                                    self.total.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "forwarded" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.path.is_set or self.path.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path.get_name_leafdata())
                                if (self.path_tear.is_set or self.path_tear.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path_tear.get_name_leafdata())
                                if (self.reservation_confirm.is_set or self.reservation_confirm.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.reservation_confirm.get_name_leafdata())
                                if (self.total.is_set or self.total.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.total.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "path" or name == "path-tear" or name == "reservation-confirm" or name == "total"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "path"):
                                    self.path = value
                                    self.path.value_namespace = name_space
                                    self.path.value_namespace_prefix = name_space_prefix
                                if(value_path == "path-tear"):
                                    self.path_tear = value
                                    self.path_tear.value_namespace = name_space
                                    self.path_tear.value_namespace_prefix = name_space_prefix
                                if(value_path == "reservation-confirm"):
                                    self.reservation_confirm = value
                                    self.reservation_confirm.value_namespace = name_space
                                    self.reservation_confirm.value_namespace_prefix = name_space_prefix
                                if(value_path == "total"):
                                    self.total = value
                                    self.total.value_namespace = name_space
                                    self.total.value_namespace_prefix = name_space_prefix


                        class LocallyDestined(Entity):
                            """
                            Count of locally destined messages
                            
                            .. attribute:: path
                            
                            	Count of Path messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: path_tear
                            
                            	Count of PathTear messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: reservation_confirm
                            
                            	Count of ReservationConfirm messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: total
                            
                            	Total count of messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Rsvp.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.LocallyDestined, self).__init__()

                                self.yang_name = "locally-destined"
                                self.yang_parent_name = "interface"

                                self.path = YLeaf(YType.uint32, "path")

                                self.path_tear = YLeaf(YType.uint32, "path-tear")

                                self.reservation_confirm = YLeaf(YType.uint32, "reservation-confirm")

                                self.total = YLeaf(YType.uint32, "total")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("path",
                                                "path_tear",
                                                "reservation_confirm",
                                                "total") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Rsvp.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.LocallyDestined, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Rsvp.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.LocallyDestined, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.path.is_set or
                                    self.path_tear.is_set or
                                    self.reservation_confirm.is_set or
                                    self.total.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.path.yfilter != YFilter.not_set or
                                    self.path_tear.yfilter != YFilter.not_set or
                                    self.reservation_confirm.yfilter != YFilter.not_set or
                                    self.total.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "locally-destined" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.path.is_set or self.path.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path.get_name_leafdata())
                                if (self.path_tear.is_set or self.path_tear.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path_tear.get_name_leafdata())
                                if (self.reservation_confirm.is_set or self.reservation_confirm.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.reservation_confirm.get_name_leafdata())
                                if (self.total.is_set or self.total.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.total.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "path" or name == "path-tear" or name == "reservation-confirm" or name == "total"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "path"):
                                    self.path = value
                                    self.path.value_namespace = name_space
                                    self.path.value_namespace_prefix = name_space_prefix
                                if(value_path == "path-tear"):
                                    self.path_tear = value
                                    self.path_tear.value_namespace = name_space
                                    self.path_tear.value_namespace_prefix = name_space_prefix
                                if(value_path == "reservation-confirm"):
                                    self.reservation_confirm = value
                                    self.reservation_confirm.value_namespace = name_space
                                    self.reservation_confirm.value_namespace_prefix = name_space_prefix
                                if(value_path == "total"):
                                    self.total = value
                                    self.total.value_namespace = name_space
                                    self.total.value_namespace_prefix = name_space_prefix


                        class Dropped(Entity):
                            """
                            Count of messages dropped
                            
                            .. attribute:: path
                            
                            	Count of Path messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: path_tear
                            
                            	Count of PathTear messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: reservation_confirm
                            
                            	Count of ReservationConfirm messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: total
                            
                            	Total count of messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Rsvp.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.Dropped, self).__init__()

                                self.yang_name = "dropped"
                                self.yang_parent_name = "interface"

                                self.path = YLeaf(YType.uint32, "path")

                                self.path_tear = YLeaf(YType.uint32, "path-tear")

                                self.reservation_confirm = YLeaf(YType.uint32, "reservation-confirm")

                                self.total = YLeaf(YType.uint32, "total")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("path",
                                                "path_tear",
                                                "reservation_confirm",
                                                "total") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Rsvp.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.Dropped, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Rsvp.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.Dropped, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.path.is_set or
                                    self.path_tear.is_set or
                                    self.reservation_confirm.is_set or
                                    self.total.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.path.yfilter != YFilter.not_set or
                                    self.path_tear.yfilter != YFilter.not_set or
                                    self.reservation_confirm.yfilter != YFilter.not_set or
                                    self.total.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "dropped" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.path.is_set or self.path.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path.get_name_leafdata())
                                if (self.path_tear.is_set or self.path_tear.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path_tear.get_name_leafdata())
                                if (self.reservation_confirm.is_set or self.reservation_confirm.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.reservation_confirm.get_name_leafdata())
                                if (self.total.is_set or self.total.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.total.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "path" or name == "path-tear" or name == "reservation-confirm" or name == "total"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "path"):
                                    self.path = value
                                    self.path.value_namespace = name_space
                                    self.path.value_namespace_prefix = name_space_prefix
                                if(value_path == "path-tear"):
                                    self.path_tear = value
                                    self.path_tear.value_namespace = name_space
                                    self.path_tear.value_namespace_prefix = name_space_prefix
                                if(value_path == "reservation-confirm"):
                                    self.reservation_confirm = value
                                    self.reservation_confirm.value_namespace = name_space
                                    self.reservation_confirm.value_namespace_prefix = name_space_prefix
                                if(value_path == "total"):
                                    self.total = value
                                    self.total.value_namespace = name_space
                                    self.total.value_namespace_prefix = name_space_prefix


                        class DefaultActionDropped(Entity):
                            """
                            Count of messages which got dropped due to
                            default ACL action
                            
                            .. attribute:: path
                            
                            	Count of Path messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: path_tear
                            
                            	Count of PathTear messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: reservation_confirm
                            
                            	Count of ReservationConfirm messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: total
                            
                            	Total count of messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Rsvp.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.DefaultActionDropped, self).__init__()

                                self.yang_name = "default-action-dropped"
                                self.yang_parent_name = "interface"

                                self.path = YLeaf(YType.uint32, "path")

                                self.path_tear = YLeaf(YType.uint32, "path-tear")

                                self.reservation_confirm = YLeaf(YType.uint32, "reservation-confirm")

                                self.total = YLeaf(YType.uint32, "total")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("path",
                                                "path_tear",
                                                "reservation_confirm",
                                                "total") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Rsvp.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.DefaultActionDropped, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Rsvp.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.DefaultActionDropped, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.path.is_set or
                                    self.path_tear.is_set or
                                    self.reservation_confirm.is_set or
                                    self.total.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.path.yfilter != YFilter.not_set or
                                    self.path_tear.yfilter != YFilter.not_set or
                                    self.reservation_confirm.yfilter != YFilter.not_set or
                                    self.total.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "default-action-dropped" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.path.is_set or self.path.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path.get_name_leafdata())
                                if (self.path_tear.is_set or self.path_tear.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path_tear.get_name_leafdata())
                                if (self.reservation_confirm.is_set or self.reservation_confirm.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.reservation_confirm.get_name_leafdata())
                                if (self.total.is_set or self.total.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.total.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "path" or name == "path-tear" or name == "reservation-confirm" or name == "total"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "path"):
                                    self.path = value
                                    self.path.value_namespace = name_space
                                    self.path.value_namespace_prefix = name_space_prefix
                                if(value_path == "path-tear"):
                                    self.path_tear = value
                                    self.path_tear.value_namespace = name_space
                                    self.path_tear.value_namespace_prefix = name_space_prefix
                                if(value_path == "reservation-confirm"):
                                    self.reservation_confirm = value
                                    self.reservation_confirm.value_namespace = name_space
                                    self.reservation_confirm.value_namespace_prefix = name_space_prefix
                                if(value_path == "total"):
                                    self.total = value
                                    self.total.value_namespace = name_space
                                    self.total.value_namespace_prefix = name_space_prefix


                        class DefaultActionProcessed(Entity):
                            """
                            Count of messages which were processed due to
                            default ACL action
                            
                            .. attribute:: path
                            
                            	Count of Path messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: path_tear
                            
                            	Count of PathTear messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: reservation_confirm
                            
                            	Count of ReservationConfirm messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: total
                            
                            	Total count of messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Rsvp.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.DefaultActionProcessed, self).__init__()

                                self.yang_name = "default-action-processed"
                                self.yang_parent_name = "interface"

                                self.path = YLeaf(YType.uint32, "path")

                                self.path_tear = YLeaf(YType.uint32, "path-tear")

                                self.reservation_confirm = YLeaf(YType.uint32, "reservation-confirm")

                                self.total = YLeaf(YType.uint32, "total")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("path",
                                                "path_tear",
                                                "reservation_confirm",
                                                "total") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Rsvp.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.DefaultActionProcessed, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Rsvp.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.DefaultActionProcessed, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.path.is_set or
                                    self.path_tear.is_set or
                                    self.reservation_confirm.is_set or
                                    self.total.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.path.yfilter != YFilter.not_set or
                                    self.path_tear.yfilter != YFilter.not_set or
                                    self.reservation_confirm.yfilter != YFilter.not_set or
                                    self.total.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "default-action-processed" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.path.is_set or self.path.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path.get_name_leafdata())
                                if (self.path_tear.is_set or self.path_tear.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path_tear.get_name_leafdata())
                                if (self.reservation_confirm.is_set or self.reservation_confirm.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.reservation_confirm.get_name_leafdata())
                                if (self.total.is_set or self.total.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.total.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "path" or name == "path-tear" or name == "reservation-confirm" or name == "total"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "path"):
                                    self.path = value
                                    self.path.value_namespace = name_space
                                    self.path.value_namespace_prefix = name_space_prefix
                                if(value_path == "path-tear"):
                                    self.path_tear = value
                                    self.path_tear.value_namespace = name_space
                                    self.path_tear.value_namespace_prefix = name_space_prefix
                                if(value_path == "reservation-confirm"):
                                    self.reservation_confirm = value
                                    self.reservation_confirm.value_namespace = name_space
                                    self.reservation_confirm.value_namespace_prefix = name_space_prefix
                                if(value_path == "total"):
                                    self.total = value
                                    self.total.value_namespace = name_space
                                    self.total.value_namespace_prefix = name_space_prefix


                        class Total(Entity):
                            """
                            Count of total messages
                            
                            .. attribute:: path
                            
                            	Count of Path messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: path_tear
                            
                            	Count of PathTear messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: reservation_confirm
                            
                            	Count of ReservationConfirm messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: total
                            
                            	Total count of messages
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Rsvp.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.Total, self).__init__()

                                self.yang_name = "total"
                                self.yang_parent_name = "interface"

                                self.path = YLeaf(YType.uint32, "path")

                                self.path_tear = YLeaf(YType.uint32, "path-tear")

                                self.reservation_confirm = YLeaf(YType.uint32, "reservation-confirm")

                                self.total = YLeaf(YType.uint32, "total")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("path",
                                                "path_tear",
                                                "reservation_confirm",
                                                "total") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Rsvp.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.Total, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Rsvp.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.Total, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.path.is_set or
                                    self.path_tear.is_set or
                                    self.reservation_confirm.is_set or
                                    self.total.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.path.yfilter != YFilter.not_set or
                                    self.path_tear.yfilter != YFilter.not_set or
                                    self.reservation_confirm.yfilter != YFilter.not_set or
                                    self.total.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "total" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.path.is_set or self.path.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path.get_name_leafdata())
                                if (self.path_tear.is_set or self.path_tear.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.path_tear.get_name_leafdata())
                                if (self.reservation_confirm.is_set or self.reservation_confirm.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.reservation_confirm.get_name_leafdata())
                                if (self.total.is_set or self.total.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.total.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "path" or name == "path-tear" or name == "reservation-confirm" or name == "total"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "path"):
                                    self.path = value
                                    self.path.value_namespace = name_space
                                    self.path.value_namespace_prefix = name_space_prefix
                                if(value_path == "path-tear"):
                                    self.path_tear = value
                                    self.path_tear.value_namespace = name_space
                                    self.path_tear.value_namespace_prefix = name_space_prefix
                                if(value_path == "reservation-confirm"):
                                    self.reservation_confirm = value
                                    self.reservation_confirm.value_namespace = name_space
                                    self.reservation_confirm.value_namespace_prefix = name_space_prefix
                                if(value_path == "total"):
                                    self.total = value
                                    self.total.value_namespace = name_space
                                    self.total.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.interface_name.is_set or
                                (self.default_action_dropped is not None and self.default_action_dropped.has_data()) or
                                (self.default_action_processed is not None and self.default_action_processed.has_data()) or
                                (self.dropped is not None and self.dropped.has_data()) or
                                (self.forwarded is not None and self.forwarded.has_data()) or
                                (self.locally_destined is not None and self.locally_destined.has_data()) or
                                (self.total is not None and self.total.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                (self.default_action_dropped is not None and self.default_action_dropped.has_operation()) or
                                (self.default_action_processed is not None and self.default_action_processed.has_operation()) or
                                (self.dropped is not None and self.dropped.has_operation()) or
                                (self.forwarded is not None and self.forwarded.has_operation()) or
                                (self.locally_destined is not None and self.locally_destined.has_operation()) or
                                (self.total is not None and self.total.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/counters/prefix-filtering/interfaces/interfaces/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "default-action-dropped"):
                                if (self.default_action_dropped is None):
                                    self.default_action_dropped = Rsvp.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.DefaultActionDropped()
                                    self.default_action_dropped.parent = self
                                    self._children_name_map["default_action_dropped"] = "default-action-dropped"
                                return self.default_action_dropped

                            if (child_yang_name == "default-action-processed"):
                                if (self.default_action_processed is None):
                                    self.default_action_processed = Rsvp.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.DefaultActionProcessed()
                                    self.default_action_processed.parent = self
                                    self._children_name_map["default_action_processed"] = "default-action-processed"
                                return self.default_action_processed

                            if (child_yang_name == "dropped"):
                                if (self.dropped is None):
                                    self.dropped = Rsvp.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.Dropped()
                                    self.dropped.parent = self
                                    self._children_name_map["dropped"] = "dropped"
                                return self.dropped

                            if (child_yang_name == "forwarded"):
                                if (self.forwarded is None):
                                    self.forwarded = Rsvp.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.Forwarded()
                                    self.forwarded.parent = self
                                    self._children_name_map["forwarded"] = "forwarded"
                                return self.forwarded

                            if (child_yang_name == "locally-destined"):
                                if (self.locally_destined is None):
                                    self.locally_destined = Rsvp.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.LocallyDestined()
                                    self.locally_destined.parent = self
                                    self._children_name_map["locally_destined"] = "locally-destined"
                                return self.locally_destined

                            if (child_yang_name == "total"):
                                if (self.total is None):
                                    self.total = Rsvp.Counters.PrefixFiltering.Interfaces.Interfaces.Interface.Total()
                                    self.total.parent = self
                                    self._children_name_map["total"] = "total"
                                return self.total

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "default-action-dropped" or name == "default-action-processed" or name == "dropped" or name == "forwarded" or name == "locally-destined" or name == "total" or name == "interface-name"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.interface:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interfaces" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/counters/prefix-filtering/interfaces/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "interface"):
                            for c in self.interface:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Rsvp.Counters.PrefixFiltering.Interfaces.Interfaces.Interface()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        (self.interfaces is not None and self.interfaces.has_data()) or
                        (self.summary is not None and self.summary.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.interfaces is not None and self.interfaces.has_operation()) or
                        (self.summary is not None and self.summary.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "interfaces" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/counters/prefix-filtering/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interfaces"):
                        if (self.interfaces is None):
                            self.interfaces = Rsvp.Counters.PrefixFiltering.Interfaces.Interfaces()
                            self.interfaces.parent = self
                            self._children_name_map["interfaces"] = "interfaces"
                        return self.interfaces

                    if (child_yang_name == "summary"):
                        if (self.summary is None):
                            self.summary = Rsvp.Counters.PrefixFiltering.Interfaces.Summary()
                            self.summary.parent = self
                            self._children_name_map["summary"] = "summary"
                        return self.summary

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interfaces" or name == "summary"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (
                    (self.accesses is not None and self.accesses.has_data()) or
                    (self.interfaces is not None and self.interfaces.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.accesses is not None and self.accesses.has_operation()) or
                    (self.interfaces is not None and self.interfaces.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "prefix-filtering" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/counters/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "accesses"):
                    if (self.accesses is None):
                        self.accesses = Rsvp.Counters.PrefixFiltering.Accesses()
                        self.accesses.parent = self
                        self._children_name_map["accesses"] = "accesses"
                    return self.accesses

                if (child_yang_name == "interfaces"):
                    if (self.interfaces is None):
                        self.interfaces = Rsvp.Counters.PrefixFiltering.Interfaces()
                        self.interfaces.parent = self
                        self._children_name_map["interfaces"] = "interfaces"
                    return self.interfaces

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "accesses" or name == "interfaces"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class OutOfResource(Entity):
            """
            Out of resource counters
            
            .. attribute:: interfaces
            
            	Interface specific out of resource counters
            	**type**\:   :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Counters.OutOfResource.Interfaces>`
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Rsvp.Counters.OutOfResource, self).__init__()

                self.yang_name = "out-of-resource"
                self.yang_parent_name = "counters"

                self.interfaces = Rsvp.Counters.OutOfResource.Interfaces()
                self.interfaces.parent = self
                self._children_name_map["interfaces"] = "interfaces"
                self._children_yang_names.add("interfaces")


            class Interfaces(Entity):
                """
                Interface specific out of resource counters
                
                .. attribute:: interfaces
                
                	Table of interface specific out of resource counters
                	**type**\:   :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Counters.OutOfResource.Interfaces.Interfaces>`
                
                .. attribute:: summary
                
                	Summary of out of resource counts for all interfaces
                	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Counters.OutOfResource.Interfaces.Summary>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.Counters.OutOfResource.Interfaces, self).__init__()

                    self.yang_name = "interfaces"
                    self.yang_parent_name = "out-of-resource"

                    self.interfaces = Rsvp.Counters.OutOfResource.Interfaces.Interfaces()
                    self.interfaces.parent = self
                    self._children_name_map["interfaces"] = "interfaces"
                    self._children_yang_names.add("interfaces")

                    self.summary = Rsvp.Counters.OutOfResource.Interfaces.Summary()
                    self.summary.parent = self
                    self._children_name_map["summary"] = "summary"
                    self._children_yang_names.add("summary")


                class Summary(Entity):
                    """
                    Summary of out of resource counts for all
                    interfaces
                    
                    .. attribute:: dropped_path_messages
                    
                    	Count of Path messages dropped due to an out of resource condition
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.Counters.OutOfResource.Interfaces.Summary, self).__init__()

                        self.yang_name = "summary"
                        self.yang_parent_name = "interfaces"

                        self.dropped_path_messages = YLeaf(YType.uint32, "dropped-path-messages")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("dropped_path_messages") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.Counters.OutOfResource.Interfaces.Summary, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.Counters.OutOfResource.Interfaces.Summary, self).__setattr__(name, value)

                    def has_data(self):
                        return self.dropped_path_messages.is_set

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.dropped_path_messages.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "summary" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/counters/out-of-resource/interfaces/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.dropped_path_messages.is_set or self.dropped_path_messages.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.dropped_path_messages.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "dropped-path-messages"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "dropped-path-messages"):
                            self.dropped_path_messages = value
                            self.dropped_path_messages.value_namespace = name_space
                            self.dropped_path_messages.value_namespace_prefix = name_space_prefix


                class Interfaces(Entity):
                    """
                    Table of interface specific out of resource
                    counters
                    
                    .. attribute:: interface
                    
                    	Out of resource counters for a specific interface
                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Counters.OutOfResource.Interfaces.Interfaces.Interface>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.Counters.OutOfResource.Interfaces.Interfaces, self).__init__()

                        self.yang_name = "interfaces"
                        self.yang_parent_name = "interfaces"

                        self.interface = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in () and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.Counters.OutOfResource.Interfaces.Interfaces, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.Counters.OutOfResource.Interfaces.Interfaces, self).__setattr__(name, value)


                    class Interface(Entity):
                        """
                        Out of resource counters for a specific
                        interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface Name. 'None' is used internally where the true interface is unknown (e.g. for routed packets)
                        	**type**\:  str
                        
                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                        
                        .. attribute:: dropped_path_messages
                        
                        	Count of Path messages dropped due to an out of resource condition
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.Counters.OutOfResource.Interfaces.Interfaces.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "interfaces"

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.dropped_path_messages = YLeaf(YType.uint32, "dropped-path-messages")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("interface_name",
                                            "dropped_path_messages") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.Counters.OutOfResource.Interfaces.Interfaces.Interface, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.Counters.OutOfResource.Interfaces.Interfaces.Interface, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.interface_name.is_set or
                                self.dropped_path_messages.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.interface_name.yfilter != YFilter.not_set or
                                self.dropped_path_messages.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "interface" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/counters/out-of-resource/interfaces/interfaces/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.interface_name.get_name_leafdata())
                            if (self.dropped_path_messages.is_set or self.dropped_path_messages.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.dropped_path_messages.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "interface-name" or name == "dropped-path-messages"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "interface-name"):
                                self.interface_name = value
                                self.interface_name.value_namespace = name_space
                                self.interface_name.value_namespace_prefix = name_space_prefix
                            if(value_path == "dropped-path-messages"):
                                self.dropped_path_messages = value
                                self.dropped_path_messages.value_namespace = name_space
                                self.dropped_path_messages.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.interface:
                            if (c.has_data()):
                                return True
                        return False

                    def has_operation(self):
                        for c in self.interface:
                            if (c.has_operation()):
                                return True
                        return self.yfilter != YFilter.not_set

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "interfaces" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/counters/out-of-resource/interfaces/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "interface"):
                            for c in self.interface:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Rsvp.Counters.OutOfResource.Interfaces.Interfaces.Interface()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.interface.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "interface"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        (self.interfaces is not None and self.interfaces.has_data()) or
                        (self.summary is not None and self.summary.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.interfaces is not None and self.interfaces.has_operation()) or
                        (self.summary is not None and self.summary.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "interfaces" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/counters/out-of-resource/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "interfaces"):
                        if (self.interfaces is None):
                            self.interfaces = Rsvp.Counters.OutOfResource.Interfaces.Interfaces()
                            self.interfaces.parent = self
                            self._children_name_map["interfaces"] = "interfaces"
                        return self.interfaces

                    if (child_yang_name == "summary"):
                        if (self.summary is None):
                            self.summary = Rsvp.Counters.OutOfResource.Interfaces.Summary()
                            self.summary.parent = self
                            self._children_name_map["summary"] = "summary"
                        return self.summary

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interfaces" or name == "summary"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                return (self.interfaces is not None and self.interfaces.has_data())

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    (self.interfaces is not None and self.interfaces.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "out-of-resource" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/counters/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "interfaces"):
                    if (self.interfaces is None):
                        self.interfaces = Rsvp.Counters.OutOfResource.Interfaces()
                        self.interfaces.parent = self
                        self._children_name_map["interfaces"] = "interfaces"
                    return self.interfaces

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "interfaces"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class InterfaceEvents(Entity):
            """
            Event counters
            
            .. attribute:: interface_event
            
            	Event counters for an interface
            	**type**\: list of    :py:class:`InterfaceEvent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Counters.InterfaceEvents.InterfaceEvent>`
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Rsvp.Counters.InterfaceEvents, self).__init__()

                self.yang_name = "interface-events"
                self.yang_parent_name = "counters"

                self.interface_event = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Rsvp.Counters.InterfaceEvents, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Rsvp.Counters.InterfaceEvents, self).__setattr__(name, value)


            class InterfaceEvent(Entity):
                """
                Event counters for an interface
                
                .. attribute:: interface_name  <key>
                
                	Interface Name. 'None' is used internally where the true interface is unknown (e.g. for routed packets)
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: expired_paths
                
                	Counter for Expired Path states
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: expired_reservations
                
                	Counter for Expired Reservation states
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: nac_ks
                
                	Counter for NACKs received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.Counters.InterfaceEvents.InterfaceEvent, self).__init__()

                    self.yang_name = "interface-event"
                    self.yang_parent_name = "interface-events"

                    self.interface_name = YLeaf(YType.str, "interface-name")

                    self.expired_paths = YLeaf(YType.uint32, "expired-paths")

                    self.expired_reservations = YLeaf(YType.uint32, "expired-reservations")

                    self.nac_ks = YLeaf(YType.uint32, "nac-ks")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("interface_name",
                                    "expired_paths",
                                    "expired_reservations",
                                    "nac_ks") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.Counters.InterfaceEvents.InterfaceEvent, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.Counters.InterfaceEvents.InterfaceEvent, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.interface_name.is_set or
                        self.expired_paths.is_set or
                        self.expired_reservations.is_set or
                        self.nac_ks.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.interface_name.yfilter != YFilter.not_set or
                        self.expired_paths.yfilter != YFilter.not_set or
                        self.expired_reservations.yfilter != YFilter.not_set or
                        self.nac_ks.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "interface-event" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/counters/interface-events/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                    if (self.expired_paths.is_set or self.expired_paths.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.expired_paths.get_name_leafdata())
                    if (self.expired_reservations.is_set or self.expired_reservations.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.expired_reservations.get_name_leafdata())
                    if (self.nac_ks.is_set or self.nac_ks.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.nac_ks.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface-name" or name == "expired-paths" or name == "expired-reservations" or name == "nac-ks"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "interface-name"):
                        self.interface_name = value
                        self.interface_name.value_namespace = name_space
                        self.interface_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "expired-paths"):
                        self.expired_paths = value
                        self.expired_paths.value_namespace = name_space
                        self.expired_paths.value_namespace_prefix = name_space_prefix
                    if(value_path == "expired-reservations"):
                        self.expired_reservations = value
                        self.expired_reservations.value_namespace = name_space
                        self.expired_reservations.value_namespace_prefix = name_space_prefix
                    if(value_path == "nac-ks"):
                        self.nac_ks = value
                        self.nac_ks.value_namespace = name_space
                        self.nac_ks.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.interface_event:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.interface_event:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "interface-events" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/counters/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "interface-event"):
                    for c in self.interface_event:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = Rsvp.Counters.InterfaceEvents.InterfaceEvent()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.interface_event.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "interface-event"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass


        class Nsr(Entity):
            """
            Summary information for all RSVP NSR counters
            
            .. attribute:: last_cleared_timestamp
            
            	The timestamp, in seconds, when these statistics are cleared              since 00\:00\:00 UTC, January 1, 1970
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            	**units**\: second
            
            .. attribute:: last_idt_states
            
            	Last IDT number of states
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: rsvp_process_role
            
            	Process role
            	**type**\:   :py:class:`RsvpProcRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpProcRole>`
            
            .. attribute:: total_deletions
            
            	Total number of deletions
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: total_id_ts
            
            	Total number of IDTs
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: total_nacks
            
            	Total number of NACKs
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: total_states
            
            	Total number of states
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Rsvp.Counters.Nsr, self).__init__()

                self.yang_name = "nsr"
                self.yang_parent_name = "counters"

                self.last_cleared_timestamp = YLeaf(YType.uint32, "last-cleared-timestamp")

                self.last_idt_states = YLeaf(YType.uint32, "last-idt-states")

                self.rsvp_process_role = YLeaf(YType.enumeration, "rsvp-process-role")

                self.total_deletions = YLeaf(YType.uint32, "total-deletions")

                self.total_id_ts = YLeaf(YType.uint32, "total-id-ts")

                self.total_nacks = YLeaf(YType.uint64, "total-nacks")

                self.total_states = YLeaf(YType.uint32, "total-states")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("last_cleared_timestamp",
                                "last_idt_states",
                                "rsvp_process_role",
                                "total_deletions",
                                "total_id_ts",
                                "total_nacks",
                                "total_states") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Rsvp.Counters.Nsr, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Rsvp.Counters.Nsr, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.last_cleared_timestamp.is_set or
                    self.last_idt_states.is_set or
                    self.rsvp_process_role.is_set or
                    self.total_deletions.is_set or
                    self.total_id_ts.is_set or
                    self.total_nacks.is_set or
                    self.total_states.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.last_cleared_timestamp.yfilter != YFilter.not_set or
                    self.last_idt_states.yfilter != YFilter.not_set or
                    self.rsvp_process_role.yfilter != YFilter.not_set or
                    self.total_deletions.yfilter != YFilter.not_set or
                    self.total_id_ts.yfilter != YFilter.not_set or
                    self.total_nacks.yfilter != YFilter.not_set or
                    self.total_states.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "nsr" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/counters/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.last_cleared_timestamp.is_set or self.last_cleared_timestamp.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.last_cleared_timestamp.get_name_leafdata())
                if (self.last_idt_states.is_set or self.last_idt_states.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.last_idt_states.get_name_leafdata())
                if (self.rsvp_process_role.is_set or self.rsvp_process_role.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.rsvp_process_role.get_name_leafdata())
                if (self.total_deletions.is_set or self.total_deletions.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.total_deletions.get_name_leafdata())
                if (self.total_id_ts.is_set or self.total_id_ts.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.total_id_ts.get_name_leafdata())
                if (self.total_nacks.is_set or self.total_nacks.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.total_nacks.get_name_leafdata())
                if (self.total_states.is_set or self.total_states.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.total_states.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "last-cleared-timestamp" or name == "last-idt-states" or name == "rsvp-process-role" or name == "total-deletions" or name == "total-id-ts" or name == "total-nacks" or name == "total-states"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "last-cleared-timestamp"):
                    self.last_cleared_timestamp = value
                    self.last_cleared_timestamp.value_namespace = name_space
                    self.last_cleared_timestamp.value_namespace_prefix = name_space_prefix
                if(value_path == "last-idt-states"):
                    self.last_idt_states = value
                    self.last_idt_states.value_namespace = name_space
                    self.last_idt_states.value_namespace_prefix = name_space_prefix
                if(value_path == "rsvp-process-role"):
                    self.rsvp_process_role = value
                    self.rsvp_process_role.value_namespace = name_space
                    self.rsvp_process_role.value_namespace_prefix = name_space_prefix
                if(value_path == "total-deletions"):
                    self.total_deletions = value
                    self.total_deletions.value_namespace = name_space
                    self.total_deletions.value_namespace_prefix = name_space_prefix
                if(value_path == "total-id-ts"):
                    self.total_id_ts = value
                    self.total_id_ts.value_namespace = name_space
                    self.total_id_ts.value_namespace_prefix = name_space_prefix
                if(value_path == "total-nacks"):
                    self.total_nacks = value
                    self.total_nacks.value_namespace = name_space
                    self.total_nacks.value_namespace_prefix = name_space_prefix
                if(value_path == "total-states"):
                    self.total_states = value
                    self.total_states.value_namespace = name_space
                    self.total_states.value_namespace_prefix = name_space_prefix


        class Issu(Entity):
            """
            Summary information for all RSVP ISSU counters
            
            .. attribute:: last_cleared_timestamp
            
            	The timestamp, in seconds, when these statistics are cleared              since 00\:00\:00 UTC, January 1, 1970
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            	**units**\: second
            
            .. attribute:: last_idt_states
            
            	Last IDT number of states
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: rsvp_process_role
            
            	Process role
            	**type**\:   :py:class:`RsvpProcRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpProcRole>`
            
            .. attribute:: total_deletions
            
            	Total number of deletions
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: total_id_ts
            
            	Total number of IDTs
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: total_nacks
            
            	Total number of NACKs
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: total_states
            
            	Total number of states
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Rsvp.Counters.Issu, self).__init__()

                self.yang_name = "issu"
                self.yang_parent_name = "counters"

                self.last_cleared_timestamp = YLeaf(YType.uint32, "last-cleared-timestamp")

                self.last_idt_states = YLeaf(YType.uint32, "last-idt-states")

                self.rsvp_process_role = YLeaf(YType.enumeration, "rsvp-process-role")

                self.total_deletions = YLeaf(YType.uint32, "total-deletions")

                self.total_id_ts = YLeaf(YType.uint32, "total-id-ts")

                self.total_nacks = YLeaf(YType.uint64, "total-nacks")

                self.total_states = YLeaf(YType.uint32, "total-states")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("last_cleared_timestamp",
                                "last_idt_states",
                                "rsvp_process_role",
                                "total_deletions",
                                "total_id_ts",
                                "total_nacks",
                                "total_states") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Rsvp.Counters.Issu, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Rsvp.Counters.Issu, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.last_cleared_timestamp.is_set or
                    self.last_idt_states.is_set or
                    self.rsvp_process_role.is_set or
                    self.total_deletions.is_set or
                    self.total_id_ts.is_set or
                    self.total_nacks.is_set or
                    self.total_states.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.last_cleared_timestamp.yfilter != YFilter.not_set or
                    self.last_idt_states.yfilter != YFilter.not_set or
                    self.rsvp_process_role.yfilter != YFilter.not_set or
                    self.total_deletions.yfilter != YFilter.not_set or
                    self.total_id_ts.yfilter != YFilter.not_set or
                    self.total_nacks.yfilter != YFilter.not_set or
                    self.total_states.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "issu" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/counters/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.last_cleared_timestamp.is_set or self.last_cleared_timestamp.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.last_cleared_timestamp.get_name_leafdata())
                if (self.last_idt_states.is_set or self.last_idt_states.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.last_idt_states.get_name_leafdata())
                if (self.rsvp_process_role.is_set or self.rsvp_process_role.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.rsvp_process_role.get_name_leafdata())
                if (self.total_deletions.is_set or self.total_deletions.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.total_deletions.get_name_leafdata())
                if (self.total_id_ts.is_set or self.total_id_ts.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.total_id_ts.get_name_leafdata())
                if (self.total_nacks.is_set or self.total_nacks.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.total_nacks.get_name_leafdata())
                if (self.total_states.is_set or self.total_states.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.total_states.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "last-cleared-timestamp" or name == "last-idt-states" or name == "rsvp-process-role" or name == "total-deletions" or name == "total-id-ts" or name == "total-nacks" or name == "total-states"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "last-cleared-timestamp"):
                    self.last_cleared_timestamp = value
                    self.last_cleared_timestamp.value_namespace = name_space
                    self.last_cleared_timestamp.value_namespace_prefix = name_space_prefix
                if(value_path == "last-idt-states"):
                    self.last_idt_states = value
                    self.last_idt_states.value_namespace = name_space
                    self.last_idt_states.value_namespace_prefix = name_space_prefix
                if(value_path == "rsvp-process-role"):
                    self.rsvp_process_role = value
                    self.rsvp_process_role.value_namespace = name_space
                    self.rsvp_process_role.value_namespace_prefix = name_space_prefix
                if(value_path == "total-deletions"):
                    self.total_deletions = value
                    self.total_deletions.value_namespace = name_space
                    self.total_deletions.value_namespace_prefix = name_space_prefix
                if(value_path == "total-id-ts"):
                    self.total_id_ts = value
                    self.total_id_ts.value_namespace = name_space
                    self.total_id_ts.value_namespace_prefix = name_space_prefix
                if(value_path == "total-nacks"):
                    self.total_nacks = value
                    self.total_nacks.value_namespace = name_space
                    self.total_nacks.value_namespace_prefix = name_space_prefix
                if(value_path == "total-states"):
                    self.total_states = value
                    self.total_states.value_namespace = name_space
                    self.total_states.value_namespace_prefix = name_space_prefix


        class Database(Entity):
            """
            Summary information for all RSVP database
            counters
            
            .. attribute:: incoming_paths
            
            	Number of locally created and incoming path states
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: incoming_reservations
            
            	Number of locally created and incoming reservation states
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: interfaces
            
            	Number of Interfaces
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: outgoing_paths
            
            	Number of outgoing path states
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: outgoing_reservations
            
            	Number of outgoing reservation states
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: sessions
            
            	Number of sessions
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Rsvp.Counters.Database, self).__init__()

                self.yang_name = "database"
                self.yang_parent_name = "counters"

                self.incoming_paths = YLeaf(YType.uint32, "incoming-paths")

                self.incoming_reservations = YLeaf(YType.uint32, "incoming-reservations")

                self.interfaces = YLeaf(YType.uint32, "interfaces")

                self.outgoing_paths = YLeaf(YType.uint32, "outgoing-paths")

                self.outgoing_reservations = YLeaf(YType.uint32, "outgoing-reservations")

                self.sessions = YLeaf(YType.uint32, "sessions")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("incoming_paths",
                                "incoming_reservations",
                                "interfaces",
                                "outgoing_paths",
                                "outgoing_reservations",
                                "sessions") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Rsvp.Counters.Database, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Rsvp.Counters.Database, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.incoming_paths.is_set or
                    self.incoming_reservations.is_set or
                    self.interfaces.is_set or
                    self.outgoing_paths.is_set or
                    self.outgoing_reservations.is_set or
                    self.sessions.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.incoming_paths.yfilter != YFilter.not_set or
                    self.incoming_reservations.yfilter != YFilter.not_set or
                    self.interfaces.yfilter != YFilter.not_set or
                    self.outgoing_paths.yfilter != YFilter.not_set or
                    self.outgoing_reservations.yfilter != YFilter.not_set or
                    self.sessions.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "database" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/counters/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.incoming_paths.is_set or self.incoming_paths.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.incoming_paths.get_name_leafdata())
                if (self.incoming_reservations.is_set or self.incoming_reservations.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.incoming_reservations.get_name_leafdata())
                if (self.interfaces.is_set or self.interfaces.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.interfaces.get_name_leafdata())
                if (self.outgoing_paths.is_set or self.outgoing_paths.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.outgoing_paths.get_name_leafdata())
                if (self.outgoing_reservations.is_set or self.outgoing_reservations.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.outgoing_reservations.get_name_leafdata())
                if (self.sessions.is_set or self.sessions.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.sessions.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "incoming-paths" or name == "incoming-reservations" or name == "interfaces" or name == "outgoing-paths" or name == "outgoing-reservations" or name == "sessions"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "incoming-paths"):
                    self.incoming_paths = value
                    self.incoming_paths.value_namespace = name_space
                    self.incoming_paths.value_namespace_prefix = name_space_prefix
                if(value_path == "incoming-reservations"):
                    self.incoming_reservations = value
                    self.incoming_reservations.value_namespace = name_space
                    self.incoming_reservations.value_namespace_prefix = name_space_prefix
                if(value_path == "interfaces"):
                    self.interfaces = value
                    self.interfaces.value_namespace = name_space
                    self.interfaces.value_namespace_prefix = name_space_prefix
                if(value_path == "outgoing-paths"):
                    self.outgoing_paths = value
                    self.outgoing_paths.value_namespace = name_space
                    self.outgoing_paths.value_namespace_prefix = name_space_prefix
                if(value_path == "outgoing-reservations"):
                    self.outgoing_reservations = value
                    self.outgoing_reservations.value_namespace = name_space
                    self.outgoing_reservations.value_namespace_prefix = name_space_prefix
                if(value_path == "sessions"):
                    self.sessions = value
                    self.sessions.value_namespace = name_space
                    self.sessions.value_namespace_prefix = name_space_prefix


        class EventSyncs(Entity):
            """
            Table containing event sync counters
            
            .. attribute:: event_sync
            
            	Event sync counters
            	**type**\: list of    :py:class:`EventSync <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Counters.EventSyncs.EventSync>`
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Rsvp.Counters.EventSyncs, self).__init__()

                self.yang_name = "event-syncs"
                self.yang_parent_name = "counters"

                self.event_sync = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in () and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Rsvp.Counters.EventSyncs, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Rsvp.Counters.EventSyncs, self).__setattr__(name, value)


            class EventSync(Entity):
                """
                Event sync counters
                
                .. attribute:: interface_name  <key>
                
                	Interface Name
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: expired_paths
                
                	Counter for Expired Path states
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: expired_reservations
                
                	Counter for Expired Reservation states
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: nac_ks
                
                	Counter for NACKs received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.Counters.EventSyncs.EventSync, self).__init__()

                    self.yang_name = "event-sync"
                    self.yang_parent_name = "event-syncs"

                    self.interface_name = YLeaf(YType.str, "interface-name")

                    self.expired_paths = YLeaf(YType.uint32, "expired-paths")

                    self.expired_reservations = YLeaf(YType.uint32, "expired-reservations")

                    self.nac_ks = YLeaf(YType.uint32, "nac-ks")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("interface_name",
                                    "expired_paths",
                                    "expired_reservations",
                                    "nac_ks") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.Counters.EventSyncs.EventSync, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.Counters.EventSyncs.EventSync, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.interface_name.is_set or
                        self.expired_paths.is_set or
                        self.expired_reservations.is_set or
                        self.nac_ks.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.interface_name.yfilter != YFilter.not_set or
                        self.expired_paths.yfilter != YFilter.not_set or
                        self.expired_reservations.yfilter != YFilter.not_set or
                        self.nac_ks.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "event-sync" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/counters/event-syncs/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface_name.get_name_leafdata())
                    if (self.expired_paths.is_set or self.expired_paths.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.expired_paths.get_name_leafdata())
                    if (self.expired_reservations.is_set or self.expired_reservations.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.expired_reservations.get_name_leafdata())
                    if (self.nac_ks.is_set or self.nac_ks.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.nac_ks.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface-name" or name == "expired-paths" or name == "expired-reservations" or name == "nac-ks"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "interface-name"):
                        self.interface_name = value
                        self.interface_name.value_namespace = name_space
                        self.interface_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "expired-paths"):
                        self.expired_paths = value
                        self.expired_paths.value_namespace = name_space
                        self.expired_paths.value_namespace_prefix = name_space_prefix
                    if(value_path == "expired-reservations"):
                        self.expired_reservations = value
                        self.expired_reservations.value_namespace = name_space
                        self.expired_reservations.value_namespace_prefix = name_space_prefix
                    if(value_path == "nac-ks"):
                        self.nac_ks = value
                        self.nac_ks.value_namespace = name_space
                        self.nac_ks.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.event_sync:
                    if (c.has_data()):
                        return True
                return False

            def has_operation(self):
                for c in self.event_sync:
                    if (c.has_operation()):
                        return True
                return self.yfilter != YFilter.not_set

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "event-syncs" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/counters/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "event-sync"):
                    for c in self.event_sync:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = Rsvp.Counters.EventSyncs.EventSync()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.event_sync.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "event-sync"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                pass

        def has_data(self):
            return (
                (self.database is not None and self.database.has_data()) or
                (self.event_syncs is not None and self.event_syncs.has_data()) or
                (self.interface_events is not None and self.interface_events.has_data()) or
                (self.interface_messages is not None and self.interface_messages.has_data()) or
                (self.issu is not None and self.issu.has_data()) or
                (self.message_summary is not None and self.message_summary.has_data()) or
                (self.nsr is not None and self.nsr.has_data()) or
                (self.out_of_resource is not None and self.out_of_resource.has_data()) or
                (self.prefix_filtering is not None and self.prefix_filtering.has_data()))

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.database is not None and self.database.has_operation()) or
                (self.event_syncs is not None and self.event_syncs.has_operation()) or
                (self.interface_events is not None and self.interface_events.has_operation()) or
                (self.interface_messages is not None and self.interface_messages.has_operation()) or
                (self.issu is not None and self.issu.has_operation()) or
                (self.message_summary is not None and self.message_summary.has_operation()) or
                (self.nsr is not None and self.nsr.has_operation()) or
                (self.out_of_resource is not None and self.out_of_resource.has_operation()) or
                (self.prefix_filtering is not None and self.prefix_filtering.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "counters" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "database"):
                if (self.database is None):
                    self.database = Rsvp.Counters.Database()
                    self.database.parent = self
                    self._children_name_map["database"] = "database"
                return self.database

            if (child_yang_name == "event-syncs"):
                if (self.event_syncs is None):
                    self.event_syncs = Rsvp.Counters.EventSyncs()
                    self.event_syncs.parent = self
                    self._children_name_map["event_syncs"] = "event-syncs"
                return self.event_syncs

            if (child_yang_name == "interface-events"):
                if (self.interface_events is None):
                    self.interface_events = Rsvp.Counters.InterfaceEvents()
                    self.interface_events.parent = self
                    self._children_name_map["interface_events"] = "interface-events"
                return self.interface_events

            if (child_yang_name == "interface-messages"):
                if (self.interface_messages is None):
                    self.interface_messages = Rsvp.Counters.InterfaceMessages()
                    self.interface_messages.parent = self
                    self._children_name_map["interface_messages"] = "interface-messages"
                return self.interface_messages

            if (child_yang_name == "issu"):
                if (self.issu is None):
                    self.issu = Rsvp.Counters.Issu()
                    self.issu.parent = self
                    self._children_name_map["issu"] = "issu"
                return self.issu

            if (child_yang_name == "message-summary"):
                if (self.message_summary is None):
                    self.message_summary = Rsvp.Counters.MessageSummary()
                    self.message_summary.parent = self
                    self._children_name_map["message_summary"] = "message-summary"
                return self.message_summary

            if (child_yang_name == "nsr"):
                if (self.nsr is None):
                    self.nsr = Rsvp.Counters.Nsr()
                    self.nsr.parent = self
                    self._children_name_map["nsr"] = "nsr"
                return self.nsr

            if (child_yang_name == "out-of-resource"):
                if (self.out_of_resource is None):
                    self.out_of_resource = Rsvp.Counters.OutOfResource()
                    self.out_of_resource.parent = self
                    self._children_name_map["out_of_resource"] = "out-of-resource"
                return self.out_of_resource

            if (child_yang_name == "prefix-filtering"):
                if (self.prefix_filtering is None):
                    self.prefix_filtering = Rsvp.Counters.PrefixFiltering()
                    self.prefix_filtering.parent = self
                    self._children_name_map["prefix_filtering"] = "prefix-filtering"
                return self.prefix_filtering

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "database" or name == "event-syncs" or name == "interface-events" or name == "interface-messages" or name == "issu" or name == "message-summary" or name == "nsr" or name == "out-of-resource" or name == "prefix-filtering"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class InterfaceDetaileds(Entity):
        """
        Table of detailed info about RSVP\-enabled
        interfaces
        
        .. attribute:: interface_detailed
        
        	Detailed info about an RSVP\-enabled interface
        	**type**\: list of    :py:class:`InterfaceDetailed <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.InterfaceDetaileds.InterfaceDetailed>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Rsvp.InterfaceDetaileds, self).__init__()

            self.yang_name = "interface-detaileds"
            self.yang_parent_name = "rsvp"

            self.interface_detailed = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(Rsvp.InterfaceDetaileds, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(Rsvp.InterfaceDetaileds, self).__setattr__(name, value)


        class InterfaceDetailed(Entity):
            """
            Detailed info about an RSVP\-enabled interface
            
            .. attribute:: interface_name  <key>
            
            	Interface Name
            	**type**\:  str
            
            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
            
            .. attribute:: ack_hold_time
            
            	ACK hold time in msec
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: ack_max_size
            
            	Max size for ACK message
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: bandwidth_information
            
            	Interface bandwidth information
            	**type**\:   :py:class:`BandwidthInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.InterfaceDetaileds.InterfaceDetailed.BandwidthInformation>`
            
            .. attribute:: bundle_message_max_size
            
            	Max size in bytes of a single Bundle message
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            	**units**\: byte
            
            .. attribute:: expiry_drops_tolerated
            
            	Number of missed messages tolerated
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: expiry_interval
            
            	Expiry interval in msecs
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            	**units**\: millisecond
            
            .. attribute:: expiry_states
            
            	Number of states for expiry check
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: expiry_timer_state
            
            	Expiry timer state
            	**type**\:   :py:class:`RsvpTimerState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpTimerState>`
            
            .. attribute:: flags
            
            	Interface flags
            	**type**\:   :py:class:`Flags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.InterfaceDetaileds.InterfaceDetailed.Flags>`
            
            .. attribute:: integrity_receive_password
            
            	Integrity receive password
            	**type**\:  str
            
            	**length:** 0..40
            
            .. attribute:: integrity_receive_password_optional
            
            	Integrity recv password optional
            	**type**\:  int
            
            	**range:** 0..255
            
            .. attribute:: integrity_send_password
            
            	Integrity send password
            	**type**\:  str
            
            	**length:** 0..40
            
            .. attribute:: interface_name_xr
            
            	Interface Name
            	**type**\:  str
            
            .. attribute:: neighbor_array
            
            	Neighbor array
            	**type**\: list of    :py:class:`NeighborArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.InterfaceDetaileds.InterfaceDetailed.NeighborArray>`
            
            .. attribute:: out_of_band_expiry_drops_tolerated
            
            	Number of out\-of\-band missed messages tolerated
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: out_of_band_refresh_interval
            
            	Out\-of\-band Refresh interval in msecs
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            	**units**\: millisecond
            
            .. attribute:: pacing_interval
            
            	Pacing interval in msecs
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            	**units**\: millisecond
            
            .. attribute:: pacing_message_rate
            
            	No. of messages per interval
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: pacing_messages
            
            	Number of messages deferred for pacing
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: pacing_timer_state
            
            	State of pacing timer
            	**type**\:   :py:class:`RsvpTimerState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpTimerState>`
            
            .. attribute:: refresh_interval
            
            	Refresh interval in msecs
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            	**units**\: millisecond
            
            .. attribute:: refresh_timer_state
            
            	Refresh timer state
            	**type**\:   :py:class:`RsvpTimerState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpTimerState>`
            
            .. attribute:: retransmit_time
            
            	Retransmit time in msec
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: signalling_ip_tos
            
            	IP TOS (precedence/DSCP) to use in signalling messages
            	**type**\:  int
            
            	**range:** 0..255
            
            .. attribute:: summary_refresh_max_size
            
            	Max size in bytes of a single SRefresh
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            	**units**\: byte
            
            .. attribute:: summary_refresh_timer_state
            
            	Summary refresh timer state
            	**type**\:   :py:class:`RsvpTimerState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpTimerState>`
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Rsvp.InterfaceDetaileds.InterfaceDetailed, self).__init__()

                self.yang_name = "interface-detailed"
                self.yang_parent_name = "interface-detaileds"

                self.interface_name = YLeaf(YType.str, "interface-name")

                self.ack_hold_time = YLeaf(YType.uint32, "ack-hold-time")

                self.ack_max_size = YLeaf(YType.uint32, "ack-max-size")

                self.bundle_message_max_size = YLeaf(YType.uint32, "bundle-message-max-size")

                self.expiry_drops_tolerated = YLeaf(YType.int32, "expiry-drops-tolerated")

                self.expiry_interval = YLeaf(YType.int32, "expiry-interval")

                self.expiry_states = YLeaf(YType.int32, "expiry-states")

                self.expiry_timer_state = YLeaf(YType.enumeration, "expiry-timer-state")

                self.integrity_receive_password = YLeaf(YType.str, "integrity-receive-password")

                self.integrity_receive_password_optional = YLeaf(YType.uint8, "integrity-receive-password-optional")

                self.integrity_send_password = YLeaf(YType.str, "integrity-send-password")

                self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                self.out_of_band_expiry_drops_tolerated = YLeaf(YType.uint32, "out-of-band-expiry-drops-tolerated")

                self.out_of_band_refresh_interval = YLeaf(YType.uint32, "out-of-band-refresh-interval")

                self.pacing_interval = YLeaf(YType.uint32, "pacing-interval")

                self.pacing_message_rate = YLeaf(YType.uint32, "pacing-message-rate")

                self.pacing_messages = YLeaf(YType.int32, "pacing-messages")

                self.pacing_timer_state = YLeaf(YType.enumeration, "pacing-timer-state")

                self.refresh_interval = YLeaf(YType.int32, "refresh-interval")

                self.refresh_timer_state = YLeaf(YType.enumeration, "refresh-timer-state")

                self.retransmit_time = YLeaf(YType.uint32, "retransmit-time")

                self.signalling_ip_tos = YLeaf(YType.uint8, "signalling-ip-tos")

                self.summary_refresh_max_size = YLeaf(YType.uint32, "summary-refresh-max-size")

                self.summary_refresh_timer_state = YLeaf(YType.enumeration, "summary-refresh-timer-state")

                self.bandwidth_information = Rsvp.InterfaceDetaileds.InterfaceDetailed.BandwidthInformation()
                self.bandwidth_information.parent = self
                self._children_name_map["bandwidth_information"] = "bandwidth-information"
                self._children_yang_names.add("bandwidth-information")

                self.flags = Rsvp.InterfaceDetaileds.InterfaceDetailed.Flags()
                self.flags.parent = self
                self._children_name_map["flags"] = "flags"
                self._children_yang_names.add("flags")

                self.neighbor_array = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("interface_name",
                                "ack_hold_time",
                                "ack_max_size",
                                "bundle_message_max_size",
                                "expiry_drops_tolerated",
                                "expiry_interval",
                                "expiry_states",
                                "expiry_timer_state",
                                "integrity_receive_password",
                                "integrity_receive_password_optional",
                                "integrity_send_password",
                                "interface_name_xr",
                                "out_of_band_expiry_drops_tolerated",
                                "out_of_band_refresh_interval",
                                "pacing_interval",
                                "pacing_message_rate",
                                "pacing_messages",
                                "pacing_timer_state",
                                "refresh_interval",
                                "refresh_timer_state",
                                "retransmit_time",
                                "signalling_ip_tos",
                                "summary_refresh_max_size",
                                "summary_refresh_timer_state") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Rsvp.InterfaceDetaileds.InterfaceDetailed, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Rsvp.InterfaceDetaileds.InterfaceDetailed, self).__setattr__(name, value)


            class BandwidthInformation(Entity):
                """
                Interface bandwidth information
                
                .. attribute:: dste_mode
                
                	DSTEMode
                	**type**\:   :py:class:`RsvpMgmtDsteModes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtDsteModes>`
                
                .. attribute:: pre_standard_dste_interface
                
                	Prestandard DSTE interface information
                	**type**\:   :py:class:`PreStandardDsteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.InterfaceDetaileds.InterfaceDetailed.BandwidthInformation.PreStandardDsteInterface>`
                
                .. attribute:: standard_dste_interface
                
                	Standard DSTE interface information
                	**type**\:   :py:class:`StandardDsteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.InterfaceDetaileds.InterfaceDetailed.BandwidthInformation.StandardDsteInterface>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.InterfaceDetaileds.InterfaceDetailed.BandwidthInformation, self).__init__()

                    self.yang_name = "bandwidth-information"
                    self.yang_parent_name = "interface-detailed"

                    self.dste_mode = YLeaf(YType.enumeration, "dste-mode")

                    self.pre_standard_dste_interface = Rsvp.InterfaceDetaileds.InterfaceDetailed.BandwidthInformation.PreStandardDsteInterface()
                    self.pre_standard_dste_interface.parent = self
                    self._children_name_map["pre_standard_dste_interface"] = "pre-standard-dste-interface"
                    self._children_yang_names.add("pre-standard-dste-interface")

                    self.standard_dste_interface = Rsvp.InterfaceDetaileds.InterfaceDetailed.BandwidthInformation.StandardDsteInterface()
                    self.standard_dste_interface.parent = self
                    self._children_name_map["standard_dste_interface"] = "standard-dste-interface"
                    self._children_yang_names.add("standard-dste-interface")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("dste_mode") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.InterfaceDetaileds.InterfaceDetailed.BandwidthInformation, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.InterfaceDetaileds.InterfaceDetailed.BandwidthInformation, self).__setattr__(name, value)


                class PreStandardDsteInterface(Entity):
                    """
                    Prestandard DSTE interface information
                    
                    .. attribute:: allocated_bit_rate
                    
                    	Bandwidth (bits per second) now allocated
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: is_max_bandwidth_absolute
                    
                    	True if the Max B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: is_max_subpool_bandwidth_absolute
                    
                    	True if the Max sub\-pool B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: max_bandwidth
                    
                    	Max bandwidth (bits per second) allowed
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_flow_bandwidth
                    
                    	Max bandwidth (bits per second) allowed per flow
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_subpool_bandwidth
                    
                    	Max bandwidth (bits per second) allowed in subpool
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.InterfaceDetaileds.InterfaceDetailed.BandwidthInformation.PreStandardDsteInterface, self).__init__()

                        self.yang_name = "pre-standard-dste-interface"
                        self.yang_parent_name = "bandwidth-information"

                        self.allocated_bit_rate = YLeaf(YType.uint64, "allocated-bit-rate")

                        self.is_max_bandwidth_absolute = YLeaf(YType.boolean, "is-max-bandwidth-absolute")

                        self.is_max_subpool_bandwidth_absolute = YLeaf(YType.boolean, "is-max-subpool-bandwidth-absolute")

                        self.max_bandwidth = YLeaf(YType.uint64, "max-bandwidth")

                        self.max_flow_bandwidth = YLeaf(YType.uint64, "max-flow-bandwidth")

                        self.max_subpool_bandwidth = YLeaf(YType.uint64, "max-subpool-bandwidth")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("allocated_bit_rate",
                                        "is_max_bandwidth_absolute",
                                        "is_max_subpool_bandwidth_absolute",
                                        "max_bandwidth",
                                        "max_flow_bandwidth",
                                        "max_subpool_bandwidth") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.InterfaceDetaileds.InterfaceDetailed.BandwidthInformation.PreStandardDsteInterface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.InterfaceDetaileds.InterfaceDetailed.BandwidthInformation.PreStandardDsteInterface, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.allocated_bit_rate.is_set or
                            self.is_max_bandwidth_absolute.is_set or
                            self.is_max_subpool_bandwidth_absolute.is_set or
                            self.max_bandwidth.is_set or
                            self.max_flow_bandwidth.is_set or
                            self.max_subpool_bandwidth.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.allocated_bit_rate.yfilter != YFilter.not_set or
                            self.is_max_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.is_max_subpool_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.max_bandwidth.yfilter != YFilter.not_set or
                            self.max_flow_bandwidth.yfilter != YFilter.not_set or
                            self.max_subpool_bandwidth.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "pre-standard-dste-interface" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.allocated_bit_rate.is_set or self.allocated_bit_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.allocated_bit_rate.get_name_leafdata())
                        if (self.is_max_bandwidth_absolute.is_set or self.is_max_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_bandwidth_absolute.get_name_leafdata())
                        if (self.is_max_subpool_bandwidth_absolute.is_set or self.is_max_subpool_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_subpool_bandwidth_absolute.get_name_leafdata())
                        if (self.max_bandwidth.is_set or self.max_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_bandwidth.get_name_leafdata())
                        if (self.max_flow_bandwidth.is_set or self.max_flow_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_flow_bandwidth.get_name_leafdata())
                        if (self.max_subpool_bandwidth.is_set or self.max_subpool_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_subpool_bandwidth.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "allocated-bit-rate" or name == "is-max-bandwidth-absolute" or name == "is-max-subpool-bandwidth-absolute" or name == "max-bandwidth" or name == "max-flow-bandwidth" or name == "max-subpool-bandwidth"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "allocated-bit-rate"):
                            self.allocated_bit_rate = value
                            self.allocated_bit_rate.value_namespace = name_space
                            self.allocated_bit_rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-bandwidth-absolute"):
                            self.is_max_bandwidth_absolute = value
                            self.is_max_bandwidth_absolute.value_namespace = name_space
                            self.is_max_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-subpool-bandwidth-absolute"):
                            self.is_max_subpool_bandwidth_absolute = value
                            self.is_max_subpool_bandwidth_absolute.value_namespace = name_space
                            self.is_max_subpool_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-bandwidth"):
                            self.max_bandwidth = value
                            self.max_bandwidth.value_namespace = name_space
                            self.max_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-flow-bandwidth"):
                            self.max_flow_bandwidth = value
                            self.max_flow_bandwidth.value_namespace = name_space
                            self.max_flow_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-subpool-bandwidth"):
                            self.max_subpool_bandwidth = value
                            self.max_subpool_bandwidth.value_namespace = name_space
                            self.max_subpool_bandwidth.value_namespace_prefix = name_space_prefix


                class StandardDsteInterface(Entity):
                    """
                    Standard DSTE interface information
                    
                    .. attribute:: allocated_bit_rate
                    
                    	Bandwidth (bits per second) now allocated
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: is_max_bandwidth_absolute
                    
                    	True if the Max B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: is_max_bc0_bandwidth_absolute
                    
                    	True if the Max BC0 B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: is_max_bc1_bandwidth_absolute
                    
                    	True if the Max BC1 sub\-pool B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: max_bandwidth
                    
                    	Max bandwidth (bits per second) allowed
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_flow_bandwidth
                    
                    	Max bandwidth (bits per second) allowed per flow
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_pool0_bandwidth
                    
                    	Max bandwidth (bits per second) allowed in BC0 pool
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_pool1_bandwidth
                    
                    	Max bandwidth (bits per second) allowed in BC1 pool
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.InterfaceDetaileds.InterfaceDetailed.BandwidthInformation.StandardDsteInterface, self).__init__()

                        self.yang_name = "standard-dste-interface"
                        self.yang_parent_name = "bandwidth-information"

                        self.allocated_bit_rate = YLeaf(YType.uint64, "allocated-bit-rate")

                        self.is_max_bandwidth_absolute = YLeaf(YType.boolean, "is-max-bandwidth-absolute")

                        self.is_max_bc0_bandwidth_absolute = YLeaf(YType.boolean, "is-max-bc0-bandwidth-absolute")

                        self.is_max_bc1_bandwidth_absolute = YLeaf(YType.boolean, "is-max-bc1-bandwidth-absolute")

                        self.max_bandwidth = YLeaf(YType.uint64, "max-bandwidth")

                        self.max_flow_bandwidth = YLeaf(YType.uint64, "max-flow-bandwidth")

                        self.max_pool0_bandwidth = YLeaf(YType.uint64, "max-pool0-bandwidth")

                        self.max_pool1_bandwidth = YLeaf(YType.uint64, "max-pool1-bandwidth")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("allocated_bit_rate",
                                        "is_max_bandwidth_absolute",
                                        "is_max_bc0_bandwidth_absolute",
                                        "is_max_bc1_bandwidth_absolute",
                                        "max_bandwidth",
                                        "max_flow_bandwidth",
                                        "max_pool0_bandwidth",
                                        "max_pool1_bandwidth") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.InterfaceDetaileds.InterfaceDetailed.BandwidthInformation.StandardDsteInterface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.InterfaceDetaileds.InterfaceDetailed.BandwidthInformation.StandardDsteInterface, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.allocated_bit_rate.is_set or
                            self.is_max_bandwidth_absolute.is_set or
                            self.is_max_bc0_bandwidth_absolute.is_set or
                            self.is_max_bc1_bandwidth_absolute.is_set or
                            self.max_bandwidth.is_set or
                            self.max_flow_bandwidth.is_set or
                            self.max_pool0_bandwidth.is_set or
                            self.max_pool1_bandwidth.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.allocated_bit_rate.yfilter != YFilter.not_set or
                            self.is_max_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.is_max_bc0_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.is_max_bc1_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.max_bandwidth.yfilter != YFilter.not_set or
                            self.max_flow_bandwidth.yfilter != YFilter.not_set or
                            self.max_pool0_bandwidth.yfilter != YFilter.not_set or
                            self.max_pool1_bandwidth.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "standard-dste-interface" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.allocated_bit_rate.is_set or self.allocated_bit_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.allocated_bit_rate.get_name_leafdata())
                        if (self.is_max_bandwidth_absolute.is_set or self.is_max_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_bandwidth_absolute.get_name_leafdata())
                        if (self.is_max_bc0_bandwidth_absolute.is_set or self.is_max_bc0_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_bc0_bandwidth_absolute.get_name_leafdata())
                        if (self.is_max_bc1_bandwidth_absolute.is_set or self.is_max_bc1_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_bc1_bandwidth_absolute.get_name_leafdata())
                        if (self.max_bandwidth.is_set or self.max_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_bandwidth.get_name_leafdata())
                        if (self.max_flow_bandwidth.is_set or self.max_flow_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_flow_bandwidth.get_name_leafdata())
                        if (self.max_pool0_bandwidth.is_set or self.max_pool0_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_pool0_bandwidth.get_name_leafdata())
                        if (self.max_pool1_bandwidth.is_set or self.max_pool1_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_pool1_bandwidth.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "allocated-bit-rate" or name == "is-max-bandwidth-absolute" or name == "is-max-bc0-bandwidth-absolute" or name == "is-max-bc1-bandwidth-absolute" or name == "max-bandwidth" or name == "max-flow-bandwidth" or name == "max-pool0-bandwidth" or name == "max-pool1-bandwidth"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "allocated-bit-rate"):
                            self.allocated_bit_rate = value
                            self.allocated_bit_rate.value_namespace = name_space
                            self.allocated_bit_rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-bandwidth-absolute"):
                            self.is_max_bandwidth_absolute = value
                            self.is_max_bandwidth_absolute.value_namespace = name_space
                            self.is_max_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-bc0-bandwidth-absolute"):
                            self.is_max_bc0_bandwidth_absolute = value
                            self.is_max_bc0_bandwidth_absolute.value_namespace = name_space
                            self.is_max_bc0_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-bc1-bandwidth-absolute"):
                            self.is_max_bc1_bandwidth_absolute = value
                            self.is_max_bc1_bandwidth_absolute.value_namespace = name_space
                            self.is_max_bc1_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-bandwidth"):
                            self.max_bandwidth = value
                            self.max_bandwidth.value_namespace = name_space
                            self.max_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-flow-bandwidth"):
                            self.max_flow_bandwidth = value
                            self.max_flow_bandwidth.value_namespace = name_space
                            self.max_flow_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-pool0-bandwidth"):
                            self.max_pool0_bandwidth = value
                            self.max_pool0_bandwidth.value_namespace = name_space
                            self.max_pool0_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-pool1-bandwidth"):
                            self.max_pool1_bandwidth = value
                            self.max_pool1_bandwidth.value_namespace = name_space
                            self.max_pool1_bandwidth.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.dste_mode.is_set or
                        (self.pre_standard_dste_interface is not None and self.pre_standard_dste_interface.has_data()) or
                        (self.standard_dste_interface is not None and self.standard_dste_interface.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.dste_mode.yfilter != YFilter.not_set or
                        (self.pre_standard_dste_interface is not None and self.pre_standard_dste_interface.has_operation()) or
                        (self.standard_dste_interface is not None and self.standard_dste_interface.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bandwidth-information" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.dste_mode.is_set or self.dste_mode.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.dste_mode.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "pre-standard-dste-interface"):
                        if (self.pre_standard_dste_interface is None):
                            self.pre_standard_dste_interface = Rsvp.InterfaceDetaileds.InterfaceDetailed.BandwidthInformation.PreStandardDsteInterface()
                            self.pre_standard_dste_interface.parent = self
                            self._children_name_map["pre_standard_dste_interface"] = "pre-standard-dste-interface"
                        return self.pre_standard_dste_interface

                    if (child_yang_name == "standard-dste-interface"):
                        if (self.standard_dste_interface is None):
                            self.standard_dste_interface = Rsvp.InterfaceDetaileds.InterfaceDetailed.BandwidthInformation.StandardDsteInterface()
                            self.standard_dste_interface.parent = self
                            self._children_name_map["standard_dste_interface"] = "standard-dste-interface"
                        return self.standard_dste_interface

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "pre-standard-dste-interface" or name == "standard-dste-interface" or name == "dste-mode"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "dste-mode"):
                        self.dste_mode = value
                        self.dste_mode.value_namespace = name_space
                        self.dste_mode.value_namespace_prefix = name_space_prefix


            class Flags(Entity):
                """
                Interface flags
                
                .. attribute:: is_backup_tunnel
                
                	This is backup tunnel
                	**type**\:  bool
                
                .. attribute:: is_interface_created
                
                	Interface is created
                	**type**\:  bool
                
                .. attribute:: is_interface_down
                
                	Interface is DOWN
                	**type**\:  bool
                
                .. attribute:: is_message_bundling_enabled
                
                	Use bundling for outgoing RSVP messages
                	**type**\:  bool
                
                .. attribute:: is_mpls_enabled
                
                	MPLS enabled on interface
                	**type**\:  bool
                
                .. attribute:: is_non_default_vrf
                
                	Interface is defined in non\-Default VRF
                	**type**\:  bool
                
                .. attribute:: is_pacing_enabled
                
                	Message pacing enabled
                	**type**\:  bool
                
                .. attribute:: is_refresh_enabled
                
                	Refresh enabled
                	**type**\:  bool
                
                .. attribute:: is_refresh_reduction_enabled
                
                	Refresh Reduction enabled
                	**type**\:  bool
                
                .. attribute:: is_rel_s_refresh_enabled
                
                	Use reliable xmt for SRefresh
                	**type**\:  bool
                
                .. attribute:: is_rsvp_configured
                
                	RSVP explicitly configured
                	**type**\:  bool
                
                .. attribute:: is_s_refresh_enabled
                
                	Summary Refresh enabled
                	**type**\:  bool
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.InterfaceDetaileds.InterfaceDetailed.Flags, self).__init__()

                    self.yang_name = "flags"
                    self.yang_parent_name = "interface-detailed"

                    self.is_backup_tunnel = YLeaf(YType.boolean, "is-backup-tunnel")

                    self.is_interface_created = YLeaf(YType.boolean, "is-interface-created")

                    self.is_interface_down = YLeaf(YType.boolean, "is-interface-down")

                    self.is_message_bundling_enabled = YLeaf(YType.boolean, "is-message-bundling-enabled")

                    self.is_mpls_enabled = YLeaf(YType.boolean, "is-mpls-enabled")

                    self.is_non_default_vrf = YLeaf(YType.boolean, "is-non-default-vrf")

                    self.is_pacing_enabled = YLeaf(YType.boolean, "is-pacing-enabled")

                    self.is_refresh_enabled = YLeaf(YType.boolean, "is-refresh-enabled")

                    self.is_refresh_reduction_enabled = YLeaf(YType.boolean, "is-refresh-reduction-enabled")

                    self.is_rel_s_refresh_enabled = YLeaf(YType.boolean, "is-rel-s-refresh-enabled")

                    self.is_rsvp_configured = YLeaf(YType.boolean, "is-rsvp-configured")

                    self.is_s_refresh_enabled = YLeaf(YType.boolean, "is-s-refresh-enabled")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("is_backup_tunnel",
                                    "is_interface_created",
                                    "is_interface_down",
                                    "is_message_bundling_enabled",
                                    "is_mpls_enabled",
                                    "is_non_default_vrf",
                                    "is_pacing_enabled",
                                    "is_refresh_enabled",
                                    "is_refresh_reduction_enabled",
                                    "is_rel_s_refresh_enabled",
                                    "is_rsvp_configured",
                                    "is_s_refresh_enabled") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.InterfaceDetaileds.InterfaceDetailed.Flags, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.InterfaceDetaileds.InterfaceDetailed.Flags, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.is_backup_tunnel.is_set or
                        self.is_interface_created.is_set or
                        self.is_interface_down.is_set or
                        self.is_message_bundling_enabled.is_set or
                        self.is_mpls_enabled.is_set or
                        self.is_non_default_vrf.is_set or
                        self.is_pacing_enabled.is_set or
                        self.is_refresh_enabled.is_set or
                        self.is_refresh_reduction_enabled.is_set or
                        self.is_rel_s_refresh_enabled.is_set or
                        self.is_rsvp_configured.is_set or
                        self.is_s_refresh_enabled.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.is_backup_tunnel.yfilter != YFilter.not_set or
                        self.is_interface_created.yfilter != YFilter.not_set or
                        self.is_interface_down.yfilter != YFilter.not_set or
                        self.is_message_bundling_enabled.yfilter != YFilter.not_set or
                        self.is_mpls_enabled.yfilter != YFilter.not_set or
                        self.is_non_default_vrf.yfilter != YFilter.not_set or
                        self.is_pacing_enabled.yfilter != YFilter.not_set or
                        self.is_refresh_enabled.yfilter != YFilter.not_set or
                        self.is_refresh_reduction_enabled.yfilter != YFilter.not_set or
                        self.is_rel_s_refresh_enabled.yfilter != YFilter.not_set or
                        self.is_rsvp_configured.yfilter != YFilter.not_set or
                        self.is_s_refresh_enabled.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "flags" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.is_backup_tunnel.is_set or self.is_backup_tunnel.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_backup_tunnel.get_name_leafdata())
                    if (self.is_interface_created.is_set or self.is_interface_created.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_interface_created.get_name_leafdata())
                    if (self.is_interface_down.is_set or self.is_interface_down.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_interface_down.get_name_leafdata())
                    if (self.is_message_bundling_enabled.is_set or self.is_message_bundling_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_message_bundling_enabled.get_name_leafdata())
                    if (self.is_mpls_enabled.is_set or self.is_mpls_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_mpls_enabled.get_name_leafdata())
                    if (self.is_non_default_vrf.is_set or self.is_non_default_vrf.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_non_default_vrf.get_name_leafdata())
                    if (self.is_pacing_enabled.is_set or self.is_pacing_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_pacing_enabled.get_name_leafdata())
                    if (self.is_refresh_enabled.is_set or self.is_refresh_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_refresh_enabled.get_name_leafdata())
                    if (self.is_refresh_reduction_enabled.is_set or self.is_refresh_reduction_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_refresh_reduction_enabled.get_name_leafdata())
                    if (self.is_rel_s_refresh_enabled.is_set or self.is_rel_s_refresh_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_rel_s_refresh_enabled.get_name_leafdata())
                    if (self.is_rsvp_configured.is_set or self.is_rsvp_configured.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_rsvp_configured.get_name_leafdata())
                    if (self.is_s_refresh_enabled.is_set or self.is_s_refresh_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_s_refresh_enabled.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "is-backup-tunnel" or name == "is-interface-created" or name == "is-interface-down" or name == "is-message-bundling-enabled" or name == "is-mpls-enabled" or name == "is-non-default-vrf" or name == "is-pacing-enabled" or name == "is-refresh-enabled" or name == "is-refresh-reduction-enabled" or name == "is-rel-s-refresh-enabled" or name == "is-rsvp-configured" or name == "is-s-refresh-enabled"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "is-backup-tunnel"):
                        self.is_backup_tunnel = value
                        self.is_backup_tunnel.value_namespace = name_space
                        self.is_backup_tunnel.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-interface-created"):
                        self.is_interface_created = value
                        self.is_interface_created.value_namespace = name_space
                        self.is_interface_created.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-interface-down"):
                        self.is_interface_down = value
                        self.is_interface_down.value_namespace = name_space
                        self.is_interface_down.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-message-bundling-enabled"):
                        self.is_message_bundling_enabled = value
                        self.is_message_bundling_enabled.value_namespace = name_space
                        self.is_message_bundling_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-mpls-enabled"):
                        self.is_mpls_enabled = value
                        self.is_mpls_enabled.value_namespace = name_space
                        self.is_mpls_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-non-default-vrf"):
                        self.is_non_default_vrf = value
                        self.is_non_default_vrf.value_namespace = name_space
                        self.is_non_default_vrf.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-pacing-enabled"):
                        self.is_pacing_enabled = value
                        self.is_pacing_enabled.value_namespace = name_space
                        self.is_pacing_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-refresh-enabled"):
                        self.is_refresh_enabled = value
                        self.is_refresh_enabled.value_namespace = name_space
                        self.is_refresh_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-refresh-reduction-enabled"):
                        self.is_refresh_reduction_enabled = value
                        self.is_refresh_reduction_enabled.value_namespace = name_space
                        self.is_refresh_reduction_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-rel-s-refresh-enabled"):
                        self.is_rel_s_refresh_enabled = value
                        self.is_rel_s_refresh_enabled.value_namespace = name_space
                        self.is_rel_s_refresh_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-rsvp-configured"):
                        self.is_rsvp_configured = value
                        self.is_rsvp_configured.value_namespace = name_space
                        self.is_rsvp_configured.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-s-refresh-enabled"):
                        self.is_s_refresh_enabled = value
                        self.is_s_refresh_enabled.value_namespace = name_space
                        self.is_s_refresh_enabled.value_namespace_prefix = name_space_prefix


            class NeighborArray(Entity):
                """
                Neighbor array
                
                .. attribute:: expiry_time
                
                	Expiry time
                	**type**\:   :py:class:`ExpiryTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.InterfaceDetaileds.InterfaceDetailed.NeighborArray.ExpiryTime>`
                
                .. attribute:: is_neighbor_refresh_reduction_capable
                
                	Is neighbor capable of Refresh Reduction
                	**type**\:  bool
                
                .. attribute:: message_ids
                
                	Number of MessageIDs
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: neighbor_address
                
                	IP address of the neighbor
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: neighbor_message_id
                
                	List of Neighbor MessageIDs
                	**type**\: list of    :py:class:`NeighborMessageId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.InterfaceDetaileds.InterfaceDetailed.NeighborArray.NeighborMessageId>`
                
                .. attribute:: outgoing_states
                
                	Number of outgoing states to the neighbour
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.InterfaceDetaileds.InterfaceDetailed.NeighborArray, self).__init__()

                    self.yang_name = "neighbor-array"
                    self.yang_parent_name = "interface-detailed"

                    self.is_neighbor_refresh_reduction_capable = YLeaf(YType.boolean, "is-neighbor-refresh-reduction-capable")

                    self.message_ids = YLeaf(YType.uint32, "message-ids")

                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                    self.outgoing_states = YLeaf(YType.int32, "outgoing-states")

                    self.expiry_time = Rsvp.InterfaceDetaileds.InterfaceDetailed.NeighborArray.ExpiryTime()
                    self.expiry_time.parent = self
                    self._children_name_map["expiry_time"] = "expiry-time"
                    self._children_yang_names.add("expiry-time")

                    self.neighbor_message_id = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("is_neighbor_refresh_reduction_capable",
                                    "message_ids",
                                    "neighbor_address",
                                    "outgoing_states") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.InterfaceDetaileds.InterfaceDetailed.NeighborArray, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.InterfaceDetaileds.InterfaceDetailed.NeighborArray, self).__setattr__(name, value)


                class ExpiryTime(Entity):
                    """
                    Expiry time
                    
                    .. attribute:: nanoseconds
                    
                    	Time Value in Nano\-seconds
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: nanosecond
                    
                    .. attribute:: seconds
                    
                    	Time Value in Seconds
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.InterfaceDetaileds.InterfaceDetailed.NeighborArray.ExpiryTime, self).__init__()

                        self.yang_name = "expiry-time"
                        self.yang_parent_name = "neighbor-array"

                        self.nanoseconds = YLeaf(YType.int32, "nanoseconds")

                        self.seconds = YLeaf(YType.int32, "seconds")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("nanoseconds",
                                        "seconds") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.InterfaceDetaileds.InterfaceDetailed.NeighborArray.ExpiryTime, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.InterfaceDetaileds.InterfaceDetailed.NeighborArray.ExpiryTime, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.nanoseconds.is_set or
                            self.seconds.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.nanoseconds.yfilter != YFilter.not_set or
                            self.seconds.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "expiry-time" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.nanoseconds.is_set or self.nanoseconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.nanoseconds.get_name_leafdata())
                        if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.seconds.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "nanoseconds" or name == "seconds"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "nanoseconds"):
                            self.nanoseconds = value
                            self.nanoseconds.value_namespace = name_space
                            self.nanoseconds.value_namespace_prefix = name_space_prefix
                        if(value_path == "seconds"):
                            self.seconds = value
                            self.seconds.value_namespace = name_space
                            self.seconds.value_namespace_prefix = name_space_prefix


                class NeighborMessageId(Entity):
                    """
                    List of Neighbor MessageIDs
                    
                    .. attribute:: message_id
                    
                    	Message ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.InterfaceDetaileds.InterfaceDetailed.NeighborArray.NeighborMessageId, self).__init__()

                        self.yang_name = "neighbor-message-id"
                        self.yang_parent_name = "neighbor-array"

                        self.message_id = YLeaf(YType.uint32, "message-id")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("message_id") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.InterfaceDetaileds.InterfaceDetailed.NeighborArray.NeighborMessageId, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.InterfaceDetaileds.InterfaceDetailed.NeighborArray.NeighborMessageId, self).__setattr__(name, value)

                    def has_data(self):
                        return self.message_id.is_set

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.message_id.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "neighbor-message-id" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.message_id.is_set or self.message_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.message_id.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "message-id"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "message-id"):
                            self.message_id = value
                            self.message_id.value_namespace = name_space
                            self.message_id.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.neighbor_message_id:
                        if (c.has_data()):
                            return True
                    return (
                        self.is_neighbor_refresh_reduction_capable.is_set or
                        self.message_ids.is_set or
                        self.neighbor_address.is_set or
                        self.outgoing_states.is_set or
                        (self.expiry_time is not None and self.expiry_time.has_data()))

                def has_operation(self):
                    for c in self.neighbor_message_id:
                        if (c.has_operation()):
                            return True
                    return (
                        self.yfilter != YFilter.not_set or
                        self.is_neighbor_refresh_reduction_capable.yfilter != YFilter.not_set or
                        self.message_ids.yfilter != YFilter.not_set or
                        self.neighbor_address.yfilter != YFilter.not_set or
                        self.outgoing_states.yfilter != YFilter.not_set or
                        (self.expiry_time is not None and self.expiry_time.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "neighbor-array" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.is_neighbor_refresh_reduction_capable.is_set or self.is_neighbor_refresh_reduction_capable.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_neighbor_refresh_reduction_capable.get_name_leafdata())
                    if (self.message_ids.is_set or self.message_ids.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.message_ids.get_name_leafdata())
                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                    if (self.outgoing_states.is_set or self.outgoing_states.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.outgoing_states.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "expiry-time"):
                        if (self.expiry_time is None):
                            self.expiry_time = Rsvp.InterfaceDetaileds.InterfaceDetailed.NeighborArray.ExpiryTime()
                            self.expiry_time.parent = self
                            self._children_name_map["expiry_time"] = "expiry-time"
                        return self.expiry_time

                    if (child_yang_name == "neighbor-message-id"):
                        for c in self.neighbor_message_id:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Rsvp.InterfaceDetaileds.InterfaceDetailed.NeighborArray.NeighborMessageId()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.neighbor_message_id.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "expiry-time" or name == "neighbor-message-id" or name == "is-neighbor-refresh-reduction-capable" or name == "message-ids" or name == "neighbor-address" or name == "outgoing-states"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "is-neighbor-refresh-reduction-capable"):
                        self.is_neighbor_refresh_reduction_capable = value
                        self.is_neighbor_refresh_reduction_capable.value_namespace = name_space
                        self.is_neighbor_refresh_reduction_capable.value_namespace_prefix = name_space_prefix
                    if(value_path == "message-ids"):
                        self.message_ids = value
                        self.message_ids.value_namespace = name_space
                        self.message_ids.value_namespace_prefix = name_space_prefix
                    if(value_path == "neighbor-address"):
                        self.neighbor_address = value
                        self.neighbor_address.value_namespace = name_space
                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "outgoing-states"):
                        self.outgoing_states = value
                        self.outgoing_states.value_namespace = name_space
                        self.outgoing_states.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.neighbor_array:
                    if (c.has_data()):
                        return True
                return (
                    self.interface_name.is_set or
                    self.ack_hold_time.is_set or
                    self.ack_max_size.is_set or
                    self.bundle_message_max_size.is_set or
                    self.expiry_drops_tolerated.is_set or
                    self.expiry_interval.is_set or
                    self.expiry_states.is_set or
                    self.expiry_timer_state.is_set or
                    self.integrity_receive_password.is_set or
                    self.integrity_receive_password_optional.is_set or
                    self.integrity_send_password.is_set or
                    self.interface_name_xr.is_set or
                    self.out_of_band_expiry_drops_tolerated.is_set or
                    self.out_of_band_refresh_interval.is_set or
                    self.pacing_interval.is_set or
                    self.pacing_message_rate.is_set or
                    self.pacing_messages.is_set or
                    self.pacing_timer_state.is_set or
                    self.refresh_interval.is_set or
                    self.refresh_timer_state.is_set or
                    self.retransmit_time.is_set or
                    self.signalling_ip_tos.is_set or
                    self.summary_refresh_max_size.is_set or
                    self.summary_refresh_timer_state.is_set or
                    (self.bandwidth_information is not None and self.bandwidth_information.has_data()) or
                    (self.flags is not None and self.flags.has_data()))

            def has_operation(self):
                for c in self.neighbor_array:
                    if (c.has_operation()):
                        return True
                return (
                    self.yfilter != YFilter.not_set or
                    self.interface_name.yfilter != YFilter.not_set or
                    self.ack_hold_time.yfilter != YFilter.not_set or
                    self.ack_max_size.yfilter != YFilter.not_set or
                    self.bundle_message_max_size.yfilter != YFilter.not_set or
                    self.expiry_drops_tolerated.yfilter != YFilter.not_set or
                    self.expiry_interval.yfilter != YFilter.not_set or
                    self.expiry_states.yfilter != YFilter.not_set or
                    self.expiry_timer_state.yfilter != YFilter.not_set or
                    self.integrity_receive_password.yfilter != YFilter.not_set or
                    self.integrity_receive_password_optional.yfilter != YFilter.not_set or
                    self.integrity_send_password.yfilter != YFilter.not_set or
                    self.interface_name_xr.yfilter != YFilter.not_set or
                    self.out_of_band_expiry_drops_tolerated.yfilter != YFilter.not_set or
                    self.out_of_band_refresh_interval.yfilter != YFilter.not_set or
                    self.pacing_interval.yfilter != YFilter.not_set or
                    self.pacing_message_rate.yfilter != YFilter.not_set or
                    self.pacing_messages.yfilter != YFilter.not_set or
                    self.pacing_timer_state.yfilter != YFilter.not_set or
                    self.refresh_interval.yfilter != YFilter.not_set or
                    self.refresh_timer_state.yfilter != YFilter.not_set or
                    self.retransmit_time.yfilter != YFilter.not_set or
                    self.signalling_ip_tos.yfilter != YFilter.not_set or
                    self.summary_refresh_max_size.yfilter != YFilter.not_set or
                    self.summary_refresh_timer_state.yfilter != YFilter.not_set or
                    (self.bandwidth_information is not None and self.bandwidth_information.has_operation()) or
                    (self.flags is not None and self.flags.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "interface-detailed" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/interface-detaileds/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                if (self.ack_hold_time.is_set or self.ack_hold_time.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.ack_hold_time.get_name_leafdata())
                if (self.ack_max_size.is_set or self.ack_max_size.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.ack_max_size.get_name_leafdata())
                if (self.bundle_message_max_size.is_set or self.bundle_message_max_size.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.bundle_message_max_size.get_name_leafdata())
                if (self.expiry_drops_tolerated.is_set or self.expiry_drops_tolerated.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.expiry_drops_tolerated.get_name_leafdata())
                if (self.expiry_interval.is_set or self.expiry_interval.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.expiry_interval.get_name_leafdata())
                if (self.expiry_states.is_set or self.expiry_states.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.expiry_states.get_name_leafdata())
                if (self.expiry_timer_state.is_set or self.expiry_timer_state.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.expiry_timer_state.get_name_leafdata())
                if (self.integrity_receive_password.is_set or self.integrity_receive_password.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.integrity_receive_password.get_name_leafdata())
                if (self.integrity_receive_password_optional.is_set or self.integrity_receive_password_optional.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.integrity_receive_password_optional.get_name_leafdata())
                if (self.integrity_send_password.is_set or self.integrity_send_password.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.integrity_send_password.get_name_leafdata())
                if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.interface_name_xr.get_name_leafdata())
                if (self.out_of_band_expiry_drops_tolerated.is_set or self.out_of_band_expiry_drops_tolerated.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.out_of_band_expiry_drops_tolerated.get_name_leafdata())
                if (self.out_of_band_refresh_interval.is_set or self.out_of_band_refresh_interval.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.out_of_band_refresh_interval.get_name_leafdata())
                if (self.pacing_interval.is_set or self.pacing_interval.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.pacing_interval.get_name_leafdata())
                if (self.pacing_message_rate.is_set or self.pacing_message_rate.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.pacing_message_rate.get_name_leafdata())
                if (self.pacing_messages.is_set or self.pacing_messages.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.pacing_messages.get_name_leafdata())
                if (self.pacing_timer_state.is_set or self.pacing_timer_state.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.pacing_timer_state.get_name_leafdata())
                if (self.refresh_interval.is_set or self.refresh_interval.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.refresh_interval.get_name_leafdata())
                if (self.refresh_timer_state.is_set or self.refresh_timer_state.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.refresh_timer_state.get_name_leafdata())
                if (self.retransmit_time.is_set or self.retransmit_time.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.retransmit_time.get_name_leafdata())
                if (self.signalling_ip_tos.is_set or self.signalling_ip_tos.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.signalling_ip_tos.get_name_leafdata())
                if (self.summary_refresh_max_size.is_set or self.summary_refresh_max_size.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.summary_refresh_max_size.get_name_leafdata())
                if (self.summary_refresh_timer_state.is_set or self.summary_refresh_timer_state.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.summary_refresh_timer_state.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "bandwidth-information"):
                    if (self.bandwidth_information is None):
                        self.bandwidth_information = Rsvp.InterfaceDetaileds.InterfaceDetailed.BandwidthInformation()
                        self.bandwidth_information.parent = self
                        self._children_name_map["bandwidth_information"] = "bandwidth-information"
                    return self.bandwidth_information

                if (child_yang_name == "flags"):
                    if (self.flags is None):
                        self.flags = Rsvp.InterfaceDetaileds.InterfaceDetailed.Flags()
                        self.flags.parent = self
                        self._children_name_map["flags"] = "flags"
                    return self.flags

                if (child_yang_name == "neighbor-array"):
                    for c in self.neighbor_array:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = Rsvp.InterfaceDetaileds.InterfaceDetailed.NeighborArray()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.neighbor_array.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "bandwidth-information" or name == "flags" or name == "neighbor-array" or name == "interface-name" or name == "ack-hold-time" or name == "ack-max-size" or name == "bundle-message-max-size" or name == "expiry-drops-tolerated" or name == "expiry-interval" or name == "expiry-states" or name == "expiry-timer-state" or name == "integrity-receive-password" or name == "integrity-receive-password-optional" or name == "integrity-send-password" or name == "interface-name-xr" or name == "out-of-band-expiry-drops-tolerated" or name == "out-of-band-refresh-interval" or name == "pacing-interval" or name == "pacing-message-rate" or name == "pacing-messages" or name == "pacing-timer-state" or name == "refresh-interval" or name == "refresh-timer-state" or name == "retransmit-time" or name == "signalling-ip-tos" or name == "summary-refresh-max-size" or name == "summary-refresh-timer-state"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "interface-name"):
                    self.interface_name = value
                    self.interface_name.value_namespace = name_space
                    self.interface_name.value_namespace_prefix = name_space_prefix
                if(value_path == "ack-hold-time"):
                    self.ack_hold_time = value
                    self.ack_hold_time.value_namespace = name_space
                    self.ack_hold_time.value_namespace_prefix = name_space_prefix
                if(value_path == "ack-max-size"):
                    self.ack_max_size = value
                    self.ack_max_size.value_namespace = name_space
                    self.ack_max_size.value_namespace_prefix = name_space_prefix
                if(value_path == "bundle-message-max-size"):
                    self.bundle_message_max_size = value
                    self.bundle_message_max_size.value_namespace = name_space
                    self.bundle_message_max_size.value_namespace_prefix = name_space_prefix
                if(value_path == "expiry-drops-tolerated"):
                    self.expiry_drops_tolerated = value
                    self.expiry_drops_tolerated.value_namespace = name_space
                    self.expiry_drops_tolerated.value_namespace_prefix = name_space_prefix
                if(value_path == "expiry-interval"):
                    self.expiry_interval = value
                    self.expiry_interval.value_namespace = name_space
                    self.expiry_interval.value_namespace_prefix = name_space_prefix
                if(value_path == "expiry-states"):
                    self.expiry_states = value
                    self.expiry_states.value_namespace = name_space
                    self.expiry_states.value_namespace_prefix = name_space_prefix
                if(value_path == "expiry-timer-state"):
                    self.expiry_timer_state = value
                    self.expiry_timer_state.value_namespace = name_space
                    self.expiry_timer_state.value_namespace_prefix = name_space_prefix
                if(value_path == "integrity-receive-password"):
                    self.integrity_receive_password = value
                    self.integrity_receive_password.value_namespace = name_space
                    self.integrity_receive_password.value_namespace_prefix = name_space_prefix
                if(value_path == "integrity-receive-password-optional"):
                    self.integrity_receive_password_optional = value
                    self.integrity_receive_password_optional.value_namespace = name_space
                    self.integrity_receive_password_optional.value_namespace_prefix = name_space_prefix
                if(value_path == "integrity-send-password"):
                    self.integrity_send_password = value
                    self.integrity_send_password.value_namespace = name_space
                    self.integrity_send_password.value_namespace_prefix = name_space_prefix
                if(value_path == "interface-name-xr"):
                    self.interface_name_xr = value
                    self.interface_name_xr.value_namespace = name_space
                    self.interface_name_xr.value_namespace_prefix = name_space_prefix
                if(value_path == "out-of-band-expiry-drops-tolerated"):
                    self.out_of_band_expiry_drops_tolerated = value
                    self.out_of_band_expiry_drops_tolerated.value_namespace = name_space
                    self.out_of_band_expiry_drops_tolerated.value_namespace_prefix = name_space_prefix
                if(value_path == "out-of-band-refresh-interval"):
                    self.out_of_band_refresh_interval = value
                    self.out_of_band_refresh_interval.value_namespace = name_space
                    self.out_of_band_refresh_interval.value_namespace_prefix = name_space_prefix
                if(value_path == "pacing-interval"):
                    self.pacing_interval = value
                    self.pacing_interval.value_namespace = name_space
                    self.pacing_interval.value_namespace_prefix = name_space_prefix
                if(value_path == "pacing-message-rate"):
                    self.pacing_message_rate = value
                    self.pacing_message_rate.value_namespace = name_space
                    self.pacing_message_rate.value_namespace_prefix = name_space_prefix
                if(value_path == "pacing-messages"):
                    self.pacing_messages = value
                    self.pacing_messages.value_namespace = name_space
                    self.pacing_messages.value_namespace_prefix = name_space_prefix
                if(value_path == "pacing-timer-state"):
                    self.pacing_timer_state = value
                    self.pacing_timer_state.value_namespace = name_space
                    self.pacing_timer_state.value_namespace_prefix = name_space_prefix
                if(value_path == "refresh-interval"):
                    self.refresh_interval = value
                    self.refresh_interval.value_namespace = name_space
                    self.refresh_interval.value_namespace_prefix = name_space_prefix
                if(value_path == "refresh-timer-state"):
                    self.refresh_timer_state = value
                    self.refresh_timer_state.value_namespace = name_space
                    self.refresh_timer_state.value_namespace_prefix = name_space_prefix
                if(value_path == "retransmit-time"):
                    self.retransmit_time = value
                    self.retransmit_time.value_namespace = name_space
                    self.retransmit_time.value_namespace_prefix = name_space_prefix
                if(value_path == "signalling-ip-tos"):
                    self.signalling_ip_tos = value
                    self.signalling_ip_tos.value_namespace = name_space
                    self.signalling_ip_tos.value_namespace_prefix = name_space_prefix
                if(value_path == "summary-refresh-max-size"):
                    self.summary_refresh_max_size = value
                    self.summary_refresh_max_size.value_namespace = name_space
                    self.summary_refresh_max_size.value_namespace_prefix = name_space_prefix
                if(value_path == "summary-refresh-timer-state"):
                    self.summary_refresh_timer_state = value
                    self.summary_refresh_timer_state.value_namespace = name_space
                    self.summary_refresh_timer_state.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.interface_detailed:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.interface_detailed:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "interface-detaileds" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "interface-detailed"):
                for c in self.interface_detailed:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = Rsvp.InterfaceDetaileds.InterfaceDetailed()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.interface_detailed.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "interface-detailed"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class ControllerBriefs(Entity):
        """
        Table of brief info about RSVP\-enabled
        controller
        
        .. attribute:: controller_brief
        
        	Brief info about an RSVP\-enabled controller
        	**type**\: list of    :py:class:`ControllerBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.ControllerBriefs.ControllerBrief>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Rsvp.ControllerBriefs, self).__init__()

            self.yang_name = "controller-briefs"
            self.yang_parent_name = "rsvp"

            self.controller_brief = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(Rsvp.ControllerBriefs, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(Rsvp.ControllerBriefs, self).__setattr__(name, value)


        class ControllerBrief(Entity):
            """
            Brief info about an RSVP\-enabled controller
            
            .. attribute:: controller_name  <key>
            
            	Controller Name
            	**type**\:  str
            
            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
            
            .. attribute:: bandwidth_information
            
            	Interface bandwidth information
            	**type**\:   :py:class:`BandwidthInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.ControllerBriefs.ControllerBrief.BandwidthInformation>`
            
            .. attribute:: interface_name_xr
            
            	Interface Name
            	**type**\:  str
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Rsvp.ControllerBriefs.ControllerBrief, self).__init__()

                self.yang_name = "controller-brief"
                self.yang_parent_name = "controller-briefs"

                self.controller_name = YLeaf(YType.str, "controller-name")

                self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                self.bandwidth_information = Rsvp.ControllerBriefs.ControllerBrief.BandwidthInformation()
                self.bandwidth_information.parent = self
                self._children_name_map["bandwidth_information"] = "bandwidth-information"
                self._children_yang_names.add("bandwidth-information")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("controller_name",
                                "interface_name_xr") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Rsvp.ControllerBriefs.ControllerBrief, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Rsvp.ControllerBriefs.ControllerBrief, self).__setattr__(name, value)


            class BandwidthInformation(Entity):
                """
                Interface bandwidth information
                
                .. attribute:: dste_mode
                
                	DSTEMode
                	**type**\:   :py:class:`RsvpMgmtDsteModes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtDsteModes>`
                
                .. attribute:: pre_standard_dste_interface
                
                	Prestandard DSTE interface information
                	**type**\:   :py:class:`PreStandardDsteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.ControllerBriefs.ControllerBrief.BandwidthInformation.PreStandardDsteInterface>`
                
                .. attribute:: standard_dste_interface
                
                	Standard DSTE interface information
                	**type**\:   :py:class:`StandardDsteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.ControllerBriefs.ControllerBrief.BandwidthInformation.StandardDsteInterface>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.ControllerBriefs.ControllerBrief.BandwidthInformation, self).__init__()

                    self.yang_name = "bandwidth-information"
                    self.yang_parent_name = "controller-brief"

                    self.dste_mode = YLeaf(YType.enumeration, "dste-mode")

                    self.pre_standard_dste_interface = Rsvp.ControllerBriefs.ControllerBrief.BandwidthInformation.PreStandardDsteInterface()
                    self.pre_standard_dste_interface.parent = self
                    self._children_name_map["pre_standard_dste_interface"] = "pre-standard-dste-interface"
                    self._children_yang_names.add("pre-standard-dste-interface")

                    self.standard_dste_interface = Rsvp.ControllerBriefs.ControllerBrief.BandwidthInformation.StandardDsteInterface()
                    self.standard_dste_interface.parent = self
                    self._children_name_map["standard_dste_interface"] = "standard-dste-interface"
                    self._children_yang_names.add("standard-dste-interface")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("dste_mode") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.ControllerBriefs.ControllerBrief.BandwidthInformation, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.ControllerBriefs.ControllerBrief.BandwidthInformation, self).__setattr__(name, value)


                class PreStandardDsteInterface(Entity):
                    """
                    Prestandard DSTE interface information
                    
                    .. attribute:: allocated_bit_rate
                    
                    	Bandwidth (bits per second) now allocated
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: is_max_bandwidth_absolute
                    
                    	True if the Max B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: is_max_subpool_bandwidth_absolute
                    
                    	True if the Max sub\-pool B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: max_bandwidth
                    
                    	Max bandwidth (bits per second) allowed
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_flow_bandwidth
                    
                    	Max bandwidth (bits per second) allowed per flow
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_subpool_bandwidth
                    
                    	Max bandwidth (bits per second) allowed in subpool
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.ControllerBriefs.ControllerBrief.BandwidthInformation.PreStandardDsteInterface, self).__init__()

                        self.yang_name = "pre-standard-dste-interface"
                        self.yang_parent_name = "bandwidth-information"

                        self.allocated_bit_rate = YLeaf(YType.uint64, "allocated-bit-rate")

                        self.is_max_bandwidth_absolute = YLeaf(YType.boolean, "is-max-bandwidth-absolute")

                        self.is_max_subpool_bandwidth_absolute = YLeaf(YType.boolean, "is-max-subpool-bandwidth-absolute")

                        self.max_bandwidth = YLeaf(YType.uint64, "max-bandwidth")

                        self.max_flow_bandwidth = YLeaf(YType.uint64, "max-flow-bandwidth")

                        self.max_subpool_bandwidth = YLeaf(YType.uint64, "max-subpool-bandwidth")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("allocated_bit_rate",
                                        "is_max_bandwidth_absolute",
                                        "is_max_subpool_bandwidth_absolute",
                                        "max_bandwidth",
                                        "max_flow_bandwidth",
                                        "max_subpool_bandwidth") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.ControllerBriefs.ControllerBrief.BandwidthInformation.PreStandardDsteInterface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.ControllerBriefs.ControllerBrief.BandwidthInformation.PreStandardDsteInterface, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.allocated_bit_rate.is_set or
                            self.is_max_bandwidth_absolute.is_set or
                            self.is_max_subpool_bandwidth_absolute.is_set or
                            self.max_bandwidth.is_set or
                            self.max_flow_bandwidth.is_set or
                            self.max_subpool_bandwidth.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.allocated_bit_rate.yfilter != YFilter.not_set or
                            self.is_max_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.is_max_subpool_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.max_bandwidth.yfilter != YFilter.not_set or
                            self.max_flow_bandwidth.yfilter != YFilter.not_set or
                            self.max_subpool_bandwidth.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "pre-standard-dste-interface" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.allocated_bit_rate.is_set or self.allocated_bit_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.allocated_bit_rate.get_name_leafdata())
                        if (self.is_max_bandwidth_absolute.is_set or self.is_max_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_bandwidth_absolute.get_name_leafdata())
                        if (self.is_max_subpool_bandwidth_absolute.is_set or self.is_max_subpool_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_subpool_bandwidth_absolute.get_name_leafdata())
                        if (self.max_bandwidth.is_set or self.max_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_bandwidth.get_name_leafdata())
                        if (self.max_flow_bandwidth.is_set or self.max_flow_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_flow_bandwidth.get_name_leafdata())
                        if (self.max_subpool_bandwidth.is_set or self.max_subpool_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_subpool_bandwidth.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "allocated-bit-rate" or name == "is-max-bandwidth-absolute" or name == "is-max-subpool-bandwidth-absolute" or name == "max-bandwidth" or name == "max-flow-bandwidth" or name == "max-subpool-bandwidth"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "allocated-bit-rate"):
                            self.allocated_bit_rate = value
                            self.allocated_bit_rate.value_namespace = name_space
                            self.allocated_bit_rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-bandwidth-absolute"):
                            self.is_max_bandwidth_absolute = value
                            self.is_max_bandwidth_absolute.value_namespace = name_space
                            self.is_max_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-subpool-bandwidth-absolute"):
                            self.is_max_subpool_bandwidth_absolute = value
                            self.is_max_subpool_bandwidth_absolute.value_namespace = name_space
                            self.is_max_subpool_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-bandwidth"):
                            self.max_bandwidth = value
                            self.max_bandwidth.value_namespace = name_space
                            self.max_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-flow-bandwidth"):
                            self.max_flow_bandwidth = value
                            self.max_flow_bandwidth.value_namespace = name_space
                            self.max_flow_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-subpool-bandwidth"):
                            self.max_subpool_bandwidth = value
                            self.max_subpool_bandwidth.value_namespace = name_space
                            self.max_subpool_bandwidth.value_namespace_prefix = name_space_prefix


                class StandardDsteInterface(Entity):
                    """
                    Standard DSTE interface information
                    
                    .. attribute:: allocated_bit_rate
                    
                    	Bandwidth (bits per second) now allocated
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: is_max_bandwidth_absolute
                    
                    	True if the Max B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: is_max_bc0_bandwidth_absolute
                    
                    	True if the Max BC0 B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: is_max_bc1_bandwidth_absolute
                    
                    	True if the Max BC1 sub\-pool B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: max_bandwidth
                    
                    	Max bandwidth (bits per second) allowed
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_flow_bandwidth
                    
                    	Max bandwidth (bits per second) allowed per flow
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_pool0_bandwidth
                    
                    	Max bandwidth (bits per second) allowed in BC0 pool
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_pool1_bandwidth
                    
                    	Max bandwidth (bits per second) allowed in BC1 pool
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.ControllerBriefs.ControllerBrief.BandwidthInformation.StandardDsteInterface, self).__init__()

                        self.yang_name = "standard-dste-interface"
                        self.yang_parent_name = "bandwidth-information"

                        self.allocated_bit_rate = YLeaf(YType.uint64, "allocated-bit-rate")

                        self.is_max_bandwidth_absolute = YLeaf(YType.boolean, "is-max-bandwidth-absolute")

                        self.is_max_bc0_bandwidth_absolute = YLeaf(YType.boolean, "is-max-bc0-bandwidth-absolute")

                        self.is_max_bc1_bandwidth_absolute = YLeaf(YType.boolean, "is-max-bc1-bandwidth-absolute")

                        self.max_bandwidth = YLeaf(YType.uint64, "max-bandwidth")

                        self.max_flow_bandwidth = YLeaf(YType.uint64, "max-flow-bandwidth")

                        self.max_pool0_bandwidth = YLeaf(YType.uint64, "max-pool0-bandwidth")

                        self.max_pool1_bandwidth = YLeaf(YType.uint64, "max-pool1-bandwidth")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("allocated_bit_rate",
                                        "is_max_bandwidth_absolute",
                                        "is_max_bc0_bandwidth_absolute",
                                        "is_max_bc1_bandwidth_absolute",
                                        "max_bandwidth",
                                        "max_flow_bandwidth",
                                        "max_pool0_bandwidth",
                                        "max_pool1_bandwidth") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.ControllerBriefs.ControllerBrief.BandwidthInformation.StandardDsteInterface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.ControllerBriefs.ControllerBrief.BandwidthInformation.StandardDsteInterface, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.allocated_bit_rate.is_set or
                            self.is_max_bandwidth_absolute.is_set or
                            self.is_max_bc0_bandwidth_absolute.is_set or
                            self.is_max_bc1_bandwidth_absolute.is_set or
                            self.max_bandwidth.is_set or
                            self.max_flow_bandwidth.is_set or
                            self.max_pool0_bandwidth.is_set or
                            self.max_pool1_bandwidth.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.allocated_bit_rate.yfilter != YFilter.not_set or
                            self.is_max_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.is_max_bc0_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.is_max_bc1_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.max_bandwidth.yfilter != YFilter.not_set or
                            self.max_flow_bandwidth.yfilter != YFilter.not_set or
                            self.max_pool0_bandwidth.yfilter != YFilter.not_set or
                            self.max_pool1_bandwidth.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "standard-dste-interface" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.allocated_bit_rate.is_set or self.allocated_bit_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.allocated_bit_rate.get_name_leafdata())
                        if (self.is_max_bandwidth_absolute.is_set or self.is_max_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_bandwidth_absolute.get_name_leafdata())
                        if (self.is_max_bc0_bandwidth_absolute.is_set or self.is_max_bc0_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_bc0_bandwidth_absolute.get_name_leafdata())
                        if (self.is_max_bc1_bandwidth_absolute.is_set or self.is_max_bc1_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_bc1_bandwidth_absolute.get_name_leafdata())
                        if (self.max_bandwidth.is_set or self.max_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_bandwidth.get_name_leafdata())
                        if (self.max_flow_bandwidth.is_set or self.max_flow_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_flow_bandwidth.get_name_leafdata())
                        if (self.max_pool0_bandwidth.is_set or self.max_pool0_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_pool0_bandwidth.get_name_leafdata())
                        if (self.max_pool1_bandwidth.is_set or self.max_pool1_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_pool1_bandwidth.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "allocated-bit-rate" or name == "is-max-bandwidth-absolute" or name == "is-max-bc0-bandwidth-absolute" or name == "is-max-bc1-bandwidth-absolute" or name == "max-bandwidth" or name == "max-flow-bandwidth" or name == "max-pool0-bandwidth" or name == "max-pool1-bandwidth"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "allocated-bit-rate"):
                            self.allocated_bit_rate = value
                            self.allocated_bit_rate.value_namespace = name_space
                            self.allocated_bit_rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-bandwidth-absolute"):
                            self.is_max_bandwidth_absolute = value
                            self.is_max_bandwidth_absolute.value_namespace = name_space
                            self.is_max_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-bc0-bandwidth-absolute"):
                            self.is_max_bc0_bandwidth_absolute = value
                            self.is_max_bc0_bandwidth_absolute.value_namespace = name_space
                            self.is_max_bc0_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-bc1-bandwidth-absolute"):
                            self.is_max_bc1_bandwidth_absolute = value
                            self.is_max_bc1_bandwidth_absolute.value_namespace = name_space
                            self.is_max_bc1_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-bandwidth"):
                            self.max_bandwidth = value
                            self.max_bandwidth.value_namespace = name_space
                            self.max_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-flow-bandwidth"):
                            self.max_flow_bandwidth = value
                            self.max_flow_bandwidth.value_namespace = name_space
                            self.max_flow_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-pool0-bandwidth"):
                            self.max_pool0_bandwidth = value
                            self.max_pool0_bandwidth.value_namespace = name_space
                            self.max_pool0_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-pool1-bandwidth"):
                            self.max_pool1_bandwidth = value
                            self.max_pool1_bandwidth.value_namespace = name_space
                            self.max_pool1_bandwidth.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.dste_mode.is_set or
                        (self.pre_standard_dste_interface is not None and self.pre_standard_dste_interface.has_data()) or
                        (self.standard_dste_interface is not None and self.standard_dste_interface.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.dste_mode.yfilter != YFilter.not_set or
                        (self.pre_standard_dste_interface is not None and self.pre_standard_dste_interface.has_operation()) or
                        (self.standard_dste_interface is not None and self.standard_dste_interface.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bandwidth-information" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.dste_mode.is_set or self.dste_mode.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.dste_mode.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "pre-standard-dste-interface"):
                        if (self.pre_standard_dste_interface is None):
                            self.pre_standard_dste_interface = Rsvp.ControllerBriefs.ControllerBrief.BandwidthInformation.PreStandardDsteInterface()
                            self.pre_standard_dste_interface.parent = self
                            self._children_name_map["pre_standard_dste_interface"] = "pre-standard-dste-interface"
                        return self.pre_standard_dste_interface

                    if (child_yang_name == "standard-dste-interface"):
                        if (self.standard_dste_interface is None):
                            self.standard_dste_interface = Rsvp.ControllerBriefs.ControllerBrief.BandwidthInformation.StandardDsteInterface()
                            self.standard_dste_interface.parent = self
                            self._children_name_map["standard_dste_interface"] = "standard-dste-interface"
                        return self.standard_dste_interface

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "pre-standard-dste-interface" or name == "standard-dste-interface" or name == "dste-mode"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "dste-mode"):
                        self.dste_mode = value
                        self.dste_mode.value_namespace = name_space
                        self.dste_mode.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.controller_name.is_set or
                    self.interface_name_xr.is_set or
                    (self.bandwidth_information is not None and self.bandwidth_information.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.controller_name.yfilter != YFilter.not_set or
                    self.interface_name_xr.yfilter != YFilter.not_set or
                    (self.bandwidth_information is not None and self.bandwidth_information.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "controller-brief" + "[controller-name='" + self.controller_name.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/controller-briefs/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.controller_name.is_set or self.controller_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.controller_name.get_name_leafdata())
                if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.interface_name_xr.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "bandwidth-information"):
                    if (self.bandwidth_information is None):
                        self.bandwidth_information = Rsvp.ControllerBriefs.ControllerBrief.BandwidthInformation()
                        self.bandwidth_information.parent = self
                        self._children_name_map["bandwidth_information"] = "bandwidth-information"
                    return self.bandwidth_information

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "bandwidth-information" or name == "controller-name" or name == "interface-name-xr"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "controller-name"):
                    self.controller_name = value
                    self.controller_name.value_namespace = name_space
                    self.controller_name.value_namespace_prefix = name_space_prefix
                if(value_path == "interface-name-xr"):
                    self.interface_name_xr = value
                    self.interface_name_xr.value_namespace = name_space
                    self.interface_name_xr.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.controller_brief:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.controller_brief:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "controller-briefs" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "controller-brief"):
                for c in self.controller_brief:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = Rsvp.ControllerBriefs.ControllerBrief()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.controller_brief.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "controller-brief"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class GracefulRestart(Entity):
        """
        Info about graceful\-restart
        
        .. attribute:: global_neighbors
        
        	Global neighbor count
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: hello_interval
        
        	Interval at which hello messages are sent
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: is_gr_enabled
        
        	Whether GR is enabled
        	**type**\:  bool
        
        .. attribute:: is_recovery_timer_running
        
        	Whether recovery timer is running
        	**type**\:  bool
        
        .. attribute:: local_node_address
        
        	Local node address
        	**type**\: list of    :py:class:`LocalNodeAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.GracefulRestart.LocalNodeAddress>`
        
        .. attribute:: missed_hellos
        
        	Max number of hellos missed before hellos declared down
        	**type**\:  int
        
        	**range:** 0..255
        
        .. attribute:: pending_states
        
        	Total number of pending states
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: recovery_time
        
        	Recovery time (milliseconds)
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        	**units**\: millisecond
        
        .. attribute:: recovery_time_left
        
        	How much recovery timer remains
        	**type**\:   :py:class:`RecoveryTimeLeft <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.GracefulRestart.RecoveryTimeLeft>`
        
        .. attribute:: recovery_timer_exp_time
        
        	Time at which recovery timer will expire
        	**type**\:   :py:class:`RecoveryTimerExpTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.GracefulRestart.RecoveryTimerExpTime>`
        
        .. attribute:: restart_time
        
        	Restart time (milliseconds)
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        	**units**\: millisecond
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Rsvp.GracefulRestart, self).__init__()

            self.yang_name = "graceful-restart"
            self.yang_parent_name = "rsvp"

            self.global_neighbors = YLeaf(YType.uint32, "global-neighbors")

            self.hello_interval = YLeaf(YType.uint32, "hello-interval")

            self.is_gr_enabled = YLeaf(YType.boolean, "is-gr-enabled")

            self.is_recovery_timer_running = YLeaf(YType.boolean, "is-recovery-timer-running")

            self.missed_hellos = YLeaf(YType.uint8, "missed-hellos")

            self.pending_states = YLeaf(YType.uint32, "pending-states")

            self.recovery_time = YLeaf(YType.uint32, "recovery-time")

            self.restart_time = YLeaf(YType.uint32, "restart-time")

            self.recovery_time_left = Rsvp.GracefulRestart.RecoveryTimeLeft()
            self.recovery_time_left.parent = self
            self._children_name_map["recovery_time_left"] = "recovery-time-left"
            self._children_yang_names.add("recovery-time-left")

            self.recovery_timer_exp_time = Rsvp.GracefulRestart.RecoveryTimerExpTime()
            self.recovery_timer_exp_time.parent = self
            self._children_name_map["recovery_timer_exp_time"] = "recovery-timer-exp-time"
            self._children_yang_names.add("recovery-timer-exp-time")

            self.local_node_address = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in ("global_neighbors",
                            "hello_interval",
                            "is_gr_enabled",
                            "is_recovery_timer_running",
                            "missed_hellos",
                            "pending_states",
                            "recovery_time",
                            "restart_time") and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(Rsvp.GracefulRestart, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(Rsvp.GracefulRestart, self).__setattr__(name, value)


        class RecoveryTimeLeft(Entity):
            """
            How much recovery timer remains
            
            .. attribute:: nanoseconds
            
            	Time Value in Nano\-seconds
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            	**units**\: nanosecond
            
            .. attribute:: seconds
            
            	Time Value in Seconds
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            	**units**\: second
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Rsvp.GracefulRestart.RecoveryTimeLeft, self).__init__()

                self.yang_name = "recovery-time-left"
                self.yang_parent_name = "graceful-restart"

                self.nanoseconds = YLeaf(YType.int32, "nanoseconds")

                self.seconds = YLeaf(YType.int32, "seconds")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("nanoseconds",
                                "seconds") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Rsvp.GracefulRestart.RecoveryTimeLeft, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Rsvp.GracefulRestart.RecoveryTimeLeft, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.nanoseconds.is_set or
                    self.seconds.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.nanoseconds.yfilter != YFilter.not_set or
                    self.seconds.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "recovery-time-left" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/graceful-restart/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.nanoseconds.is_set or self.nanoseconds.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.nanoseconds.get_name_leafdata())
                if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.seconds.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "nanoseconds" or name == "seconds"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "nanoseconds"):
                    self.nanoseconds = value
                    self.nanoseconds.value_namespace = name_space
                    self.nanoseconds.value_namespace_prefix = name_space_prefix
                if(value_path == "seconds"):
                    self.seconds = value
                    self.seconds.value_namespace = name_space
                    self.seconds.value_namespace_prefix = name_space_prefix


        class RecoveryTimerExpTime(Entity):
            """
            Time at which recovery timer will expire
            
            .. attribute:: nanoseconds
            
            	Time Value in Nano\-seconds
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            	**units**\: nanosecond
            
            .. attribute:: seconds
            
            	Time Value in Seconds
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            	**units**\: second
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Rsvp.GracefulRestart.RecoveryTimerExpTime, self).__init__()

                self.yang_name = "recovery-timer-exp-time"
                self.yang_parent_name = "graceful-restart"

                self.nanoseconds = YLeaf(YType.int32, "nanoseconds")

                self.seconds = YLeaf(YType.int32, "seconds")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("nanoseconds",
                                "seconds") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Rsvp.GracefulRestart.RecoveryTimerExpTime, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Rsvp.GracefulRestart.RecoveryTimerExpTime, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.nanoseconds.is_set or
                    self.seconds.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.nanoseconds.yfilter != YFilter.not_set or
                    self.seconds.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "recovery-timer-exp-time" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/graceful-restart/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.nanoseconds.is_set or self.nanoseconds.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.nanoseconds.get_name_leafdata())
                if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.seconds.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "nanoseconds" or name == "seconds"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "nanoseconds"):
                    self.nanoseconds = value
                    self.nanoseconds.value_namespace = name_space
                    self.nanoseconds.value_namespace_prefix = name_space_prefix
                if(value_path == "seconds"):
                    self.seconds = value
                    self.seconds.value_namespace = name_space
                    self.seconds.value_namespace_prefix = name_space_prefix


        class LocalNodeAddress(Entity):
            """
            Local node address
            
            .. attribute:: application_type
            
            	GR local node\-id app type
            	**type**\:   :py:class:`RsvpMgmtGrApp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtGrApp>`
            
            .. attribute:: local_node_ip_address
            
            	Local node address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Rsvp.GracefulRestart.LocalNodeAddress, self).__init__()

                self.yang_name = "local-node-address"
                self.yang_parent_name = "graceful-restart"

                self.application_type = YLeaf(YType.enumeration, "application-type")

                self.local_node_ip_address = YLeaf(YType.str, "local-node-ip-address")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("application_type",
                                "local_node_ip_address") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Rsvp.GracefulRestart.LocalNodeAddress, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Rsvp.GracefulRestart.LocalNodeAddress, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.application_type.is_set or
                    self.local_node_ip_address.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.application_type.yfilter != YFilter.not_set or
                    self.local_node_ip_address.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "local-node-address" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/graceful-restart/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.application_type.is_set or self.application_type.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.application_type.get_name_leafdata())
                if (self.local_node_ip_address.is_set or self.local_node_ip_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.local_node_ip_address.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "application-type" or name == "local-node-ip-address"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "application-type"):
                    self.application_type = value
                    self.application_type.value_namespace = name_space
                    self.application_type.value_namespace_prefix = name_space_prefix
                if(value_path == "local-node-ip-address"):
                    self.local_node_ip_address = value
                    self.local_node_ip_address.value_namespace = name_space
                    self.local_node_ip_address.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.local_node_address:
                if (c.has_data()):
                    return True
            return (
                self.global_neighbors.is_set or
                self.hello_interval.is_set or
                self.is_gr_enabled.is_set or
                self.is_recovery_timer_running.is_set or
                self.missed_hellos.is_set or
                self.pending_states.is_set or
                self.recovery_time.is_set or
                self.restart_time.is_set or
                (self.recovery_time_left is not None and self.recovery_time_left.has_data()) or
                (self.recovery_timer_exp_time is not None and self.recovery_timer_exp_time.has_data()))

        def has_operation(self):
            for c in self.local_node_address:
                if (c.has_operation()):
                    return True
            return (
                self.yfilter != YFilter.not_set or
                self.global_neighbors.yfilter != YFilter.not_set or
                self.hello_interval.yfilter != YFilter.not_set or
                self.is_gr_enabled.yfilter != YFilter.not_set or
                self.is_recovery_timer_running.yfilter != YFilter.not_set or
                self.missed_hellos.yfilter != YFilter.not_set or
                self.pending_states.yfilter != YFilter.not_set or
                self.recovery_time.yfilter != YFilter.not_set or
                self.restart_time.yfilter != YFilter.not_set or
                (self.recovery_time_left is not None and self.recovery_time_left.has_operation()) or
                (self.recovery_timer_exp_time is not None and self.recovery_timer_exp_time.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "graceful-restart" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()
            if (self.global_neighbors.is_set or self.global_neighbors.yfilter != YFilter.not_set):
                leaf_name_data.append(self.global_neighbors.get_name_leafdata())
            if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                leaf_name_data.append(self.hello_interval.get_name_leafdata())
            if (self.is_gr_enabled.is_set or self.is_gr_enabled.yfilter != YFilter.not_set):
                leaf_name_data.append(self.is_gr_enabled.get_name_leafdata())
            if (self.is_recovery_timer_running.is_set or self.is_recovery_timer_running.yfilter != YFilter.not_set):
                leaf_name_data.append(self.is_recovery_timer_running.get_name_leafdata())
            if (self.missed_hellos.is_set or self.missed_hellos.yfilter != YFilter.not_set):
                leaf_name_data.append(self.missed_hellos.get_name_leafdata())
            if (self.pending_states.is_set or self.pending_states.yfilter != YFilter.not_set):
                leaf_name_data.append(self.pending_states.get_name_leafdata())
            if (self.recovery_time.is_set or self.recovery_time.yfilter != YFilter.not_set):
                leaf_name_data.append(self.recovery_time.get_name_leafdata())
            if (self.restart_time.is_set or self.restart_time.yfilter != YFilter.not_set):
                leaf_name_data.append(self.restart_time.get_name_leafdata())

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "local-node-address"):
                for c in self.local_node_address:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = Rsvp.GracefulRestart.LocalNodeAddress()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.local_node_address.append(c)
                return c

            if (child_yang_name == "recovery-time-left"):
                if (self.recovery_time_left is None):
                    self.recovery_time_left = Rsvp.GracefulRestart.RecoveryTimeLeft()
                    self.recovery_time_left.parent = self
                    self._children_name_map["recovery_time_left"] = "recovery-time-left"
                return self.recovery_time_left

            if (child_yang_name == "recovery-timer-exp-time"):
                if (self.recovery_timer_exp_time is None):
                    self.recovery_timer_exp_time = Rsvp.GracefulRestart.RecoveryTimerExpTime()
                    self.recovery_timer_exp_time.parent = self
                    self._children_name_map["recovery_timer_exp_time"] = "recovery-timer-exp-time"
                return self.recovery_timer_exp_time

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "local-node-address" or name == "recovery-time-left" or name == "recovery-timer-exp-time" or name == "global-neighbors" or name == "hello-interval" or name == "is-gr-enabled" or name == "is-recovery-timer-running" or name == "missed-hellos" or name == "pending-states" or name == "recovery-time" or name == "restart-time"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            if(value_path == "global-neighbors"):
                self.global_neighbors = value
                self.global_neighbors.value_namespace = name_space
                self.global_neighbors.value_namespace_prefix = name_space_prefix
            if(value_path == "hello-interval"):
                self.hello_interval = value
                self.hello_interval.value_namespace = name_space
                self.hello_interval.value_namespace_prefix = name_space_prefix
            if(value_path == "is-gr-enabled"):
                self.is_gr_enabled = value
                self.is_gr_enabled.value_namespace = name_space
                self.is_gr_enabled.value_namespace_prefix = name_space_prefix
            if(value_path == "is-recovery-timer-running"):
                self.is_recovery_timer_running = value
                self.is_recovery_timer_running.value_namespace = name_space
                self.is_recovery_timer_running.value_namespace_prefix = name_space_prefix
            if(value_path == "missed-hellos"):
                self.missed_hellos = value
                self.missed_hellos.value_namespace = name_space
                self.missed_hellos.value_namespace_prefix = name_space_prefix
            if(value_path == "pending-states"):
                self.pending_states = value
                self.pending_states.value_namespace = name_space
                self.pending_states.value_namespace_prefix = name_space_prefix
            if(value_path == "recovery-time"):
                self.recovery_time = value
                self.recovery_time.value_namespace = name_space
                self.recovery_time.value_namespace_prefix = name_space_prefix
            if(value_path == "restart-time"):
                self.restart_time = value
                self.restart_time.value_namespace = name_space
                self.restart_time.value_namespace_prefix = name_space_prefix


    class HelloInterfaceInstanceBriefs(Entity):
        """
        Table of brief info about i/f\-based hello
        instances
        
        .. attribute:: hello_interface_instance_brief
        
        	Brief info for a single interface\-based hello instance
        	**type**\: list of    :py:class:`HelloInterfaceInstanceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.HelloInterfaceInstanceBriefs.HelloInterfaceInstanceBrief>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Rsvp.HelloInterfaceInstanceBriefs, self).__init__()

            self.yang_name = "hello-interface-instance-briefs"
            self.yang_parent_name = "rsvp"

            self.hello_interface_instance_brief = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(Rsvp.HelloInterfaceInstanceBriefs, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(Rsvp.HelloInterfaceInstanceBriefs, self).__setattr__(name, value)


        class HelloInterfaceInstanceBrief(Entity):
            """
            Brief info for a single interface\-based hello
            instance
            
            .. attribute:: source_address  <key>
            
            	Source Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: destination_address  <key>
            
            	Destination Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: destination_address_xr
            
            	Destination address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: hello_interface
            
            	Interface to use
            	**type**\:  str
            
            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
            
            .. attribute:: instance_type
            
            	Hello instance type
            	**type**\:   :py:class:`RsvpMgmtHelloInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtHelloInstance>`
            
            .. attribute:: source_address_xr
            
            	Source address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Rsvp.HelloInterfaceInstanceBriefs.HelloInterfaceInstanceBrief, self).__init__()

                self.yang_name = "hello-interface-instance-brief"
                self.yang_parent_name = "hello-interface-instance-briefs"

                self.source_address = YLeaf(YType.str, "source-address")

                self.destination_address = YLeaf(YType.str, "destination-address")

                self.destination_address_xr = YLeaf(YType.str, "destination-address-xr")

                self.hello_interface = YLeaf(YType.str, "hello-interface")

                self.instance_type = YLeaf(YType.enumeration, "instance-type")

                self.source_address_xr = YLeaf(YType.str, "source-address-xr")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("source_address",
                                "destination_address",
                                "destination_address_xr",
                                "hello_interface",
                                "instance_type",
                                "source_address_xr") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Rsvp.HelloInterfaceInstanceBriefs.HelloInterfaceInstanceBrief, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Rsvp.HelloInterfaceInstanceBriefs.HelloInterfaceInstanceBrief, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.source_address.is_set or
                    self.destination_address.is_set or
                    self.destination_address_xr.is_set or
                    self.hello_interface.is_set or
                    self.instance_type.is_set or
                    self.source_address_xr.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.source_address.yfilter != YFilter.not_set or
                    self.destination_address.yfilter != YFilter.not_set or
                    self.destination_address_xr.yfilter != YFilter.not_set or
                    self.hello_interface.yfilter != YFilter.not_set or
                    self.instance_type.yfilter != YFilter.not_set or
                    self.source_address_xr.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "hello-interface-instance-brief" + "[source-address='" + self.source_address.get() + "']" + "[destination-address='" + self.destination_address.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/hello-interface-instance-briefs/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_address.get_name_leafdata())
                if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_address.get_name_leafdata())
                if (self.destination_address_xr.is_set or self.destination_address_xr.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_address_xr.get_name_leafdata())
                if (self.hello_interface.is_set or self.hello_interface.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.hello_interface.get_name_leafdata())
                if (self.instance_type.is_set or self.instance_type.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.instance_type.get_name_leafdata())
                if (self.source_address_xr.is_set or self.source_address_xr.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_address_xr.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "source-address" or name == "destination-address" or name == "destination-address-xr" or name == "hello-interface" or name == "instance-type" or name == "source-address-xr"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "source-address"):
                    self.source_address = value
                    self.source_address.value_namespace = name_space
                    self.source_address.value_namespace_prefix = name_space_prefix
                if(value_path == "destination-address"):
                    self.destination_address = value
                    self.destination_address.value_namespace = name_space
                    self.destination_address.value_namespace_prefix = name_space_prefix
                if(value_path == "destination-address-xr"):
                    self.destination_address_xr = value
                    self.destination_address_xr.value_namespace = name_space
                    self.destination_address_xr.value_namespace_prefix = name_space_prefix
                if(value_path == "hello-interface"):
                    self.hello_interface = value
                    self.hello_interface.value_namespace = name_space
                    self.hello_interface.value_namespace_prefix = name_space_prefix
                if(value_path == "instance-type"):
                    self.instance_type = value
                    self.instance_type.value_namespace = name_space
                    self.instance_type.value_namespace_prefix = name_space_prefix
                if(value_path == "source-address-xr"):
                    self.source_address_xr = value
                    self.source_address_xr.value_namespace = name_space
                    self.source_address_xr.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.hello_interface_instance_brief:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.hello_interface_instance_brief:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "hello-interface-instance-briefs" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "hello-interface-instance-brief"):
                for c in self.hello_interface_instance_brief:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = Rsvp.HelloInterfaceInstanceBriefs.HelloInterfaceInstanceBrief()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.hello_interface_instance_brief.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "hello-interface-instance-brief"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class HelloInterfaceInstanceDetails(Entity):
        """
        Table of detailed info about i/f\-based hello
        instances
        
        .. attribute:: hello_interface_instance_detail
        
        	Detailed info for a single interface\-based hello instance
        	**type**\: list of    :py:class:`HelloInterfaceInstanceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.HelloInterfaceInstanceDetails.HelloInterfaceInstanceDetail>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Rsvp.HelloInterfaceInstanceDetails, self).__init__()

            self.yang_name = "hello-interface-instance-details"
            self.yang_parent_name = "rsvp"

            self.hello_interface_instance_detail = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(Rsvp.HelloInterfaceInstanceDetails, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(Rsvp.HelloInterfaceInstanceDetails, self).__setattr__(name, value)


        class HelloInterfaceInstanceDetail(Entity):
            """
            Detailed info for a single interface\-based
            hello instance
            
            .. attribute:: source_address  <key>
            
            	Source Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: destination_address  <key>
            
            	Destination Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: destination_address_xr
            
            	Destination address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: destination_instance
            
            	Destination Instance
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: hello_global_neighbor_id
            
            	Global Neighbor ID
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: hello_interface
            
            	Interface to use
            	**type**\:  str
            
            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
            
            .. attribute:: hello_messages_received
            
            	Number of hello messages received
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: hello_messages_sent
            
            	Number of hello messages sent
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: instance_type
            
            	Hello instance type
            	**type**\:   :py:class:`RsvpMgmtHelloInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtHelloInstance>`
            
            .. attribute:: last_message_sent_time
            
            	Last Ack/msg sent time
            	**type**\:   :py:class:`LastMessageSentTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.HelloInterfaceInstanceDetails.HelloInterfaceInstanceDetail.LastMessageSentTime>`
            
            .. attribute:: source_address_xr
            
            	Source address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: source_instance
            
            	Source Instance
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Rsvp.HelloInterfaceInstanceDetails.HelloInterfaceInstanceDetail, self).__init__()

                self.yang_name = "hello-interface-instance-detail"
                self.yang_parent_name = "hello-interface-instance-details"

                self.source_address = YLeaf(YType.str, "source-address")

                self.destination_address = YLeaf(YType.str, "destination-address")

                self.destination_address_xr = YLeaf(YType.str, "destination-address-xr")

                self.destination_instance = YLeaf(YType.uint32, "destination-instance")

                self.hello_global_neighbor_id = YLeaf(YType.str, "hello-global-neighbor-id")

                self.hello_interface = YLeaf(YType.str, "hello-interface")

                self.hello_messages_received = YLeaf(YType.uint64, "hello-messages-received")

                self.hello_messages_sent = YLeaf(YType.uint64, "hello-messages-sent")

                self.instance_type = YLeaf(YType.enumeration, "instance-type")

                self.source_address_xr = YLeaf(YType.str, "source-address-xr")

                self.source_instance = YLeaf(YType.uint32, "source-instance")

                self.last_message_sent_time = Rsvp.HelloInterfaceInstanceDetails.HelloInterfaceInstanceDetail.LastMessageSentTime()
                self.last_message_sent_time.parent = self
                self._children_name_map["last_message_sent_time"] = "last-message-sent-time"
                self._children_yang_names.add("last-message-sent-time")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("source_address",
                                "destination_address",
                                "destination_address_xr",
                                "destination_instance",
                                "hello_global_neighbor_id",
                                "hello_interface",
                                "hello_messages_received",
                                "hello_messages_sent",
                                "instance_type",
                                "source_address_xr",
                                "source_instance") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Rsvp.HelloInterfaceInstanceDetails.HelloInterfaceInstanceDetail, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Rsvp.HelloInterfaceInstanceDetails.HelloInterfaceInstanceDetail, self).__setattr__(name, value)


            class LastMessageSentTime(Entity):
                """
                Last Ack/msg sent time
                
                .. attribute:: nanoseconds
                
                	Time Value in Nano\-seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: nanosecond
                
                .. attribute:: seconds
                
                	Time Value in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.HelloInterfaceInstanceDetails.HelloInterfaceInstanceDetail.LastMessageSentTime, self).__init__()

                    self.yang_name = "last-message-sent-time"
                    self.yang_parent_name = "hello-interface-instance-detail"

                    self.nanoseconds = YLeaf(YType.int32, "nanoseconds")

                    self.seconds = YLeaf(YType.int32, "seconds")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("nanoseconds",
                                    "seconds") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.HelloInterfaceInstanceDetails.HelloInterfaceInstanceDetail.LastMessageSentTime, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.HelloInterfaceInstanceDetails.HelloInterfaceInstanceDetail.LastMessageSentTime, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.nanoseconds.is_set or
                        self.seconds.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.nanoseconds.yfilter != YFilter.not_set or
                        self.seconds.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "last-message-sent-time" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.nanoseconds.is_set or self.nanoseconds.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.nanoseconds.get_name_leafdata())
                    if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.seconds.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "nanoseconds" or name == "seconds"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "nanoseconds"):
                        self.nanoseconds = value
                        self.nanoseconds.value_namespace = name_space
                        self.nanoseconds.value_namespace_prefix = name_space_prefix
                    if(value_path == "seconds"):
                        self.seconds = value
                        self.seconds.value_namespace = name_space
                        self.seconds.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.source_address.is_set or
                    self.destination_address.is_set or
                    self.destination_address_xr.is_set or
                    self.destination_instance.is_set or
                    self.hello_global_neighbor_id.is_set or
                    self.hello_interface.is_set or
                    self.hello_messages_received.is_set or
                    self.hello_messages_sent.is_set or
                    self.instance_type.is_set or
                    self.source_address_xr.is_set or
                    self.source_instance.is_set or
                    (self.last_message_sent_time is not None and self.last_message_sent_time.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.source_address.yfilter != YFilter.not_set or
                    self.destination_address.yfilter != YFilter.not_set or
                    self.destination_address_xr.yfilter != YFilter.not_set or
                    self.destination_instance.yfilter != YFilter.not_set or
                    self.hello_global_neighbor_id.yfilter != YFilter.not_set or
                    self.hello_interface.yfilter != YFilter.not_set or
                    self.hello_messages_received.yfilter != YFilter.not_set or
                    self.hello_messages_sent.yfilter != YFilter.not_set or
                    self.instance_type.yfilter != YFilter.not_set or
                    self.source_address_xr.yfilter != YFilter.not_set or
                    self.source_instance.yfilter != YFilter.not_set or
                    (self.last_message_sent_time is not None and self.last_message_sent_time.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "hello-interface-instance-detail" + "[source-address='" + self.source_address.get() + "']" + "[destination-address='" + self.destination_address.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/hello-interface-instance-details/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_address.get_name_leafdata())
                if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_address.get_name_leafdata())
                if (self.destination_address_xr.is_set or self.destination_address_xr.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_address_xr.get_name_leafdata())
                if (self.destination_instance.is_set or self.destination_instance.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_instance.get_name_leafdata())
                if (self.hello_global_neighbor_id.is_set or self.hello_global_neighbor_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.hello_global_neighbor_id.get_name_leafdata())
                if (self.hello_interface.is_set or self.hello_interface.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.hello_interface.get_name_leafdata())
                if (self.hello_messages_received.is_set or self.hello_messages_received.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.hello_messages_received.get_name_leafdata())
                if (self.hello_messages_sent.is_set or self.hello_messages_sent.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.hello_messages_sent.get_name_leafdata())
                if (self.instance_type.is_set or self.instance_type.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.instance_type.get_name_leafdata())
                if (self.source_address_xr.is_set or self.source_address_xr.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_address_xr.get_name_leafdata())
                if (self.source_instance.is_set or self.source_instance.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_instance.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "last-message-sent-time"):
                    if (self.last_message_sent_time is None):
                        self.last_message_sent_time = Rsvp.HelloInterfaceInstanceDetails.HelloInterfaceInstanceDetail.LastMessageSentTime()
                        self.last_message_sent_time.parent = self
                        self._children_name_map["last_message_sent_time"] = "last-message-sent-time"
                    return self.last_message_sent_time

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "last-message-sent-time" or name == "source-address" or name == "destination-address" or name == "destination-address-xr" or name == "destination-instance" or name == "hello-global-neighbor-id" or name == "hello-interface" or name == "hello-messages-received" or name == "hello-messages-sent" or name == "instance-type" or name == "source-address-xr" or name == "source-instance"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "source-address"):
                    self.source_address = value
                    self.source_address.value_namespace = name_space
                    self.source_address.value_namespace_prefix = name_space_prefix
                if(value_path == "destination-address"):
                    self.destination_address = value
                    self.destination_address.value_namespace = name_space
                    self.destination_address.value_namespace_prefix = name_space_prefix
                if(value_path == "destination-address-xr"):
                    self.destination_address_xr = value
                    self.destination_address_xr.value_namespace = name_space
                    self.destination_address_xr.value_namespace_prefix = name_space_prefix
                if(value_path == "destination-instance"):
                    self.destination_instance = value
                    self.destination_instance.value_namespace = name_space
                    self.destination_instance.value_namespace_prefix = name_space_prefix
                if(value_path == "hello-global-neighbor-id"):
                    self.hello_global_neighbor_id = value
                    self.hello_global_neighbor_id.value_namespace = name_space
                    self.hello_global_neighbor_id.value_namespace_prefix = name_space_prefix
                if(value_path == "hello-interface"):
                    self.hello_interface = value
                    self.hello_interface.value_namespace = name_space
                    self.hello_interface.value_namespace_prefix = name_space_prefix
                if(value_path == "hello-messages-received"):
                    self.hello_messages_received = value
                    self.hello_messages_received.value_namespace = name_space
                    self.hello_messages_received.value_namespace_prefix = name_space_prefix
                if(value_path == "hello-messages-sent"):
                    self.hello_messages_sent = value
                    self.hello_messages_sent.value_namespace = name_space
                    self.hello_messages_sent.value_namespace_prefix = name_space_prefix
                if(value_path == "instance-type"):
                    self.instance_type = value
                    self.instance_type.value_namespace = name_space
                    self.instance_type.value_namespace_prefix = name_space_prefix
                if(value_path == "source-address-xr"):
                    self.source_address_xr = value
                    self.source_address_xr.value_namespace = name_space
                    self.source_address_xr.value_namespace_prefix = name_space_prefix
                if(value_path == "source-instance"):
                    self.source_instance = value
                    self.source_instance.value_namespace = name_space
                    self.source_instance.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.hello_interface_instance_detail:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.hello_interface_instance_detail:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "hello-interface-instance-details" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "hello-interface-instance-detail"):
                for c in self.hello_interface_instance_detail:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = Rsvp.HelloInterfaceInstanceDetails.HelloInterfaceInstanceDetail()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.hello_interface_instance_detail.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "hello-interface-instance-detail"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class InterfaceNeighborDetails(Entity):
        """
        Table of detailed info about I/F neighbors
        
        .. attribute:: interface_neighbor_detail
        
        	Detailed info for a single interface neighbor
        	**type**\: list of    :py:class:`InterfaceNeighborDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.InterfaceNeighborDetails.InterfaceNeighborDetail>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Rsvp.InterfaceNeighborDetails, self).__init__()

            self.yang_name = "interface-neighbor-details"
            self.yang_parent_name = "rsvp"

            self.interface_neighbor_detail = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(Rsvp.InterfaceNeighborDetails, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(Rsvp.InterfaceNeighborDetails, self).__setattr__(name, value)


        class InterfaceNeighborDetail(Entity):
            """
            Detailed info for a single interface neighbor
            
            .. attribute:: neighbor_address  <key>
            
            	Address of global neighbor
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: interface_neighbor_list_detail
            
            	Detail list of I/F Neighbors
            	**type**\: list of    :py:class:`InterfaceNeighborListDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.InterfaceNeighborDetails.InterfaceNeighborDetail.InterfaceNeighborListDetail>`
            
            .. attribute:: node_address
            
            	Neighbor node address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Rsvp.InterfaceNeighborDetails.InterfaceNeighborDetail, self).__init__()

                self.yang_name = "interface-neighbor-detail"
                self.yang_parent_name = "interface-neighbor-details"

                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                self.node_address = YLeaf(YType.str, "node-address")

                self.interface_neighbor_list_detail = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("neighbor_address",
                                "node_address") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Rsvp.InterfaceNeighborDetails.InterfaceNeighborDetail, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Rsvp.InterfaceNeighborDetails.InterfaceNeighborDetail, self).__setattr__(name, value)


            class InterfaceNeighborListDetail(Entity):
                """
                Detail list of I/F Neighbors
                
                .. attribute:: interface_neighbor_address
                
                	Interface Neighbor address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: is_rr_enabled
                
                	Is Neighbor's RR enable
                	**type**\:  bool
                
                .. attribute:: neighbor_epoch
                
                	Neighbor's epoch value
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: neighbor_interface_name
                
                	Neighbor's Interface handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: out_of_order_messages
                
                	Number of out of order msgs
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: retransmitted_messages
                
                	Number of retransmitted msgs
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.InterfaceNeighborDetails.InterfaceNeighborDetail.InterfaceNeighborListDetail, self).__init__()

                    self.yang_name = "interface-neighbor-list-detail"
                    self.yang_parent_name = "interface-neighbor-detail"

                    self.interface_neighbor_address = YLeaf(YType.str, "interface-neighbor-address")

                    self.is_rr_enabled = YLeaf(YType.boolean, "is-rr-enabled")

                    self.neighbor_epoch = YLeaf(YType.uint32, "neighbor-epoch")

                    self.neighbor_interface_name = YLeaf(YType.str, "neighbor-interface-name")

                    self.out_of_order_messages = YLeaf(YType.uint32, "out-of-order-messages")

                    self.retransmitted_messages = YLeaf(YType.uint32, "retransmitted-messages")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("interface_neighbor_address",
                                    "is_rr_enabled",
                                    "neighbor_epoch",
                                    "neighbor_interface_name",
                                    "out_of_order_messages",
                                    "retransmitted_messages") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.InterfaceNeighborDetails.InterfaceNeighborDetail.InterfaceNeighborListDetail, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.InterfaceNeighborDetails.InterfaceNeighborDetail.InterfaceNeighborListDetail, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.interface_neighbor_address.is_set or
                        self.is_rr_enabled.is_set or
                        self.neighbor_epoch.is_set or
                        self.neighbor_interface_name.is_set or
                        self.out_of_order_messages.is_set or
                        self.retransmitted_messages.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.interface_neighbor_address.yfilter != YFilter.not_set or
                        self.is_rr_enabled.yfilter != YFilter.not_set or
                        self.neighbor_epoch.yfilter != YFilter.not_set or
                        self.neighbor_interface_name.yfilter != YFilter.not_set or
                        self.out_of_order_messages.yfilter != YFilter.not_set or
                        self.retransmitted_messages.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "interface-neighbor-list-detail" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.interface_neighbor_address.is_set or self.interface_neighbor_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.interface_neighbor_address.get_name_leafdata())
                    if (self.is_rr_enabled.is_set or self.is_rr_enabled.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_rr_enabled.get_name_leafdata())
                    if (self.neighbor_epoch.is_set or self.neighbor_epoch.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.neighbor_epoch.get_name_leafdata())
                    if (self.neighbor_interface_name.is_set or self.neighbor_interface_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.neighbor_interface_name.get_name_leafdata())
                    if (self.out_of_order_messages.is_set or self.out_of_order_messages.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.out_of_order_messages.get_name_leafdata())
                    if (self.retransmitted_messages.is_set or self.retransmitted_messages.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.retransmitted_messages.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "interface-neighbor-address" or name == "is-rr-enabled" or name == "neighbor-epoch" or name == "neighbor-interface-name" or name == "out-of-order-messages" or name == "retransmitted-messages"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "interface-neighbor-address"):
                        self.interface_neighbor_address = value
                        self.interface_neighbor_address.value_namespace = name_space
                        self.interface_neighbor_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-rr-enabled"):
                        self.is_rr_enabled = value
                        self.is_rr_enabled.value_namespace = name_space
                        self.is_rr_enabled.value_namespace_prefix = name_space_prefix
                    if(value_path == "neighbor-epoch"):
                        self.neighbor_epoch = value
                        self.neighbor_epoch.value_namespace = name_space
                        self.neighbor_epoch.value_namespace_prefix = name_space_prefix
                    if(value_path == "neighbor-interface-name"):
                        self.neighbor_interface_name = value
                        self.neighbor_interface_name.value_namespace = name_space
                        self.neighbor_interface_name.value_namespace_prefix = name_space_prefix
                    if(value_path == "out-of-order-messages"):
                        self.out_of_order_messages = value
                        self.out_of_order_messages.value_namespace = name_space
                        self.out_of_order_messages.value_namespace_prefix = name_space_prefix
                    if(value_path == "retransmitted-messages"):
                        self.retransmitted_messages = value
                        self.retransmitted_messages.value_namespace = name_space
                        self.retransmitted_messages.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.interface_neighbor_list_detail:
                    if (c.has_data()):
                        return True
                return (
                    self.neighbor_address.is_set or
                    self.node_address.is_set)

            def has_operation(self):
                for c in self.interface_neighbor_list_detail:
                    if (c.has_operation()):
                        return True
                return (
                    self.yfilter != YFilter.not_set or
                    self.neighbor_address.yfilter != YFilter.not_set or
                    self.node_address.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "interface-neighbor-detail" + "[neighbor-address='" + self.neighbor_address.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/interface-neighbor-details/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                if (self.node_address.is_set or self.node_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.node_address.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "interface-neighbor-list-detail"):
                    for c in self.interface_neighbor_list_detail:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = Rsvp.InterfaceNeighborDetails.InterfaceNeighborDetail.InterfaceNeighborListDetail()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.interface_neighbor_list_detail.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "interface-neighbor-list-detail" or name == "neighbor-address" or name == "node-address"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "neighbor-address"):
                    self.neighbor_address = value
                    self.neighbor_address.value_namespace = name_space
                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                if(value_path == "node-address"):
                    self.node_address = value
                    self.node_address.value_namespace = name_space
                    self.node_address.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.interface_neighbor_detail:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.interface_neighbor_detail:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "interface-neighbor-details" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "interface-neighbor-detail"):
                for c in self.interface_neighbor_detail:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = Rsvp.InterfaceNeighborDetails.InterfaceNeighborDetail()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.interface_neighbor_detail.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "interface-neighbor-detail"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class Nsr(Entity):
        """
        RSVP NSR information
        
        .. attribute:: status
        
        	RSVP NSR status information
        	**type**\:   :py:class:`Status <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Nsr.Status>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Rsvp.Nsr, self).__init__()

            self.yang_name = "nsr"
            self.yang_parent_name = "rsvp"

            self.status = Rsvp.Nsr.Status()
            self.status.parent = self
            self._children_name_map["status"] = "status"
            self._children_yang_names.add("status")


        class Status(Entity):
            """
            RSVP NSR status information
            
            .. attribute:: idt_status
            
            	IDT status
            	**type**\:   :py:class:`IdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Nsr.Status.IdtStatus>`
            
            .. attribute:: previous_idt_status
            
            	Previous IDT status
            	**type**\:   :py:class:`PreviousIdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Nsr.Status.PreviousIdtStatus>`
            
            .. attribute:: role
            
            	Process role
            	**type**\:   :py:class:`RsvpProcRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpProcRole>`
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Rsvp.Nsr.Status, self).__init__()

                self.yang_name = "status"
                self.yang_parent_name = "nsr"

                self.role = YLeaf(YType.enumeration, "role")

                self.idt_status = Rsvp.Nsr.Status.IdtStatus()
                self.idt_status.parent = self
                self._children_name_map["idt_status"] = "idt-status"
                self._children_yang_names.add("idt-status")

                self.previous_idt_status = Rsvp.Nsr.Status.PreviousIdtStatus()
                self.previous_idt_status.parent = self
                self._children_name_map["previous_idt_status"] = "previous-idt-status"
                self._children_yang_names.add("previous-idt-status")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("role") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Rsvp.Nsr.Status, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Rsvp.Nsr.Status, self).__setattr__(name, value)


            class IdtStatus(Entity):
                """
                IDT status
                
                .. attribute:: declare_time
                
                	Declare ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_end_time
                
                	IDT end timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_start_time
                
                	IDT start timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: not_ready_reason
                
                	Not ready reason
                	**type**\:   :py:class:`RsvpProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpProcNsrNotReadyReason>`
                
                .. attribute:: sync_status
                
                	Sync status
                	**type**\:   :py:class:`RsvpSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpSyncStatus>`
                
                .. attribute:: withdraw_time
                
                	Withdraw ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.Nsr.Status.IdtStatus, self).__init__()

                    self.yang_name = "idt-status"
                    self.yang_parent_name = "status"

                    self.declare_time = YLeaf(YType.uint32, "declare-time")

                    self.idt_end_time = YLeaf(YType.uint32, "idt-end-time")

                    self.idt_start_time = YLeaf(YType.uint32, "idt-start-time")

                    self.not_ready_reason = YLeaf(YType.enumeration, "not-ready-reason")

                    self.sync_status = YLeaf(YType.enumeration, "sync-status")

                    self.withdraw_time = YLeaf(YType.uint32, "withdraw-time")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("declare_time",
                                    "idt_end_time",
                                    "idt_start_time",
                                    "not_ready_reason",
                                    "sync_status",
                                    "withdraw_time") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.Nsr.Status.IdtStatus, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.Nsr.Status.IdtStatus, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.declare_time.is_set or
                        self.idt_end_time.is_set or
                        self.idt_start_time.is_set or
                        self.not_ready_reason.is_set or
                        self.sync_status.is_set or
                        self.withdraw_time.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.declare_time.yfilter != YFilter.not_set or
                        self.idt_end_time.yfilter != YFilter.not_set or
                        self.idt_start_time.yfilter != YFilter.not_set or
                        self.not_ready_reason.yfilter != YFilter.not_set or
                        self.sync_status.yfilter != YFilter.not_set or
                        self.withdraw_time.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "idt-status" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/nsr/status/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.declare_time.is_set or self.declare_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.declare_time.get_name_leafdata())
                    if (self.idt_end_time.is_set or self.idt_end_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.idt_end_time.get_name_leafdata())
                    if (self.idt_start_time.is_set or self.idt_start_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.idt_start_time.get_name_leafdata())
                    if (self.not_ready_reason.is_set or self.not_ready_reason.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.not_ready_reason.get_name_leafdata())
                    if (self.sync_status.is_set or self.sync_status.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sync_status.get_name_leafdata())
                    if (self.withdraw_time.is_set or self.withdraw_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.withdraw_time.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "declare-time" or name == "idt-end-time" or name == "idt-start-time" or name == "not-ready-reason" or name == "sync-status" or name == "withdraw-time"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "declare-time"):
                        self.declare_time = value
                        self.declare_time.value_namespace = name_space
                        self.declare_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "idt-end-time"):
                        self.idt_end_time = value
                        self.idt_end_time.value_namespace = name_space
                        self.idt_end_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "idt-start-time"):
                        self.idt_start_time = value
                        self.idt_start_time.value_namespace = name_space
                        self.idt_start_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "not-ready-reason"):
                        self.not_ready_reason = value
                        self.not_ready_reason.value_namespace = name_space
                        self.not_ready_reason.value_namespace_prefix = name_space_prefix
                    if(value_path == "sync-status"):
                        self.sync_status = value
                        self.sync_status.value_namespace = name_space
                        self.sync_status.value_namespace_prefix = name_space_prefix
                    if(value_path == "withdraw-time"):
                        self.withdraw_time = value
                        self.withdraw_time.value_namespace = name_space
                        self.withdraw_time.value_namespace_prefix = name_space_prefix


            class PreviousIdtStatus(Entity):
                """
                Previous IDT status
                
                .. attribute:: declare_time
                
                	Declare ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_end_time
                
                	IDT end timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_start_time
                
                	IDT start timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: not_ready_reason
                
                	Not ready reason
                	**type**\:   :py:class:`RsvpProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpProcNsrNotReadyReason>`
                
                .. attribute:: sync_status
                
                	Sync status
                	**type**\:   :py:class:`RsvpSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpSyncStatus>`
                
                .. attribute:: withdraw_time
                
                	Withdraw ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.Nsr.Status.PreviousIdtStatus, self).__init__()

                    self.yang_name = "previous-idt-status"
                    self.yang_parent_name = "status"

                    self.declare_time = YLeaf(YType.uint32, "declare-time")

                    self.idt_end_time = YLeaf(YType.uint32, "idt-end-time")

                    self.idt_start_time = YLeaf(YType.uint32, "idt-start-time")

                    self.not_ready_reason = YLeaf(YType.enumeration, "not-ready-reason")

                    self.sync_status = YLeaf(YType.enumeration, "sync-status")

                    self.withdraw_time = YLeaf(YType.uint32, "withdraw-time")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("declare_time",
                                    "idt_end_time",
                                    "idt_start_time",
                                    "not_ready_reason",
                                    "sync_status",
                                    "withdraw_time") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.Nsr.Status.PreviousIdtStatus, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.Nsr.Status.PreviousIdtStatus, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.declare_time.is_set or
                        self.idt_end_time.is_set or
                        self.idt_start_time.is_set or
                        self.not_ready_reason.is_set or
                        self.sync_status.is_set or
                        self.withdraw_time.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.declare_time.yfilter != YFilter.not_set or
                        self.idt_end_time.yfilter != YFilter.not_set or
                        self.idt_start_time.yfilter != YFilter.not_set or
                        self.not_ready_reason.yfilter != YFilter.not_set or
                        self.sync_status.yfilter != YFilter.not_set or
                        self.withdraw_time.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "previous-idt-status" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/nsr/status/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.declare_time.is_set or self.declare_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.declare_time.get_name_leafdata())
                    if (self.idt_end_time.is_set or self.idt_end_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.idt_end_time.get_name_leafdata())
                    if (self.idt_start_time.is_set or self.idt_start_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.idt_start_time.get_name_leafdata())
                    if (self.not_ready_reason.is_set or self.not_ready_reason.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.not_ready_reason.get_name_leafdata())
                    if (self.sync_status.is_set or self.sync_status.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sync_status.get_name_leafdata())
                    if (self.withdraw_time.is_set or self.withdraw_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.withdraw_time.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "declare-time" or name == "idt-end-time" or name == "idt-start-time" or name == "not-ready-reason" or name == "sync-status" or name == "withdraw-time"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "declare-time"):
                        self.declare_time = value
                        self.declare_time.value_namespace = name_space
                        self.declare_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "idt-end-time"):
                        self.idt_end_time = value
                        self.idt_end_time.value_namespace = name_space
                        self.idt_end_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "idt-start-time"):
                        self.idt_start_time = value
                        self.idt_start_time.value_namespace = name_space
                        self.idt_start_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "not-ready-reason"):
                        self.not_ready_reason = value
                        self.not_ready_reason.value_namespace = name_space
                        self.not_ready_reason.value_namespace_prefix = name_space_prefix
                    if(value_path == "sync-status"):
                        self.sync_status = value
                        self.sync_status.value_namespace = name_space
                        self.sync_status.value_namespace_prefix = name_space_prefix
                    if(value_path == "withdraw-time"):
                        self.withdraw_time = value
                        self.withdraw_time.value_namespace = name_space
                        self.withdraw_time.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.role.is_set or
                    (self.idt_status is not None and self.idt_status.has_data()) or
                    (self.previous_idt_status is not None and self.previous_idt_status.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.role.yfilter != YFilter.not_set or
                    (self.idt_status is not None and self.idt_status.has_operation()) or
                    (self.previous_idt_status is not None and self.previous_idt_status.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "status" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/nsr/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.role.is_set or self.role.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.role.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "idt-status"):
                    if (self.idt_status is None):
                        self.idt_status = Rsvp.Nsr.Status.IdtStatus()
                        self.idt_status.parent = self
                        self._children_name_map["idt_status"] = "idt-status"
                    return self.idt_status

                if (child_yang_name == "previous-idt-status"):
                    if (self.previous_idt_status is None):
                        self.previous_idt_status = Rsvp.Nsr.Status.PreviousIdtStatus()
                        self.previous_idt_status.parent = self
                        self._children_name_map["previous_idt_status"] = "previous-idt-status"
                    return self.previous_idt_status

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "idt-status" or name == "previous-idt-status" or name == "role"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "role"):
                    self.role = value
                    self.role.value_namespace = name_space
                    self.role.value_namespace_prefix = name_space_prefix

        def has_data(self):
            return (self.status is not None and self.status.has_data())

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                (self.status is not None and self.status.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "nsr" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "status"):
                if (self.status is None):
                    self.status = Rsvp.Nsr.Status()
                    self.status.parent = self
                    self._children_name_map["status"] = "status"
                return self.status

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "status"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class Summary(Entity):
        """
        RSVP summary information
        
        .. attribute:: database_counters
        
        	All database counters
        	**type**\:   :py:class:`DatabaseCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Summary.DatabaseCounters>`
        
        .. attribute:: interfaces
        
        	Total interfaces
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: issu_status
        
        	Issu status
        	**type**\:   :py:class:`IssuStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Summary.IssuStatus>`
        
        .. attribute:: ls_ps
        
        	Total LSPs
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: nsr_status
        
        	NSR status
        	**type**\:   :py:class:`NsrStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Summary.NsrStatus>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Rsvp.Summary, self).__init__()

            self.yang_name = "summary"
            self.yang_parent_name = "rsvp"

            self.interfaces = YLeaf(YType.uint32, "interfaces")

            self.ls_ps = YLeaf(YType.uint32, "ls-ps")

            self.database_counters = Rsvp.Summary.DatabaseCounters()
            self.database_counters.parent = self
            self._children_name_map["database_counters"] = "database-counters"
            self._children_yang_names.add("database-counters")

            self.issu_status = Rsvp.Summary.IssuStatus()
            self.issu_status.parent = self
            self._children_name_map["issu_status"] = "issu-status"
            self._children_yang_names.add("issu-status")

            self.nsr_status = Rsvp.Summary.NsrStatus()
            self.nsr_status.parent = self
            self._children_name_map["nsr_status"] = "nsr-status"
            self._children_yang_names.add("nsr-status")

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in ("interfaces",
                            "ls_ps") and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(Rsvp.Summary, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(Rsvp.Summary, self).__setattr__(name, value)


        class IssuStatus(Entity):
            """
            Issu status
            
            .. attribute:: idt_status
            
            	IDT status
            	**type**\:   :py:class:`IdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Summary.IssuStatus.IdtStatus>`
            
            .. attribute:: previous_idt_status
            
            	Previous IDT status
            	**type**\:   :py:class:`PreviousIdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Summary.IssuStatus.PreviousIdtStatus>`
            
            .. attribute:: role
            
            	Process role
            	**type**\:   :py:class:`RsvpProcRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpProcRole>`
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Rsvp.Summary.IssuStatus, self).__init__()

                self.yang_name = "issu-status"
                self.yang_parent_name = "summary"

                self.role = YLeaf(YType.enumeration, "role")

                self.idt_status = Rsvp.Summary.IssuStatus.IdtStatus()
                self.idt_status.parent = self
                self._children_name_map["idt_status"] = "idt-status"
                self._children_yang_names.add("idt-status")

                self.previous_idt_status = Rsvp.Summary.IssuStatus.PreviousIdtStatus()
                self.previous_idt_status.parent = self
                self._children_name_map["previous_idt_status"] = "previous-idt-status"
                self._children_yang_names.add("previous-idt-status")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("role") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Rsvp.Summary.IssuStatus, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Rsvp.Summary.IssuStatus, self).__setattr__(name, value)


            class IdtStatus(Entity):
                """
                IDT status
                
                .. attribute:: declare_time
                
                	Declare ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_end_time
                
                	IDT end timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_start_time
                
                	IDT start timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: not_ready_reason
                
                	Not ready reason
                	**type**\:   :py:class:`RsvpProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpProcNsrNotReadyReason>`
                
                .. attribute:: sync_status
                
                	Sync status
                	**type**\:   :py:class:`RsvpSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpSyncStatus>`
                
                .. attribute:: withdraw_time
                
                	Withdraw ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.Summary.IssuStatus.IdtStatus, self).__init__()

                    self.yang_name = "idt-status"
                    self.yang_parent_name = "issu-status"

                    self.declare_time = YLeaf(YType.uint32, "declare-time")

                    self.idt_end_time = YLeaf(YType.uint32, "idt-end-time")

                    self.idt_start_time = YLeaf(YType.uint32, "idt-start-time")

                    self.not_ready_reason = YLeaf(YType.enumeration, "not-ready-reason")

                    self.sync_status = YLeaf(YType.enumeration, "sync-status")

                    self.withdraw_time = YLeaf(YType.uint32, "withdraw-time")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("declare_time",
                                    "idt_end_time",
                                    "idt_start_time",
                                    "not_ready_reason",
                                    "sync_status",
                                    "withdraw_time") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.Summary.IssuStatus.IdtStatus, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.Summary.IssuStatus.IdtStatus, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.declare_time.is_set or
                        self.idt_end_time.is_set or
                        self.idt_start_time.is_set or
                        self.not_ready_reason.is_set or
                        self.sync_status.is_set or
                        self.withdraw_time.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.declare_time.yfilter != YFilter.not_set or
                        self.idt_end_time.yfilter != YFilter.not_set or
                        self.idt_start_time.yfilter != YFilter.not_set or
                        self.not_ready_reason.yfilter != YFilter.not_set or
                        self.sync_status.yfilter != YFilter.not_set or
                        self.withdraw_time.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "idt-status" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/summary/issu-status/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.declare_time.is_set or self.declare_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.declare_time.get_name_leafdata())
                    if (self.idt_end_time.is_set or self.idt_end_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.idt_end_time.get_name_leafdata())
                    if (self.idt_start_time.is_set or self.idt_start_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.idt_start_time.get_name_leafdata())
                    if (self.not_ready_reason.is_set or self.not_ready_reason.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.not_ready_reason.get_name_leafdata())
                    if (self.sync_status.is_set or self.sync_status.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sync_status.get_name_leafdata())
                    if (self.withdraw_time.is_set or self.withdraw_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.withdraw_time.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "declare-time" or name == "idt-end-time" or name == "idt-start-time" or name == "not-ready-reason" or name == "sync-status" or name == "withdraw-time"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "declare-time"):
                        self.declare_time = value
                        self.declare_time.value_namespace = name_space
                        self.declare_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "idt-end-time"):
                        self.idt_end_time = value
                        self.idt_end_time.value_namespace = name_space
                        self.idt_end_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "idt-start-time"):
                        self.idt_start_time = value
                        self.idt_start_time.value_namespace = name_space
                        self.idt_start_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "not-ready-reason"):
                        self.not_ready_reason = value
                        self.not_ready_reason.value_namespace = name_space
                        self.not_ready_reason.value_namespace_prefix = name_space_prefix
                    if(value_path == "sync-status"):
                        self.sync_status = value
                        self.sync_status.value_namespace = name_space
                        self.sync_status.value_namespace_prefix = name_space_prefix
                    if(value_path == "withdraw-time"):
                        self.withdraw_time = value
                        self.withdraw_time.value_namespace = name_space
                        self.withdraw_time.value_namespace_prefix = name_space_prefix


            class PreviousIdtStatus(Entity):
                """
                Previous IDT status
                
                .. attribute:: declare_time
                
                	Declare ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_end_time
                
                	IDT end timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_start_time
                
                	IDT start timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: not_ready_reason
                
                	Not ready reason
                	**type**\:   :py:class:`RsvpProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpProcNsrNotReadyReason>`
                
                .. attribute:: sync_status
                
                	Sync status
                	**type**\:   :py:class:`RsvpSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpSyncStatus>`
                
                .. attribute:: withdraw_time
                
                	Withdraw ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.Summary.IssuStatus.PreviousIdtStatus, self).__init__()

                    self.yang_name = "previous-idt-status"
                    self.yang_parent_name = "issu-status"

                    self.declare_time = YLeaf(YType.uint32, "declare-time")

                    self.idt_end_time = YLeaf(YType.uint32, "idt-end-time")

                    self.idt_start_time = YLeaf(YType.uint32, "idt-start-time")

                    self.not_ready_reason = YLeaf(YType.enumeration, "not-ready-reason")

                    self.sync_status = YLeaf(YType.enumeration, "sync-status")

                    self.withdraw_time = YLeaf(YType.uint32, "withdraw-time")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("declare_time",
                                    "idt_end_time",
                                    "idt_start_time",
                                    "not_ready_reason",
                                    "sync_status",
                                    "withdraw_time") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.Summary.IssuStatus.PreviousIdtStatus, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.Summary.IssuStatus.PreviousIdtStatus, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.declare_time.is_set or
                        self.idt_end_time.is_set or
                        self.idt_start_time.is_set or
                        self.not_ready_reason.is_set or
                        self.sync_status.is_set or
                        self.withdraw_time.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.declare_time.yfilter != YFilter.not_set or
                        self.idt_end_time.yfilter != YFilter.not_set or
                        self.idt_start_time.yfilter != YFilter.not_set or
                        self.not_ready_reason.yfilter != YFilter.not_set or
                        self.sync_status.yfilter != YFilter.not_set or
                        self.withdraw_time.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "previous-idt-status" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/summary/issu-status/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.declare_time.is_set or self.declare_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.declare_time.get_name_leafdata())
                    if (self.idt_end_time.is_set or self.idt_end_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.idt_end_time.get_name_leafdata())
                    if (self.idt_start_time.is_set or self.idt_start_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.idt_start_time.get_name_leafdata())
                    if (self.not_ready_reason.is_set or self.not_ready_reason.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.not_ready_reason.get_name_leafdata())
                    if (self.sync_status.is_set or self.sync_status.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sync_status.get_name_leafdata())
                    if (self.withdraw_time.is_set or self.withdraw_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.withdraw_time.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "declare-time" or name == "idt-end-time" or name == "idt-start-time" or name == "not-ready-reason" or name == "sync-status" or name == "withdraw-time"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "declare-time"):
                        self.declare_time = value
                        self.declare_time.value_namespace = name_space
                        self.declare_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "idt-end-time"):
                        self.idt_end_time = value
                        self.idt_end_time.value_namespace = name_space
                        self.idt_end_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "idt-start-time"):
                        self.idt_start_time = value
                        self.idt_start_time.value_namespace = name_space
                        self.idt_start_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "not-ready-reason"):
                        self.not_ready_reason = value
                        self.not_ready_reason.value_namespace = name_space
                        self.not_ready_reason.value_namespace_prefix = name_space_prefix
                    if(value_path == "sync-status"):
                        self.sync_status = value
                        self.sync_status.value_namespace = name_space
                        self.sync_status.value_namespace_prefix = name_space_prefix
                    if(value_path == "withdraw-time"):
                        self.withdraw_time = value
                        self.withdraw_time.value_namespace = name_space
                        self.withdraw_time.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.role.is_set or
                    (self.idt_status is not None and self.idt_status.has_data()) or
                    (self.previous_idt_status is not None and self.previous_idt_status.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.role.yfilter != YFilter.not_set or
                    (self.idt_status is not None and self.idt_status.has_operation()) or
                    (self.previous_idt_status is not None and self.previous_idt_status.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "issu-status" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/summary/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.role.is_set or self.role.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.role.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "idt-status"):
                    if (self.idt_status is None):
                        self.idt_status = Rsvp.Summary.IssuStatus.IdtStatus()
                        self.idt_status.parent = self
                        self._children_name_map["idt_status"] = "idt-status"
                    return self.idt_status

                if (child_yang_name == "previous-idt-status"):
                    if (self.previous_idt_status is None):
                        self.previous_idt_status = Rsvp.Summary.IssuStatus.PreviousIdtStatus()
                        self.previous_idt_status.parent = self
                        self._children_name_map["previous_idt_status"] = "previous-idt-status"
                    return self.previous_idt_status

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "idt-status" or name == "previous-idt-status" or name == "role"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "role"):
                    self.role = value
                    self.role.value_namespace = name_space
                    self.role.value_namespace_prefix = name_space_prefix


        class NsrStatus(Entity):
            """
            NSR status
            
            .. attribute:: idt_status
            
            	IDT status
            	**type**\:   :py:class:`IdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Summary.NsrStatus.IdtStatus>`
            
            .. attribute:: previous_idt_status
            
            	Previous IDT status
            	**type**\:   :py:class:`PreviousIdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Summary.NsrStatus.PreviousIdtStatus>`
            
            .. attribute:: role
            
            	Process role
            	**type**\:   :py:class:`RsvpProcRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpProcRole>`
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Rsvp.Summary.NsrStatus, self).__init__()

                self.yang_name = "nsr-status"
                self.yang_parent_name = "summary"

                self.role = YLeaf(YType.enumeration, "role")

                self.idt_status = Rsvp.Summary.NsrStatus.IdtStatus()
                self.idt_status.parent = self
                self._children_name_map["idt_status"] = "idt-status"
                self._children_yang_names.add("idt-status")

                self.previous_idt_status = Rsvp.Summary.NsrStatus.PreviousIdtStatus()
                self.previous_idt_status.parent = self
                self._children_name_map["previous_idt_status"] = "previous-idt-status"
                self._children_yang_names.add("previous-idt-status")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("role") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Rsvp.Summary.NsrStatus, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Rsvp.Summary.NsrStatus, self).__setattr__(name, value)


            class IdtStatus(Entity):
                """
                IDT status
                
                .. attribute:: declare_time
                
                	Declare ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_end_time
                
                	IDT end timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_start_time
                
                	IDT start timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: not_ready_reason
                
                	Not ready reason
                	**type**\:   :py:class:`RsvpProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpProcNsrNotReadyReason>`
                
                .. attribute:: sync_status
                
                	Sync status
                	**type**\:   :py:class:`RsvpSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpSyncStatus>`
                
                .. attribute:: withdraw_time
                
                	Withdraw ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.Summary.NsrStatus.IdtStatus, self).__init__()

                    self.yang_name = "idt-status"
                    self.yang_parent_name = "nsr-status"

                    self.declare_time = YLeaf(YType.uint32, "declare-time")

                    self.idt_end_time = YLeaf(YType.uint32, "idt-end-time")

                    self.idt_start_time = YLeaf(YType.uint32, "idt-start-time")

                    self.not_ready_reason = YLeaf(YType.enumeration, "not-ready-reason")

                    self.sync_status = YLeaf(YType.enumeration, "sync-status")

                    self.withdraw_time = YLeaf(YType.uint32, "withdraw-time")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("declare_time",
                                    "idt_end_time",
                                    "idt_start_time",
                                    "not_ready_reason",
                                    "sync_status",
                                    "withdraw_time") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.Summary.NsrStatus.IdtStatus, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.Summary.NsrStatus.IdtStatus, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.declare_time.is_set or
                        self.idt_end_time.is_set or
                        self.idt_start_time.is_set or
                        self.not_ready_reason.is_set or
                        self.sync_status.is_set or
                        self.withdraw_time.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.declare_time.yfilter != YFilter.not_set or
                        self.idt_end_time.yfilter != YFilter.not_set or
                        self.idt_start_time.yfilter != YFilter.not_set or
                        self.not_ready_reason.yfilter != YFilter.not_set or
                        self.sync_status.yfilter != YFilter.not_set or
                        self.withdraw_time.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "idt-status" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/summary/nsr-status/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.declare_time.is_set or self.declare_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.declare_time.get_name_leafdata())
                    if (self.idt_end_time.is_set or self.idt_end_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.idt_end_time.get_name_leafdata())
                    if (self.idt_start_time.is_set or self.idt_start_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.idt_start_time.get_name_leafdata())
                    if (self.not_ready_reason.is_set or self.not_ready_reason.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.not_ready_reason.get_name_leafdata())
                    if (self.sync_status.is_set or self.sync_status.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sync_status.get_name_leafdata())
                    if (self.withdraw_time.is_set or self.withdraw_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.withdraw_time.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "declare-time" or name == "idt-end-time" or name == "idt-start-time" or name == "not-ready-reason" or name == "sync-status" or name == "withdraw-time"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "declare-time"):
                        self.declare_time = value
                        self.declare_time.value_namespace = name_space
                        self.declare_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "idt-end-time"):
                        self.idt_end_time = value
                        self.idt_end_time.value_namespace = name_space
                        self.idt_end_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "idt-start-time"):
                        self.idt_start_time = value
                        self.idt_start_time.value_namespace = name_space
                        self.idt_start_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "not-ready-reason"):
                        self.not_ready_reason = value
                        self.not_ready_reason.value_namespace = name_space
                        self.not_ready_reason.value_namespace_prefix = name_space_prefix
                    if(value_path == "sync-status"):
                        self.sync_status = value
                        self.sync_status.value_namespace = name_space
                        self.sync_status.value_namespace_prefix = name_space_prefix
                    if(value_path == "withdraw-time"):
                        self.withdraw_time = value
                        self.withdraw_time.value_namespace = name_space
                        self.withdraw_time.value_namespace_prefix = name_space_prefix


            class PreviousIdtStatus(Entity):
                """
                Previous IDT status
                
                .. attribute:: declare_time
                
                	Declare ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_end_time
                
                	IDT end timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_start_time
                
                	IDT start timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: not_ready_reason
                
                	Not ready reason
                	**type**\:   :py:class:`RsvpProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpProcNsrNotReadyReason>`
                
                .. attribute:: sync_status
                
                	Sync status
                	**type**\:   :py:class:`RsvpSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpSyncStatus>`
                
                .. attribute:: withdraw_time
                
                	Withdraw ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.Summary.NsrStatus.PreviousIdtStatus, self).__init__()

                    self.yang_name = "previous-idt-status"
                    self.yang_parent_name = "nsr-status"

                    self.declare_time = YLeaf(YType.uint32, "declare-time")

                    self.idt_end_time = YLeaf(YType.uint32, "idt-end-time")

                    self.idt_start_time = YLeaf(YType.uint32, "idt-start-time")

                    self.not_ready_reason = YLeaf(YType.enumeration, "not-ready-reason")

                    self.sync_status = YLeaf(YType.enumeration, "sync-status")

                    self.withdraw_time = YLeaf(YType.uint32, "withdraw-time")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("declare_time",
                                    "idt_end_time",
                                    "idt_start_time",
                                    "not_ready_reason",
                                    "sync_status",
                                    "withdraw_time") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.Summary.NsrStatus.PreviousIdtStatus, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.Summary.NsrStatus.PreviousIdtStatus, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.declare_time.is_set or
                        self.idt_end_time.is_set or
                        self.idt_start_time.is_set or
                        self.not_ready_reason.is_set or
                        self.sync_status.is_set or
                        self.withdraw_time.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.declare_time.yfilter != YFilter.not_set or
                        self.idt_end_time.yfilter != YFilter.not_set or
                        self.idt_start_time.yfilter != YFilter.not_set or
                        self.not_ready_reason.yfilter != YFilter.not_set or
                        self.sync_status.yfilter != YFilter.not_set or
                        self.withdraw_time.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "previous-idt-status" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/summary/nsr-status/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.declare_time.is_set or self.declare_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.declare_time.get_name_leafdata())
                    if (self.idt_end_time.is_set or self.idt_end_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.idt_end_time.get_name_leafdata())
                    if (self.idt_start_time.is_set or self.idt_start_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.idt_start_time.get_name_leafdata())
                    if (self.not_ready_reason.is_set or self.not_ready_reason.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.not_ready_reason.get_name_leafdata())
                    if (self.sync_status.is_set or self.sync_status.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sync_status.get_name_leafdata())
                    if (self.withdraw_time.is_set or self.withdraw_time.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.withdraw_time.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "declare-time" or name == "idt-end-time" or name == "idt-start-time" or name == "not-ready-reason" or name == "sync-status" or name == "withdraw-time"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "declare-time"):
                        self.declare_time = value
                        self.declare_time.value_namespace = name_space
                        self.declare_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "idt-end-time"):
                        self.idt_end_time = value
                        self.idt_end_time.value_namespace = name_space
                        self.idt_end_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "idt-start-time"):
                        self.idt_start_time = value
                        self.idt_start_time.value_namespace = name_space
                        self.idt_start_time.value_namespace_prefix = name_space_prefix
                    if(value_path == "not-ready-reason"):
                        self.not_ready_reason = value
                        self.not_ready_reason.value_namespace = name_space
                        self.not_ready_reason.value_namespace_prefix = name_space_prefix
                    if(value_path == "sync-status"):
                        self.sync_status = value
                        self.sync_status.value_namespace = name_space
                        self.sync_status.value_namespace_prefix = name_space_prefix
                    if(value_path == "withdraw-time"):
                        self.withdraw_time = value
                        self.withdraw_time.value_namespace = name_space
                        self.withdraw_time.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.role.is_set or
                    (self.idt_status is not None and self.idt_status.has_data()) or
                    (self.previous_idt_status is not None and self.previous_idt_status.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.role.yfilter != YFilter.not_set or
                    (self.idt_status is not None and self.idt_status.has_operation()) or
                    (self.previous_idt_status is not None and self.previous_idt_status.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "nsr-status" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/summary/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.role.is_set or self.role.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.role.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "idt-status"):
                    if (self.idt_status is None):
                        self.idt_status = Rsvp.Summary.NsrStatus.IdtStatus()
                        self.idt_status.parent = self
                        self._children_name_map["idt_status"] = "idt-status"
                    return self.idt_status

                if (child_yang_name == "previous-idt-status"):
                    if (self.previous_idt_status is None):
                        self.previous_idt_status = Rsvp.Summary.NsrStatus.PreviousIdtStatus()
                        self.previous_idt_status.parent = self
                        self._children_name_map["previous_idt_status"] = "previous-idt-status"
                    return self.previous_idt_status

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "idt-status" or name == "previous-idt-status" or name == "role"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "role"):
                    self.role = value
                    self.role.value_namespace = name_space
                    self.role.value_namespace_prefix = name_space_prefix


        class DatabaseCounters(Entity):
            """
            All database counters
            
            .. attribute:: incoming_paths
            
            	Number of locally created and incoming path states
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: incoming_reservations
            
            	Number of locally created and incoming reservation states
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: interfaces
            
            	Number of Interfaces
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: outgoing_paths
            
            	Number of outgoing path states
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: outgoing_reservations
            
            	Number of outgoing reservation states
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: sessions
            
            	Number of sessions
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Rsvp.Summary.DatabaseCounters, self).__init__()

                self.yang_name = "database-counters"
                self.yang_parent_name = "summary"

                self.incoming_paths = YLeaf(YType.uint32, "incoming-paths")

                self.incoming_reservations = YLeaf(YType.uint32, "incoming-reservations")

                self.interfaces = YLeaf(YType.uint32, "interfaces")

                self.outgoing_paths = YLeaf(YType.uint32, "outgoing-paths")

                self.outgoing_reservations = YLeaf(YType.uint32, "outgoing-reservations")

                self.sessions = YLeaf(YType.uint32, "sessions")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("incoming_paths",
                                "incoming_reservations",
                                "interfaces",
                                "outgoing_paths",
                                "outgoing_reservations",
                                "sessions") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Rsvp.Summary.DatabaseCounters, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Rsvp.Summary.DatabaseCounters, self).__setattr__(name, value)

            def has_data(self):
                return (
                    self.incoming_paths.is_set or
                    self.incoming_reservations.is_set or
                    self.interfaces.is_set or
                    self.outgoing_paths.is_set or
                    self.outgoing_reservations.is_set or
                    self.sessions.is_set)

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.incoming_paths.yfilter != YFilter.not_set or
                    self.incoming_reservations.yfilter != YFilter.not_set or
                    self.interfaces.yfilter != YFilter.not_set or
                    self.outgoing_paths.yfilter != YFilter.not_set or
                    self.outgoing_reservations.yfilter != YFilter.not_set or
                    self.sessions.yfilter != YFilter.not_set)

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "database-counters" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/summary/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.incoming_paths.is_set or self.incoming_paths.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.incoming_paths.get_name_leafdata())
                if (self.incoming_reservations.is_set or self.incoming_reservations.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.incoming_reservations.get_name_leafdata())
                if (self.interfaces.is_set or self.interfaces.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.interfaces.get_name_leafdata())
                if (self.outgoing_paths.is_set or self.outgoing_paths.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.outgoing_paths.get_name_leafdata())
                if (self.outgoing_reservations.is_set or self.outgoing_reservations.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.outgoing_reservations.get_name_leafdata())
                if (self.sessions.is_set or self.sessions.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.sessions.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "incoming-paths" or name == "incoming-reservations" or name == "interfaces" or name == "outgoing-paths" or name == "outgoing-reservations" or name == "sessions"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "incoming-paths"):
                    self.incoming_paths = value
                    self.incoming_paths.value_namespace = name_space
                    self.incoming_paths.value_namespace_prefix = name_space_prefix
                if(value_path == "incoming-reservations"):
                    self.incoming_reservations = value
                    self.incoming_reservations.value_namespace = name_space
                    self.incoming_reservations.value_namespace_prefix = name_space_prefix
                if(value_path == "interfaces"):
                    self.interfaces = value
                    self.interfaces.value_namespace = name_space
                    self.interfaces.value_namespace_prefix = name_space_prefix
                if(value_path == "outgoing-paths"):
                    self.outgoing_paths = value
                    self.outgoing_paths.value_namespace = name_space
                    self.outgoing_paths.value_namespace_prefix = name_space_prefix
                if(value_path == "outgoing-reservations"):
                    self.outgoing_reservations = value
                    self.outgoing_reservations.value_namespace = name_space
                    self.outgoing_reservations.value_namespace_prefix = name_space_prefix
                if(value_path == "sessions"):
                    self.sessions = value
                    self.sessions.value_namespace = name_space
                    self.sessions.value_namespace_prefix = name_space_prefix

        def has_data(self):
            return (
                self.interfaces.is_set or
                self.ls_ps.is_set or
                (self.database_counters is not None and self.database_counters.has_data()) or
                (self.issu_status is not None and self.issu_status.has_data()) or
                (self.nsr_status is not None and self.nsr_status.has_data()))

        def has_operation(self):
            return (
                self.yfilter != YFilter.not_set or
                self.interfaces.yfilter != YFilter.not_set or
                self.ls_ps.yfilter != YFilter.not_set or
                (self.database_counters is not None and self.database_counters.has_operation()) or
                (self.issu_status is not None and self.issu_status.has_operation()) or
                (self.nsr_status is not None and self.nsr_status.has_operation()))

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "summary" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()
            if (self.interfaces.is_set or self.interfaces.yfilter != YFilter.not_set):
                leaf_name_data.append(self.interfaces.get_name_leafdata())
            if (self.ls_ps.is_set or self.ls_ps.yfilter != YFilter.not_set):
                leaf_name_data.append(self.ls_ps.get_name_leafdata())

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "database-counters"):
                if (self.database_counters is None):
                    self.database_counters = Rsvp.Summary.DatabaseCounters()
                    self.database_counters.parent = self
                    self._children_name_map["database_counters"] = "database-counters"
                return self.database_counters

            if (child_yang_name == "issu-status"):
                if (self.issu_status is None):
                    self.issu_status = Rsvp.Summary.IssuStatus()
                    self.issu_status.parent = self
                    self._children_name_map["issu_status"] = "issu-status"
                return self.issu_status

            if (child_yang_name == "nsr-status"):
                if (self.nsr_status is None):
                    self.nsr_status = Rsvp.Summary.NsrStatus()
                    self.nsr_status.parent = self
                    self._children_name_map["nsr_status"] = "nsr-status"
                return self.nsr_status

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "database-counters" or name == "issu-status" or name == "nsr-status" or name == "interfaces" or name == "ls-ps"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            if(value_path == "interfaces"):
                self.interfaces = value
                self.interfaces.value_namespace = name_space
                self.interfaces.value_namespace_prefix = name_space_prefix
            if(value_path == "ls-ps"):
                self.ls_ps = value
                self.ls_ps.value_namespace = name_space
                self.ls_ps.value_namespace_prefix = name_space_prefix


    class Frrs(Entity):
        """
        Table of detailed info about Fast Re\-route
        states
        
        .. attribute:: frr
        
        	Detailed info for a single Fast Re\-route state
        	**type**\: list of    :py:class:`Frr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Frrs.Frr>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Rsvp.Frrs, self).__init__()

            self.yang_name = "frrs"
            self.yang_parent_name = "rsvp"

            self.frr = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(Rsvp.Frrs, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(Rsvp.Frrs, self).__setattr__(name, value)


        class Frr(Entity):
            """
            Detailed info for a single Fast Re\-route state
            
            .. attribute:: destination_address
            
            	Destination Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: destination_port
            
            	Destination Port
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: extended_tunnel_id
            
            	Extended Tunnel ID
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: p2mp_id
            
            	P2MP ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: path_status
            
            	RSVP FRR Path States
            	**type**\:   :py:class:`RsvpMgmtFrrStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtFrrStateEnum>`
            
            .. attribute:: protocol
            
            	Protocol
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: reservation_status
            
            	RSVP FRR Reservation States
            	**type**\:   :py:class:`RsvpMgmtFrrStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtFrrStateEnum>`
            
            .. attribute:: s2l_sub_lsp
            
            	RSVP S2L Sub\-LSP information
            	**type**\:   :py:class:`S2LSubLsp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Frrs.Frr.S2LSubLsp>`
            
            .. attribute:: session
            
            	RSVP Session Information
            	**type**\:   :py:class:`Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Frrs.Frr.Session>`
            
            .. attribute:: session_type
            
            	Session Type
            	**type**\:   :py:class:`RsvpSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpSession>`
            
            .. attribute:: source_address
            
            	Source Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: source_port
            
            	Source Port
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: sub_group_id
            
            	Subgroup ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: sub_group_origin
            
            	Subgroup Origin
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: vrf_name
            
            	VRF Name
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Rsvp.Frrs.Frr, self).__init__()

                self.yang_name = "frr"
                self.yang_parent_name = "frrs"

                self.destination_address = YLeaf(YType.str, "destination-address")

                self.destination_port = YLeaf(YType.int32, "destination-port")

                self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                self.p2mp_id = YLeaf(YType.int32, "p2mp-id")

                self.path_status = YLeaf(YType.enumeration, "path-status")

                self.protocol = YLeaf(YType.int32, "protocol")

                self.reservation_status = YLeaf(YType.enumeration, "reservation-status")

                self.session_type = YLeaf(YType.enumeration, "session-type")

                self.source_address = YLeaf(YType.str, "source-address")

                self.source_port = YLeaf(YType.int32, "source-port")

                self.sub_group_id = YLeaf(YType.int32, "sub-group-id")

                self.sub_group_origin = YLeaf(YType.str, "sub-group-origin")

                self.vrf_name = YLeaf(YType.str, "vrf-name")

                self.s2l_sub_lsp = Rsvp.Frrs.Frr.S2LSubLsp()
                self.s2l_sub_lsp.parent = self
                self._children_name_map["s2l_sub_lsp"] = "s2l-sub-lsp"
                self._children_yang_names.add("s2l-sub-lsp")

                self.session = Rsvp.Frrs.Frr.Session()
                self.session.parent = self
                self._children_name_map["session"] = "session"
                self._children_yang_names.add("session")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("destination_address",
                                "destination_port",
                                "extended_tunnel_id",
                                "p2mp_id",
                                "path_status",
                                "protocol",
                                "reservation_status",
                                "session_type",
                                "source_address",
                                "source_port",
                                "sub_group_id",
                                "sub_group_origin",
                                "vrf_name") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Rsvp.Frrs.Frr, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Rsvp.Frrs.Frr, self).__setattr__(name, value)


            class Session(Entity):
                """
                RSVP Session Information
                
                .. attribute:: rsvp_session
                
                	RSVP Session
                	**type**\:   :py:class:`RsvpSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Frrs.Frr.Session.RsvpSession>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.Frrs.Frr.Session, self).__init__()

                    self.yang_name = "session"
                    self.yang_parent_name = "frr"

                    self.rsvp_session = Rsvp.Frrs.Frr.Session.RsvpSession()
                    self.rsvp_session.parent = self
                    self._children_name_map["rsvp_session"] = "rsvp-session"
                    self._children_yang_names.add("rsvp-session")


                class RsvpSession(Entity):
                    """
                    RSVP Session
                    
                    .. attribute:: ipv4
                    
                    	UDP IPv4 session
                    	**type**\:   :py:class:`Ipv4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Frrs.Frr.Session.RsvpSession.Ipv4>`
                    
                    .. attribute:: ipv4_lsp_session
                    
                    	IPv4 LSP session
                    	**type**\:   :py:class:`Ipv4LspSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Frrs.Frr.Session.RsvpSession.Ipv4LspSession>`
                    
                    .. attribute:: ipv4_p2mp_lsp_session
                    
                    	IPv4 P2MP LSP session
                    	**type**\:   :py:class:`Ipv4P2MpLspSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Frrs.Frr.Session.RsvpSession.Ipv4P2MpLspSession>`
                    
                    .. attribute:: ipv4_uni_session
                    
                    	IPv4 UNI session
                    	**type**\:   :py:class:`Ipv4UniSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.Frrs.Frr.Session.RsvpSession.Ipv4UniSession>`
                    
                    .. attribute:: session_type
                    
                    	SessionType
                    	**type**\:   :py:class:`RsvpMgmtSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtSession>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.Frrs.Frr.Session.RsvpSession, self).__init__()

                        self.yang_name = "rsvp-session"
                        self.yang_parent_name = "session"

                        self.session_type = YLeaf(YType.enumeration, "session-type")

                        self.ipv4 = Rsvp.Frrs.Frr.Session.RsvpSession.Ipv4()
                        self.ipv4.parent = self
                        self._children_name_map["ipv4"] = "ipv4"
                        self._children_yang_names.add("ipv4")

                        self.ipv4_lsp_session = Rsvp.Frrs.Frr.Session.RsvpSession.Ipv4LspSession()
                        self.ipv4_lsp_session.parent = self
                        self._children_name_map["ipv4_lsp_session"] = "ipv4-lsp-session"
                        self._children_yang_names.add("ipv4-lsp-session")

                        self.ipv4_p2mp_lsp_session = Rsvp.Frrs.Frr.Session.RsvpSession.Ipv4P2MpLspSession()
                        self.ipv4_p2mp_lsp_session.parent = self
                        self._children_name_map["ipv4_p2mp_lsp_session"] = "ipv4-p2mp-lsp-session"
                        self._children_yang_names.add("ipv4-p2mp-lsp-session")

                        self.ipv4_uni_session = Rsvp.Frrs.Frr.Session.RsvpSession.Ipv4UniSession()
                        self.ipv4_uni_session.parent = self
                        self._children_name_map["ipv4_uni_session"] = "ipv4-uni-session"
                        self._children_yang_names.add("ipv4-uni-session")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("session_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.Frrs.Frr.Session.RsvpSession, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.Frrs.Frr.Session.RsvpSession, self).__setattr__(name, value)


                    class Ipv4(Entity):
                        """
                        UDP IPv4 session
                        
                        .. attribute:: destination_address
                        
                        	Destination address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: destination_port
                        
                        	The Session Destination Port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: protocol
                        
                        	Protocol type (originally defined in RFC 790, further values in subsequent RFCs)
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.Frrs.Frr.Session.RsvpSession.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "rsvp-session"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.destination_port = YLeaf(YType.uint16, "destination-port")

                            self.protocol = YLeaf(YType.uint8, "protocol")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "destination_port",
                                            "protocol") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.Frrs.Frr.Session.RsvpSession.Ipv4, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.Frrs.Frr.Session.RsvpSession.Ipv4, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination_address.is_set or
                                self.destination_port.is_set or
                                self.protocol.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.destination_port.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/frrs/frr/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.destination_port.is_set or self.destination_port.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_port.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "destination-port" or name == "protocol"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "destination-port"):
                                self.destination_port = value
                                self.destination_port.value_namespace = name_space
                                self.destination_port.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix


                    class Ipv4LspSession(Entity):
                        """
                        IPv4 LSP session
                        
                        .. attribute:: destination_address
                        
                        	Destination address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: extended_tunnel_id
                        
                        	The Session Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: tunnel_id
                        
                        	The Session Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.Frrs.Frr.Session.RsvpSession.Ipv4LspSession, self).__init__()

                            self.yang_name = "ipv4-lsp-session"
                            self.yang_parent_name = "rsvp-session"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                            self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "extended_tunnel_id",
                                            "tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.Frrs.Frr.Session.RsvpSession.Ipv4LspSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.Frrs.Frr.Session.RsvpSession.Ipv4LspSession, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination_address.is_set or
                                self.extended_tunnel_id.is_set or
                                self.tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.extended_tunnel_id.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-lsp-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/frrs/frr/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "extended-tunnel-id" or name == "tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "extended-tunnel-id"):
                                self.extended_tunnel_id = value
                                self.extended_tunnel_id.value_namespace = name_space
                                self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix


                    class Ipv4UniSession(Entity):
                        """
                        IPv4 UNI session
                        
                        .. attribute:: destination_address
                        
                        	Destination address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: extended_address
                        
                        	The Session Extended Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: tunnel_id
                        
                        	The Session Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.Frrs.Frr.Session.RsvpSession.Ipv4UniSession, self).__init__()

                            self.yang_name = "ipv4-uni-session"
                            self.yang_parent_name = "rsvp-session"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.extended_address = YLeaf(YType.str, "extended-address")

                            self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "extended_address",
                                            "tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.Frrs.Frr.Session.RsvpSession.Ipv4UniSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.Frrs.Frr.Session.RsvpSession.Ipv4UniSession, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination_address.is_set or
                                self.extended_address.is_set or
                                self.tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.extended_address.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-uni-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/frrs/frr/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.extended_address.is_set or self.extended_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_address.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "extended-address" or name == "tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "extended-address"):
                                self.extended_address = value
                                self.extended_address.value_namespace = name_space
                                self.extended_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix


                    class Ipv4P2MpLspSession(Entity):
                        """
                        IPv4 P2MP LSP session
                        
                        .. attribute:: extended_tunnel_id
                        
                        	The Session Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: p2mp_id
                        
                        	The Point to Multipoint ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tunnel_id
                        
                        	The Session Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.Frrs.Frr.Session.RsvpSession.Ipv4P2MpLspSession, self).__init__()

                            self.yang_name = "ipv4-p2mp-lsp-session"
                            self.yang_parent_name = "rsvp-session"

                            self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                            self.p2mp_id = YLeaf(YType.uint32, "p2mp-id")

                            self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("extended_tunnel_id",
                                            "p2mp_id",
                                            "tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.Frrs.Frr.Session.RsvpSession.Ipv4P2MpLspSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.Frrs.Frr.Session.RsvpSession.Ipv4P2MpLspSession, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.extended_tunnel_id.is_set or
                                self.p2mp_id.is_set or
                                self.tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.extended_tunnel_id.yfilter != YFilter.not_set or
                                self.p2mp_id.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-p2mp-lsp-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/frrs/frr/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                            if (self.p2mp_id.is_set or self.p2mp_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.p2mp_id.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "extended-tunnel-id" or name == "p2mp-id" or name == "tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "extended-tunnel-id"):
                                self.extended_tunnel_id = value
                                self.extended_tunnel_id.value_namespace = name_space
                                self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "p2mp-id"):
                                self.p2mp_id = value
                                self.p2mp_id.value_namespace = name_space
                                self.p2mp_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.session_type.is_set or
                            (self.ipv4 is not None and self.ipv4.has_data()) or
                            (self.ipv4_lsp_session is not None and self.ipv4_lsp_session.has_data()) or
                            (self.ipv4_p2mp_lsp_session is not None and self.ipv4_p2mp_lsp_session.has_data()) or
                            (self.ipv4_uni_session is not None and self.ipv4_uni_session.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.session_type.yfilter != YFilter.not_set or
                            (self.ipv4 is not None and self.ipv4.has_operation()) or
                            (self.ipv4_lsp_session is not None and self.ipv4_lsp_session.has_operation()) or
                            (self.ipv4_p2mp_lsp_session is not None and self.ipv4_p2mp_lsp_session.has_operation()) or
                            (self.ipv4_uni_session is not None and self.ipv4_uni_session.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rsvp-session" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/frrs/frr/session/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.session_type.is_set or self.session_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.session_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "ipv4"):
                            if (self.ipv4 is None):
                                self.ipv4 = Rsvp.Frrs.Frr.Session.RsvpSession.Ipv4()
                                self.ipv4.parent = self
                                self._children_name_map["ipv4"] = "ipv4"
                            return self.ipv4

                        if (child_yang_name == "ipv4-lsp-session"):
                            if (self.ipv4_lsp_session is None):
                                self.ipv4_lsp_session = Rsvp.Frrs.Frr.Session.RsvpSession.Ipv4LspSession()
                                self.ipv4_lsp_session.parent = self
                                self._children_name_map["ipv4_lsp_session"] = "ipv4-lsp-session"
                            return self.ipv4_lsp_session

                        if (child_yang_name == "ipv4-p2mp-lsp-session"):
                            if (self.ipv4_p2mp_lsp_session is None):
                                self.ipv4_p2mp_lsp_session = Rsvp.Frrs.Frr.Session.RsvpSession.Ipv4P2MpLspSession()
                                self.ipv4_p2mp_lsp_session.parent = self
                                self._children_name_map["ipv4_p2mp_lsp_session"] = "ipv4-p2mp-lsp-session"
                            return self.ipv4_p2mp_lsp_session

                        if (child_yang_name == "ipv4-uni-session"):
                            if (self.ipv4_uni_session is None):
                                self.ipv4_uni_session = Rsvp.Frrs.Frr.Session.RsvpSession.Ipv4UniSession()
                                self.ipv4_uni_session.parent = self
                                self._children_name_map["ipv4_uni_session"] = "ipv4-uni-session"
                            return self.ipv4_uni_session

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ipv4" or name == "ipv4-lsp-session" or name == "ipv4-p2mp-lsp-session" or name == "ipv4-uni-session" or name == "session-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "session-type"):
                            self.session_type = value
                            self.session_type.value_namespace = name_space
                            self.session_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (self.rsvp_session is not None and self.rsvp_session.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.rsvp_session is not None and self.rsvp_session.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "session" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/frrs/frr/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "rsvp-session"):
                        if (self.rsvp_session is None):
                            self.rsvp_session = Rsvp.Frrs.Frr.Session.RsvpSession()
                            self.rsvp_session.parent = self
                            self._children_name_map["rsvp_session"] = "rsvp-session"
                        return self.rsvp_session

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "rsvp-session"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class S2LSubLsp(Entity):
                """
                RSVP S2L Sub\-LSP information
                
                .. attribute:: s2l_destination_address
                
                	S2L Sub\-LSP Destination Address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.Frrs.Frr.S2LSubLsp, self).__init__()

                    self.yang_name = "s2l-sub-lsp"
                    self.yang_parent_name = "frr"

                    self.s2l_destination_address = YLeaf(YType.str, "s2l-destination-address")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("s2l_destination_address") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.Frrs.Frr.S2LSubLsp, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.Frrs.Frr.S2LSubLsp, self).__setattr__(name, value)

                def has_data(self):
                    return self.s2l_destination_address.is_set

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.s2l_destination_address.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "s2l-sub-lsp" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/frrs/frr/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.s2l_destination_address.is_set or self.s2l_destination_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.s2l_destination_address.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "s2l-destination-address"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "s2l-destination-address"):
                        self.s2l_destination_address = value
                        self.s2l_destination_address.value_namespace = name_space
                        self.s2l_destination_address.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.destination_address.is_set or
                    self.destination_port.is_set or
                    self.extended_tunnel_id.is_set or
                    self.p2mp_id.is_set or
                    self.path_status.is_set or
                    self.protocol.is_set or
                    self.reservation_status.is_set or
                    self.session_type.is_set or
                    self.source_address.is_set or
                    self.source_port.is_set or
                    self.sub_group_id.is_set or
                    self.sub_group_origin.is_set or
                    self.vrf_name.is_set or
                    (self.s2l_sub_lsp is not None and self.s2l_sub_lsp.has_data()) or
                    (self.session is not None and self.session.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.destination_address.yfilter != YFilter.not_set or
                    self.destination_port.yfilter != YFilter.not_set or
                    self.extended_tunnel_id.yfilter != YFilter.not_set or
                    self.p2mp_id.yfilter != YFilter.not_set or
                    self.path_status.yfilter != YFilter.not_set or
                    self.protocol.yfilter != YFilter.not_set or
                    self.reservation_status.yfilter != YFilter.not_set or
                    self.session_type.yfilter != YFilter.not_set or
                    self.source_address.yfilter != YFilter.not_set or
                    self.source_port.yfilter != YFilter.not_set or
                    self.sub_group_id.yfilter != YFilter.not_set or
                    self.sub_group_origin.yfilter != YFilter.not_set or
                    self.vrf_name.yfilter != YFilter.not_set or
                    (self.s2l_sub_lsp is not None and self.s2l_sub_lsp.has_operation()) or
                    (self.session is not None and self.session.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "frr" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/frrs/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_address.get_name_leafdata())
                if (self.destination_port.is_set or self.destination_port.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_port.get_name_leafdata())
                if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                if (self.p2mp_id.is_set or self.p2mp_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.p2mp_id.get_name_leafdata())
                if (self.path_status.is_set or self.path_status.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.path_status.get_name_leafdata())
                if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.protocol.get_name_leafdata())
                if (self.reservation_status.is_set or self.reservation_status.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.reservation_status.get_name_leafdata())
                if (self.session_type.is_set or self.session_type.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.session_type.get_name_leafdata())
                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_address.get_name_leafdata())
                if (self.source_port.is_set or self.source_port.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_port.get_name_leafdata())
                if (self.sub_group_id.is_set or self.sub_group_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.sub_group_id.get_name_leafdata())
                if (self.sub_group_origin.is_set or self.sub_group_origin.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.sub_group_origin.get_name_leafdata())
                if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.vrf_name.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "s2l-sub-lsp"):
                    if (self.s2l_sub_lsp is None):
                        self.s2l_sub_lsp = Rsvp.Frrs.Frr.S2LSubLsp()
                        self.s2l_sub_lsp.parent = self
                        self._children_name_map["s2l_sub_lsp"] = "s2l-sub-lsp"
                    return self.s2l_sub_lsp

                if (child_yang_name == "session"):
                    if (self.session is None):
                        self.session = Rsvp.Frrs.Frr.Session()
                        self.session.parent = self
                        self._children_name_map["session"] = "session"
                    return self.session

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "s2l-sub-lsp" or name == "session" or name == "destination-address" or name == "destination-port" or name == "extended-tunnel-id" or name == "p2mp-id" or name == "path-status" or name == "protocol" or name == "reservation-status" or name == "session-type" or name == "source-address" or name == "source-port" or name == "sub-group-id" or name == "sub-group-origin" or name == "vrf-name"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "destination-address"):
                    self.destination_address = value
                    self.destination_address.value_namespace = name_space
                    self.destination_address.value_namespace_prefix = name_space_prefix
                if(value_path == "destination-port"):
                    self.destination_port = value
                    self.destination_port.value_namespace = name_space
                    self.destination_port.value_namespace_prefix = name_space_prefix
                if(value_path == "extended-tunnel-id"):
                    self.extended_tunnel_id = value
                    self.extended_tunnel_id.value_namespace = name_space
                    self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                if(value_path == "p2mp-id"):
                    self.p2mp_id = value
                    self.p2mp_id.value_namespace = name_space
                    self.p2mp_id.value_namespace_prefix = name_space_prefix
                if(value_path == "path-status"):
                    self.path_status = value
                    self.path_status.value_namespace = name_space
                    self.path_status.value_namespace_prefix = name_space_prefix
                if(value_path == "protocol"):
                    self.protocol = value
                    self.protocol.value_namespace = name_space
                    self.protocol.value_namespace_prefix = name_space_prefix
                if(value_path == "reservation-status"):
                    self.reservation_status = value
                    self.reservation_status.value_namespace = name_space
                    self.reservation_status.value_namespace_prefix = name_space_prefix
                if(value_path == "session-type"):
                    self.session_type = value
                    self.session_type.value_namespace = name_space
                    self.session_type.value_namespace_prefix = name_space_prefix
                if(value_path == "source-address"):
                    self.source_address = value
                    self.source_address.value_namespace = name_space
                    self.source_address.value_namespace_prefix = name_space_prefix
                if(value_path == "source-port"):
                    self.source_port = value
                    self.source_port.value_namespace = name_space
                    self.source_port.value_namespace_prefix = name_space_prefix
                if(value_path == "sub-group-id"):
                    self.sub_group_id = value
                    self.sub_group_id.value_namespace = name_space
                    self.sub_group_id.value_namespace_prefix = name_space_prefix
                if(value_path == "sub-group-origin"):
                    self.sub_group_origin = value
                    self.sub_group_origin.value_namespace = name_space
                    self.sub_group_origin.value_namespace_prefix = name_space_prefix
                if(value_path == "vrf-name"):
                    self.vrf_name = value
                    self.vrf_name.value_namespace = name_space
                    self.vrf_name.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.frr:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.frr:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "frrs" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "frr"):
                for c in self.frr:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = Rsvp.Frrs.Frr()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.frr.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "frr"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class RequestBriefs(Entity):
        """
        Table of brief info about requests
        
        .. attribute:: request_brief
        
        	Brief info for a request
        	**type**\: list of    :py:class:`RequestBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RequestBriefs.RequestBrief>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Rsvp.RequestBriefs, self).__init__()

            self.yang_name = "request-briefs"
            self.yang_parent_name = "rsvp"

            self.request_brief = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(Rsvp.RequestBriefs, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(Rsvp.RequestBriefs, self).__setattr__(name, value)


        class RequestBrief(Entity):
            """
            Brief info for a request
            
            .. attribute:: destination_address
            
            	Destination Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: destination_port
            
            	Destination Port
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: extended_tunnel_id
            
            	Extended Tunnel ID
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: filter
            
            	RSVP Filter
            	**type**\:   :py:class:`Filter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RequestBriefs.RequestBrief.Filter>`
            
            .. attribute:: flow_spec
            
            	Flow Spec Information
            	**type**\:   :py:class:`FlowSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RequestBriefs.RequestBrief.FlowSpec>`
            
            .. attribute:: generic_flow_spec
            
            	Generic Flow Spec Information
            	**type**\:   :py:class:`GenericFlowSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RequestBriefs.RequestBrief.GenericFlowSpec>`
            
            .. attribute:: output_interface
            
            	Output Interface
            	**type**\:  str
            
            .. attribute:: p2mp_id
            
            	P2MP ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: protocol
            
            	Protocol
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: s2l_sub_lsp
            
            	RSVP S2L Sub\-LSP information
            	**type**\:   :py:class:`S2LSubLsp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RequestBriefs.RequestBrief.S2LSubLsp>`
            
            .. attribute:: session
            
            	RSVP Session Information
            	**type**\:   :py:class:`Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RequestBriefs.RequestBrief.Session>`
            
            .. attribute:: session_type
            
            	Session Type
            	**type**\:   :py:class:`RsvpSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpSession>`
            
            .. attribute:: source_address
            
            	Source Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: source_port
            
            	Source Port
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: style
            
            	RSVP Style
            	**type**\:   :py:class:`Style <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RequestBriefs.RequestBrief.Style>`
            
            .. attribute:: sub_group_id
            
            	Subgroup ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: sub_group_origin
            
            	Subgroup Origin
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: vrf_name
            
            	VRF Name
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Rsvp.RequestBriefs.RequestBrief, self).__init__()

                self.yang_name = "request-brief"
                self.yang_parent_name = "request-briefs"

                self.destination_address = YLeaf(YType.str, "destination-address")

                self.destination_port = YLeaf(YType.int32, "destination-port")

                self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                self.output_interface = YLeaf(YType.str, "output-interface")

                self.p2mp_id = YLeaf(YType.int32, "p2mp-id")

                self.protocol = YLeaf(YType.int32, "protocol")

                self.session_type = YLeaf(YType.enumeration, "session-type")

                self.source_address = YLeaf(YType.str, "source-address")

                self.source_port = YLeaf(YType.int32, "source-port")

                self.sub_group_id = YLeaf(YType.int32, "sub-group-id")

                self.sub_group_origin = YLeaf(YType.str, "sub-group-origin")

                self.vrf_name = YLeaf(YType.str, "vrf-name")

                self.filter = Rsvp.RequestBriefs.RequestBrief.Filter()
                self.filter.parent = self
                self._children_name_map["filter"] = "filter"
                self._children_yang_names.add("filter")

                self.flow_spec = Rsvp.RequestBriefs.RequestBrief.FlowSpec()
                self.flow_spec.parent = self
                self._children_name_map["flow_spec"] = "flow-spec"
                self._children_yang_names.add("flow-spec")

                self.generic_flow_spec = Rsvp.RequestBriefs.RequestBrief.GenericFlowSpec()
                self.generic_flow_spec.parent = self
                self._children_name_map["generic_flow_spec"] = "generic-flow-spec"
                self._children_yang_names.add("generic-flow-spec")

                self.s2l_sub_lsp = Rsvp.RequestBriefs.RequestBrief.S2LSubLsp()
                self.s2l_sub_lsp.parent = self
                self._children_name_map["s2l_sub_lsp"] = "s2l-sub-lsp"
                self._children_yang_names.add("s2l-sub-lsp")

                self.session = Rsvp.RequestBriefs.RequestBrief.Session()
                self.session.parent = self
                self._children_name_map["session"] = "session"
                self._children_yang_names.add("session")

                self.style = Rsvp.RequestBriefs.RequestBrief.Style()
                self.style.parent = self
                self._children_name_map["style"] = "style"
                self._children_yang_names.add("style")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("destination_address",
                                "destination_port",
                                "extended_tunnel_id",
                                "output_interface",
                                "p2mp_id",
                                "protocol",
                                "session_type",
                                "source_address",
                                "source_port",
                                "sub_group_id",
                                "sub_group_origin",
                                "vrf_name") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Rsvp.RequestBriefs.RequestBrief, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Rsvp.RequestBriefs.RequestBrief, self).__setattr__(name, value)


            class Session(Entity):
                """
                RSVP Session Information
                
                .. attribute:: rsvp_session
                
                	RSVP Session
                	**type**\:   :py:class:`RsvpSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RequestBriefs.RequestBrief.Session.RsvpSession>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.RequestBriefs.RequestBrief.Session, self).__init__()

                    self.yang_name = "session"
                    self.yang_parent_name = "request-brief"

                    self.rsvp_session = Rsvp.RequestBriefs.RequestBrief.Session.RsvpSession()
                    self.rsvp_session.parent = self
                    self._children_name_map["rsvp_session"] = "rsvp-session"
                    self._children_yang_names.add("rsvp-session")


                class RsvpSession(Entity):
                    """
                    RSVP Session
                    
                    .. attribute:: ipv4
                    
                    	UDP IPv4 session
                    	**type**\:   :py:class:`Ipv4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RequestBriefs.RequestBrief.Session.RsvpSession.Ipv4>`
                    
                    .. attribute:: ipv4_lsp_session
                    
                    	IPv4 LSP session
                    	**type**\:   :py:class:`Ipv4LspSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RequestBriefs.RequestBrief.Session.RsvpSession.Ipv4LspSession>`
                    
                    .. attribute:: ipv4_p2mp_lsp_session
                    
                    	IPv4 P2MP LSP session
                    	**type**\:   :py:class:`Ipv4P2MpLspSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RequestBriefs.RequestBrief.Session.RsvpSession.Ipv4P2MpLspSession>`
                    
                    .. attribute:: ipv4_uni_session
                    
                    	IPv4 UNI session
                    	**type**\:   :py:class:`Ipv4UniSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RequestBriefs.RequestBrief.Session.RsvpSession.Ipv4UniSession>`
                    
                    .. attribute:: session_type
                    
                    	SessionType
                    	**type**\:   :py:class:`RsvpMgmtSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtSession>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.RequestBriefs.RequestBrief.Session.RsvpSession, self).__init__()

                        self.yang_name = "rsvp-session"
                        self.yang_parent_name = "session"

                        self.session_type = YLeaf(YType.enumeration, "session-type")

                        self.ipv4 = Rsvp.RequestBriefs.RequestBrief.Session.RsvpSession.Ipv4()
                        self.ipv4.parent = self
                        self._children_name_map["ipv4"] = "ipv4"
                        self._children_yang_names.add("ipv4")

                        self.ipv4_lsp_session = Rsvp.RequestBriefs.RequestBrief.Session.RsvpSession.Ipv4LspSession()
                        self.ipv4_lsp_session.parent = self
                        self._children_name_map["ipv4_lsp_session"] = "ipv4-lsp-session"
                        self._children_yang_names.add("ipv4-lsp-session")

                        self.ipv4_p2mp_lsp_session = Rsvp.RequestBriefs.RequestBrief.Session.RsvpSession.Ipv4P2MpLspSession()
                        self.ipv4_p2mp_lsp_session.parent = self
                        self._children_name_map["ipv4_p2mp_lsp_session"] = "ipv4-p2mp-lsp-session"
                        self._children_yang_names.add("ipv4-p2mp-lsp-session")

                        self.ipv4_uni_session = Rsvp.RequestBriefs.RequestBrief.Session.RsvpSession.Ipv4UniSession()
                        self.ipv4_uni_session.parent = self
                        self._children_name_map["ipv4_uni_session"] = "ipv4-uni-session"
                        self._children_yang_names.add("ipv4-uni-session")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("session_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.RequestBriefs.RequestBrief.Session.RsvpSession, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.RequestBriefs.RequestBrief.Session.RsvpSession, self).__setattr__(name, value)


                    class Ipv4(Entity):
                        """
                        UDP IPv4 session
                        
                        .. attribute:: destination_address
                        
                        	Destination address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: destination_port
                        
                        	The Session Destination Port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: protocol
                        
                        	Protocol type (originally defined in RFC 790, further values in subsequent RFCs)
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.RequestBriefs.RequestBrief.Session.RsvpSession.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "rsvp-session"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.destination_port = YLeaf(YType.uint16, "destination-port")

                            self.protocol = YLeaf(YType.uint8, "protocol")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "destination_port",
                                            "protocol") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.RequestBriefs.RequestBrief.Session.RsvpSession.Ipv4, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.RequestBriefs.RequestBrief.Session.RsvpSession.Ipv4, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination_address.is_set or
                                self.destination_port.is_set or
                                self.protocol.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.destination_port.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/request-briefs/request-brief/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.destination_port.is_set or self.destination_port.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_port.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "destination-port" or name == "protocol"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "destination-port"):
                                self.destination_port = value
                                self.destination_port.value_namespace = name_space
                                self.destination_port.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix


                    class Ipv4LspSession(Entity):
                        """
                        IPv4 LSP session
                        
                        .. attribute:: destination_address
                        
                        	Destination address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: extended_tunnel_id
                        
                        	The Session Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: tunnel_id
                        
                        	The Session Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.RequestBriefs.RequestBrief.Session.RsvpSession.Ipv4LspSession, self).__init__()

                            self.yang_name = "ipv4-lsp-session"
                            self.yang_parent_name = "rsvp-session"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                            self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "extended_tunnel_id",
                                            "tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.RequestBriefs.RequestBrief.Session.RsvpSession.Ipv4LspSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.RequestBriefs.RequestBrief.Session.RsvpSession.Ipv4LspSession, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination_address.is_set or
                                self.extended_tunnel_id.is_set or
                                self.tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.extended_tunnel_id.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-lsp-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/request-briefs/request-brief/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "extended-tunnel-id" or name == "tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "extended-tunnel-id"):
                                self.extended_tunnel_id = value
                                self.extended_tunnel_id.value_namespace = name_space
                                self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix


                    class Ipv4UniSession(Entity):
                        """
                        IPv4 UNI session
                        
                        .. attribute:: destination_address
                        
                        	Destination address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: extended_address
                        
                        	The Session Extended Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: tunnel_id
                        
                        	The Session Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.RequestBriefs.RequestBrief.Session.RsvpSession.Ipv4UniSession, self).__init__()

                            self.yang_name = "ipv4-uni-session"
                            self.yang_parent_name = "rsvp-session"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.extended_address = YLeaf(YType.str, "extended-address")

                            self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "extended_address",
                                            "tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.RequestBriefs.RequestBrief.Session.RsvpSession.Ipv4UniSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.RequestBriefs.RequestBrief.Session.RsvpSession.Ipv4UniSession, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination_address.is_set or
                                self.extended_address.is_set or
                                self.tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.extended_address.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-uni-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/request-briefs/request-brief/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.extended_address.is_set or self.extended_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_address.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "extended-address" or name == "tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "extended-address"):
                                self.extended_address = value
                                self.extended_address.value_namespace = name_space
                                self.extended_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix


                    class Ipv4P2MpLspSession(Entity):
                        """
                        IPv4 P2MP LSP session
                        
                        .. attribute:: extended_tunnel_id
                        
                        	The Session Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: p2mp_id
                        
                        	The Point to Multipoint ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tunnel_id
                        
                        	The Session Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.RequestBriefs.RequestBrief.Session.RsvpSession.Ipv4P2MpLspSession, self).__init__()

                            self.yang_name = "ipv4-p2mp-lsp-session"
                            self.yang_parent_name = "rsvp-session"

                            self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                            self.p2mp_id = YLeaf(YType.uint32, "p2mp-id")

                            self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("extended_tunnel_id",
                                            "p2mp_id",
                                            "tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.RequestBriefs.RequestBrief.Session.RsvpSession.Ipv4P2MpLspSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.RequestBriefs.RequestBrief.Session.RsvpSession.Ipv4P2MpLspSession, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.extended_tunnel_id.is_set or
                                self.p2mp_id.is_set or
                                self.tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.extended_tunnel_id.yfilter != YFilter.not_set or
                                self.p2mp_id.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-p2mp-lsp-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/request-briefs/request-brief/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                            if (self.p2mp_id.is_set or self.p2mp_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.p2mp_id.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "extended-tunnel-id" or name == "p2mp-id" or name == "tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "extended-tunnel-id"):
                                self.extended_tunnel_id = value
                                self.extended_tunnel_id.value_namespace = name_space
                                self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "p2mp-id"):
                                self.p2mp_id = value
                                self.p2mp_id.value_namespace = name_space
                                self.p2mp_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.session_type.is_set or
                            (self.ipv4 is not None and self.ipv4.has_data()) or
                            (self.ipv4_lsp_session is not None and self.ipv4_lsp_session.has_data()) or
                            (self.ipv4_p2mp_lsp_session is not None and self.ipv4_p2mp_lsp_session.has_data()) or
                            (self.ipv4_uni_session is not None and self.ipv4_uni_session.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.session_type.yfilter != YFilter.not_set or
                            (self.ipv4 is not None and self.ipv4.has_operation()) or
                            (self.ipv4_lsp_session is not None and self.ipv4_lsp_session.has_operation()) or
                            (self.ipv4_p2mp_lsp_session is not None and self.ipv4_p2mp_lsp_session.has_operation()) or
                            (self.ipv4_uni_session is not None and self.ipv4_uni_session.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rsvp-session" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/request-briefs/request-brief/session/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.session_type.is_set or self.session_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.session_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "ipv4"):
                            if (self.ipv4 is None):
                                self.ipv4 = Rsvp.RequestBriefs.RequestBrief.Session.RsvpSession.Ipv4()
                                self.ipv4.parent = self
                                self._children_name_map["ipv4"] = "ipv4"
                            return self.ipv4

                        if (child_yang_name == "ipv4-lsp-session"):
                            if (self.ipv4_lsp_session is None):
                                self.ipv4_lsp_session = Rsvp.RequestBriefs.RequestBrief.Session.RsvpSession.Ipv4LspSession()
                                self.ipv4_lsp_session.parent = self
                                self._children_name_map["ipv4_lsp_session"] = "ipv4-lsp-session"
                            return self.ipv4_lsp_session

                        if (child_yang_name == "ipv4-p2mp-lsp-session"):
                            if (self.ipv4_p2mp_lsp_session is None):
                                self.ipv4_p2mp_lsp_session = Rsvp.RequestBriefs.RequestBrief.Session.RsvpSession.Ipv4P2MpLspSession()
                                self.ipv4_p2mp_lsp_session.parent = self
                                self._children_name_map["ipv4_p2mp_lsp_session"] = "ipv4-p2mp-lsp-session"
                            return self.ipv4_p2mp_lsp_session

                        if (child_yang_name == "ipv4-uni-session"):
                            if (self.ipv4_uni_session is None):
                                self.ipv4_uni_session = Rsvp.RequestBriefs.RequestBrief.Session.RsvpSession.Ipv4UniSession()
                                self.ipv4_uni_session.parent = self
                                self._children_name_map["ipv4_uni_session"] = "ipv4-uni-session"
                            return self.ipv4_uni_session

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ipv4" or name == "ipv4-lsp-session" or name == "ipv4-p2mp-lsp-session" or name == "ipv4-uni-session" or name == "session-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "session-type"):
                            self.session_type = value
                            self.session_type.value_namespace = name_space
                            self.session_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (self.rsvp_session is not None and self.rsvp_session.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.rsvp_session is not None and self.rsvp_session.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "session" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/request-briefs/request-brief/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "rsvp-session"):
                        if (self.rsvp_session is None):
                            self.rsvp_session = Rsvp.RequestBriefs.RequestBrief.Session.RsvpSession()
                            self.rsvp_session.parent = self
                            self._children_name_map["rsvp_session"] = "rsvp-session"
                        return self.rsvp_session

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "rsvp-session"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class S2LSubLsp(Entity):
                """
                RSVP S2L Sub\-LSP information
                
                .. attribute:: s2l_destination_address
                
                	S2L Sub\-LSP Destination Address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.RequestBriefs.RequestBrief.S2LSubLsp, self).__init__()

                    self.yang_name = "s2l-sub-lsp"
                    self.yang_parent_name = "request-brief"

                    self.s2l_destination_address = YLeaf(YType.str, "s2l-destination-address")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("s2l_destination_address") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.RequestBriefs.RequestBrief.S2LSubLsp, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.RequestBriefs.RequestBrief.S2LSubLsp, self).__setattr__(name, value)

                def has_data(self):
                    return self.s2l_destination_address.is_set

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.s2l_destination_address.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "s2l-sub-lsp" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/request-briefs/request-brief/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.s2l_destination_address.is_set or self.s2l_destination_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.s2l_destination_address.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "s2l-destination-address"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "s2l-destination-address"):
                        self.s2l_destination_address = value
                        self.s2l_destination_address.value_namespace = name_space
                        self.s2l_destination_address.value_namespace_prefix = name_space_prefix


            class FlowSpec(Entity):
                """
                Flow Spec Information
                
                .. attribute:: flow_average_rate
                
                	The Flow Average Rate in bytes per second
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: byte/s
                
                .. attribute:: flow_max_burst
                
                	The Flow Maximum Burst
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: flow_max_unit
                
                	The Flow Maximum Unit
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: flow_min_unit
                
                	The Flow Minimum Unit
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: flow_peak_rate
                
                	The Flow Peak Rate in bytes per second
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: byte/s
                
                .. attribute:: flow_qos
                
                	The Flow Quality of Service
                	**type**\:   :py:class:`RsvpMgmtQosServiceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtQosServiceEnum>`
                
                .. attribute:: flow_requested_rate
                
                	The Flow Requested Rate in bytes per second
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: byte/s
                
                .. attribute:: flow_slack
                
                	The Flow Slack
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.RequestBriefs.RequestBrief.FlowSpec, self).__init__()

                    self.yang_name = "flow-spec"
                    self.yang_parent_name = "request-brief"

                    self.flow_average_rate = YLeaf(YType.uint64, "flow-average-rate")

                    self.flow_max_burst = YLeaf(YType.uint64, "flow-max-burst")

                    self.flow_max_unit = YLeaf(YType.uint32, "flow-max-unit")

                    self.flow_min_unit = YLeaf(YType.uint32, "flow-min-unit")

                    self.flow_peak_rate = YLeaf(YType.uint64, "flow-peak-rate")

                    self.flow_qos = YLeaf(YType.enumeration, "flow-qos")

                    self.flow_requested_rate = YLeaf(YType.uint64, "flow-requested-rate")

                    self.flow_slack = YLeaf(YType.uint32, "flow-slack")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("flow_average_rate",
                                    "flow_max_burst",
                                    "flow_max_unit",
                                    "flow_min_unit",
                                    "flow_peak_rate",
                                    "flow_qos",
                                    "flow_requested_rate",
                                    "flow_slack") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.RequestBriefs.RequestBrief.FlowSpec, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.RequestBriefs.RequestBrief.FlowSpec, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.flow_average_rate.is_set or
                        self.flow_max_burst.is_set or
                        self.flow_max_unit.is_set or
                        self.flow_min_unit.is_set or
                        self.flow_peak_rate.is_set or
                        self.flow_qos.is_set or
                        self.flow_requested_rate.is_set or
                        self.flow_slack.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.flow_average_rate.yfilter != YFilter.not_set or
                        self.flow_max_burst.yfilter != YFilter.not_set or
                        self.flow_max_unit.yfilter != YFilter.not_set or
                        self.flow_min_unit.yfilter != YFilter.not_set or
                        self.flow_peak_rate.yfilter != YFilter.not_set or
                        self.flow_qos.yfilter != YFilter.not_set or
                        self.flow_requested_rate.yfilter != YFilter.not_set or
                        self.flow_slack.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "flow-spec" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/request-briefs/request-brief/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.flow_average_rate.is_set or self.flow_average_rate.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_average_rate.get_name_leafdata())
                    if (self.flow_max_burst.is_set or self.flow_max_burst.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_max_burst.get_name_leafdata())
                    if (self.flow_max_unit.is_set or self.flow_max_unit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_max_unit.get_name_leafdata())
                    if (self.flow_min_unit.is_set or self.flow_min_unit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_min_unit.get_name_leafdata())
                    if (self.flow_peak_rate.is_set or self.flow_peak_rate.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_peak_rate.get_name_leafdata())
                    if (self.flow_qos.is_set or self.flow_qos.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_qos.get_name_leafdata())
                    if (self.flow_requested_rate.is_set or self.flow_requested_rate.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_requested_rate.get_name_leafdata())
                    if (self.flow_slack.is_set or self.flow_slack.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_slack.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "flow-average-rate" or name == "flow-max-burst" or name == "flow-max-unit" or name == "flow-min-unit" or name == "flow-peak-rate" or name == "flow-qos" or name == "flow-requested-rate" or name == "flow-slack"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "flow-average-rate"):
                        self.flow_average_rate = value
                        self.flow_average_rate.value_namespace = name_space
                        self.flow_average_rate.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-max-burst"):
                        self.flow_max_burst = value
                        self.flow_max_burst.value_namespace = name_space
                        self.flow_max_burst.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-max-unit"):
                        self.flow_max_unit = value
                        self.flow_max_unit.value_namespace = name_space
                        self.flow_max_unit.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-min-unit"):
                        self.flow_min_unit = value
                        self.flow_min_unit.value_namespace = name_space
                        self.flow_min_unit.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-peak-rate"):
                        self.flow_peak_rate = value
                        self.flow_peak_rate.value_namespace = name_space
                        self.flow_peak_rate.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-qos"):
                        self.flow_qos = value
                        self.flow_qos.value_namespace = name_space
                        self.flow_qos.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-requested-rate"):
                        self.flow_requested_rate = value
                        self.flow_requested_rate.value_namespace = name_space
                        self.flow_requested_rate.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-slack"):
                        self.flow_slack = value
                        self.flow_slack.value_namespace = name_space
                        self.flow_slack.value_namespace_prefix = name_space_prefix


            class GenericFlowSpec(Entity):
                """
                Generic Flow Spec Information
                
                .. attribute:: flow_spec_type
                
                	FlowSpecType
                	**type**\:   :py:class:`RsvpMgmtFlowSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtFlowSpec>`
                
                .. attribute:: g709otn_flow_spec
                
                	G709 OTN FlowSpec
                	**type**\:   :py:class:`G709OtnFlowSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RequestBriefs.RequestBrief.GenericFlowSpec.G709OtnFlowSpec>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.RequestBriefs.RequestBrief.GenericFlowSpec, self).__init__()

                    self.yang_name = "generic-flow-spec"
                    self.yang_parent_name = "request-brief"

                    self.flow_spec_type = YLeaf(YType.enumeration, "flow-spec-type")

                    self.g709otn_flow_spec = Rsvp.RequestBriefs.RequestBrief.GenericFlowSpec.G709OtnFlowSpec()
                    self.g709otn_flow_spec.parent = self
                    self._children_name_map["g709otn_flow_spec"] = "g709otn-flow-spec"
                    self._children_yang_names.add("g709otn-flow-spec")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("flow_spec_type") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.RequestBriefs.RequestBrief.GenericFlowSpec, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.RequestBriefs.RequestBrief.GenericFlowSpec, self).__setattr__(name, value)


                class G709OtnFlowSpec(Entity):
                    """
                    G709 OTN FlowSpec
                    
                    .. attribute:: flow_bit_rate
                    
                    	G709 OTN Flow Bit Rate
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: flow_multiplier
                    
                    	G709 OTN Flow Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: flow_nvc
                    
                    	G709 OTN Flow NVC
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: flow_signal_type
                    
                    	G709 OTN Flow Signal Type (Refer G709 v3)
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.RequestBriefs.RequestBrief.GenericFlowSpec.G709OtnFlowSpec, self).__init__()

                        self.yang_name = "g709otn-flow-spec"
                        self.yang_parent_name = "generic-flow-spec"

                        self.flow_bit_rate = YLeaf(YType.uint64, "flow-bit-rate")

                        self.flow_multiplier = YLeaf(YType.uint16, "flow-multiplier")

                        self.flow_nvc = YLeaf(YType.uint16, "flow-nvc")

                        self.flow_signal_type = YLeaf(YType.uint8, "flow-signal-type")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("flow_bit_rate",
                                        "flow_multiplier",
                                        "flow_nvc",
                                        "flow_signal_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.RequestBriefs.RequestBrief.GenericFlowSpec.G709OtnFlowSpec, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.RequestBriefs.RequestBrief.GenericFlowSpec.G709OtnFlowSpec, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.flow_bit_rate.is_set or
                            self.flow_multiplier.is_set or
                            self.flow_nvc.is_set or
                            self.flow_signal_type.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.flow_bit_rate.yfilter != YFilter.not_set or
                            self.flow_multiplier.yfilter != YFilter.not_set or
                            self.flow_nvc.yfilter != YFilter.not_set or
                            self.flow_signal_type.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "g709otn-flow-spec" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/request-briefs/request-brief/generic-flow-spec/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.flow_bit_rate.is_set or self.flow_bit_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.flow_bit_rate.get_name_leafdata())
                        if (self.flow_multiplier.is_set or self.flow_multiplier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.flow_multiplier.get_name_leafdata())
                        if (self.flow_nvc.is_set or self.flow_nvc.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.flow_nvc.get_name_leafdata())
                        if (self.flow_signal_type.is_set or self.flow_signal_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.flow_signal_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "flow-bit-rate" or name == "flow-multiplier" or name == "flow-nvc" or name == "flow-signal-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "flow-bit-rate"):
                            self.flow_bit_rate = value
                            self.flow_bit_rate.value_namespace = name_space
                            self.flow_bit_rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "flow-multiplier"):
                            self.flow_multiplier = value
                            self.flow_multiplier.value_namespace = name_space
                            self.flow_multiplier.value_namespace_prefix = name_space_prefix
                        if(value_path == "flow-nvc"):
                            self.flow_nvc = value
                            self.flow_nvc.value_namespace = name_space
                            self.flow_nvc.value_namespace_prefix = name_space_prefix
                        if(value_path == "flow-signal-type"):
                            self.flow_signal_type = value
                            self.flow_signal_type.value_namespace = name_space
                            self.flow_signal_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.flow_spec_type.is_set or
                        (self.g709otn_flow_spec is not None and self.g709otn_flow_spec.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.flow_spec_type.yfilter != YFilter.not_set or
                        (self.g709otn_flow_spec is not None and self.g709otn_flow_spec.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "generic-flow-spec" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/request-briefs/request-brief/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.flow_spec_type.is_set or self.flow_spec_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_spec_type.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "g709otn-flow-spec"):
                        if (self.g709otn_flow_spec is None):
                            self.g709otn_flow_spec = Rsvp.RequestBriefs.RequestBrief.GenericFlowSpec.G709OtnFlowSpec()
                            self.g709otn_flow_spec.parent = self
                            self._children_name_map["g709otn_flow_spec"] = "g709otn-flow-spec"
                        return self.g709otn_flow_spec

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "g709otn-flow-spec" or name == "flow-spec-type"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "flow-spec-type"):
                        self.flow_spec_type = value
                        self.flow_spec_type.value_namespace = name_space
                        self.flow_spec_type.value_namespace_prefix = name_space_prefix


            class Filter(Entity):
                """
                RSVP Filter
                
                .. attribute:: rsvp_filter
                
                	RSVP Filter
                	**type**\:   :py:class:`RsvpFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RequestBriefs.RequestBrief.Filter.RsvpFilter>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.RequestBriefs.RequestBrief.Filter, self).__init__()

                    self.yang_name = "filter"
                    self.yang_parent_name = "request-brief"

                    self.rsvp_filter = Rsvp.RequestBriefs.RequestBrief.Filter.RsvpFilter()
                    self.rsvp_filter.parent = self
                    self._children_name_map["rsvp_filter"] = "rsvp-filter"
                    self._children_yang_names.add("rsvp-filter")


                class RsvpFilter(Entity):
                    """
                    RSVP Filter
                    
                    .. attribute:: filter_type
                    
                    	FilterType
                    	**type**\:   :py:class:`RsvpMgmtFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtFilter>`
                    
                    .. attribute:: p2mp_ipv4_session
                    
                    	IPv4 P2MP LSP FilterSpec
                    	**type**\:   :py:class:`P2MpIpv4Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RequestBriefs.RequestBrief.Filter.RsvpFilter.P2MpIpv4Session>`
                    
                    .. attribute:: udp_ipv4_session
                    
                    	UDP IPV4 FilterSpec
                    	**type**\:   :py:class:`UdpIpv4Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RequestBriefs.RequestBrief.Filter.RsvpFilter.UdpIpv4Session>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.RequestBriefs.RequestBrief.Filter.RsvpFilter, self).__init__()

                        self.yang_name = "rsvp-filter"
                        self.yang_parent_name = "filter"

                        self.filter_type = YLeaf(YType.enumeration, "filter-type")

                        self.p2mp_ipv4_session = Rsvp.RequestBriefs.RequestBrief.Filter.RsvpFilter.P2MpIpv4Session()
                        self.p2mp_ipv4_session.parent = self
                        self._children_name_map["p2mp_ipv4_session"] = "p2mp-ipv4-session"
                        self._children_yang_names.add("p2mp-ipv4-session")

                        self.udp_ipv4_session = Rsvp.RequestBriefs.RequestBrief.Filter.RsvpFilter.UdpIpv4Session()
                        self.udp_ipv4_session.parent = self
                        self._children_name_map["udp_ipv4_session"] = "udp-ipv4-session"
                        self._children_yang_names.add("udp-ipv4-session")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("filter_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.RequestBriefs.RequestBrief.Filter.RsvpFilter, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.RequestBriefs.RequestBrief.Filter.RsvpFilter, self).__setattr__(name, value)


                    class UdpIpv4Session(Entity):
                        """
                        UDP IPV4 FilterSpec
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source_port
                        
                        	Source Port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.RequestBriefs.RequestBrief.Filter.RsvpFilter.UdpIpv4Session, self).__init__()

                            self.yang_name = "udp-ipv4-session"
                            self.yang_parent_name = "rsvp-filter"

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.source_port = YLeaf(YType.uint16, "source-port")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("source_address",
                                            "source_port") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.RequestBriefs.RequestBrief.Filter.RsvpFilter.UdpIpv4Session, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.RequestBriefs.RequestBrief.Filter.RsvpFilter.UdpIpv4Session, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.source_address.is_set or
                                self.source_port.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                self.source_port.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "udp-ipv4-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/request-briefs/request-brief/filter/rsvp-filter/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())
                            if (self.source_port.is_set or self.source_port.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_port.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "source-address" or name == "source-port"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-port"):
                                self.source_port = value
                                self.source_port.value_namespace = name_space
                                self.source_port.value_namespace_prefix = name_space_prefix


                    class P2MpIpv4Session(Entity):
                        """
                        IPv4 P2MP LSP FilterSpec
                        
                        .. attribute:: p2mp_sub_group_origin
                        
                        	Point to Multipoint SubGroup Origin
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source_port
                        
                        	Source Port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: sub_group_id
                        
                        	Point to Multipoint Subgroup ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.RequestBriefs.RequestBrief.Filter.RsvpFilter.P2MpIpv4Session, self).__init__()

                            self.yang_name = "p2mp-ipv4-session"
                            self.yang_parent_name = "rsvp-filter"

                            self.p2mp_sub_group_origin = YLeaf(YType.str, "p2mp-sub-group-origin")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.source_port = YLeaf(YType.uint16, "source-port")

                            self.sub_group_id = YLeaf(YType.uint16, "sub-group-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("p2mp_sub_group_origin",
                                            "source_address",
                                            "source_port",
                                            "sub_group_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.RequestBriefs.RequestBrief.Filter.RsvpFilter.P2MpIpv4Session, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.RequestBriefs.RequestBrief.Filter.RsvpFilter.P2MpIpv4Session, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.p2mp_sub_group_origin.is_set or
                                self.source_address.is_set or
                                self.source_port.is_set or
                                self.sub_group_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.p2mp_sub_group_origin.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                self.source_port.yfilter != YFilter.not_set or
                                self.sub_group_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "p2mp-ipv4-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/request-briefs/request-brief/filter/rsvp-filter/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.p2mp_sub_group_origin.is_set or self.p2mp_sub_group_origin.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.p2mp_sub_group_origin.get_name_leafdata())
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())
                            if (self.source_port.is_set or self.source_port.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_port.get_name_leafdata())
                            if (self.sub_group_id.is_set or self.sub_group_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sub_group_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "p2mp-sub-group-origin" or name == "source-address" or name == "source-port" or name == "sub-group-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "p2mp-sub-group-origin"):
                                self.p2mp_sub_group_origin = value
                                self.p2mp_sub_group_origin.value_namespace = name_space
                                self.p2mp_sub_group_origin.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-port"):
                                self.source_port = value
                                self.source_port.value_namespace = name_space
                                self.source_port.value_namespace_prefix = name_space_prefix
                            if(value_path == "sub-group-id"):
                                self.sub_group_id = value
                                self.sub_group_id.value_namespace = name_space
                                self.sub_group_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.filter_type.is_set or
                            (self.p2mp_ipv4_session is not None and self.p2mp_ipv4_session.has_data()) or
                            (self.udp_ipv4_session is not None and self.udp_ipv4_session.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.filter_type.yfilter != YFilter.not_set or
                            (self.p2mp_ipv4_session is not None and self.p2mp_ipv4_session.has_operation()) or
                            (self.udp_ipv4_session is not None and self.udp_ipv4_session.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rsvp-filter" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/request-briefs/request-brief/filter/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.filter_type.is_set or self.filter_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.filter_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "p2mp-ipv4-session"):
                            if (self.p2mp_ipv4_session is None):
                                self.p2mp_ipv4_session = Rsvp.RequestBriefs.RequestBrief.Filter.RsvpFilter.P2MpIpv4Session()
                                self.p2mp_ipv4_session.parent = self
                                self._children_name_map["p2mp_ipv4_session"] = "p2mp-ipv4-session"
                            return self.p2mp_ipv4_session

                        if (child_yang_name == "udp-ipv4-session"):
                            if (self.udp_ipv4_session is None):
                                self.udp_ipv4_session = Rsvp.RequestBriefs.RequestBrief.Filter.RsvpFilter.UdpIpv4Session()
                                self.udp_ipv4_session.parent = self
                                self._children_name_map["udp_ipv4_session"] = "udp-ipv4-session"
                            return self.udp_ipv4_session

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "p2mp-ipv4-session" or name == "udp-ipv4-session" or name == "filter-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "filter-type"):
                            self.filter_type = value
                            self.filter_type.value_namespace = name_space
                            self.filter_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (self.rsvp_filter is not None and self.rsvp_filter.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.rsvp_filter is not None and self.rsvp_filter.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "filter" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/request-briefs/request-brief/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "rsvp-filter"):
                        if (self.rsvp_filter is None):
                            self.rsvp_filter = Rsvp.RequestBriefs.RequestBrief.Filter.RsvpFilter()
                            self.rsvp_filter.parent = self
                            self._children_name_map["rsvp_filter"] = "rsvp-filter"
                        return self.rsvp_filter

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "rsvp-filter"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Style(Entity):
                """
                RSVP Style
                
                .. attribute:: reservation_type
                
                	The Reservation Type\: WF, SE or FF
                	**type**\:   :py:class:`RsvpMgmtReservationTypeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtReservationTypeEnum>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.RequestBriefs.RequestBrief.Style, self).__init__()

                    self.yang_name = "style"
                    self.yang_parent_name = "request-brief"

                    self.reservation_type = YLeaf(YType.enumeration, "reservation-type")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("reservation_type") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.RequestBriefs.RequestBrief.Style, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.RequestBriefs.RequestBrief.Style, self).__setattr__(name, value)

                def has_data(self):
                    return self.reservation_type.is_set

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.reservation_type.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "style" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/request-briefs/request-brief/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.reservation_type.is_set or self.reservation_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reservation_type.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "reservation-type"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "reservation-type"):
                        self.reservation_type = value
                        self.reservation_type.value_namespace = name_space
                        self.reservation_type.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.destination_address.is_set or
                    self.destination_port.is_set or
                    self.extended_tunnel_id.is_set or
                    self.output_interface.is_set or
                    self.p2mp_id.is_set or
                    self.protocol.is_set or
                    self.session_type.is_set or
                    self.source_address.is_set or
                    self.source_port.is_set or
                    self.sub_group_id.is_set or
                    self.sub_group_origin.is_set or
                    self.vrf_name.is_set or
                    (self.filter is not None and self.filter.has_data()) or
                    (self.flow_spec is not None and self.flow_spec.has_data()) or
                    (self.generic_flow_spec is not None and self.generic_flow_spec.has_data()) or
                    (self.s2l_sub_lsp is not None and self.s2l_sub_lsp.has_data()) or
                    (self.session is not None and self.session.has_data()) or
                    (self.style is not None and self.style.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.destination_address.yfilter != YFilter.not_set or
                    self.destination_port.yfilter != YFilter.not_set or
                    self.extended_tunnel_id.yfilter != YFilter.not_set or
                    self.output_interface.yfilter != YFilter.not_set or
                    self.p2mp_id.yfilter != YFilter.not_set or
                    self.protocol.yfilter != YFilter.not_set or
                    self.session_type.yfilter != YFilter.not_set or
                    self.source_address.yfilter != YFilter.not_set or
                    self.source_port.yfilter != YFilter.not_set or
                    self.sub_group_id.yfilter != YFilter.not_set or
                    self.sub_group_origin.yfilter != YFilter.not_set or
                    self.vrf_name.yfilter != YFilter.not_set or
                    (self.filter is not None and self.filter.has_operation()) or
                    (self.flow_spec is not None and self.flow_spec.has_operation()) or
                    (self.generic_flow_spec is not None and self.generic_flow_spec.has_operation()) or
                    (self.s2l_sub_lsp is not None and self.s2l_sub_lsp.has_operation()) or
                    (self.session is not None and self.session.has_operation()) or
                    (self.style is not None and self.style.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "request-brief" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/request-briefs/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_address.get_name_leafdata())
                if (self.destination_port.is_set or self.destination_port.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_port.get_name_leafdata())
                if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                if (self.output_interface.is_set or self.output_interface.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.output_interface.get_name_leafdata())
                if (self.p2mp_id.is_set or self.p2mp_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.p2mp_id.get_name_leafdata())
                if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.protocol.get_name_leafdata())
                if (self.session_type.is_set or self.session_type.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.session_type.get_name_leafdata())
                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_address.get_name_leafdata())
                if (self.source_port.is_set or self.source_port.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_port.get_name_leafdata())
                if (self.sub_group_id.is_set or self.sub_group_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.sub_group_id.get_name_leafdata())
                if (self.sub_group_origin.is_set or self.sub_group_origin.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.sub_group_origin.get_name_leafdata())
                if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.vrf_name.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "filter"):
                    if (self.filter is None):
                        self.filter = Rsvp.RequestBriefs.RequestBrief.Filter()
                        self.filter.parent = self
                        self._children_name_map["filter"] = "filter"
                    return self.filter

                if (child_yang_name == "flow-spec"):
                    if (self.flow_spec is None):
                        self.flow_spec = Rsvp.RequestBriefs.RequestBrief.FlowSpec()
                        self.flow_spec.parent = self
                        self._children_name_map["flow_spec"] = "flow-spec"
                    return self.flow_spec

                if (child_yang_name == "generic-flow-spec"):
                    if (self.generic_flow_spec is None):
                        self.generic_flow_spec = Rsvp.RequestBriefs.RequestBrief.GenericFlowSpec()
                        self.generic_flow_spec.parent = self
                        self._children_name_map["generic_flow_spec"] = "generic-flow-spec"
                    return self.generic_flow_spec

                if (child_yang_name == "s2l-sub-lsp"):
                    if (self.s2l_sub_lsp is None):
                        self.s2l_sub_lsp = Rsvp.RequestBriefs.RequestBrief.S2LSubLsp()
                        self.s2l_sub_lsp.parent = self
                        self._children_name_map["s2l_sub_lsp"] = "s2l-sub-lsp"
                    return self.s2l_sub_lsp

                if (child_yang_name == "session"):
                    if (self.session is None):
                        self.session = Rsvp.RequestBriefs.RequestBrief.Session()
                        self.session.parent = self
                        self._children_name_map["session"] = "session"
                    return self.session

                if (child_yang_name == "style"):
                    if (self.style is None):
                        self.style = Rsvp.RequestBriefs.RequestBrief.Style()
                        self.style.parent = self
                        self._children_name_map["style"] = "style"
                    return self.style

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "filter" or name == "flow-spec" or name == "generic-flow-spec" or name == "s2l-sub-lsp" or name == "session" or name == "style" or name == "destination-address" or name == "destination-port" or name == "extended-tunnel-id" or name == "output-interface" or name == "p2mp-id" or name == "protocol" or name == "session-type" or name == "source-address" or name == "source-port" or name == "sub-group-id" or name == "sub-group-origin" or name == "vrf-name"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "destination-address"):
                    self.destination_address = value
                    self.destination_address.value_namespace = name_space
                    self.destination_address.value_namespace_prefix = name_space_prefix
                if(value_path == "destination-port"):
                    self.destination_port = value
                    self.destination_port.value_namespace = name_space
                    self.destination_port.value_namespace_prefix = name_space_prefix
                if(value_path == "extended-tunnel-id"):
                    self.extended_tunnel_id = value
                    self.extended_tunnel_id.value_namespace = name_space
                    self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                if(value_path == "output-interface"):
                    self.output_interface = value
                    self.output_interface.value_namespace = name_space
                    self.output_interface.value_namespace_prefix = name_space_prefix
                if(value_path == "p2mp-id"):
                    self.p2mp_id = value
                    self.p2mp_id.value_namespace = name_space
                    self.p2mp_id.value_namespace_prefix = name_space_prefix
                if(value_path == "protocol"):
                    self.protocol = value
                    self.protocol.value_namespace = name_space
                    self.protocol.value_namespace_prefix = name_space_prefix
                if(value_path == "session-type"):
                    self.session_type = value
                    self.session_type.value_namespace = name_space
                    self.session_type.value_namespace_prefix = name_space_prefix
                if(value_path == "source-address"):
                    self.source_address = value
                    self.source_address.value_namespace = name_space
                    self.source_address.value_namespace_prefix = name_space_prefix
                if(value_path == "source-port"):
                    self.source_port = value
                    self.source_port.value_namespace = name_space
                    self.source_port.value_namespace_prefix = name_space_prefix
                if(value_path == "sub-group-id"):
                    self.sub_group_id = value
                    self.sub_group_id.value_namespace = name_space
                    self.sub_group_id.value_namespace_prefix = name_space_prefix
                if(value_path == "sub-group-origin"):
                    self.sub_group_origin = value
                    self.sub_group_origin.value_namespace = name_space
                    self.sub_group_origin.value_namespace_prefix = name_space_prefix
                if(value_path == "vrf-name"):
                    self.vrf_name = value
                    self.vrf_name.value_namespace = name_space
                    self.vrf_name.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.request_brief:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.request_brief:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "request-briefs" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "request-brief"):
                for c in self.request_brief:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = Rsvp.RequestBriefs.RequestBrief()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.request_brief.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "request-brief"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class RequestDetails(Entity):
        """
        Table of detail info about requests
        
        .. attribute:: request_detail
        
        	Detail info for a request
        	**type**\: list of    :py:class:`RequestDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RequestDetails.RequestDetail>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Rsvp.RequestDetails, self).__init__()

            self.yang_name = "request-details"
            self.yang_parent_name = "rsvp"

            self.request_detail = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(Rsvp.RequestDetails, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(Rsvp.RequestDetails, self).__setattr__(name, value)


        class RequestDetail(Entity):
            """
            Detail info for a request
            
            .. attribute:: destination_address
            
            	Destination Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: destination_port
            
            	Destination Port
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: extended_tunnel_id
            
            	Extended Tunnel ID
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: filter
            
            	RSVP Filter
            	**type**\:   :py:class:`Filter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RequestDetails.RequestDetail.Filter>`
            
            .. attribute:: flow_spec
            
            	Flow Spec Information
            	**type**\:   :py:class:`FlowSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RequestDetails.RequestDetail.FlowSpec>`
            
            .. attribute:: generic_flow_spec
            
            	Generic Flow Spec Information
            	**type**\:   :py:class:`GenericFlowSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RequestDetails.RequestDetail.GenericFlowSpec>`
            
            .. attribute:: header
            
            	RSVP Header Information
            	**type**\:   :py:class:`Header <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RequestDetails.RequestDetail.Header>`
            
            .. attribute:: hop
            
            	Hop Infomation
            	**type**\:   :py:class:`Hop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RequestDetails.RequestDetail.Hop>`
            
            .. attribute:: output_interface
            
            	output Interface
            	**type**\:  str
            
            .. attribute:: p2mp_id
            
            	P2MP ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: policy_flags
            
            	RSVP Policy Flags
            	**type**\:   :py:class:`PolicyFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RequestDetails.RequestDetail.PolicyFlags>`
            
            .. attribute:: policy_query_flags
            
            	RSVP Query Flags
            	**type**\:   :py:class:`PolicyQueryFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RequestDetails.RequestDetail.PolicyQueryFlags>`
            
            .. attribute:: policy_sources
            
            	RSVP Policy Sources
            	**type**\:   :py:class:`PolicySources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RequestDetails.RequestDetail.PolicySources>`
            
            .. attribute:: protocol
            
            	Protocol
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: psb_key
            
            	List of RSB keys
            	**type**\: list of    :py:class:`PsbKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RequestDetails.RequestDetail.PsbKey>`
            
            .. attribute:: req_flags
            
            	Request flags
            	**type**\:   :py:class:`ReqFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RequestDetails.RequestDetail.ReqFlags>`
            
            .. attribute:: rsb_key
            
            	List of RSB keys
            	**type**\: list of    :py:class:`RsbKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RequestDetails.RequestDetail.RsbKey>`
            
            .. attribute:: s2l_sub_lsp
            
            	RSVP S2L Sub\-LSP information
            	**type**\:   :py:class:`S2LSubLsp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RequestDetails.RequestDetail.S2LSubLsp>`
            
            .. attribute:: session
            
            	RSVP Session Information
            	**type**\:   :py:class:`Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RequestDetails.RequestDetail.Session>`
            
            .. attribute:: session_type
            
            	Session Type
            	**type**\:   :py:class:`RsvpSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpSession>`
            
            .. attribute:: source_address
            
            	Source Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: source_port
            
            	Source Port
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: style
            
            	RSVP Style
            	**type**\:   :py:class:`Style <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RequestDetails.RequestDetail.Style>`
            
            .. attribute:: sub_group_id
            
            	Subgroup ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: sub_group_origin
            
            	Subgroup Origin
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: vrf_name
            
            	VRF Name
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Rsvp.RequestDetails.RequestDetail, self).__init__()

                self.yang_name = "request-detail"
                self.yang_parent_name = "request-details"

                self.destination_address = YLeaf(YType.str, "destination-address")

                self.destination_port = YLeaf(YType.int32, "destination-port")

                self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                self.output_interface = YLeaf(YType.str, "output-interface")

                self.p2mp_id = YLeaf(YType.int32, "p2mp-id")

                self.protocol = YLeaf(YType.int32, "protocol")

                self.session_type = YLeaf(YType.enumeration, "session-type")

                self.source_address = YLeaf(YType.str, "source-address")

                self.source_port = YLeaf(YType.int32, "source-port")

                self.sub_group_id = YLeaf(YType.int32, "sub-group-id")

                self.sub_group_origin = YLeaf(YType.str, "sub-group-origin")

                self.vrf_name = YLeaf(YType.str, "vrf-name")

                self.filter = Rsvp.RequestDetails.RequestDetail.Filter()
                self.filter.parent = self
                self._children_name_map["filter"] = "filter"
                self._children_yang_names.add("filter")

                self.flow_spec = Rsvp.RequestDetails.RequestDetail.FlowSpec()
                self.flow_spec.parent = self
                self._children_name_map["flow_spec"] = "flow-spec"
                self._children_yang_names.add("flow-spec")

                self.generic_flow_spec = Rsvp.RequestDetails.RequestDetail.GenericFlowSpec()
                self.generic_flow_spec.parent = self
                self._children_name_map["generic_flow_spec"] = "generic-flow-spec"
                self._children_yang_names.add("generic-flow-spec")

                self.header = Rsvp.RequestDetails.RequestDetail.Header()
                self.header.parent = self
                self._children_name_map["header"] = "header"
                self._children_yang_names.add("header")

                self.hop = Rsvp.RequestDetails.RequestDetail.Hop()
                self.hop.parent = self
                self._children_name_map["hop"] = "hop"
                self._children_yang_names.add("hop")

                self.policy_flags = Rsvp.RequestDetails.RequestDetail.PolicyFlags()
                self.policy_flags.parent = self
                self._children_name_map["policy_flags"] = "policy-flags"
                self._children_yang_names.add("policy-flags")

                self.policy_query_flags = Rsvp.RequestDetails.RequestDetail.PolicyQueryFlags()
                self.policy_query_flags.parent = self
                self._children_name_map["policy_query_flags"] = "policy-query-flags"
                self._children_yang_names.add("policy-query-flags")

                self.policy_sources = Rsvp.RequestDetails.RequestDetail.PolicySources()
                self.policy_sources.parent = self
                self._children_name_map["policy_sources"] = "policy-sources"
                self._children_yang_names.add("policy-sources")

                self.req_flags = Rsvp.RequestDetails.RequestDetail.ReqFlags()
                self.req_flags.parent = self
                self._children_name_map["req_flags"] = "req-flags"
                self._children_yang_names.add("req-flags")

                self.s2l_sub_lsp = Rsvp.RequestDetails.RequestDetail.S2LSubLsp()
                self.s2l_sub_lsp.parent = self
                self._children_name_map["s2l_sub_lsp"] = "s2l-sub-lsp"
                self._children_yang_names.add("s2l-sub-lsp")

                self.session = Rsvp.RequestDetails.RequestDetail.Session()
                self.session.parent = self
                self._children_name_map["session"] = "session"
                self._children_yang_names.add("session")

                self.style = Rsvp.RequestDetails.RequestDetail.Style()
                self.style.parent = self
                self._children_name_map["style"] = "style"
                self._children_yang_names.add("style")

                self.psb_key = YList(self)
                self.rsb_key = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("destination_address",
                                "destination_port",
                                "extended_tunnel_id",
                                "output_interface",
                                "p2mp_id",
                                "protocol",
                                "session_type",
                                "source_address",
                                "source_port",
                                "sub_group_id",
                                "sub_group_origin",
                                "vrf_name") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Rsvp.RequestDetails.RequestDetail, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Rsvp.RequestDetails.RequestDetail, self).__setattr__(name, value)


            class Session(Entity):
                """
                RSVP Session Information
                
                .. attribute:: rsvp_session
                
                	RSVP Session
                	**type**\:   :py:class:`RsvpSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RequestDetails.RequestDetail.Session.RsvpSession>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.RequestDetails.RequestDetail.Session, self).__init__()

                    self.yang_name = "session"
                    self.yang_parent_name = "request-detail"

                    self.rsvp_session = Rsvp.RequestDetails.RequestDetail.Session.RsvpSession()
                    self.rsvp_session.parent = self
                    self._children_name_map["rsvp_session"] = "rsvp-session"
                    self._children_yang_names.add("rsvp-session")


                class RsvpSession(Entity):
                    """
                    RSVP Session
                    
                    .. attribute:: ipv4
                    
                    	UDP IPv4 session
                    	**type**\:   :py:class:`Ipv4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RequestDetails.RequestDetail.Session.RsvpSession.Ipv4>`
                    
                    .. attribute:: ipv4_lsp_session
                    
                    	IPv4 LSP session
                    	**type**\:   :py:class:`Ipv4LspSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RequestDetails.RequestDetail.Session.RsvpSession.Ipv4LspSession>`
                    
                    .. attribute:: ipv4_p2mp_lsp_session
                    
                    	IPv4 P2MP LSP session
                    	**type**\:   :py:class:`Ipv4P2MpLspSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RequestDetails.RequestDetail.Session.RsvpSession.Ipv4P2MpLspSession>`
                    
                    .. attribute:: ipv4_uni_session
                    
                    	IPv4 UNI session
                    	**type**\:   :py:class:`Ipv4UniSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RequestDetails.RequestDetail.Session.RsvpSession.Ipv4UniSession>`
                    
                    .. attribute:: session_type
                    
                    	SessionType
                    	**type**\:   :py:class:`RsvpMgmtSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtSession>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.RequestDetails.RequestDetail.Session.RsvpSession, self).__init__()

                        self.yang_name = "rsvp-session"
                        self.yang_parent_name = "session"

                        self.session_type = YLeaf(YType.enumeration, "session-type")

                        self.ipv4 = Rsvp.RequestDetails.RequestDetail.Session.RsvpSession.Ipv4()
                        self.ipv4.parent = self
                        self._children_name_map["ipv4"] = "ipv4"
                        self._children_yang_names.add("ipv4")

                        self.ipv4_lsp_session = Rsvp.RequestDetails.RequestDetail.Session.RsvpSession.Ipv4LspSession()
                        self.ipv4_lsp_session.parent = self
                        self._children_name_map["ipv4_lsp_session"] = "ipv4-lsp-session"
                        self._children_yang_names.add("ipv4-lsp-session")

                        self.ipv4_p2mp_lsp_session = Rsvp.RequestDetails.RequestDetail.Session.RsvpSession.Ipv4P2MpLspSession()
                        self.ipv4_p2mp_lsp_session.parent = self
                        self._children_name_map["ipv4_p2mp_lsp_session"] = "ipv4-p2mp-lsp-session"
                        self._children_yang_names.add("ipv4-p2mp-lsp-session")

                        self.ipv4_uni_session = Rsvp.RequestDetails.RequestDetail.Session.RsvpSession.Ipv4UniSession()
                        self.ipv4_uni_session.parent = self
                        self._children_name_map["ipv4_uni_session"] = "ipv4-uni-session"
                        self._children_yang_names.add("ipv4-uni-session")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("session_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.RequestDetails.RequestDetail.Session.RsvpSession, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.RequestDetails.RequestDetail.Session.RsvpSession, self).__setattr__(name, value)


                    class Ipv4(Entity):
                        """
                        UDP IPv4 session
                        
                        .. attribute:: destination_address
                        
                        	Destination address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: destination_port
                        
                        	The Session Destination Port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: protocol
                        
                        	Protocol type (originally defined in RFC 790, further values in subsequent RFCs)
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.RequestDetails.RequestDetail.Session.RsvpSession.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "rsvp-session"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.destination_port = YLeaf(YType.uint16, "destination-port")

                            self.protocol = YLeaf(YType.uint8, "protocol")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "destination_port",
                                            "protocol") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.RequestDetails.RequestDetail.Session.RsvpSession.Ipv4, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.RequestDetails.RequestDetail.Session.RsvpSession.Ipv4, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination_address.is_set or
                                self.destination_port.is_set or
                                self.protocol.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.destination_port.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/request-details/request-detail/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.destination_port.is_set or self.destination_port.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_port.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "destination-port" or name == "protocol"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "destination-port"):
                                self.destination_port = value
                                self.destination_port.value_namespace = name_space
                                self.destination_port.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix


                    class Ipv4LspSession(Entity):
                        """
                        IPv4 LSP session
                        
                        .. attribute:: destination_address
                        
                        	Destination address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: extended_tunnel_id
                        
                        	The Session Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: tunnel_id
                        
                        	The Session Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.RequestDetails.RequestDetail.Session.RsvpSession.Ipv4LspSession, self).__init__()

                            self.yang_name = "ipv4-lsp-session"
                            self.yang_parent_name = "rsvp-session"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                            self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "extended_tunnel_id",
                                            "tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.RequestDetails.RequestDetail.Session.RsvpSession.Ipv4LspSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.RequestDetails.RequestDetail.Session.RsvpSession.Ipv4LspSession, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination_address.is_set or
                                self.extended_tunnel_id.is_set or
                                self.tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.extended_tunnel_id.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-lsp-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/request-details/request-detail/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "extended-tunnel-id" or name == "tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "extended-tunnel-id"):
                                self.extended_tunnel_id = value
                                self.extended_tunnel_id.value_namespace = name_space
                                self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix


                    class Ipv4UniSession(Entity):
                        """
                        IPv4 UNI session
                        
                        .. attribute:: destination_address
                        
                        	Destination address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: extended_address
                        
                        	The Session Extended Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: tunnel_id
                        
                        	The Session Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.RequestDetails.RequestDetail.Session.RsvpSession.Ipv4UniSession, self).__init__()

                            self.yang_name = "ipv4-uni-session"
                            self.yang_parent_name = "rsvp-session"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.extended_address = YLeaf(YType.str, "extended-address")

                            self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "extended_address",
                                            "tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.RequestDetails.RequestDetail.Session.RsvpSession.Ipv4UniSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.RequestDetails.RequestDetail.Session.RsvpSession.Ipv4UniSession, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination_address.is_set or
                                self.extended_address.is_set or
                                self.tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.extended_address.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-uni-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/request-details/request-detail/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.extended_address.is_set or self.extended_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_address.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "extended-address" or name == "tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "extended-address"):
                                self.extended_address = value
                                self.extended_address.value_namespace = name_space
                                self.extended_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix


                    class Ipv4P2MpLspSession(Entity):
                        """
                        IPv4 P2MP LSP session
                        
                        .. attribute:: extended_tunnel_id
                        
                        	The Session Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: p2mp_id
                        
                        	The Point to Multipoint ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tunnel_id
                        
                        	The Session Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.RequestDetails.RequestDetail.Session.RsvpSession.Ipv4P2MpLspSession, self).__init__()

                            self.yang_name = "ipv4-p2mp-lsp-session"
                            self.yang_parent_name = "rsvp-session"

                            self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                            self.p2mp_id = YLeaf(YType.uint32, "p2mp-id")

                            self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("extended_tunnel_id",
                                            "p2mp_id",
                                            "tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.RequestDetails.RequestDetail.Session.RsvpSession.Ipv4P2MpLspSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.RequestDetails.RequestDetail.Session.RsvpSession.Ipv4P2MpLspSession, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.extended_tunnel_id.is_set or
                                self.p2mp_id.is_set or
                                self.tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.extended_tunnel_id.yfilter != YFilter.not_set or
                                self.p2mp_id.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-p2mp-lsp-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/request-details/request-detail/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                            if (self.p2mp_id.is_set or self.p2mp_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.p2mp_id.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "extended-tunnel-id" or name == "p2mp-id" or name == "tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "extended-tunnel-id"):
                                self.extended_tunnel_id = value
                                self.extended_tunnel_id.value_namespace = name_space
                                self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "p2mp-id"):
                                self.p2mp_id = value
                                self.p2mp_id.value_namespace = name_space
                                self.p2mp_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.session_type.is_set or
                            (self.ipv4 is not None and self.ipv4.has_data()) or
                            (self.ipv4_lsp_session is not None and self.ipv4_lsp_session.has_data()) or
                            (self.ipv4_p2mp_lsp_session is not None and self.ipv4_p2mp_lsp_session.has_data()) or
                            (self.ipv4_uni_session is not None and self.ipv4_uni_session.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.session_type.yfilter != YFilter.not_set or
                            (self.ipv4 is not None and self.ipv4.has_operation()) or
                            (self.ipv4_lsp_session is not None and self.ipv4_lsp_session.has_operation()) or
                            (self.ipv4_p2mp_lsp_session is not None and self.ipv4_p2mp_lsp_session.has_operation()) or
                            (self.ipv4_uni_session is not None and self.ipv4_uni_session.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rsvp-session" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/request-details/request-detail/session/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.session_type.is_set or self.session_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.session_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "ipv4"):
                            if (self.ipv4 is None):
                                self.ipv4 = Rsvp.RequestDetails.RequestDetail.Session.RsvpSession.Ipv4()
                                self.ipv4.parent = self
                                self._children_name_map["ipv4"] = "ipv4"
                            return self.ipv4

                        if (child_yang_name == "ipv4-lsp-session"):
                            if (self.ipv4_lsp_session is None):
                                self.ipv4_lsp_session = Rsvp.RequestDetails.RequestDetail.Session.RsvpSession.Ipv4LspSession()
                                self.ipv4_lsp_session.parent = self
                                self._children_name_map["ipv4_lsp_session"] = "ipv4-lsp-session"
                            return self.ipv4_lsp_session

                        if (child_yang_name == "ipv4-p2mp-lsp-session"):
                            if (self.ipv4_p2mp_lsp_session is None):
                                self.ipv4_p2mp_lsp_session = Rsvp.RequestDetails.RequestDetail.Session.RsvpSession.Ipv4P2MpLspSession()
                                self.ipv4_p2mp_lsp_session.parent = self
                                self._children_name_map["ipv4_p2mp_lsp_session"] = "ipv4-p2mp-lsp-session"
                            return self.ipv4_p2mp_lsp_session

                        if (child_yang_name == "ipv4-uni-session"):
                            if (self.ipv4_uni_session is None):
                                self.ipv4_uni_session = Rsvp.RequestDetails.RequestDetail.Session.RsvpSession.Ipv4UniSession()
                                self.ipv4_uni_session.parent = self
                                self._children_name_map["ipv4_uni_session"] = "ipv4-uni-session"
                            return self.ipv4_uni_session

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ipv4" or name == "ipv4-lsp-session" or name == "ipv4-p2mp-lsp-session" or name == "ipv4-uni-session" or name == "session-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "session-type"):
                            self.session_type = value
                            self.session_type.value_namespace = name_space
                            self.session_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (self.rsvp_session is not None and self.rsvp_session.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.rsvp_session is not None and self.rsvp_session.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "session" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/request-details/request-detail/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "rsvp-session"):
                        if (self.rsvp_session is None):
                            self.rsvp_session = Rsvp.RequestDetails.RequestDetail.Session.RsvpSession()
                            self.rsvp_session.parent = self
                            self._children_name_map["rsvp_session"] = "rsvp-session"
                        return self.rsvp_session

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "rsvp-session"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class S2LSubLsp(Entity):
                """
                RSVP S2L Sub\-LSP information
                
                .. attribute:: s2l_destination_address
                
                	S2L Sub\-LSP Destination Address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.RequestDetails.RequestDetail.S2LSubLsp, self).__init__()

                    self.yang_name = "s2l-sub-lsp"
                    self.yang_parent_name = "request-detail"

                    self.s2l_destination_address = YLeaf(YType.str, "s2l-destination-address")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("s2l_destination_address") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.RequestDetails.RequestDetail.S2LSubLsp, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.RequestDetails.RequestDetail.S2LSubLsp, self).__setattr__(name, value)

                def has_data(self):
                    return self.s2l_destination_address.is_set

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.s2l_destination_address.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "s2l-sub-lsp" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/request-details/request-detail/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.s2l_destination_address.is_set or self.s2l_destination_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.s2l_destination_address.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "s2l-destination-address"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "s2l-destination-address"):
                        self.s2l_destination_address = value
                        self.s2l_destination_address.value_namespace = name_space
                        self.s2l_destination_address.value_namespace_prefix = name_space_prefix


            class FlowSpec(Entity):
                """
                Flow Spec Information
                
                .. attribute:: flow_average_rate
                
                	The Flow Average Rate in bytes per second
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: byte/s
                
                .. attribute:: flow_max_burst
                
                	The Flow Maximum Burst
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: flow_max_unit
                
                	The Flow Maximum Unit
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: flow_min_unit
                
                	The Flow Minimum Unit
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: flow_peak_rate
                
                	The Flow Peak Rate in bytes per second
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: byte/s
                
                .. attribute:: flow_qos
                
                	The Flow Quality of Service
                	**type**\:   :py:class:`RsvpMgmtQosServiceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtQosServiceEnum>`
                
                .. attribute:: flow_requested_rate
                
                	The Flow Requested Rate in bytes per second
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: byte/s
                
                .. attribute:: flow_slack
                
                	The Flow Slack
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.RequestDetails.RequestDetail.FlowSpec, self).__init__()

                    self.yang_name = "flow-spec"
                    self.yang_parent_name = "request-detail"

                    self.flow_average_rate = YLeaf(YType.uint64, "flow-average-rate")

                    self.flow_max_burst = YLeaf(YType.uint64, "flow-max-burst")

                    self.flow_max_unit = YLeaf(YType.uint32, "flow-max-unit")

                    self.flow_min_unit = YLeaf(YType.uint32, "flow-min-unit")

                    self.flow_peak_rate = YLeaf(YType.uint64, "flow-peak-rate")

                    self.flow_qos = YLeaf(YType.enumeration, "flow-qos")

                    self.flow_requested_rate = YLeaf(YType.uint64, "flow-requested-rate")

                    self.flow_slack = YLeaf(YType.uint32, "flow-slack")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("flow_average_rate",
                                    "flow_max_burst",
                                    "flow_max_unit",
                                    "flow_min_unit",
                                    "flow_peak_rate",
                                    "flow_qos",
                                    "flow_requested_rate",
                                    "flow_slack") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.RequestDetails.RequestDetail.FlowSpec, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.RequestDetails.RequestDetail.FlowSpec, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.flow_average_rate.is_set or
                        self.flow_max_burst.is_set or
                        self.flow_max_unit.is_set or
                        self.flow_min_unit.is_set or
                        self.flow_peak_rate.is_set or
                        self.flow_qos.is_set or
                        self.flow_requested_rate.is_set or
                        self.flow_slack.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.flow_average_rate.yfilter != YFilter.not_set or
                        self.flow_max_burst.yfilter != YFilter.not_set or
                        self.flow_max_unit.yfilter != YFilter.not_set or
                        self.flow_min_unit.yfilter != YFilter.not_set or
                        self.flow_peak_rate.yfilter != YFilter.not_set or
                        self.flow_qos.yfilter != YFilter.not_set or
                        self.flow_requested_rate.yfilter != YFilter.not_set or
                        self.flow_slack.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "flow-spec" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/request-details/request-detail/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.flow_average_rate.is_set or self.flow_average_rate.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_average_rate.get_name_leafdata())
                    if (self.flow_max_burst.is_set or self.flow_max_burst.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_max_burst.get_name_leafdata())
                    if (self.flow_max_unit.is_set or self.flow_max_unit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_max_unit.get_name_leafdata())
                    if (self.flow_min_unit.is_set or self.flow_min_unit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_min_unit.get_name_leafdata())
                    if (self.flow_peak_rate.is_set or self.flow_peak_rate.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_peak_rate.get_name_leafdata())
                    if (self.flow_qos.is_set or self.flow_qos.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_qos.get_name_leafdata())
                    if (self.flow_requested_rate.is_set or self.flow_requested_rate.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_requested_rate.get_name_leafdata())
                    if (self.flow_slack.is_set or self.flow_slack.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_slack.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "flow-average-rate" or name == "flow-max-burst" or name == "flow-max-unit" or name == "flow-min-unit" or name == "flow-peak-rate" or name == "flow-qos" or name == "flow-requested-rate" or name == "flow-slack"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "flow-average-rate"):
                        self.flow_average_rate = value
                        self.flow_average_rate.value_namespace = name_space
                        self.flow_average_rate.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-max-burst"):
                        self.flow_max_burst = value
                        self.flow_max_burst.value_namespace = name_space
                        self.flow_max_burst.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-max-unit"):
                        self.flow_max_unit = value
                        self.flow_max_unit.value_namespace = name_space
                        self.flow_max_unit.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-min-unit"):
                        self.flow_min_unit = value
                        self.flow_min_unit.value_namespace = name_space
                        self.flow_min_unit.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-peak-rate"):
                        self.flow_peak_rate = value
                        self.flow_peak_rate.value_namespace = name_space
                        self.flow_peak_rate.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-qos"):
                        self.flow_qos = value
                        self.flow_qos.value_namespace = name_space
                        self.flow_qos.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-requested-rate"):
                        self.flow_requested_rate = value
                        self.flow_requested_rate.value_namespace = name_space
                        self.flow_requested_rate.value_namespace_prefix = name_space_prefix
                    if(value_path == "flow-slack"):
                        self.flow_slack = value
                        self.flow_slack.value_namespace = name_space
                        self.flow_slack.value_namespace_prefix = name_space_prefix


            class GenericFlowSpec(Entity):
                """
                Generic Flow Spec Information
                
                .. attribute:: flow_spec_type
                
                	FlowSpecType
                	**type**\:   :py:class:`RsvpMgmtFlowSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtFlowSpec>`
                
                .. attribute:: g709otn_flow_spec
                
                	G709 OTN FlowSpec
                	**type**\:   :py:class:`G709OtnFlowSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RequestDetails.RequestDetail.GenericFlowSpec.G709OtnFlowSpec>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.RequestDetails.RequestDetail.GenericFlowSpec, self).__init__()

                    self.yang_name = "generic-flow-spec"
                    self.yang_parent_name = "request-detail"

                    self.flow_spec_type = YLeaf(YType.enumeration, "flow-spec-type")

                    self.g709otn_flow_spec = Rsvp.RequestDetails.RequestDetail.GenericFlowSpec.G709OtnFlowSpec()
                    self.g709otn_flow_spec.parent = self
                    self._children_name_map["g709otn_flow_spec"] = "g709otn-flow-spec"
                    self._children_yang_names.add("g709otn-flow-spec")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("flow_spec_type") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.RequestDetails.RequestDetail.GenericFlowSpec, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.RequestDetails.RequestDetail.GenericFlowSpec, self).__setattr__(name, value)


                class G709OtnFlowSpec(Entity):
                    """
                    G709 OTN FlowSpec
                    
                    .. attribute:: flow_bit_rate
                    
                    	G709 OTN Flow Bit Rate
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: flow_multiplier
                    
                    	G709 OTN Flow Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: flow_nvc
                    
                    	G709 OTN Flow NVC
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: flow_signal_type
                    
                    	G709 OTN Flow Signal Type (Refer G709 v3)
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.RequestDetails.RequestDetail.GenericFlowSpec.G709OtnFlowSpec, self).__init__()

                        self.yang_name = "g709otn-flow-spec"
                        self.yang_parent_name = "generic-flow-spec"

                        self.flow_bit_rate = YLeaf(YType.uint64, "flow-bit-rate")

                        self.flow_multiplier = YLeaf(YType.uint16, "flow-multiplier")

                        self.flow_nvc = YLeaf(YType.uint16, "flow-nvc")

                        self.flow_signal_type = YLeaf(YType.uint8, "flow-signal-type")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("flow_bit_rate",
                                        "flow_multiplier",
                                        "flow_nvc",
                                        "flow_signal_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.RequestDetails.RequestDetail.GenericFlowSpec.G709OtnFlowSpec, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.RequestDetails.RequestDetail.GenericFlowSpec.G709OtnFlowSpec, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.flow_bit_rate.is_set or
                            self.flow_multiplier.is_set or
                            self.flow_nvc.is_set or
                            self.flow_signal_type.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.flow_bit_rate.yfilter != YFilter.not_set or
                            self.flow_multiplier.yfilter != YFilter.not_set or
                            self.flow_nvc.yfilter != YFilter.not_set or
                            self.flow_signal_type.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "g709otn-flow-spec" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/request-details/request-detail/generic-flow-spec/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.flow_bit_rate.is_set or self.flow_bit_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.flow_bit_rate.get_name_leafdata())
                        if (self.flow_multiplier.is_set or self.flow_multiplier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.flow_multiplier.get_name_leafdata())
                        if (self.flow_nvc.is_set or self.flow_nvc.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.flow_nvc.get_name_leafdata())
                        if (self.flow_signal_type.is_set or self.flow_signal_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.flow_signal_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "flow-bit-rate" or name == "flow-multiplier" or name == "flow-nvc" or name == "flow-signal-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "flow-bit-rate"):
                            self.flow_bit_rate = value
                            self.flow_bit_rate.value_namespace = name_space
                            self.flow_bit_rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "flow-multiplier"):
                            self.flow_multiplier = value
                            self.flow_multiplier.value_namespace = name_space
                            self.flow_multiplier.value_namespace_prefix = name_space_prefix
                        if(value_path == "flow-nvc"):
                            self.flow_nvc = value
                            self.flow_nvc.value_namespace = name_space
                            self.flow_nvc.value_namespace_prefix = name_space_prefix
                        if(value_path == "flow-signal-type"):
                            self.flow_signal_type = value
                            self.flow_signal_type.value_namespace = name_space
                            self.flow_signal_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.flow_spec_type.is_set or
                        (self.g709otn_flow_spec is not None and self.g709otn_flow_spec.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.flow_spec_type.yfilter != YFilter.not_set or
                        (self.g709otn_flow_spec is not None and self.g709otn_flow_spec.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "generic-flow-spec" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/request-details/request-detail/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.flow_spec_type.is_set or self.flow_spec_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.flow_spec_type.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "g709otn-flow-spec"):
                        if (self.g709otn_flow_spec is None):
                            self.g709otn_flow_spec = Rsvp.RequestDetails.RequestDetail.GenericFlowSpec.G709OtnFlowSpec()
                            self.g709otn_flow_spec.parent = self
                            self._children_name_map["g709otn_flow_spec"] = "g709otn-flow-spec"
                        return self.g709otn_flow_spec

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "g709otn-flow-spec" or name == "flow-spec-type"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "flow-spec-type"):
                        self.flow_spec_type = value
                        self.flow_spec_type.value_namespace = name_space
                        self.flow_spec_type.value_namespace_prefix = name_space_prefix


            class Filter(Entity):
                """
                RSVP Filter
                
                .. attribute:: rsvp_filter
                
                	RSVP Filter
                	**type**\:   :py:class:`RsvpFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RequestDetails.RequestDetail.Filter.RsvpFilter>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.RequestDetails.RequestDetail.Filter, self).__init__()

                    self.yang_name = "filter"
                    self.yang_parent_name = "request-detail"

                    self.rsvp_filter = Rsvp.RequestDetails.RequestDetail.Filter.RsvpFilter()
                    self.rsvp_filter.parent = self
                    self._children_name_map["rsvp_filter"] = "rsvp-filter"
                    self._children_yang_names.add("rsvp-filter")


                class RsvpFilter(Entity):
                    """
                    RSVP Filter
                    
                    .. attribute:: filter_type
                    
                    	FilterType
                    	**type**\:   :py:class:`RsvpMgmtFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtFilter>`
                    
                    .. attribute:: p2mp_ipv4_session
                    
                    	IPv4 P2MP LSP FilterSpec
                    	**type**\:   :py:class:`P2MpIpv4Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RequestDetails.RequestDetail.Filter.RsvpFilter.P2MpIpv4Session>`
                    
                    .. attribute:: udp_ipv4_session
                    
                    	UDP IPV4 FilterSpec
                    	**type**\:   :py:class:`UdpIpv4Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.RequestDetails.RequestDetail.Filter.RsvpFilter.UdpIpv4Session>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.RequestDetails.RequestDetail.Filter.RsvpFilter, self).__init__()

                        self.yang_name = "rsvp-filter"
                        self.yang_parent_name = "filter"

                        self.filter_type = YLeaf(YType.enumeration, "filter-type")

                        self.p2mp_ipv4_session = Rsvp.RequestDetails.RequestDetail.Filter.RsvpFilter.P2MpIpv4Session()
                        self.p2mp_ipv4_session.parent = self
                        self._children_name_map["p2mp_ipv4_session"] = "p2mp-ipv4-session"
                        self._children_yang_names.add("p2mp-ipv4-session")

                        self.udp_ipv4_session = Rsvp.RequestDetails.RequestDetail.Filter.RsvpFilter.UdpIpv4Session()
                        self.udp_ipv4_session.parent = self
                        self._children_name_map["udp_ipv4_session"] = "udp-ipv4-session"
                        self._children_yang_names.add("udp-ipv4-session")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("filter_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.RequestDetails.RequestDetail.Filter.RsvpFilter, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.RequestDetails.RequestDetail.Filter.RsvpFilter, self).__setattr__(name, value)


                    class UdpIpv4Session(Entity):
                        """
                        UDP IPV4 FilterSpec
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source_port
                        
                        	Source Port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.RequestDetails.RequestDetail.Filter.RsvpFilter.UdpIpv4Session, self).__init__()

                            self.yang_name = "udp-ipv4-session"
                            self.yang_parent_name = "rsvp-filter"

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.source_port = YLeaf(YType.uint16, "source-port")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("source_address",
                                            "source_port") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.RequestDetails.RequestDetail.Filter.RsvpFilter.UdpIpv4Session, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.RequestDetails.RequestDetail.Filter.RsvpFilter.UdpIpv4Session, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.source_address.is_set or
                                self.source_port.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                self.source_port.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "udp-ipv4-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/request-details/request-detail/filter/rsvp-filter/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())
                            if (self.source_port.is_set or self.source_port.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_port.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "source-address" or name == "source-port"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-port"):
                                self.source_port = value
                                self.source_port.value_namespace = name_space
                                self.source_port.value_namespace_prefix = name_space_prefix


                    class P2MpIpv4Session(Entity):
                        """
                        IPv4 P2MP LSP FilterSpec
                        
                        .. attribute:: p2mp_sub_group_origin
                        
                        	Point to Multipoint SubGroup Origin
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source_port
                        
                        	Source Port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: sub_group_id
                        
                        	Point to Multipoint Subgroup ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.RequestDetails.RequestDetail.Filter.RsvpFilter.P2MpIpv4Session, self).__init__()

                            self.yang_name = "p2mp-ipv4-session"
                            self.yang_parent_name = "rsvp-filter"

                            self.p2mp_sub_group_origin = YLeaf(YType.str, "p2mp-sub-group-origin")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.source_port = YLeaf(YType.uint16, "source-port")

                            self.sub_group_id = YLeaf(YType.uint16, "sub-group-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("p2mp_sub_group_origin",
                                            "source_address",
                                            "source_port",
                                            "sub_group_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.RequestDetails.RequestDetail.Filter.RsvpFilter.P2MpIpv4Session, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.RequestDetails.RequestDetail.Filter.RsvpFilter.P2MpIpv4Session, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.p2mp_sub_group_origin.is_set or
                                self.source_address.is_set or
                                self.source_port.is_set or
                                self.sub_group_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.p2mp_sub_group_origin.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                self.source_port.yfilter != YFilter.not_set or
                                self.sub_group_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "p2mp-ipv4-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/request-details/request-detail/filter/rsvp-filter/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.p2mp_sub_group_origin.is_set or self.p2mp_sub_group_origin.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.p2mp_sub_group_origin.get_name_leafdata())
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())
                            if (self.source_port.is_set or self.source_port.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_port.get_name_leafdata())
                            if (self.sub_group_id.is_set or self.sub_group_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sub_group_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "p2mp-sub-group-origin" or name == "source-address" or name == "source-port" or name == "sub-group-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "p2mp-sub-group-origin"):
                                self.p2mp_sub_group_origin = value
                                self.p2mp_sub_group_origin.value_namespace = name_space
                                self.p2mp_sub_group_origin.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-port"):
                                self.source_port = value
                                self.source_port.value_namespace = name_space
                                self.source_port.value_namespace_prefix = name_space_prefix
                            if(value_path == "sub-group-id"):
                                self.sub_group_id = value
                                self.sub_group_id.value_namespace = name_space
                                self.sub_group_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.filter_type.is_set or
                            (self.p2mp_ipv4_session is not None and self.p2mp_ipv4_session.has_data()) or
                            (self.udp_ipv4_session is not None and self.udp_ipv4_session.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.filter_type.yfilter != YFilter.not_set or
                            (self.p2mp_ipv4_session is not None and self.p2mp_ipv4_session.has_operation()) or
                            (self.udp_ipv4_session is not None and self.udp_ipv4_session.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rsvp-filter" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/request-details/request-detail/filter/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.filter_type.is_set or self.filter_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.filter_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "p2mp-ipv4-session"):
                            if (self.p2mp_ipv4_session is None):
                                self.p2mp_ipv4_session = Rsvp.RequestDetails.RequestDetail.Filter.RsvpFilter.P2MpIpv4Session()
                                self.p2mp_ipv4_session.parent = self
                                self._children_name_map["p2mp_ipv4_session"] = "p2mp-ipv4-session"
                            return self.p2mp_ipv4_session

                        if (child_yang_name == "udp-ipv4-session"):
                            if (self.udp_ipv4_session is None):
                                self.udp_ipv4_session = Rsvp.RequestDetails.RequestDetail.Filter.RsvpFilter.UdpIpv4Session()
                                self.udp_ipv4_session.parent = self
                                self._children_name_map["udp_ipv4_session"] = "udp-ipv4-session"
                            return self.udp_ipv4_session

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "p2mp-ipv4-session" or name == "udp-ipv4-session" or name == "filter-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "filter-type"):
                            self.filter_type = value
                            self.filter_type.value_namespace = name_space
                            self.filter_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (self.rsvp_filter is not None and self.rsvp_filter.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.rsvp_filter is not None and self.rsvp_filter.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "filter" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/request-details/request-detail/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "rsvp-filter"):
                        if (self.rsvp_filter is None):
                            self.rsvp_filter = Rsvp.RequestDetails.RequestDetail.Filter.RsvpFilter()
                            self.rsvp_filter.parent = self
                            self._children_name_map["rsvp_filter"] = "rsvp-filter"
                        return self.rsvp_filter

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "rsvp-filter"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class Style(Entity):
                """
                RSVP Style
                
                .. attribute:: reservation_type
                
                	The Reservation Type\: WF, SE or FF
                	**type**\:   :py:class:`RsvpMgmtReservationTypeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtReservationTypeEnum>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.RequestDetails.RequestDetail.Style, self).__init__()

                    self.yang_name = "style"
                    self.yang_parent_name = "request-detail"

                    self.reservation_type = YLeaf(YType.enumeration, "reservation-type")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("reservation_type") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.RequestDetails.RequestDetail.Style, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.RequestDetails.RequestDetail.Style, self).__setattr__(name, value)

                def has_data(self):
                    return self.reservation_type.is_set

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.reservation_type.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "style" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/request-details/request-detail/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.reservation_type.is_set or self.reservation_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reservation_type.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "reservation-type"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "reservation-type"):
                        self.reservation_type = value
                        self.reservation_type.value_namespace = name_space
                        self.reservation_type.value_namespace_prefix = name_space_prefix


            class ReqFlags(Entity):
                """
                Request flags
                
                .. attribute:: is_ack_outstanding
                
                	Is ACK message outstanding
                	**type**\:  bool
                
                .. attribute:: is_label_request_in_path
                
                	The Path message contains Label Request
                	**type**\:  bool
                
                .. attribute:: is_local_receiver
                
                	Local Receiver
                	**type**\:  bool
                
                .. attribute:: is_merge_point
                
                	Is node a Merge Point
                	**type**\:  bool
                
                .. attribute:: is_message_id_allocated
                
                	Is MessageID allocated
                	**type**\:  bool
                
                .. attribute:: is_nack_received
                
                	A NACK message was received
                	**type**\:  bool
                
                .. attribute:: is_paced
                
                	Message is paced
                	**type**\:  bool
                
                .. attribute:: is_record_label_in_path
                
                	Path has Session\-Attr object with Record Labels set
                	**type**\:  bool
                
                .. attribute:: is_refreshing
                
                	Is neighbor refreshing
                	**type**\:  bool
                
                .. attribute:: is_retransmit
                
                	Retransmit the message
                	**type**\:  bool
                
                .. attribute:: is_rro_in_path
                
                	The Path message contains RRO
                	**type**\:  bool
                
                .. attribute:: is_send_confirm
                
                	Send Confirm message
                	**type**\:  bool
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.RequestDetails.RequestDetail.ReqFlags, self).__init__()

                    self.yang_name = "req-flags"
                    self.yang_parent_name = "request-detail"

                    self.is_ack_outstanding = YLeaf(YType.boolean, "is-ack-outstanding")

                    self.is_label_request_in_path = YLeaf(YType.boolean, "is-label-request-in-path")

                    self.is_local_receiver = YLeaf(YType.boolean, "is-local-receiver")

                    self.is_merge_point = YLeaf(YType.boolean, "is-merge-point")

                    self.is_message_id_allocated = YLeaf(YType.boolean, "is-message-id-allocated")

                    self.is_nack_received = YLeaf(YType.boolean, "is-nack-received")

                    self.is_paced = YLeaf(YType.boolean, "is-paced")

                    self.is_record_label_in_path = YLeaf(YType.boolean, "is-record-label-in-path")

                    self.is_refreshing = YLeaf(YType.boolean, "is-refreshing")

                    self.is_retransmit = YLeaf(YType.boolean, "is-retransmit")

                    self.is_rro_in_path = YLeaf(YType.boolean, "is-rro-in-path")

                    self.is_send_confirm = YLeaf(YType.boolean, "is-send-confirm")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("is_ack_outstanding",
                                    "is_label_request_in_path",
                                    "is_local_receiver",
                                    "is_merge_point",
                                    "is_message_id_allocated",
                                    "is_nack_received",
                                    "is_paced",
                                    "is_record_label_in_path",
                                    "is_refreshing",
                                    "is_retransmit",
                                    "is_rro_in_path",
                                    "is_send_confirm") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.RequestDetails.RequestDetail.ReqFlags, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.RequestDetails.RequestDetail.ReqFlags, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.is_ack_outstanding.is_set or
                        self.is_label_request_in_path.is_set or
                        self.is_local_receiver.is_set or
                        self.is_merge_point.is_set or
                        self.is_message_id_allocated.is_set or
                        self.is_nack_received.is_set or
                        self.is_paced.is_set or
                        self.is_record_label_in_path.is_set or
                        self.is_refreshing.is_set or
                        self.is_retransmit.is_set or
                        self.is_rro_in_path.is_set or
                        self.is_send_confirm.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.is_ack_outstanding.yfilter != YFilter.not_set or
                        self.is_label_request_in_path.yfilter != YFilter.not_set or
                        self.is_local_receiver.yfilter != YFilter.not_set or
                        self.is_merge_point.yfilter != YFilter.not_set or
                        self.is_message_id_allocated.yfilter != YFilter.not_set or
                        self.is_nack_received.yfilter != YFilter.not_set or
                        self.is_paced.yfilter != YFilter.not_set or
                        self.is_record_label_in_path.yfilter != YFilter.not_set or
                        self.is_refreshing.yfilter != YFilter.not_set or
                        self.is_retransmit.yfilter != YFilter.not_set or
                        self.is_rro_in_path.yfilter != YFilter.not_set or
                        self.is_send_confirm.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "req-flags" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/request-details/request-detail/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.is_ack_outstanding.is_set or self.is_ack_outstanding.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_ack_outstanding.get_name_leafdata())
                    if (self.is_label_request_in_path.is_set or self.is_label_request_in_path.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_label_request_in_path.get_name_leafdata())
                    if (self.is_local_receiver.is_set or self.is_local_receiver.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_local_receiver.get_name_leafdata())
                    if (self.is_merge_point.is_set or self.is_merge_point.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_merge_point.get_name_leafdata())
                    if (self.is_message_id_allocated.is_set or self.is_message_id_allocated.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_message_id_allocated.get_name_leafdata())
                    if (self.is_nack_received.is_set or self.is_nack_received.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_nack_received.get_name_leafdata())
                    if (self.is_paced.is_set or self.is_paced.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_paced.get_name_leafdata())
                    if (self.is_record_label_in_path.is_set or self.is_record_label_in_path.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_record_label_in_path.get_name_leafdata())
                    if (self.is_refreshing.is_set or self.is_refreshing.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_refreshing.get_name_leafdata())
                    if (self.is_retransmit.is_set or self.is_retransmit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_retransmit.get_name_leafdata())
                    if (self.is_rro_in_path.is_set or self.is_rro_in_path.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_rro_in_path.get_name_leafdata())
                    if (self.is_send_confirm.is_set or self.is_send_confirm.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_send_confirm.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "is-ack-outstanding" or name == "is-label-request-in-path" or name == "is-local-receiver" or name == "is-merge-point" or name == "is-message-id-allocated" or name == "is-nack-received" or name == "is-paced" or name == "is-record-label-in-path" or name == "is-refreshing" or name == "is-retransmit" or name == "is-rro-in-path" or name == "is-send-confirm"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "is-ack-outstanding"):
                        self.is_ack_outstanding = value
                        self.is_ack_outstanding.value_namespace = name_space
                        self.is_ack_outstanding.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-label-request-in-path"):
                        self.is_label_request_in_path = value
                        self.is_label_request_in_path.value_namespace = name_space
                        self.is_label_request_in_path.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-local-receiver"):
                        self.is_local_receiver = value
                        self.is_local_receiver.value_namespace = name_space
                        self.is_local_receiver.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-merge-point"):
                        self.is_merge_point = value
                        self.is_merge_point.value_namespace = name_space
                        self.is_merge_point.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-message-id-allocated"):
                        self.is_message_id_allocated = value
                        self.is_message_id_allocated.value_namespace = name_space
                        self.is_message_id_allocated.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-nack-received"):
                        self.is_nack_received = value
                        self.is_nack_received.value_namespace = name_space
                        self.is_nack_received.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-paced"):
                        self.is_paced = value
                        self.is_paced.value_namespace = name_space
                        self.is_paced.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-record-label-in-path"):
                        self.is_record_label_in_path = value
                        self.is_record_label_in_path.value_namespace = name_space
                        self.is_record_label_in_path.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-refreshing"):
                        self.is_refreshing = value
                        self.is_refreshing.value_namespace = name_space
                        self.is_refreshing.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-retransmit"):
                        self.is_retransmit = value
                        self.is_retransmit.value_namespace = name_space
                        self.is_retransmit.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-rro-in-path"):
                        self.is_rro_in_path = value
                        self.is_rro_in_path.value_namespace = name_space
                        self.is_rro_in_path.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-send-confirm"):
                        self.is_send_confirm = value
                        self.is_send_confirm.value_namespace = name_space
                        self.is_send_confirm.value_namespace_prefix = name_space_prefix


            class Hop(Entity):
                """
                Hop Infomation
                
                .. attribute:: neighbor_address
                
                	IP address of the neighbor
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: neighbor_logical_interface_name
                
                	Neighbor Logical Interface Name
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.RequestDetails.RequestDetail.Hop, self).__init__()

                    self.yang_name = "hop"
                    self.yang_parent_name = "request-detail"

                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                    self.neighbor_logical_interface_name = YLeaf(YType.str, "neighbor-logical-interface-name")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("neighbor_address",
                                    "neighbor_logical_interface_name") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.RequestDetails.RequestDetail.Hop, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.RequestDetails.RequestDetail.Hop, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.neighbor_address.is_set or
                        self.neighbor_logical_interface_name.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.neighbor_address.yfilter != YFilter.not_set or
                        self.neighbor_logical_interface_name.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "hop" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/request-details/request-detail/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                    if (self.neighbor_logical_interface_name.is_set or self.neighbor_logical_interface_name.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.neighbor_logical_interface_name.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "neighbor-address" or name == "neighbor-logical-interface-name"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "neighbor-address"):
                        self.neighbor_address = value
                        self.neighbor_address.value_namespace = name_space
                        self.neighbor_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "neighbor-logical-interface-name"):
                        self.neighbor_logical_interface_name = value
                        self.neighbor_logical_interface_name.value_namespace = name_space
                        self.neighbor_logical_interface_name.value_namespace_prefix = name_space_prefix


            class Header(Entity):
                """
                RSVP Header Information
                
                .. attribute:: ip_source_address
                
                	IP Source Address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: ip_tos
                
                	IP Type of Service
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: ip_ttl
                
                	IP TTL
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: rsvp_header_flags
                
                	RSVP Header Flags (defined in RFC2205 Section 3 .1.1)
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: rsvp_message_type
                
                	RSVP Message Type
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: rsvp_ttl
                
                	RSVP TTL
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: rsvp_version
                
                	RSVP Version
                	**type**\:  int
                
                	**range:** 0..255
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.RequestDetails.RequestDetail.Header, self).__init__()

                    self.yang_name = "header"
                    self.yang_parent_name = "request-detail"

                    self.ip_source_address = YLeaf(YType.str, "ip-source-address")

                    self.ip_tos = YLeaf(YType.uint8, "ip-tos")

                    self.ip_ttl = YLeaf(YType.uint8, "ip-ttl")

                    self.rsvp_header_flags = YLeaf(YType.uint8, "rsvp-header-flags")

                    self.rsvp_message_type = YLeaf(YType.uint8, "rsvp-message-type")

                    self.rsvp_ttl = YLeaf(YType.uint8, "rsvp-ttl")

                    self.rsvp_version = YLeaf(YType.uint8, "rsvp-version")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("ip_source_address",
                                    "ip_tos",
                                    "ip_ttl",
                                    "rsvp_header_flags",
                                    "rsvp_message_type",
                                    "rsvp_ttl",
                                    "rsvp_version") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.RequestDetails.RequestDetail.Header, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.RequestDetails.RequestDetail.Header, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.ip_source_address.is_set or
                        self.ip_tos.is_set or
                        self.ip_ttl.is_set or
                        self.rsvp_header_flags.is_set or
                        self.rsvp_message_type.is_set or
                        self.rsvp_ttl.is_set or
                        self.rsvp_version.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.ip_source_address.yfilter != YFilter.not_set or
                        self.ip_tos.yfilter != YFilter.not_set or
                        self.ip_ttl.yfilter != YFilter.not_set or
                        self.rsvp_header_flags.yfilter != YFilter.not_set or
                        self.rsvp_message_type.yfilter != YFilter.not_set or
                        self.rsvp_ttl.yfilter != YFilter.not_set or
                        self.rsvp_version.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "header" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/request-details/request-detail/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.ip_source_address.is_set or self.ip_source_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ip_source_address.get_name_leafdata())
                    if (self.ip_tos.is_set or self.ip_tos.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ip_tos.get_name_leafdata())
                    if (self.ip_ttl.is_set or self.ip_ttl.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ip_ttl.get_name_leafdata())
                    if (self.rsvp_header_flags.is_set or self.rsvp_header_flags.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_header_flags.get_name_leafdata())
                    if (self.rsvp_message_type.is_set or self.rsvp_message_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_message_type.get_name_leafdata())
                    if (self.rsvp_ttl.is_set or self.rsvp_ttl.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_ttl.get_name_leafdata())
                    if (self.rsvp_version.is_set or self.rsvp_version.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rsvp_version.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "ip-source-address" or name == "ip-tos" or name == "ip-ttl" or name == "rsvp-header-flags" or name == "rsvp-message-type" or name == "rsvp-ttl" or name == "rsvp-version"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "ip-source-address"):
                        self.ip_source_address = value
                        self.ip_source_address.value_namespace = name_space
                        self.ip_source_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "ip-tos"):
                        self.ip_tos = value
                        self.ip_tos.value_namespace = name_space
                        self.ip_tos.value_namespace_prefix = name_space_prefix
                    if(value_path == "ip-ttl"):
                        self.ip_ttl = value
                        self.ip_ttl.value_namespace = name_space
                        self.ip_ttl.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-header-flags"):
                        self.rsvp_header_flags = value
                        self.rsvp_header_flags.value_namespace = name_space
                        self.rsvp_header_flags.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-message-type"):
                        self.rsvp_message_type = value
                        self.rsvp_message_type.value_namespace = name_space
                        self.rsvp_message_type.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-ttl"):
                        self.rsvp_ttl = value
                        self.rsvp_ttl.value_namespace = name_space
                        self.rsvp_ttl.value_namespace_prefix = name_space_prefix
                    if(value_path == "rsvp-version"):
                        self.rsvp_version = value
                        self.rsvp_version.value_namespace = name_space
                        self.rsvp_version.value_namespace_prefix = name_space_prefix


            class PolicySources(Entity):
                """
                RSVP Policy Sources
                
                .. attribute:: is_cable
                
                	Policy Source is Cable
                	**type**\:  bool
                
                .. attribute:: is_cops
                
                	Policy Source is COPS
                	**type**\:  bool
                
                .. attribute:: is_default
                
                	Policy Source is Default
                	**type**\:  bool
                
                .. attribute:: is_local
                
                	Policy Source is Local
                	**type**\:  bool
                
                .. attribute:: is_te_link
                
                	Policy Source is TE Link
                	**type**\:  bool
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.RequestDetails.RequestDetail.PolicySources, self).__init__()

                    self.yang_name = "policy-sources"
                    self.yang_parent_name = "request-detail"

                    self.is_cable = YLeaf(YType.boolean, "is-cable")

                    self.is_cops = YLeaf(YType.boolean, "is-cops")

                    self.is_default = YLeaf(YType.boolean, "is-default")

                    self.is_local = YLeaf(YType.boolean, "is-local")

                    self.is_te_link = YLeaf(YType.boolean, "is-te-link")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("is_cable",
                                    "is_cops",
                                    "is_default",
                                    "is_local",
                                    "is_te_link") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.RequestDetails.RequestDetail.PolicySources, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.RequestDetails.RequestDetail.PolicySources, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.is_cable.is_set or
                        self.is_cops.is_set or
                        self.is_default.is_set or
                        self.is_local.is_set or
                        self.is_te_link.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.is_cable.yfilter != YFilter.not_set or
                        self.is_cops.yfilter != YFilter.not_set or
                        self.is_default.yfilter != YFilter.not_set or
                        self.is_local.yfilter != YFilter.not_set or
                        self.is_te_link.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "policy-sources" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/request-details/request-detail/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.is_cable.is_set or self.is_cable.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_cable.get_name_leafdata())
                    if (self.is_cops.is_set or self.is_cops.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_cops.get_name_leafdata())
                    if (self.is_default.is_set or self.is_default.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_default.get_name_leafdata())
                    if (self.is_local.is_set or self.is_local.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_local.get_name_leafdata())
                    if (self.is_te_link.is_set or self.is_te_link.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_te_link.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "is-cable" or name == "is-cops" or name == "is-default" or name == "is-local" or name == "is-te-link"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "is-cable"):
                        self.is_cable = value
                        self.is_cable.value_namespace = name_space
                        self.is_cable.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-cops"):
                        self.is_cops = value
                        self.is_cops.value_namespace = name_space
                        self.is_cops.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-default"):
                        self.is_default = value
                        self.is_default.value_namespace = name_space
                        self.is_default.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-local"):
                        self.is_local = value
                        self.is_local.value_namespace = name_space
                        self.is_local.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-te-link"):
                        self.is_te_link = value
                        self.is_te_link.value_namespace = name_space
                        self.is_te_link.value_namespace_prefix = name_space_prefix


            class PolicyFlags(Entity):
                """
                RSVP Policy Flags
                
                .. attribute:: is_accepted
                
                	Accepted
                	**type**\:  bool
                
                .. attribute:: is_forwarding
                
                	Forwarding
                	**type**\:  bool
                
                .. attribute:: is_installed
                
                	Installed
                	**type**\:  bool
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.RequestDetails.RequestDetail.PolicyFlags, self).__init__()

                    self.yang_name = "policy-flags"
                    self.yang_parent_name = "request-detail"

                    self.is_accepted = YLeaf(YType.boolean, "is-accepted")

                    self.is_forwarding = YLeaf(YType.boolean, "is-forwarding")

                    self.is_installed = YLeaf(YType.boolean, "is-installed")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("is_accepted",
                                    "is_forwarding",
                                    "is_installed") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.RequestDetails.RequestDetail.PolicyFlags, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.RequestDetails.RequestDetail.PolicyFlags, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.is_accepted.is_set or
                        self.is_forwarding.is_set or
                        self.is_installed.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.is_accepted.yfilter != YFilter.not_set or
                        self.is_forwarding.yfilter != YFilter.not_set or
                        self.is_installed.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "policy-flags" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/request-details/request-detail/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.is_accepted.is_set or self.is_accepted.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_accepted.get_name_leafdata())
                    if (self.is_forwarding.is_set or self.is_forwarding.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_forwarding.get_name_leafdata())
                    if (self.is_installed.is_set or self.is_installed.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_installed.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "is-accepted" or name == "is-forwarding" or name == "is-installed"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "is-accepted"):
                        self.is_accepted = value
                        self.is_accepted.value_namespace = name_space
                        self.is_accepted.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-forwarding"):
                        self.is_forwarding = value
                        self.is_forwarding.value_namespace = name_space
                        self.is_forwarding.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-installed"):
                        self.is_installed = value
                        self.is_installed.value_namespace = name_space
                        self.is_installed.value_namespace_prefix = name_space_prefix


            class PolicyQueryFlags(Entity):
                """
                RSVP Query Flags
                
                .. attribute:: is_bypass
                
                	Bypass
                	**type**\:  bool
                
                .. attribute:: is_needed
                
                	Needed
                	**type**\:  bool
                
                .. attribute:: is_report_required
                
                	Report Required
                	**type**\:  bool
                
                .. attribute:: is_resync
                
                	Resynchronization
                	**type**\:  bool
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.RequestDetails.RequestDetail.PolicyQueryFlags, self).__init__()

                    self.yang_name = "policy-query-flags"
                    self.yang_parent_name = "request-detail"

                    self.is_bypass = YLeaf(YType.boolean, "is-bypass")

                    self.is_needed = YLeaf(YType.boolean, "is-needed")

                    self.is_report_required = YLeaf(YType.boolean, "is-report-required")

                    self.is_resync = YLeaf(YType.boolean, "is-resync")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("is_bypass",
                                    "is_needed",
                                    "is_report_required",
                                    "is_resync") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.RequestDetails.RequestDetail.PolicyQueryFlags, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.RequestDetails.RequestDetail.PolicyQueryFlags, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.is_bypass.is_set or
                        self.is_needed.is_set or
                        self.is_report_required.is_set or
                        self.is_resync.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.is_bypass.yfilter != YFilter.not_set or
                        self.is_needed.yfilter != YFilter.not_set or
                        self.is_report_required.yfilter != YFilter.not_set or
                        self.is_resync.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "policy-query-flags" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/request-details/request-detail/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.is_bypass.is_set or self.is_bypass.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_bypass.get_name_leafdata())
                    if (self.is_needed.is_set or self.is_needed.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_needed.get_name_leafdata())
                    if (self.is_report_required.is_set or self.is_report_required.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_report_required.get_name_leafdata())
                    if (self.is_resync.is_set or self.is_resync.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_resync.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "is-bypass" or name == "is-needed" or name == "is-report-required" or name == "is-resync"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "is-bypass"):
                        self.is_bypass = value
                        self.is_bypass.value_namespace = name_space
                        self.is_bypass.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-needed"):
                        self.is_needed = value
                        self.is_needed.value_namespace = name_space
                        self.is_needed.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-report-required"):
                        self.is_report_required = value
                        self.is_report_required.value_namespace = name_space
                        self.is_report_required.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-resync"):
                        self.is_resync = value
                        self.is_resync.value_namespace = name_space
                        self.is_resync.value_namespace_prefix = name_space_prefix


            class PsbKey(Entity):
                """
                List of RSB keys
                
                .. attribute:: destination_address
                
                	Destination address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: destination_port_or_tunnel_id
                
                	Destination Port or Tunnel ID. For the LSP and OUNI session types this represents the Tunnel ID whereas for the UDP session type this represents the Destination Port
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: extended_tunnel_id
                
                	Protocol or Extended Tunnel ID. For the LSP and OUNI sesion types this represents the Extended Tunnel ID
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: p2mp_id
                
                	Point\-to\-multipoint ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: p2mp_sub_group_origin
                
                	Point to Multipoint SubGroup Origin
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: protocol
                
                	Protocol. UDP session type this represents the Protocol (UDP not supported at present)
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: session_type
                
                	Session Type (e.g. LSP, OUNI or UDP)
                	**type**\:   :py:class:`RsvpMgmtSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtSession>`
                
                .. attribute:: source_address
                
                	Source Address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: source_port_or_lsp_id
                
                	Source Port or LSP\_ID. For the LSP and OUNI session types this represents the LSP\_ID whereas for the UDP session type this represents the SourcePort
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: sub_group_id
                
                	Point to Multipoint Subgroup ID
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: vrfid
                
                	Signalling VRF ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.RequestDetails.RequestDetail.PsbKey, self).__init__()

                    self.yang_name = "psb-key"
                    self.yang_parent_name = "request-detail"

                    self.destination_address = YLeaf(YType.str, "destination-address")

                    self.destination_port_or_tunnel_id = YLeaf(YType.uint32, "destination-port-or-tunnel-id")

                    self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                    self.p2mp_id = YLeaf(YType.uint32, "p2mp-id")

                    self.p2mp_sub_group_origin = YLeaf(YType.str, "p2mp-sub-group-origin")

                    self.protocol = YLeaf(YType.uint32, "protocol")

                    self.session_type = YLeaf(YType.enumeration, "session-type")

                    self.source_address = YLeaf(YType.str, "source-address")

                    self.source_port_or_lsp_id = YLeaf(YType.uint32, "source-port-or-lsp-id")

                    self.sub_group_id = YLeaf(YType.uint16, "sub-group-id")

                    self.vrfid = YLeaf(YType.uint32, "vrfid")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("destination_address",
                                    "destination_port_or_tunnel_id",
                                    "extended_tunnel_id",
                                    "p2mp_id",
                                    "p2mp_sub_group_origin",
                                    "protocol",
                                    "session_type",
                                    "source_address",
                                    "source_port_or_lsp_id",
                                    "sub_group_id",
                                    "vrfid") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.RequestDetails.RequestDetail.PsbKey, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.RequestDetails.RequestDetail.PsbKey, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.destination_address.is_set or
                        self.destination_port_or_tunnel_id.is_set or
                        self.extended_tunnel_id.is_set or
                        self.p2mp_id.is_set or
                        self.p2mp_sub_group_origin.is_set or
                        self.protocol.is_set or
                        self.session_type.is_set or
                        self.source_address.is_set or
                        self.source_port_or_lsp_id.is_set or
                        self.sub_group_id.is_set or
                        self.vrfid.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.destination_address.yfilter != YFilter.not_set or
                        self.destination_port_or_tunnel_id.yfilter != YFilter.not_set or
                        self.extended_tunnel_id.yfilter != YFilter.not_set or
                        self.p2mp_id.yfilter != YFilter.not_set or
                        self.p2mp_sub_group_origin.yfilter != YFilter.not_set or
                        self.protocol.yfilter != YFilter.not_set or
                        self.session_type.yfilter != YFilter.not_set or
                        self.source_address.yfilter != YFilter.not_set or
                        self.source_port_or_lsp_id.yfilter != YFilter.not_set or
                        self.sub_group_id.yfilter != YFilter.not_set or
                        self.vrfid.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "psb-key" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/request-details/request-detail/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.destination_address.get_name_leafdata())
                    if (self.destination_port_or_tunnel_id.is_set or self.destination_port_or_tunnel_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.destination_port_or_tunnel_id.get_name_leafdata())
                    if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                    if (self.p2mp_id.is_set or self.p2mp_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.p2mp_id.get_name_leafdata())
                    if (self.p2mp_sub_group_origin.is_set or self.p2mp_sub_group_origin.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.p2mp_sub_group_origin.get_name_leafdata())
                    if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.protocol.get_name_leafdata())
                    if (self.session_type.is_set or self.session_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.session_type.get_name_leafdata())
                    if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.source_address.get_name_leafdata())
                    if (self.source_port_or_lsp_id.is_set or self.source_port_or_lsp_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.source_port_or_lsp_id.get_name_leafdata())
                    if (self.sub_group_id.is_set or self.sub_group_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sub_group_id.get_name_leafdata())
                    if (self.vrfid.is_set or self.vrfid.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.vrfid.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "destination-address" or name == "destination-port-or-tunnel-id" or name == "extended-tunnel-id" or name == "p2mp-id" or name == "p2mp-sub-group-origin" or name == "protocol" or name == "session-type" or name == "source-address" or name == "source-port-or-lsp-id" or name == "sub-group-id" or name == "vrfid"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "destination-address"):
                        self.destination_address = value
                        self.destination_address.value_namespace = name_space
                        self.destination_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "destination-port-or-tunnel-id"):
                        self.destination_port_or_tunnel_id = value
                        self.destination_port_or_tunnel_id.value_namespace = name_space
                        self.destination_port_or_tunnel_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "extended-tunnel-id"):
                        self.extended_tunnel_id = value
                        self.extended_tunnel_id.value_namespace = name_space
                        self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "p2mp-id"):
                        self.p2mp_id = value
                        self.p2mp_id.value_namespace = name_space
                        self.p2mp_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "p2mp-sub-group-origin"):
                        self.p2mp_sub_group_origin = value
                        self.p2mp_sub_group_origin.value_namespace = name_space
                        self.p2mp_sub_group_origin.value_namespace_prefix = name_space_prefix
                    if(value_path == "protocol"):
                        self.protocol = value
                        self.protocol.value_namespace = name_space
                        self.protocol.value_namespace_prefix = name_space_prefix
                    if(value_path == "session-type"):
                        self.session_type = value
                        self.session_type.value_namespace = name_space
                        self.session_type.value_namespace_prefix = name_space_prefix
                    if(value_path == "source-address"):
                        self.source_address = value
                        self.source_address.value_namespace = name_space
                        self.source_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "source-port-or-lsp-id"):
                        self.source_port_or_lsp_id = value
                        self.source_port_or_lsp_id.value_namespace = name_space
                        self.source_port_or_lsp_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "sub-group-id"):
                        self.sub_group_id = value
                        self.sub_group_id.value_namespace = name_space
                        self.sub_group_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "vrfid"):
                        self.vrfid = value
                        self.vrfid.value_namespace = name_space
                        self.vrfid.value_namespace_prefix = name_space_prefix


            class RsbKey(Entity):
                """
                List of RSB keys
                
                .. attribute:: destination_address
                
                	Destination address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: destination_port_or_tunnel_id
                
                	Destination Port or Tunnel ID. For the LSP and OUNI session types this represents the Tunnel ID whereas for the UDP session type this represents the Destination Port
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: extended_tunnel_id
                
                	Protocol or Extended Tunnel ID. For the LSP and OUNI sesion types this represents the Extended Tunnel ID
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: p2mp_id
                
                	Point\-to\-multipoint ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: p2mp_sub_group_origin
                
                	Point to Multipoint SubGroup Origin
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: protocol
                
                	Protocol. UDP session type this represents the Protocol (UDP not supported at present)
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: session_type
                
                	Session Type (e.g. LSP, OUNI or UDP)
                	**type**\:   :py:class:`RsvpMgmtSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtSession>`
                
                .. attribute:: source_address
                
                	Source Address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: source_port_or_lsp_id
                
                	Source Port or LSP\_ID. For the LSP and OUNI session types this represents the LSP\_ID whereas for the UDP session type this represents the SourcePort
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: sub_group_id
                
                	Point to Multipoint Subgroup ID
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: vrfid
                
                	Signalling VRF ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.RequestDetails.RequestDetail.RsbKey, self).__init__()

                    self.yang_name = "rsb-key"
                    self.yang_parent_name = "request-detail"

                    self.destination_address = YLeaf(YType.str, "destination-address")

                    self.destination_port_or_tunnel_id = YLeaf(YType.uint32, "destination-port-or-tunnel-id")

                    self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                    self.p2mp_id = YLeaf(YType.uint32, "p2mp-id")

                    self.p2mp_sub_group_origin = YLeaf(YType.str, "p2mp-sub-group-origin")

                    self.protocol = YLeaf(YType.uint32, "protocol")

                    self.session_type = YLeaf(YType.enumeration, "session-type")

                    self.source_address = YLeaf(YType.str, "source-address")

                    self.source_port_or_lsp_id = YLeaf(YType.uint32, "source-port-or-lsp-id")

                    self.sub_group_id = YLeaf(YType.uint16, "sub-group-id")

                    self.vrfid = YLeaf(YType.uint32, "vrfid")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("destination_address",
                                    "destination_port_or_tunnel_id",
                                    "extended_tunnel_id",
                                    "p2mp_id",
                                    "p2mp_sub_group_origin",
                                    "protocol",
                                    "session_type",
                                    "source_address",
                                    "source_port_or_lsp_id",
                                    "sub_group_id",
                                    "vrfid") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.RequestDetails.RequestDetail.RsbKey, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.RequestDetails.RequestDetail.RsbKey, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.destination_address.is_set or
                        self.destination_port_or_tunnel_id.is_set or
                        self.extended_tunnel_id.is_set or
                        self.p2mp_id.is_set or
                        self.p2mp_sub_group_origin.is_set or
                        self.protocol.is_set or
                        self.session_type.is_set or
                        self.source_address.is_set or
                        self.source_port_or_lsp_id.is_set or
                        self.sub_group_id.is_set or
                        self.vrfid.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.destination_address.yfilter != YFilter.not_set or
                        self.destination_port_or_tunnel_id.yfilter != YFilter.not_set or
                        self.extended_tunnel_id.yfilter != YFilter.not_set or
                        self.p2mp_id.yfilter != YFilter.not_set or
                        self.p2mp_sub_group_origin.yfilter != YFilter.not_set or
                        self.protocol.yfilter != YFilter.not_set or
                        self.session_type.yfilter != YFilter.not_set or
                        self.source_address.yfilter != YFilter.not_set or
                        self.source_port_or_lsp_id.yfilter != YFilter.not_set or
                        self.sub_group_id.yfilter != YFilter.not_set or
                        self.vrfid.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "rsb-key" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/request-details/request-detail/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.destination_address.get_name_leafdata())
                    if (self.destination_port_or_tunnel_id.is_set or self.destination_port_or_tunnel_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.destination_port_or_tunnel_id.get_name_leafdata())
                    if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                    if (self.p2mp_id.is_set or self.p2mp_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.p2mp_id.get_name_leafdata())
                    if (self.p2mp_sub_group_origin.is_set or self.p2mp_sub_group_origin.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.p2mp_sub_group_origin.get_name_leafdata())
                    if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.protocol.get_name_leafdata())
                    if (self.session_type.is_set or self.session_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.session_type.get_name_leafdata())
                    if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.source_address.get_name_leafdata())
                    if (self.source_port_or_lsp_id.is_set or self.source_port_or_lsp_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.source_port_or_lsp_id.get_name_leafdata())
                    if (self.sub_group_id.is_set or self.sub_group_id.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.sub_group_id.get_name_leafdata())
                    if (self.vrfid.is_set or self.vrfid.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.vrfid.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "destination-address" or name == "destination-port-or-tunnel-id" or name == "extended-tunnel-id" or name == "p2mp-id" or name == "p2mp-sub-group-origin" or name == "protocol" or name == "session-type" or name == "source-address" or name == "source-port-or-lsp-id" or name == "sub-group-id" or name == "vrfid"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "destination-address"):
                        self.destination_address = value
                        self.destination_address.value_namespace = name_space
                        self.destination_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "destination-port-or-tunnel-id"):
                        self.destination_port_or_tunnel_id = value
                        self.destination_port_or_tunnel_id.value_namespace = name_space
                        self.destination_port_or_tunnel_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "extended-tunnel-id"):
                        self.extended_tunnel_id = value
                        self.extended_tunnel_id.value_namespace = name_space
                        self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "p2mp-id"):
                        self.p2mp_id = value
                        self.p2mp_id.value_namespace = name_space
                        self.p2mp_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "p2mp-sub-group-origin"):
                        self.p2mp_sub_group_origin = value
                        self.p2mp_sub_group_origin.value_namespace = name_space
                        self.p2mp_sub_group_origin.value_namespace_prefix = name_space_prefix
                    if(value_path == "protocol"):
                        self.protocol = value
                        self.protocol.value_namespace = name_space
                        self.protocol.value_namespace_prefix = name_space_prefix
                    if(value_path == "session-type"):
                        self.session_type = value
                        self.session_type.value_namespace = name_space
                        self.session_type.value_namespace_prefix = name_space_prefix
                    if(value_path == "source-address"):
                        self.source_address = value
                        self.source_address.value_namespace = name_space
                        self.source_address.value_namespace_prefix = name_space_prefix
                    if(value_path == "source-port-or-lsp-id"):
                        self.source_port_or_lsp_id = value
                        self.source_port_or_lsp_id.value_namespace = name_space
                        self.source_port_or_lsp_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "sub-group-id"):
                        self.sub_group_id = value
                        self.sub_group_id.value_namespace = name_space
                        self.sub_group_id.value_namespace_prefix = name_space_prefix
                    if(value_path == "vrfid"):
                        self.vrfid = value
                        self.vrfid.value_namespace = name_space
                        self.vrfid.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.psb_key:
                    if (c.has_data()):
                        return True
                for c in self.rsb_key:
                    if (c.has_data()):
                        return True
                return (
                    self.destination_address.is_set or
                    self.destination_port.is_set or
                    self.extended_tunnel_id.is_set or
                    self.output_interface.is_set or
                    self.p2mp_id.is_set or
                    self.protocol.is_set or
                    self.session_type.is_set or
                    self.source_address.is_set or
                    self.source_port.is_set or
                    self.sub_group_id.is_set or
                    self.sub_group_origin.is_set or
                    self.vrf_name.is_set or
                    (self.filter is not None and self.filter.has_data()) or
                    (self.flow_spec is not None and self.flow_spec.has_data()) or
                    (self.generic_flow_spec is not None and self.generic_flow_spec.has_data()) or
                    (self.header is not None and self.header.has_data()) or
                    (self.hop is not None and self.hop.has_data()) or
                    (self.policy_flags is not None and self.policy_flags.has_data()) or
                    (self.policy_query_flags is not None and self.policy_query_flags.has_data()) or
                    (self.policy_sources is not None and self.policy_sources.has_data()) or
                    (self.req_flags is not None and self.req_flags.has_data()) or
                    (self.s2l_sub_lsp is not None and self.s2l_sub_lsp.has_data()) or
                    (self.session is not None and self.session.has_data()) or
                    (self.style is not None and self.style.has_data()))

            def has_operation(self):
                for c in self.psb_key:
                    if (c.has_operation()):
                        return True
                for c in self.rsb_key:
                    if (c.has_operation()):
                        return True
                return (
                    self.yfilter != YFilter.not_set or
                    self.destination_address.yfilter != YFilter.not_set or
                    self.destination_port.yfilter != YFilter.not_set or
                    self.extended_tunnel_id.yfilter != YFilter.not_set or
                    self.output_interface.yfilter != YFilter.not_set or
                    self.p2mp_id.yfilter != YFilter.not_set or
                    self.protocol.yfilter != YFilter.not_set or
                    self.session_type.yfilter != YFilter.not_set or
                    self.source_address.yfilter != YFilter.not_set or
                    self.source_port.yfilter != YFilter.not_set or
                    self.sub_group_id.yfilter != YFilter.not_set or
                    self.sub_group_origin.yfilter != YFilter.not_set or
                    self.vrf_name.yfilter != YFilter.not_set or
                    (self.filter is not None and self.filter.has_operation()) or
                    (self.flow_spec is not None and self.flow_spec.has_operation()) or
                    (self.generic_flow_spec is not None and self.generic_flow_spec.has_operation()) or
                    (self.header is not None and self.header.has_operation()) or
                    (self.hop is not None and self.hop.has_operation()) or
                    (self.policy_flags is not None and self.policy_flags.has_operation()) or
                    (self.policy_query_flags is not None and self.policy_query_flags.has_operation()) or
                    (self.policy_sources is not None and self.policy_sources.has_operation()) or
                    (self.req_flags is not None and self.req_flags.has_operation()) or
                    (self.s2l_sub_lsp is not None and self.s2l_sub_lsp.has_operation()) or
                    (self.session is not None and self.session.has_operation()) or
                    (self.style is not None and self.style.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "request-detail" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/request-details/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_address.get_name_leafdata())
                if (self.destination_port.is_set or self.destination_port.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_port.get_name_leafdata())
                if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                if (self.output_interface.is_set or self.output_interface.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.output_interface.get_name_leafdata())
                if (self.p2mp_id.is_set or self.p2mp_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.p2mp_id.get_name_leafdata())
                if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.protocol.get_name_leafdata())
                if (self.session_type.is_set or self.session_type.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.session_type.get_name_leafdata())
                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_address.get_name_leafdata())
                if (self.source_port.is_set or self.source_port.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_port.get_name_leafdata())
                if (self.sub_group_id.is_set or self.sub_group_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.sub_group_id.get_name_leafdata())
                if (self.sub_group_origin.is_set or self.sub_group_origin.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.sub_group_origin.get_name_leafdata())
                if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.vrf_name.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "filter"):
                    if (self.filter is None):
                        self.filter = Rsvp.RequestDetails.RequestDetail.Filter()
                        self.filter.parent = self
                        self._children_name_map["filter"] = "filter"
                    return self.filter

                if (child_yang_name == "flow-spec"):
                    if (self.flow_spec is None):
                        self.flow_spec = Rsvp.RequestDetails.RequestDetail.FlowSpec()
                        self.flow_spec.parent = self
                        self._children_name_map["flow_spec"] = "flow-spec"
                    return self.flow_spec

                if (child_yang_name == "generic-flow-spec"):
                    if (self.generic_flow_spec is None):
                        self.generic_flow_spec = Rsvp.RequestDetails.RequestDetail.GenericFlowSpec()
                        self.generic_flow_spec.parent = self
                        self._children_name_map["generic_flow_spec"] = "generic-flow-spec"
                    return self.generic_flow_spec

                if (child_yang_name == "header"):
                    if (self.header is None):
                        self.header = Rsvp.RequestDetails.RequestDetail.Header()
                        self.header.parent = self
                        self._children_name_map["header"] = "header"
                    return self.header

                if (child_yang_name == "hop"):
                    if (self.hop is None):
                        self.hop = Rsvp.RequestDetails.RequestDetail.Hop()
                        self.hop.parent = self
                        self._children_name_map["hop"] = "hop"
                    return self.hop

                if (child_yang_name == "policy-flags"):
                    if (self.policy_flags is None):
                        self.policy_flags = Rsvp.RequestDetails.RequestDetail.PolicyFlags()
                        self.policy_flags.parent = self
                        self._children_name_map["policy_flags"] = "policy-flags"
                    return self.policy_flags

                if (child_yang_name == "policy-query-flags"):
                    if (self.policy_query_flags is None):
                        self.policy_query_flags = Rsvp.RequestDetails.RequestDetail.PolicyQueryFlags()
                        self.policy_query_flags.parent = self
                        self._children_name_map["policy_query_flags"] = "policy-query-flags"
                    return self.policy_query_flags

                if (child_yang_name == "policy-sources"):
                    if (self.policy_sources is None):
                        self.policy_sources = Rsvp.RequestDetails.RequestDetail.PolicySources()
                        self.policy_sources.parent = self
                        self._children_name_map["policy_sources"] = "policy-sources"
                    return self.policy_sources

                if (child_yang_name == "psb-key"):
                    for c in self.psb_key:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = Rsvp.RequestDetails.RequestDetail.PsbKey()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.psb_key.append(c)
                    return c

                if (child_yang_name == "req-flags"):
                    if (self.req_flags is None):
                        self.req_flags = Rsvp.RequestDetails.RequestDetail.ReqFlags()
                        self.req_flags.parent = self
                        self._children_name_map["req_flags"] = "req-flags"
                    return self.req_flags

                if (child_yang_name == "rsb-key"):
                    for c in self.rsb_key:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = Rsvp.RequestDetails.RequestDetail.RsbKey()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.rsb_key.append(c)
                    return c

                if (child_yang_name == "s2l-sub-lsp"):
                    if (self.s2l_sub_lsp is None):
                        self.s2l_sub_lsp = Rsvp.RequestDetails.RequestDetail.S2LSubLsp()
                        self.s2l_sub_lsp.parent = self
                        self._children_name_map["s2l_sub_lsp"] = "s2l-sub-lsp"
                    return self.s2l_sub_lsp

                if (child_yang_name == "session"):
                    if (self.session is None):
                        self.session = Rsvp.RequestDetails.RequestDetail.Session()
                        self.session.parent = self
                        self._children_name_map["session"] = "session"
                    return self.session

                if (child_yang_name == "style"):
                    if (self.style is None):
                        self.style = Rsvp.RequestDetails.RequestDetail.Style()
                        self.style.parent = self
                        self._children_name_map["style"] = "style"
                    return self.style

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "filter" or name == "flow-spec" or name == "generic-flow-spec" or name == "header" or name == "hop" or name == "policy-flags" or name == "policy-query-flags" or name == "policy-sources" or name == "psb-key" or name == "req-flags" or name == "rsb-key" or name == "s2l-sub-lsp" or name == "session" or name == "style" or name == "destination-address" or name == "destination-port" or name == "extended-tunnel-id" or name == "output-interface" or name == "p2mp-id" or name == "protocol" or name == "session-type" or name == "source-address" or name == "source-port" or name == "sub-group-id" or name == "sub-group-origin" or name == "vrf-name"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "destination-address"):
                    self.destination_address = value
                    self.destination_address.value_namespace = name_space
                    self.destination_address.value_namespace_prefix = name_space_prefix
                if(value_path == "destination-port"):
                    self.destination_port = value
                    self.destination_port.value_namespace = name_space
                    self.destination_port.value_namespace_prefix = name_space_prefix
                if(value_path == "extended-tunnel-id"):
                    self.extended_tunnel_id = value
                    self.extended_tunnel_id.value_namespace = name_space
                    self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                if(value_path == "output-interface"):
                    self.output_interface = value
                    self.output_interface.value_namespace = name_space
                    self.output_interface.value_namespace_prefix = name_space_prefix
                if(value_path == "p2mp-id"):
                    self.p2mp_id = value
                    self.p2mp_id.value_namespace = name_space
                    self.p2mp_id.value_namespace_prefix = name_space_prefix
                if(value_path == "protocol"):
                    self.protocol = value
                    self.protocol.value_namespace = name_space
                    self.protocol.value_namespace_prefix = name_space_prefix
                if(value_path == "session-type"):
                    self.session_type = value
                    self.session_type.value_namespace = name_space
                    self.session_type.value_namespace_prefix = name_space_prefix
                if(value_path == "source-address"):
                    self.source_address = value
                    self.source_address.value_namespace = name_space
                    self.source_address.value_namespace_prefix = name_space_prefix
                if(value_path == "source-port"):
                    self.source_port = value
                    self.source_port.value_namespace = name_space
                    self.source_port.value_namespace_prefix = name_space_prefix
                if(value_path == "sub-group-id"):
                    self.sub_group_id = value
                    self.sub_group_id.value_namespace = name_space
                    self.sub_group_id.value_namespace_prefix = name_space_prefix
                if(value_path == "sub-group-origin"):
                    self.sub_group_origin = value
                    self.sub_group_origin.value_namespace = name_space
                    self.sub_group_origin.value_namespace_prefix = name_space_prefix
                if(value_path == "vrf-name"):
                    self.vrf_name = value
                    self.vrf_name.value_namespace = name_space
                    self.vrf_name.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.request_detail:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.request_detail:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "request-details" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "request-detail"):
                for c in self.request_detail:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = Rsvp.RequestDetails.RequestDetail()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.request_detail.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "request-detail"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class InterfaceBriefs(Entity):
        """
        Table of brief info about RSVP\-enabled
        interfaces
        
        .. attribute:: interface_brief
        
        	Brief info about an RSVP\-enabled interface
        	**type**\: list of    :py:class:`InterfaceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.InterfaceBriefs.InterfaceBrief>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Rsvp.InterfaceBriefs, self).__init__()

            self.yang_name = "interface-briefs"
            self.yang_parent_name = "rsvp"

            self.interface_brief = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(Rsvp.InterfaceBriefs, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(Rsvp.InterfaceBriefs, self).__setattr__(name, value)


        class InterfaceBrief(Entity):
            """
            Brief info about an RSVP\-enabled interface
            
            .. attribute:: interface_name  <key>
            
            	Interface Name
            	**type**\:  str
            
            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
            
            .. attribute:: bandwidth_information
            
            	Interface bandwidth information
            	**type**\:   :py:class:`BandwidthInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.InterfaceBriefs.InterfaceBrief.BandwidthInformation>`
            
            .. attribute:: interface_name_xr
            
            	Interface Name
            	**type**\:  str
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Rsvp.InterfaceBriefs.InterfaceBrief, self).__init__()

                self.yang_name = "interface-brief"
                self.yang_parent_name = "interface-briefs"

                self.interface_name = YLeaf(YType.str, "interface-name")

                self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                self.bandwidth_information = Rsvp.InterfaceBriefs.InterfaceBrief.BandwidthInformation()
                self.bandwidth_information.parent = self
                self._children_name_map["bandwidth_information"] = "bandwidth-information"
                self._children_yang_names.add("bandwidth-information")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("interface_name",
                                "interface_name_xr") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Rsvp.InterfaceBriefs.InterfaceBrief, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Rsvp.InterfaceBriefs.InterfaceBrief, self).__setattr__(name, value)


            class BandwidthInformation(Entity):
                """
                Interface bandwidth information
                
                .. attribute:: dste_mode
                
                	DSTEMode
                	**type**\:   :py:class:`RsvpMgmtDsteModes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtDsteModes>`
                
                .. attribute:: pre_standard_dste_interface
                
                	Prestandard DSTE interface information
                	**type**\:   :py:class:`PreStandardDsteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.InterfaceBriefs.InterfaceBrief.BandwidthInformation.PreStandardDsteInterface>`
                
                .. attribute:: standard_dste_interface
                
                	Standard DSTE interface information
                	**type**\:   :py:class:`StandardDsteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.InterfaceBriefs.InterfaceBrief.BandwidthInformation.StandardDsteInterface>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.InterfaceBriefs.InterfaceBrief.BandwidthInformation, self).__init__()

                    self.yang_name = "bandwidth-information"
                    self.yang_parent_name = "interface-brief"

                    self.dste_mode = YLeaf(YType.enumeration, "dste-mode")

                    self.pre_standard_dste_interface = Rsvp.InterfaceBriefs.InterfaceBrief.BandwidthInformation.PreStandardDsteInterface()
                    self.pre_standard_dste_interface.parent = self
                    self._children_name_map["pre_standard_dste_interface"] = "pre-standard-dste-interface"
                    self._children_yang_names.add("pre-standard-dste-interface")

                    self.standard_dste_interface = Rsvp.InterfaceBriefs.InterfaceBrief.BandwidthInformation.StandardDsteInterface()
                    self.standard_dste_interface.parent = self
                    self._children_name_map["standard_dste_interface"] = "standard-dste-interface"
                    self._children_yang_names.add("standard-dste-interface")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("dste_mode") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.InterfaceBriefs.InterfaceBrief.BandwidthInformation, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.InterfaceBriefs.InterfaceBrief.BandwidthInformation, self).__setattr__(name, value)


                class PreStandardDsteInterface(Entity):
                    """
                    Prestandard DSTE interface information
                    
                    .. attribute:: allocated_bit_rate
                    
                    	Bandwidth (bits per second) now allocated
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: is_max_bandwidth_absolute
                    
                    	True if the Max B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: is_max_subpool_bandwidth_absolute
                    
                    	True if the Max sub\-pool B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: max_bandwidth
                    
                    	Max bandwidth (bits per second) allowed
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_flow_bandwidth
                    
                    	Max bandwidth (bits per second) allowed per flow
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_subpool_bandwidth
                    
                    	Max bandwidth (bits per second) allowed in subpool
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.InterfaceBriefs.InterfaceBrief.BandwidthInformation.PreStandardDsteInterface, self).__init__()

                        self.yang_name = "pre-standard-dste-interface"
                        self.yang_parent_name = "bandwidth-information"

                        self.allocated_bit_rate = YLeaf(YType.uint64, "allocated-bit-rate")

                        self.is_max_bandwidth_absolute = YLeaf(YType.boolean, "is-max-bandwidth-absolute")

                        self.is_max_subpool_bandwidth_absolute = YLeaf(YType.boolean, "is-max-subpool-bandwidth-absolute")

                        self.max_bandwidth = YLeaf(YType.uint64, "max-bandwidth")

                        self.max_flow_bandwidth = YLeaf(YType.uint64, "max-flow-bandwidth")

                        self.max_subpool_bandwidth = YLeaf(YType.uint64, "max-subpool-bandwidth")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("allocated_bit_rate",
                                        "is_max_bandwidth_absolute",
                                        "is_max_subpool_bandwidth_absolute",
                                        "max_bandwidth",
                                        "max_flow_bandwidth",
                                        "max_subpool_bandwidth") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.InterfaceBriefs.InterfaceBrief.BandwidthInformation.PreStandardDsteInterface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.InterfaceBriefs.InterfaceBrief.BandwidthInformation.PreStandardDsteInterface, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.allocated_bit_rate.is_set or
                            self.is_max_bandwidth_absolute.is_set or
                            self.is_max_subpool_bandwidth_absolute.is_set or
                            self.max_bandwidth.is_set or
                            self.max_flow_bandwidth.is_set or
                            self.max_subpool_bandwidth.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.allocated_bit_rate.yfilter != YFilter.not_set or
                            self.is_max_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.is_max_subpool_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.max_bandwidth.yfilter != YFilter.not_set or
                            self.max_flow_bandwidth.yfilter != YFilter.not_set or
                            self.max_subpool_bandwidth.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "pre-standard-dste-interface" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.allocated_bit_rate.is_set or self.allocated_bit_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.allocated_bit_rate.get_name_leafdata())
                        if (self.is_max_bandwidth_absolute.is_set or self.is_max_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_bandwidth_absolute.get_name_leafdata())
                        if (self.is_max_subpool_bandwidth_absolute.is_set or self.is_max_subpool_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_subpool_bandwidth_absolute.get_name_leafdata())
                        if (self.max_bandwidth.is_set or self.max_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_bandwidth.get_name_leafdata())
                        if (self.max_flow_bandwidth.is_set or self.max_flow_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_flow_bandwidth.get_name_leafdata())
                        if (self.max_subpool_bandwidth.is_set or self.max_subpool_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_subpool_bandwidth.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "allocated-bit-rate" or name == "is-max-bandwidth-absolute" or name == "is-max-subpool-bandwidth-absolute" or name == "max-bandwidth" or name == "max-flow-bandwidth" or name == "max-subpool-bandwidth"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "allocated-bit-rate"):
                            self.allocated_bit_rate = value
                            self.allocated_bit_rate.value_namespace = name_space
                            self.allocated_bit_rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-bandwidth-absolute"):
                            self.is_max_bandwidth_absolute = value
                            self.is_max_bandwidth_absolute.value_namespace = name_space
                            self.is_max_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-subpool-bandwidth-absolute"):
                            self.is_max_subpool_bandwidth_absolute = value
                            self.is_max_subpool_bandwidth_absolute.value_namespace = name_space
                            self.is_max_subpool_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-bandwidth"):
                            self.max_bandwidth = value
                            self.max_bandwidth.value_namespace = name_space
                            self.max_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-flow-bandwidth"):
                            self.max_flow_bandwidth = value
                            self.max_flow_bandwidth.value_namespace = name_space
                            self.max_flow_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-subpool-bandwidth"):
                            self.max_subpool_bandwidth = value
                            self.max_subpool_bandwidth.value_namespace = name_space
                            self.max_subpool_bandwidth.value_namespace_prefix = name_space_prefix


                class StandardDsteInterface(Entity):
                    """
                    Standard DSTE interface information
                    
                    .. attribute:: allocated_bit_rate
                    
                    	Bandwidth (bits per second) now allocated
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: is_max_bandwidth_absolute
                    
                    	True if the Max B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: is_max_bc0_bandwidth_absolute
                    
                    	True if the Max BC0 B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: is_max_bc1_bandwidth_absolute
                    
                    	True if the Max BC1 sub\-pool B/W is an absolute value and false if its a percentage
                    	**type**\:  bool
                    
                    .. attribute:: max_bandwidth
                    
                    	Max bandwidth (bits per second) allowed
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_flow_bandwidth
                    
                    	Max bandwidth (bits per second) allowed per flow
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_pool0_bandwidth
                    
                    	Max bandwidth (bits per second) allowed in BC0 pool
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    .. attribute:: max_pool1_bandwidth
                    
                    	Max bandwidth (bits per second) allowed in BC1 pool
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: bit/s
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.InterfaceBriefs.InterfaceBrief.BandwidthInformation.StandardDsteInterface, self).__init__()

                        self.yang_name = "standard-dste-interface"
                        self.yang_parent_name = "bandwidth-information"

                        self.allocated_bit_rate = YLeaf(YType.uint64, "allocated-bit-rate")

                        self.is_max_bandwidth_absolute = YLeaf(YType.boolean, "is-max-bandwidth-absolute")

                        self.is_max_bc0_bandwidth_absolute = YLeaf(YType.boolean, "is-max-bc0-bandwidth-absolute")

                        self.is_max_bc1_bandwidth_absolute = YLeaf(YType.boolean, "is-max-bc1-bandwidth-absolute")

                        self.max_bandwidth = YLeaf(YType.uint64, "max-bandwidth")

                        self.max_flow_bandwidth = YLeaf(YType.uint64, "max-flow-bandwidth")

                        self.max_pool0_bandwidth = YLeaf(YType.uint64, "max-pool0-bandwidth")

                        self.max_pool1_bandwidth = YLeaf(YType.uint64, "max-pool1-bandwidth")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("allocated_bit_rate",
                                        "is_max_bandwidth_absolute",
                                        "is_max_bc0_bandwidth_absolute",
                                        "is_max_bc1_bandwidth_absolute",
                                        "max_bandwidth",
                                        "max_flow_bandwidth",
                                        "max_pool0_bandwidth",
                                        "max_pool1_bandwidth") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.InterfaceBriefs.InterfaceBrief.BandwidthInformation.StandardDsteInterface, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.InterfaceBriefs.InterfaceBrief.BandwidthInformation.StandardDsteInterface, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.allocated_bit_rate.is_set or
                            self.is_max_bandwidth_absolute.is_set or
                            self.is_max_bc0_bandwidth_absolute.is_set or
                            self.is_max_bc1_bandwidth_absolute.is_set or
                            self.max_bandwidth.is_set or
                            self.max_flow_bandwidth.is_set or
                            self.max_pool0_bandwidth.is_set or
                            self.max_pool1_bandwidth.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.allocated_bit_rate.yfilter != YFilter.not_set or
                            self.is_max_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.is_max_bc0_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.is_max_bc1_bandwidth_absolute.yfilter != YFilter.not_set or
                            self.max_bandwidth.yfilter != YFilter.not_set or
                            self.max_flow_bandwidth.yfilter != YFilter.not_set or
                            self.max_pool0_bandwidth.yfilter != YFilter.not_set or
                            self.max_pool1_bandwidth.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "standard-dste-interface" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.allocated_bit_rate.is_set or self.allocated_bit_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.allocated_bit_rate.get_name_leafdata())
                        if (self.is_max_bandwidth_absolute.is_set or self.is_max_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_bandwidth_absolute.get_name_leafdata())
                        if (self.is_max_bc0_bandwidth_absolute.is_set or self.is_max_bc0_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_bc0_bandwidth_absolute.get_name_leafdata())
                        if (self.is_max_bc1_bandwidth_absolute.is_set or self.is_max_bc1_bandwidth_absolute.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_max_bc1_bandwidth_absolute.get_name_leafdata())
                        if (self.max_bandwidth.is_set or self.max_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_bandwidth.get_name_leafdata())
                        if (self.max_flow_bandwidth.is_set or self.max_flow_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_flow_bandwidth.get_name_leafdata())
                        if (self.max_pool0_bandwidth.is_set or self.max_pool0_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_pool0_bandwidth.get_name_leafdata())
                        if (self.max_pool1_bandwidth.is_set or self.max_pool1_bandwidth.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.max_pool1_bandwidth.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "allocated-bit-rate" or name == "is-max-bandwidth-absolute" or name == "is-max-bc0-bandwidth-absolute" or name == "is-max-bc1-bandwidth-absolute" or name == "max-bandwidth" or name == "max-flow-bandwidth" or name == "max-pool0-bandwidth" or name == "max-pool1-bandwidth"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "allocated-bit-rate"):
                            self.allocated_bit_rate = value
                            self.allocated_bit_rate.value_namespace = name_space
                            self.allocated_bit_rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-bandwidth-absolute"):
                            self.is_max_bandwidth_absolute = value
                            self.is_max_bandwidth_absolute.value_namespace = name_space
                            self.is_max_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-bc0-bandwidth-absolute"):
                            self.is_max_bc0_bandwidth_absolute = value
                            self.is_max_bc0_bandwidth_absolute.value_namespace = name_space
                            self.is_max_bc0_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-max-bc1-bandwidth-absolute"):
                            self.is_max_bc1_bandwidth_absolute = value
                            self.is_max_bc1_bandwidth_absolute.value_namespace = name_space
                            self.is_max_bc1_bandwidth_absolute.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-bandwidth"):
                            self.max_bandwidth = value
                            self.max_bandwidth.value_namespace = name_space
                            self.max_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-flow-bandwidth"):
                            self.max_flow_bandwidth = value
                            self.max_flow_bandwidth.value_namespace = name_space
                            self.max_flow_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-pool0-bandwidth"):
                            self.max_pool0_bandwidth = value
                            self.max_pool0_bandwidth.value_namespace = name_space
                            self.max_pool0_bandwidth.value_namespace_prefix = name_space_prefix
                        if(value_path == "max-pool1-bandwidth"):
                            self.max_pool1_bandwidth = value
                            self.max_pool1_bandwidth.value_namespace = name_space
                            self.max_pool1_bandwidth.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.dste_mode.is_set or
                        (self.pre_standard_dste_interface is not None and self.pre_standard_dste_interface.has_data()) or
                        (self.standard_dste_interface is not None and self.standard_dste_interface.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.dste_mode.yfilter != YFilter.not_set or
                        (self.pre_standard_dste_interface is not None and self.pre_standard_dste_interface.has_operation()) or
                        (self.standard_dste_interface is not None and self.standard_dste_interface.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "bandwidth-information" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.dste_mode.is_set or self.dste_mode.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.dste_mode.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "pre-standard-dste-interface"):
                        if (self.pre_standard_dste_interface is None):
                            self.pre_standard_dste_interface = Rsvp.InterfaceBriefs.InterfaceBrief.BandwidthInformation.PreStandardDsteInterface()
                            self.pre_standard_dste_interface.parent = self
                            self._children_name_map["pre_standard_dste_interface"] = "pre-standard-dste-interface"
                        return self.pre_standard_dste_interface

                    if (child_yang_name == "standard-dste-interface"):
                        if (self.standard_dste_interface is None):
                            self.standard_dste_interface = Rsvp.InterfaceBriefs.InterfaceBrief.BandwidthInformation.StandardDsteInterface()
                            self.standard_dste_interface.parent = self
                            self._children_name_map["standard_dste_interface"] = "standard-dste-interface"
                        return self.standard_dste_interface

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "pre-standard-dste-interface" or name == "standard-dste-interface" or name == "dste-mode"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "dste-mode"):
                        self.dste_mode = value
                        self.dste_mode.value_namespace = name_space
                        self.dste_mode.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.interface_name.is_set or
                    self.interface_name_xr.is_set or
                    (self.bandwidth_information is not None and self.bandwidth_information.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.interface_name.yfilter != YFilter.not_set or
                    self.interface_name_xr.yfilter != YFilter.not_set or
                    (self.bandwidth_information is not None and self.bandwidth_information.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "interface-brief" + "[interface-name='" + self.interface_name.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/interface-briefs/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.interface_name.is_set or self.interface_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.interface_name.get_name_leafdata())
                if (self.interface_name_xr.is_set or self.interface_name_xr.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.interface_name_xr.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "bandwidth-information"):
                    if (self.bandwidth_information is None):
                        self.bandwidth_information = Rsvp.InterfaceBriefs.InterfaceBrief.BandwidthInformation()
                        self.bandwidth_information.parent = self
                        self._children_name_map["bandwidth_information"] = "bandwidth-information"
                    return self.bandwidth_information

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "bandwidth-information" or name == "interface-name" or name == "interface-name-xr"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "interface-name"):
                    self.interface_name = value
                    self.interface_name.value_namespace = name_space
                    self.interface_name.value_namespace_prefix = name_space_prefix
                if(value_path == "interface-name-xr"):
                    self.interface_name_xr = value
                    self.interface_name_xr.value_namespace = name_space
                    self.interface_name_xr.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.interface_brief:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.interface_brief:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "interface-briefs" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "interface-brief"):
                for c in self.interface_brief:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = Rsvp.InterfaceBriefs.InterfaceBrief()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.interface_brief.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "interface-brief"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class SessionDetaileds(Entity):
        """
        Table of detailed info about sessions
        
        .. attribute:: session_detailed
        
        	Detailed info about session
        	**type**\: list of    :py:class:`SessionDetailed <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Rsvp.SessionDetaileds, self).__init__()

            self.yang_name = "session-detaileds"
            self.yang_parent_name = "rsvp"

            self.session_detailed = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(Rsvp.SessionDetaileds, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(Rsvp.SessionDetaileds, self).__setattr__(name, value)


        class SessionDetailed(Entity):
            """
            Detailed info about session
            
            .. attribute:: compact
            
            	Compact session data
            	**type**\:   :py:class:`Compact <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.Compact>`
            
            .. attribute:: destination_address
            
            	Destination Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: destination_port
            
            	Destination Port
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: extended_tunnel_id
            
            	Extended Tunnel ID
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: p2mp_id
            
            	P2MP ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: protocol
            
            	Protocol
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: psb_rsb_info
            
            	Path and Reservation Info
            	**type**\: list of    :py:class:`PsbRsbInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo>`
            
            .. attribute:: s2l_sub_lsp
            
            	RSVP S2L Sub\-LSP information
            	**type**\:   :py:class:`S2LSubLsp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.S2LSubLsp>`
            
            .. attribute:: session_type
            
            	Session Type
            	**type**\:   :py:class:`RsvpSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpSession>`
            
            .. attribute:: vrf_name
            
            	VRF Name
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Rsvp.SessionDetaileds.SessionDetailed, self).__init__()

                self.yang_name = "session-detailed"
                self.yang_parent_name = "session-detaileds"

                self.destination_address = YLeaf(YType.str, "destination-address")

                self.destination_port = YLeaf(YType.int32, "destination-port")

                self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                self.p2mp_id = YLeaf(YType.int32, "p2mp-id")

                self.protocol = YLeaf(YType.int32, "protocol")

                self.session_type = YLeaf(YType.enumeration, "session-type")

                self.vrf_name = YLeaf(YType.str, "vrf-name")

                self.compact = Rsvp.SessionDetaileds.SessionDetailed.Compact()
                self.compact.parent = self
                self._children_name_map["compact"] = "compact"
                self._children_yang_names.add("compact")

                self.s2l_sub_lsp = Rsvp.SessionDetaileds.SessionDetailed.S2LSubLsp()
                self.s2l_sub_lsp.parent = self
                self._children_name_map["s2l_sub_lsp"] = "s2l-sub-lsp"
                self._children_yang_names.add("s2l-sub-lsp")

                self.psb_rsb_info = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("destination_address",
                                "destination_port",
                                "extended_tunnel_id",
                                "p2mp_id",
                                "protocol",
                                "session_type",
                                "vrf_name") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Rsvp.SessionDetaileds.SessionDetailed, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Rsvp.SessionDetaileds.SessionDetailed, self).__setattr__(name, value)


            class Compact(Entity):
                """
                Compact session data
                
                .. attribute:: detail_list_size
                
                	Number of elements in detail list
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ps_bs
                
                	Number of path state block states
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: requests
                
                	Number of request states
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rs_bs
                
                	Number of reservation state block states
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: session
                
                	RSVP Session Information
                	**type**\:   :py:class:`Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.Compact.Session>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.SessionDetaileds.SessionDetailed.Compact, self).__init__()

                    self.yang_name = "compact"
                    self.yang_parent_name = "session-detailed"

                    self.detail_list_size = YLeaf(YType.uint32, "detail-list-size")

                    self.ps_bs = YLeaf(YType.uint32, "ps-bs")

                    self.requests = YLeaf(YType.uint32, "requests")

                    self.rs_bs = YLeaf(YType.uint32, "rs-bs")

                    self.session = Rsvp.SessionDetaileds.SessionDetailed.Compact.Session()
                    self.session.parent = self
                    self._children_name_map["session"] = "session"
                    self._children_yang_names.add("session")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("detail_list_size",
                                    "ps_bs",
                                    "requests",
                                    "rs_bs") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.SessionDetaileds.SessionDetailed.Compact, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.SessionDetaileds.SessionDetailed.Compact, self).__setattr__(name, value)


                class Session(Entity):
                    """
                    RSVP Session Information
                    
                    .. attribute:: rsvp_session
                    
                    	RSVP Session
                    	**type**\:   :py:class:`RsvpSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.SessionDetaileds.SessionDetailed.Compact.Session, self).__init__()

                        self.yang_name = "session"
                        self.yang_parent_name = "compact"

                        self.rsvp_session = Rsvp.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession()
                        self.rsvp_session.parent = self
                        self._children_name_map["rsvp_session"] = "rsvp-session"
                        self._children_yang_names.add("rsvp-session")


                    class RsvpSession(Entity):
                        """
                        RSVP Session
                        
                        .. attribute:: ipv4
                        
                        	UDP IPv4 session
                        	**type**\:   :py:class:`Ipv4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession.Ipv4>`
                        
                        .. attribute:: ipv4_lsp_session
                        
                        	IPv4 LSP session
                        	**type**\:   :py:class:`Ipv4LspSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession.Ipv4LspSession>`
                        
                        .. attribute:: ipv4_p2mp_lsp_session
                        
                        	IPv4 P2MP LSP session
                        	**type**\:   :py:class:`Ipv4P2MpLspSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession.Ipv4P2MpLspSession>`
                        
                        .. attribute:: ipv4_uni_session
                        
                        	IPv4 UNI session
                        	**type**\:   :py:class:`Ipv4UniSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession.Ipv4UniSession>`
                        
                        .. attribute:: session_type
                        
                        	SessionType
                        	**type**\:   :py:class:`RsvpMgmtSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtSession>`
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession, self).__init__()

                            self.yang_name = "rsvp-session"
                            self.yang_parent_name = "session"

                            self.session_type = YLeaf(YType.enumeration, "session-type")

                            self.ipv4 = Rsvp.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession.Ipv4()
                            self.ipv4.parent = self
                            self._children_name_map["ipv4"] = "ipv4"
                            self._children_yang_names.add("ipv4")

                            self.ipv4_lsp_session = Rsvp.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession.Ipv4LspSession()
                            self.ipv4_lsp_session.parent = self
                            self._children_name_map["ipv4_lsp_session"] = "ipv4-lsp-session"
                            self._children_yang_names.add("ipv4-lsp-session")

                            self.ipv4_p2mp_lsp_session = Rsvp.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession.Ipv4P2MpLspSession()
                            self.ipv4_p2mp_lsp_session.parent = self
                            self._children_name_map["ipv4_p2mp_lsp_session"] = "ipv4-p2mp-lsp-session"
                            self._children_yang_names.add("ipv4-p2mp-lsp-session")

                            self.ipv4_uni_session = Rsvp.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession.Ipv4UniSession()
                            self.ipv4_uni_session.parent = self
                            self._children_name_map["ipv4_uni_session"] = "ipv4-uni-session"
                            self._children_yang_names.add("ipv4-uni-session")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("session_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession, self).__setattr__(name, value)


                        class Ipv4(Entity):
                            """
                            UDP IPv4 session
                            
                            .. attribute:: destination_address
                            
                            	Destination address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: destination_port
                            
                            	The Session Destination Port
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: protocol
                            
                            	Protocol type (originally defined in RFC 790, further values in subsequent RFCs)
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Rsvp.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession.Ipv4, self).__init__()

                                self.yang_name = "ipv4"
                                self.yang_parent_name = "rsvp-session"

                                self.destination_address = YLeaf(YType.str, "destination-address")

                                self.destination_port = YLeaf(YType.uint16, "destination-port")

                                self.protocol = YLeaf(YType.uint8, "protocol")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("destination_address",
                                                "destination_port",
                                                "protocol") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Rsvp.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession.Ipv4, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Rsvp.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession.Ipv4, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.destination_address.is_set or
                                    self.destination_port.is_set or
                                    self.protocol.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.destination_address.yfilter != YFilter.not_set or
                                    self.destination_port.yfilter != YFilter.not_set or
                                    self.protocol.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ipv4" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/compact/session/rsvp-session/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.destination_address.get_name_leafdata())
                                if (self.destination_port.is_set or self.destination_port.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.destination_port.get_name_leafdata())
                                if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.protocol.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "destination-address" or name == "destination-port" or name == "protocol"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "destination-address"):
                                    self.destination_address = value
                                    self.destination_address.value_namespace = name_space
                                    self.destination_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "destination-port"):
                                    self.destination_port = value
                                    self.destination_port.value_namespace = name_space
                                    self.destination_port.value_namespace_prefix = name_space_prefix
                                if(value_path == "protocol"):
                                    self.protocol = value
                                    self.protocol.value_namespace = name_space
                                    self.protocol.value_namespace_prefix = name_space_prefix


                        class Ipv4LspSession(Entity):
                            """
                            IPv4 LSP session
                            
                            .. attribute:: destination_address
                            
                            	Destination address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: extended_tunnel_id
                            
                            	The Session Extended Tunnel ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: tunnel_id
                            
                            	The Session Tunnel ID
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Rsvp.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession.Ipv4LspSession, self).__init__()

                                self.yang_name = "ipv4-lsp-session"
                                self.yang_parent_name = "rsvp-session"

                                self.destination_address = YLeaf(YType.str, "destination-address")

                                self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                                self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("destination_address",
                                                "extended_tunnel_id",
                                                "tunnel_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Rsvp.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession.Ipv4LspSession, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Rsvp.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession.Ipv4LspSession, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.destination_address.is_set or
                                    self.extended_tunnel_id.is_set or
                                    self.tunnel_id.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.destination_address.yfilter != YFilter.not_set or
                                    self.extended_tunnel_id.yfilter != YFilter.not_set or
                                    self.tunnel_id.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ipv4-lsp-session" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/compact/session/rsvp-session/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.destination_address.get_name_leafdata())
                                if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "destination-address" or name == "extended-tunnel-id" or name == "tunnel-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "destination-address"):
                                    self.destination_address = value
                                    self.destination_address.value_namespace = name_space
                                    self.destination_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "extended-tunnel-id"):
                                    self.extended_tunnel_id = value
                                    self.extended_tunnel_id.value_namespace = name_space
                                    self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "tunnel-id"):
                                    self.tunnel_id = value
                                    self.tunnel_id.value_namespace = name_space
                                    self.tunnel_id.value_namespace_prefix = name_space_prefix


                        class Ipv4UniSession(Entity):
                            """
                            IPv4 UNI session
                            
                            .. attribute:: destination_address
                            
                            	Destination address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: extended_address
                            
                            	The Session Extended Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: tunnel_id
                            
                            	The Session Tunnel ID
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Rsvp.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession.Ipv4UniSession, self).__init__()

                                self.yang_name = "ipv4-uni-session"
                                self.yang_parent_name = "rsvp-session"

                                self.destination_address = YLeaf(YType.str, "destination-address")

                                self.extended_address = YLeaf(YType.str, "extended-address")

                                self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("destination_address",
                                                "extended_address",
                                                "tunnel_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Rsvp.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession.Ipv4UniSession, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Rsvp.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession.Ipv4UniSession, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.destination_address.is_set or
                                    self.extended_address.is_set or
                                    self.tunnel_id.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.destination_address.yfilter != YFilter.not_set or
                                    self.extended_address.yfilter != YFilter.not_set or
                                    self.tunnel_id.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ipv4-uni-session" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/compact/session/rsvp-session/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.destination_address.get_name_leafdata())
                                if (self.extended_address.is_set or self.extended_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.extended_address.get_name_leafdata())
                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "destination-address" or name == "extended-address" or name == "tunnel-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "destination-address"):
                                    self.destination_address = value
                                    self.destination_address.value_namespace = name_space
                                    self.destination_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "extended-address"):
                                    self.extended_address = value
                                    self.extended_address.value_namespace = name_space
                                    self.extended_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "tunnel-id"):
                                    self.tunnel_id = value
                                    self.tunnel_id.value_namespace = name_space
                                    self.tunnel_id.value_namespace_prefix = name_space_prefix


                        class Ipv4P2MpLspSession(Entity):
                            """
                            IPv4 P2MP LSP session
                            
                            .. attribute:: extended_tunnel_id
                            
                            	The Session Extended Tunnel ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: p2mp_id
                            
                            	The Point to Multipoint ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tunnel_id
                            
                            	The Session Tunnel ID
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Rsvp.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession.Ipv4P2MpLspSession, self).__init__()

                                self.yang_name = "ipv4-p2mp-lsp-session"
                                self.yang_parent_name = "rsvp-session"

                                self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                                self.p2mp_id = YLeaf(YType.uint32, "p2mp-id")

                                self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("extended_tunnel_id",
                                                "p2mp_id",
                                                "tunnel_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Rsvp.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession.Ipv4P2MpLspSession, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Rsvp.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession.Ipv4P2MpLspSession, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.extended_tunnel_id.is_set or
                                    self.p2mp_id.is_set or
                                    self.tunnel_id.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.extended_tunnel_id.yfilter != YFilter.not_set or
                                    self.p2mp_id.yfilter != YFilter.not_set or
                                    self.tunnel_id.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ipv4-p2mp-lsp-session" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/compact/session/rsvp-session/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                                if (self.p2mp_id.is_set or self.p2mp_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.p2mp_id.get_name_leafdata())
                                if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "extended-tunnel-id" or name == "p2mp-id" or name == "tunnel-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "extended-tunnel-id"):
                                    self.extended_tunnel_id = value
                                    self.extended_tunnel_id.value_namespace = name_space
                                    self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "p2mp-id"):
                                    self.p2mp_id = value
                                    self.p2mp_id.value_namespace = name_space
                                    self.p2mp_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "tunnel-id"):
                                    self.tunnel_id = value
                                    self.tunnel_id.value_namespace = name_space
                                    self.tunnel_id.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.session_type.is_set or
                                (self.ipv4 is not None and self.ipv4.has_data()) or
                                (self.ipv4_lsp_session is not None and self.ipv4_lsp_session.has_data()) or
                                (self.ipv4_p2mp_lsp_session is not None and self.ipv4_p2mp_lsp_session.has_data()) or
                                (self.ipv4_uni_session is not None and self.ipv4_uni_session.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.session_type.yfilter != YFilter.not_set or
                                (self.ipv4 is not None and self.ipv4.has_operation()) or
                                (self.ipv4_lsp_session is not None and self.ipv4_lsp_session.has_operation()) or
                                (self.ipv4_p2mp_lsp_session is not None and self.ipv4_p2mp_lsp_session.has_operation()) or
                                (self.ipv4_uni_session is not None and self.ipv4_uni_session.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rsvp-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/compact/session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.session_type.is_set or self.session_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.session_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "ipv4"):
                                if (self.ipv4 is None):
                                    self.ipv4 = Rsvp.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession.Ipv4()
                                    self.ipv4.parent = self
                                    self._children_name_map["ipv4"] = "ipv4"
                                return self.ipv4

                            if (child_yang_name == "ipv4-lsp-session"):
                                if (self.ipv4_lsp_session is None):
                                    self.ipv4_lsp_session = Rsvp.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession.Ipv4LspSession()
                                    self.ipv4_lsp_session.parent = self
                                    self._children_name_map["ipv4_lsp_session"] = "ipv4-lsp-session"
                                return self.ipv4_lsp_session

                            if (child_yang_name == "ipv4-p2mp-lsp-session"):
                                if (self.ipv4_p2mp_lsp_session is None):
                                    self.ipv4_p2mp_lsp_session = Rsvp.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession.Ipv4P2MpLspSession()
                                    self.ipv4_p2mp_lsp_session.parent = self
                                    self._children_name_map["ipv4_p2mp_lsp_session"] = "ipv4-p2mp-lsp-session"
                                return self.ipv4_p2mp_lsp_session

                            if (child_yang_name == "ipv4-uni-session"):
                                if (self.ipv4_uni_session is None):
                                    self.ipv4_uni_session = Rsvp.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession.Ipv4UniSession()
                                    self.ipv4_uni_session.parent = self
                                    self._children_name_map["ipv4_uni_session"] = "ipv4-uni-session"
                                return self.ipv4_uni_session

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ipv4" or name == "ipv4-lsp-session" or name == "ipv4-p2mp-lsp-session" or name == "ipv4-uni-session" or name == "session-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "session-type"):
                                self.session_type = value
                                self.session_type.value_namespace = name_space
                                self.session_type.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (self.rsvp_session is not None and self.rsvp_session.has_data())

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            (self.rsvp_session is not None and self.rsvp_session.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "session" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/compact/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "rsvp-session"):
                            if (self.rsvp_session is None):
                                self.rsvp_session = Rsvp.SessionDetaileds.SessionDetailed.Compact.Session.RsvpSession()
                                self.rsvp_session.parent = self
                                self._children_name_map["rsvp_session"] = "rsvp-session"
                            return self.rsvp_session

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "rsvp-session"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        pass

                def has_data(self):
                    return (
                        self.detail_list_size.is_set or
                        self.ps_bs.is_set or
                        self.requests.is_set or
                        self.rs_bs.is_set or
                        (self.session is not None and self.session.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.detail_list_size.yfilter != YFilter.not_set or
                        self.ps_bs.yfilter != YFilter.not_set or
                        self.requests.yfilter != YFilter.not_set or
                        self.rs_bs.yfilter != YFilter.not_set or
                        (self.session is not None and self.session.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "compact" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.detail_list_size.is_set or self.detail_list_size.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.detail_list_size.get_name_leafdata())
                    if (self.ps_bs.is_set or self.ps_bs.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.ps_bs.get_name_leafdata())
                    if (self.requests.is_set or self.requests.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.requests.get_name_leafdata())
                    if (self.rs_bs.is_set or self.rs_bs.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.rs_bs.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "session"):
                        if (self.session is None):
                            self.session = Rsvp.SessionDetaileds.SessionDetailed.Compact.Session()
                            self.session.parent = self
                            self._children_name_map["session"] = "session"
                        return self.session

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "session" or name == "detail-list-size" or name == "ps-bs" or name == "requests" or name == "rs-bs"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "detail-list-size"):
                        self.detail_list_size = value
                        self.detail_list_size.value_namespace = name_space
                        self.detail_list_size.value_namespace_prefix = name_space_prefix
                    if(value_path == "ps-bs"):
                        self.ps_bs = value
                        self.ps_bs.value_namespace = name_space
                        self.ps_bs.value_namespace_prefix = name_space_prefix
                    if(value_path == "requests"):
                        self.requests = value
                        self.requests.value_namespace = name_space
                        self.requests.value_namespace_prefix = name_space_prefix
                    if(value_path == "rs-bs"):
                        self.rs_bs = value
                        self.rs_bs.value_namespace = name_space
                        self.rs_bs.value_namespace_prefix = name_space_prefix


            class S2LSubLsp(Entity):
                """
                RSVP S2L Sub\-LSP information
                
                .. attribute:: s2l_destination_address
                
                	S2L Sub\-LSP Destination Address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.SessionDetaileds.SessionDetailed.S2LSubLsp, self).__init__()

                    self.yang_name = "s2l-sub-lsp"
                    self.yang_parent_name = "session-detailed"

                    self.s2l_destination_address = YLeaf(YType.str, "s2l-destination-address")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("s2l_destination_address") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.SessionDetaileds.SessionDetailed.S2LSubLsp, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.SessionDetaileds.SessionDetailed.S2LSubLsp, self).__setattr__(name, value)

                def has_data(self):
                    return self.s2l_destination_address.is_set

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.s2l_destination_address.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "s2l-sub-lsp" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.s2l_destination_address.is_set or self.s2l_destination_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.s2l_destination_address.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "s2l-destination-address"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "s2l-destination-address"):
                        self.s2l_destination_address = value
                        self.s2l_destination_address.value_namespace = name_space
                        self.s2l_destination_address.value_namespace_prefix = name_space_prefix


            class PsbRsbInfo(Entity):
                """
                Path and Reservation Info
                
                .. attribute:: psb_info
                
                	Path Info
                	**type**\: list of    :py:class:`PsbInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo>`
                
                .. attribute:: rsb_info
                
                	Reservation Info
                	**type**\: list of    :py:class:`RsbInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo, self).__init__()

                    self.yang_name = "psb-rsb-info"
                    self.yang_parent_name = "session-detailed"

                    self.psb_info = YList(self)
                    self.rsb_info = YList(self)

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in () and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo, self).__setattr__(name, value)


                class PsbInfo(Entity):
                    """
                    Path Info
                    
                    .. attribute:: association
                    
                    	Association object
                    	**type**\:   :py:class:`Association <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association>`
                    
                    .. attribute:: destination_address
                    
                    	Destination address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: ero
                    
                    	Explicit Route Sub Objects
                    	**type**\: list of    :py:class:`Ero <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Ero>`
                    
                    .. attribute:: generic_in_label
                    
                    	Generic Label for inbound traffic
                    	**type**\:   :py:class:`GenericInLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericInLabel>`
                    
                    .. attribute:: generic_traffic_spec
                    
                    	Generic Traffic Spec object
                    	**type**\:   :py:class:`GenericTrafficSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericTrafficSpec>`
                    
                    .. attribute:: in_interface
                    
                    	Interface on which inbound message was received
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: in_label
                    
                    	Label for inbound traffic
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: incoming_interface_address
                    
                    	IP address of Path's incoming interface
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: is_bad_address
                    
                    	Address validity
                    	**type**\:  bool
                    
                    .. attribute:: is_ero_valid
                    
                    	ERO validity
                    	**type**\:  bool
                    
                    .. attribute:: is_rro_valid
                    
                    	RRO validity
                    	**type**\:  bool
                    
                    .. attribute:: is_traffic_spec_valid
                    
                    	Traffic Spec validity
                    	**type**\:  bool
                    
                    .. attribute:: is_valid
                    
                    	Entry validity
                    	**type**\:  bool
                    
                    .. attribute:: lsp_id
                    
                    	LSP ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: lsp_wrap_label
                    
                    	LSP Wrap Label
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: p2mp_sub_group_origin
                    
                    	Point to Multipoint SubGroup Origin
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: protection
                    
                    	Protection object
                    	**type**\:   :py:class:`Protection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Protection>`
                    
                    .. attribute:: reverse_lsp
                    
                    	Reverse LSP object
                    	**type**\:   :py:class:`ReverseLsp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp>`
                    
                    .. attribute:: rro
                    
                    	Record Route Sub Objects
                    	**type**\: list of    :py:class:`Rro <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro>`
                    
                    .. attribute:: sub_group_id
                    
                    	Point to Multipoint Subgroup ID
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: traffic_spec
                    
                    	Traffic Spec object
                    	**type**\:   :py:class:`TrafficSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.TrafficSpec>`
                    
                    .. attribute:: tunnel_name
                    
                    	Tunnel name
                    	**type**\:  str
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo, self).__init__()

                        self.yang_name = "psb-info"
                        self.yang_parent_name = "psb-rsb-info"

                        self.destination_address = YLeaf(YType.str, "destination-address")

                        self.in_interface = YLeaf(YType.str, "in-interface")

                        self.in_label = YLeaf(YType.uint32, "in-label")

                        self.incoming_interface_address = YLeaf(YType.str, "incoming-interface-address")

                        self.is_bad_address = YLeaf(YType.boolean, "is-bad-address")

                        self.is_ero_valid = YLeaf(YType.boolean, "is-ero-valid")

                        self.is_rro_valid = YLeaf(YType.boolean, "is-rro-valid")

                        self.is_traffic_spec_valid = YLeaf(YType.boolean, "is-traffic-spec-valid")

                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                        self.lsp_id = YLeaf(YType.uint32, "lsp-id")

                        self.lsp_wrap_label = YLeaf(YType.uint32, "lsp-wrap-label")

                        self.p2mp_sub_group_origin = YLeaf(YType.str, "p2mp-sub-group-origin")

                        self.sub_group_id = YLeaf(YType.uint16, "sub-group-id")

                        self.tunnel_name = YLeaf(YType.str, "tunnel-name")

                        self.association = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association()
                        self.association.parent = self
                        self._children_name_map["association"] = "association"
                        self._children_yang_names.add("association")

                        self.generic_in_label = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericInLabel()
                        self.generic_in_label.parent = self
                        self._children_name_map["generic_in_label"] = "generic-in-label"
                        self._children_yang_names.add("generic-in-label")

                        self.generic_traffic_spec = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericTrafficSpec()
                        self.generic_traffic_spec.parent = self
                        self._children_name_map["generic_traffic_spec"] = "generic-traffic-spec"
                        self._children_yang_names.add("generic-traffic-spec")

                        self.protection = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Protection()
                        self.protection.parent = self
                        self._children_name_map["protection"] = "protection"
                        self._children_yang_names.add("protection")

                        self.reverse_lsp = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp()
                        self.reverse_lsp.parent = self
                        self._children_name_map["reverse_lsp"] = "reverse-lsp"
                        self._children_yang_names.add("reverse-lsp")

                        self.traffic_spec = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.TrafficSpec()
                        self.traffic_spec.parent = self
                        self._children_name_map["traffic_spec"] = "traffic-spec"
                        self._children_yang_names.add("traffic-spec")

                        self.ero = YList(self)
                        self.rro = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("destination_address",
                                        "in_interface",
                                        "in_label",
                                        "incoming_interface_address",
                                        "is_bad_address",
                                        "is_ero_valid",
                                        "is_rro_valid",
                                        "is_traffic_spec_valid",
                                        "is_valid",
                                        "lsp_id",
                                        "lsp_wrap_label",
                                        "p2mp_sub_group_origin",
                                        "sub_group_id",
                                        "tunnel_name") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo, self).__setattr__(name, value)


                    class GenericInLabel(Entity):
                        """
                        Generic Label for inbound traffic
                        
                        .. attribute:: generalized_label
                        
                        	Generalized Label
                        	**type**\:   :py:class:`GeneralizedLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericInLabel.GeneralizedLabel>`
                        
                        .. attribute:: generic_label_type
                        
                        	GenericLabelType
                        	**type**\:   :py:class:`RsvpMgmtGenericLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtGenericLabel>`
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericInLabel, self).__init__()

                            self.yang_name = "generic-in-label"
                            self.yang_parent_name = "psb-info"

                            self.generic_label_type = YLeaf(YType.enumeration, "generic-label-type")

                            self.generalized_label = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericInLabel.GeneralizedLabel()
                            self.generalized_label.parent = self
                            self._children_name_map["generalized_label"] = "generalized-label"
                            self._children_yang_names.add("generalized-label")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("generic_label_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericInLabel, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericInLabel, self).__setattr__(name, value)


                        class GeneralizedLabel(Entity):
                            """
                            Generalized Label
                            
                            .. attribute:: value
                            
                            	Generalized Label Value
                            	**type**\:  list of int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericInLabel.GeneralizedLabel, self).__init__()

                                self.yang_name = "generalized-label"
                                self.yang_parent_name = "generic-in-label"

                                self.value = YLeafList(YType.uint32, "value")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("value") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericInLabel.GeneralizedLabel, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericInLabel.GeneralizedLabel, self).__setattr__(name, value)

                            def has_data(self):
                                for leaf in self.value.getYLeafs():
                                    if (leaf.yfilter != YFilter.not_set):
                                        return True
                                return False

                            def has_operation(self):
                                for leaf in self.value.getYLeafs():
                                    if (leaf.is_set):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.value.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "generalized-label" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/psb-rsb-info/psb-info/generic-in-label/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                leaf_name_data.extend(self.value.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "value"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "value"):
                                    self.value.append(value)

                        def has_data(self):
                            return (
                                self.generic_label_type.is_set or
                                (self.generalized_label is not None and self.generalized_label.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.generic_label_type.yfilter != YFilter.not_set or
                                (self.generalized_label is not None and self.generalized_label.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "generic-in-label" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/psb-rsb-info/psb-info/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.generic_label_type.is_set or self.generic_label_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.generic_label_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "generalized-label"):
                                if (self.generalized_label is None):
                                    self.generalized_label = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericInLabel.GeneralizedLabel()
                                    self.generalized_label.parent = self
                                    self._children_name_map["generalized_label"] = "generalized-label"
                                return self.generalized_label

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "generalized-label" or name == "generic-label-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "generic-label-type"):
                                self.generic_label_type = value
                                self.generic_label_type.value_namespace = name_space
                                self.generic_label_type.value_namespace_prefix = name_space_prefix


                    class TrafficSpec(Entity):
                        """
                        Traffic Spec object
                        
                        .. attribute:: traffic_average_rate
                        
                        	Traffic Average Rate in bytes per second
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: byte/s
                        
                        .. attribute:: traffic_max_burst
                        
                        	Traffic Maximum Burst
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: traffic_max_unit
                        
                        	Traffic Maximum Unit
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: traffic_min_unit
                        
                        	Traffic Minimum Unit
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: traffic_peak_rate
                        
                        	Traffic Peak Rate in bytes per second
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: byte/s
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.TrafficSpec, self).__init__()

                            self.yang_name = "traffic-spec"
                            self.yang_parent_name = "psb-info"

                            self.traffic_average_rate = YLeaf(YType.uint64, "traffic-average-rate")

                            self.traffic_max_burst = YLeaf(YType.uint64, "traffic-max-burst")

                            self.traffic_max_unit = YLeaf(YType.uint32, "traffic-max-unit")

                            self.traffic_min_unit = YLeaf(YType.uint32, "traffic-min-unit")

                            self.traffic_peak_rate = YLeaf(YType.uint64, "traffic-peak-rate")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("traffic_average_rate",
                                            "traffic_max_burst",
                                            "traffic_max_unit",
                                            "traffic_min_unit",
                                            "traffic_peak_rate") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.TrafficSpec, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.TrafficSpec, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.traffic_average_rate.is_set or
                                self.traffic_max_burst.is_set or
                                self.traffic_max_unit.is_set or
                                self.traffic_min_unit.is_set or
                                self.traffic_peak_rate.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.traffic_average_rate.yfilter != YFilter.not_set or
                                self.traffic_max_burst.yfilter != YFilter.not_set or
                                self.traffic_max_unit.yfilter != YFilter.not_set or
                                self.traffic_min_unit.yfilter != YFilter.not_set or
                                self.traffic_peak_rate.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "traffic-spec" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/psb-rsb-info/psb-info/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.traffic_average_rate.is_set or self.traffic_average_rate.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.traffic_average_rate.get_name_leafdata())
                            if (self.traffic_max_burst.is_set or self.traffic_max_burst.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.traffic_max_burst.get_name_leafdata())
                            if (self.traffic_max_unit.is_set or self.traffic_max_unit.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.traffic_max_unit.get_name_leafdata())
                            if (self.traffic_min_unit.is_set or self.traffic_min_unit.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.traffic_min_unit.get_name_leafdata())
                            if (self.traffic_peak_rate.is_set or self.traffic_peak_rate.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.traffic_peak_rate.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "traffic-average-rate" or name == "traffic-max-burst" or name == "traffic-max-unit" or name == "traffic-min-unit" or name == "traffic-peak-rate"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "traffic-average-rate"):
                                self.traffic_average_rate = value
                                self.traffic_average_rate.value_namespace = name_space
                                self.traffic_average_rate.value_namespace_prefix = name_space_prefix
                            if(value_path == "traffic-max-burst"):
                                self.traffic_max_burst = value
                                self.traffic_max_burst.value_namespace = name_space
                                self.traffic_max_burst.value_namespace_prefix = name_space_prefix
                            if(value_path == "traffic-max-unit"):
                                self.traffic_max_unit = value
                                self.traffic_max_unit.value_namespace = name_space
                                self.traffic_max_unit.value_namespace_prefix = name_space_prefix
                            if(value_path == "traffic-min-unit"):
                                self.traffic_min_unit = value
                                self.traffic_min_unit.value_namespace = name_space
                                self.traffic_min_unit.value_namespace_prefix = name_space_prefix
                            if(value_path == "traffic-peak-rate"):
                                self.traffic_peak_rate = value
                                self.traffic_peak_rate.value_namespace = name_space
                                self.traffic_peak_rate.value_namespace_prefix = name_space_prefix


                    class GenericTrafficSpec(Entity):
                        """
                        Generic Traffic Spec object
                        
                        .. attribute:: g709otn_tspec
                        
                        	G709 OTN Sender Tspec
                        	**type**\:   :py:class:`G709OtnTspec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericTrafficSpec.G709OtnTspec>`
                        
                        .. attribute:: intsrv_tspec
                        
                        	Integrated Services Sender Tspec
                        	**type**\:   :py:class:`IntsrvTspec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericTrafficSpec.IntsrvTspec>`
                        
                        .. attribute:: tspec_type
                        
                        	TspecType
                        	**type**\:   :py:class:`RsvpMgmtTspec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtTspec>`
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericTrafficSpec, self).__init__()

                            self.yang_name = "generic-traffic-spec"
                            self.yang_parent_name = "psb-info"

                            self.tspec_type = YLeaf(YType.enumeration, "tspec-type")

                            self.g709otn_tspec = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericTrafficSpec.G709OtnTspec()
                            self.g709otn_tspec.parent = self
                            self._children_name_map["g709otn_tspec"] = "g709otn-tspec"
                            self._children_yang_names.add("g709otn-tspec")

                            self.intsrv_tspec = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericTrafficSpec.IntsrvTspec()
                            self.intsrv_tspec.parent = self
                            self._children_name_map["intsrv_tspec"] = "intsrv-tspec"
                            self._children_yang_names.add("intsrv-tspec")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("tspec_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericTrafficSpec, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericTrafficSpec, self).__setattr__(name, value)


                        class G709OtnTspec(Entity):
                            """
                            G709 OTN Sender Tspec
                            
                            .. attribute:: traffic_bit_rate
                            
                            	G709 OTN Traffic Bit Rate
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: traffic_multiplier
                            
                            	G709 OTN Traffic Multiplier
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: traffic_nvc
                            
                            	G709 OTN Traffic NVC
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: traffic_signal_type
                            
                            	G709 OTN Traffic Signal Type (Refer G709 v3)
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericTrafficSpec.G709OtnTspec, self).__init__()

                                self.yang_name = "g709otn-tspec"
                                self.yang_parent_name = "generic-traffic-spec"

                                self.traffic_bit_rate = YLeaf(YType.uint64, "traffic-bit-rate")

                                self.traffic_multiplier = YLeaf(YType.uint16, "traffic-multiplier")

                                self.traffic_nvc = YLeaf(YType.uint16, "traffic-nvc")

                                self.traffic_signal_type = YLeaf(YType.uint8, "traffic-signal-type")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("traffic_bit_rate",
                                                "traffic_multiplier",
                                                "traffic_nvc",
                                                "traffic_signal_type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericTrafficSpec.G709OtnTspec, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericTrafficSpec.G709OtnTspec, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.traffic_bit_rate.is_set or
                                    self.traffic_multiplier.is_set or
                                    self.traffic_nvc.is_set or
                                    self.traffic_signal_type.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.traffic_bit_rate.yfilter != YFilter.not_set or
                                    self.traffic_multiplier.yfilter != YFilter.not_set or
                                    self.traffic_nvc.yfilter != YFilter.not_set or
                                    self.traffic_signal_type.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "g709otn-tspec" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/psb-rsb-info/psb-info/generic-traffic-spec/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.traffic_bit_rate.is_set or self.traffic_bit_rate.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.traffic_bit_rate.get_name_leafdata())
                                if (self.traffic_multiplier.is_set or self.traffic_multiplier.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.traffic_multiplier.get_name_leafdata())
                                if (self.traffic_nvc.is_set or self.traffic_nvc.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.traffic_nvc.get_name_leafdata())
                                if (self.traffic_signal_type.is_set or self.traffic_signal_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.traffic_signal_type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "traffic-bit-rate" or name == "traffic-multiplier" or name == "traffic-nvc" or name == "traffic-signal-type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "traffic-bit-rate"):
                                    self.traffic_bit_rate = value
                                    self.traffic_bit_rate.value_namespace = name_space
                                    self.traffic_bit_rate.value_namespace_prefix = name_space_prefix
                                if(value_path == "traffic-multiplier"):
                                    self.traffic_multiplier = value
                                    self.traffic_multiplier.value_namespace = name_space
                                    self.traffic_multiplier.value_namespace_prefix = name_space_prefix
                                if(value_path == "traffic-nvc"):
                                    self.traffic_nvc = value
                                    self.traffic_nvc.value_namespace = name_space
                                    self.traffic_nvc.value_namespace_prefix = name_space_prefix
                                if(value_path == "traffic-signal-type"):
                                    self.traffic_signal_type = value
                                    self.traffic_signal_type.value_namespace = name_space
                                    self.traffic_signal_type.value_namespace_prefix = name_space_prefix


                        class IntsrvTspec(Entity):
                            """
                            Integrated Services Sender Tspec
                            
                            .. attribute:: traffic_average_rate
                            
                            	Traffic Average Rate in bytes per second
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: byte/s
                            
                            .. attribute:: traffic_max_burst
                            
                            	Traffic Maximum Burst
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: traffic_max_unit
                            
                            	Traffic Maximum Unit
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: traffic_min_unit
                            
                            	Traffic Minimum Unit
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: traffic_peak_rate
                            
                            	Traffic Peak Rate in bytes per second
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: byte/s
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericTrafficSpec.IntsrvTspec, self).__init__()

                                self.yang_name = "intsrv-tspec"
                                self.yang_parent_name = "generic-traffic-spec"

                                self.traffic_average_rate = YLeaf(YType.uint64, "traffic-average-rate")

                                self.traffic_max_burst = YLeaf(YType.uint64, "traffic-max-burst")

                                self.traffic_max_unit = YLeaf(YType.uint32, "traffic-max-unit")

                                self.traffic_min_unit = YLeaf(YType.uint32, "traffic-min-unit")

                                self.traffic_peak_rate = YLeaf(YType.uint64, "traffic-peak-rate")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("traffic_average_rate",
                                                "traffic_max_burst",
                                                "traffic_max_unit",
                                                "traffic_min_unit",
                                                "traffic_peak_rate") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericTrafficSpec.IntsrvTspec, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericTrafficSpec.IntsrvTspec, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.traffic_average_rate.is_set or
                                    self.traffic_max_burst.is_set or
                                    self.traffic_max_unit.is_set or
                                    self.traffic_min_unit.is_set or
                                    self.traffic_peak_rate.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.traffic_average_rate.yfilter != YFilter.not_set or
                                    self.traffic_max_burst.yfilter != YFilter.not_set or
                                    self.traffic_max_unit.yfilter != YFilter.not_set or
                                    self.traffic_min_unit.yfilter != YFilter.not_set or
                                    self.traffic_peak_rate.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "intsrv-tspec" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/psb-rsb-info/psb-info/generic-traffic-spec/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.traffic_average_rate.is_set or self.traffic_average_rate.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.traffic_average_rate.get_name_leafdata())
                                if (self.traffic_max_burst.is_set or self.traffic_max_burst.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.traffic_max_burst.get_name_leafdata())
                                if (self.traffic_max_unit.is_set or self.traffic_max_unit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.traffic_max_unit.get_name_leafdata())
                                if (self.traffic_min_unit.is_set or self.traffic_min_unit.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.traffic_min_unit.get_name_leafdata())
                                if (self.traffic_peak_rate.is_set or self.traffic_peak_rate.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.traffic_peak_rate.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "traffic-average-rate" or name == "traffic-max-burst" or name == "traffic-max-unit" or name == "traffic-min-unit" or name == "traffic-peak-rate"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "traffic-average-rate"):
                                    self.traffic_average_rate = value
                                    self.traffic_average_rate.value_namespace = name_space
                                    self.traffic_average_rate.value_namespace_prefix = name_space_prefix
                                if(value_path == "traffic-max-burst"):
                                    self.traffic_max_burst = value
                                    self.traffic_max_burst.value_namespace = name_space
                                    self.traffic_max_burst.value_namespace_prefix = name_space_prefix
                                if(value_path == "traffic-max-unit"):
                                    self.traffic_max_unit = value
                                    self.traffic_max_unit.value_namespace = name_space
                                    self.traffic_max_unit.value_namespace_prefix = name_space_prefix
                                if(value_path == "traffic-min-unit"):
                                    self.traffic_min_unit = value
                                    self.traffic_min_unit.value_namespace = name_space
                                    self.traffic_min_unit.value_namespace_prefix = name_space_prefix
                                if(value_path == "traffic-peak-rate"):
                                    self.traffic_peak_rate = value
                                    self.traffic_peak_rate.value_namespace = name_space
                                    self.traffic_peak_rate.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.tspec_type.is_set or
                                (self.g709otn_tspec is not None and self.g709otn_tspec.has_data()) or
                                (self.intsrv_tspec is not None and self.intsrv_tspec.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.tspec_type.yfilter != YFilter.not_set or
                                (self.g709otn_tspec is not None and self.g709otn_tspec.has_operation()) or
                                (self.intsrv_tspec is not None and self.intsrv_tspec.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "generic-traffic-spec" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/psb-rsb-info/psb-info/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.tspec_type.is_set or self.tspec_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tspec_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "g709otn-tspec"):
                                if (self.g709otn_tspec is None):
                                    self.g709otn_tspec = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericTrafficSpec.G709OtnTspec()
                                    self.g709otn_tspec.parent = self
                                    self._children_name_map["g709otn_tspec"] = "g709otn-tspec"
                                return self.g709otn_tspec

                            if (child_yang_name == "intsrv-tspec"):
                                if (self.intsrv_tspec is None):
                                    self.intsrv_tspec = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericTrafficSpec.IntsrvTspec()
                                    self.intsrv_tspec.parent = self
                                    self._children_name_map["intsrv_tspec"] = "intsrv-tspec"
                                return self.intsrv_tspec

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "g709otn-tspec" or name == "intsrv-tspec" or name == "tspec-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "tspec-type"):
                                self.tspec_type = value
                                self.tspec_type.value_namespace = name_space
                                self.tspec_type.value_namespace_prefix = name_space_prefix


                    class Association(Entity):
                        """
                        Association object
                        
                        .. attribute:: association_type
                        
                        	AssociationType
                        	**type**\:   :py:class:`RsvpMgmtAssociation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtAssociation>`
                        
                        .. attribute:: extended_ipv4
                        
                        	EXTENDED IPV4 ASSOCIATION Object
                        	**type**\:   :py:class:`ExtendedIpv4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association.ExtendedIpv4>`
                        
                        .. attribute:: extended_ipv6
                        
                        	EXTENDED IPV6 ASSOCIATION Object
                        	**type**\:   :py:class:`ExtendedIpv6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association.ExtendedIpv6>`
                        
                        .. attribute:: ipv4
                        
                        	IPV4 ASSOCIATION Object
                        	**type**\:   :py:class:`Ipv4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association.Ipv4>`
                        
                        .. attribute:: ipv6
                        
                        	IPV6 ASSOCIATION Object
                        	**type**\:   :py:class:`Ipv6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association.Ipv6>`
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association, self).__init__()

                            self.yang_name = "association"
                            self.yang_parent_name = "psb-info"

                            self.association_type = YLeaf(YType.enumeration, "association-type")

                            self.extended_ipv4 = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association.ExtendedIpv4()
                            self.extended_ipv4.parent = self
                            self._children_name_map["extended_ipv4"] = "extended-ipv4"
                            self._children_yang_names.add("extended-ipv4")

                            self.extended_ipv6 = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association.ExtendedIpv6()
                            self.extended_ipv6.parent = self
                            self._children_name_map["extended_ipv6"] = "extended-ipv6"
                            self._children_yang_names.add("extended-ipv6")

                            self.ipv4 = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association.Ipv4()
                            self.ipv4.parent = self
                            self._children_name_map["ipv4"] = "ipv4"
                            self._children_yang_names.add("ipv4")

                            self.ipv6 = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association.Ipv6()
                            self.ipv6.parent = self
                            self._children_name_map["ipv6"] = "ipv6"
                            self._children_yang_names.add("ipv6")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("association_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association, self).__setattr__(name, value)


                        class Ipv4(Entity):
                            """
                            IPV4 ASSOCIATION Object
                            
                            .. attribute:: id
                            
                            	Association ID
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: source
                            
                            	Association IPV4 Source Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: type
                            
                            	Association Type (RFC 4872)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association.Ipv4, self).__init__()

                                self.yang_name = "ipv4"
                                self.yang_parent_name = "association"

                                self.id = YLeaf(YType.uint16, "id")

                                self.source = YLeaf(YType.str, "source")

                                self.type = YLeaf(YType.uint16, "type")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("id",
                                                "source",
                                                "type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association.Ipv4, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association.Ipv4, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.id.is_set or
                                    self.source.is_set or
                                    self.type.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.id.yfilter != YFilter.not_set or
                                    self.source.yfilter != YFilter.not_set or
                                    self.type.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ipv4" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/psb-rsb-info/psb-info/association/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.id.is_set or self.id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.id.get_name_leafdata())
                                if (self.source.is_set or self.source.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.source.get_name_leafdata())
                                if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "id" or name == "source" or name == "type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "id"):
                                    self.id = value
                                    self.id.value_namespace = name_space
                                    self.id.value_namespace_prefix = name_space_prefix
                                if(value_path == "source"):
                                    self.source = value
                                    self.source.value_namespace = name_space
                                    self.source.value_namespace_prefix = name_space_prefix
                                if(value_path == "type"):
                                    self.type = value
                                    self.type.value_namespace = name_space
                                    self.type.value_namespace_prefix = name_space_prefix


                        class Ipv6(Entity):
                            """
                            IPV6 ASSOCIATION Object
                            
                            .. attribute:: id
                            
                            	Association ID
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: source
                            
                            	Association IPV6 Source Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: type
                            
                            	Association Type (RFC 4872)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association.Ipv6, self).__init__()

                                self.yang_name = "ipv6"
                                self.yang_parent_name = "association"

                                self.id = YLeaf(YType.uint16, "id")

                                self.source = YLeaf(YType.str, "source")

                                self.type = YLeaf(YType.uint16, "type")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("id",
                                                "source",
                                                "type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association.Ipv6, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association.Ipv6, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.id.is_set or
                                    self.source.is_set or
                                    self.type.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.id.yfilter != YFilter.not_set or
                                    self.source.yfilter != YFilter.not_set or
                                    self.type.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ipv6" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/psb-rsb-info/psb-info/association/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.id.is_set or self.id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.id.get_name_leafdata())
                                if (self.source.is_set or self.source.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.source.get_name_leafdata())
                                if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "id" or name == "source" or name == "type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "id"):
                                    self.id = value
                                    self.id.value_namespace = name_space
                                    self.id.value_namespace_prefix = name_space_prefix
                                if(value_path == "source"):
                                    self.source = value
                                    self.source.value_namespace = name_space
                                    self.source.value_namespace_prefix = name_space_prefix
                                if(value_path == "type"):
                                    self.type = value
                                    self.type.value_namespace = name_space
                                    self.type.value_namespace_prefix = name_space_prefix


                        class ExtendedIpv4(Entity):
                            """
                            EXTENDED IPV4 ASSOCIATION Object
                            
                            .. attribute:: extended_id
                            
                            	Extended Association ID
                            	**type**\:  list of int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: global_source
                            
                            	Global Association Source
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: id
                            
                            	Association ID
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: source
                            
                            	Association IPV4 Source Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: type
                            
                            	Association Type (RFC 4872)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association.ExtendedIpv4, self).__init__()

                                self.yang_name = "extended-ipv4"
                                self.yang_parent_name = "association"

                                self.extended_id = YLeafList(YType.uint32, "extended-id")

                                self.global_source = YLeaf(YType.uint32, "global-source")

                                self.id = YLeaf(YType.uint16, "id")

                                self.source = YLeaf(YType.str, "source")

                                self.type = YLeaf(YType.uint16, "type")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("extended_id",
                                                "global_source",
                                                "id",
                                                "source",
                                                "type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association.ExtendedIpv4, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association.ExtendedIpv4, self).__setattr__(name, value)

                            def has_data(self):
                                for leaf in self.extended_id.getYLeafs():
                                    if (leaf.yfilter != YFilter.not_set):
                                        return True
                                return (
                                    self.global_source.is_set or
                                    self.id.is_set or
                                    self.source.is_set or
                                    self.type.is_set)

                            def has_operation(self):
                                for leaf in self.extended_id.getYLeafs():
                                    if (leaf.is_set):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.extended_id.yfilter != YFilter.not_set or
                                    self.global_source.yfilter != YFilter.not_set or
                                    self.id.yfilter != YFilter.not_set or
                                    self.source.yfilter != YFilter.not_set or
                                    self.type.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "extended-ipv4" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/psb-rsb-info/psb-info/association/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.global_source.is_set or self.global_source.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.global_source.get_name_leafdata())
                                if (self.id.is_set or self.id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.id.get_name_leafdata())
                                if (self.source.is_set or self.source.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.source.get_name_leafdata())
                                if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.type.get_name_leafdata())

                                leaf_name_data.extend(self.extended_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "extended-id" or name == "global-source" or name == "id" or name == "source" or name == "type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "extended-id"):
                                    self.extended_id.append(value)
                                if(value_path == "global-source"):
                                    self.global_source = value
                                    self.global_source.value_namespace = name_space
                                    self.global_source.value_namespace_prefix = name_space_prefix
                                if(value_path == "id"):
                                    self.id = value
                                    self.id.value_namespace = name_space
                                    self.id.value_namespace_prefix = name_space_prefix
                                if(value_path == "source"):
                                    self.source = value
                                    self.source.value_namespace = name_space
                                    self.source.value_namespace_prefix = name_space_prefix
                                if(value_path == "type"):
                                    self.type = value
                                    self.type.value_namespace = name_space
                                    self.type.value_namespace_prefix = name_space_prefix


                        class ExtendedIpv6(Entity):
                            """
                            EXTENDED IPV6 ASSOCIATION Object
                            
                            .. attribute:: extended_id
                            
                            	Extended Association ID
                            	**type**\:  list of int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: global_source
                            
                            	Global Association Source
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: id
                            
                            	Association ID
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: source
                            
                            	Association IPV6 Source Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: type
                            
                            	Association Type (RFC 4872)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association.ExtendedIpv6, self).__init__()

                                self.yang_name = "extended-ipv6"
                                self.yang_parent_name = "association"

                                self.extended_id = YLeafList(YType.uint32, "extended-id")

                                self.global_source = YLeaf(YType.uint32, "global-source")

                                self.id = YLeaf(YType.uint16, "id")

                                self.source = YLeaf(YType.str, "source")

                                self.type = YLeaf(YType.uint16, "type")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("extended_id",
                                                "global_source",
                                                "id",
                                                "source",
                                                "type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association.ExtendedIpv6, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association.ExtendedIpv6, self).__setattr__(name, value)

                            def has_data(self):
                                for leaf in self.extended_id.getYLeafs():
                                    if (leaf.yfilter != YFilter.not_set):
                                        return True
                                return (
                                    self.global_source.is_set or
                                    self.id.is_set or
                                    self.source.is_set or
                                    self.type.is_set)

                            def has_operation(self):
                                for leaf in self.extended_id.getYLeafs():
                                    if (leaf.is_set):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.extended_id.yfilter != YFilter.not_set or
                                    self.global_source.yfilter != YFilter.not_set or
                                    self.id.yfilter != YFilter.not_set or
                                    self.source.yfilter != YFilter.not_set or
                                    self.type.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "extended-ipv6" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/psb-rsb-info/psb-info/association/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.global_source.is_set or self.global_source.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.global_source.get_name_leafdata())
                                if (self.id.is_set or self.id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.id.get_name_leafdata())
                                if (self.source.is_set or self.source.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.source.get_name_leafdata())
                                if (self.type.is_set or self.type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.type.get_name_leafdata())

                                leaf_name_data.extend(self.extended_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "extended-id" or name == "global-source" or name == "id" or name == "source" or name == "type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "extended-id"):
                                    self.extended_id.append(value)
                                if(value_path == "global-source"):
                                    self.global_source = value
                                    self.global_source.value_namespace = name_space
                                    self.global_source.value_namespace_prefix = name_space_prefix
                                if(value_path == "id"):
                                    self.id = value
                                    self.id.value_namespace = name_space
                                    self.id.value_namespace_prefix = name_space_prefix
                                if(value_path == "source"):
                                    self.source = value
                                    self.source.value_namespace = name_space
                                    self.source.value_namespace_prefix = name_space_prefix
                                if(value_path == "type"):
                                    self.type = value
                                    self.type.value_namespace = name_space
                                    self.type.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.association_type.is_set or
                                (self.extended_ipv4 is not None and self.extended_ipv4.has_data()) or
                                (self.extended_ipv6 is not None and self.extended_ipv6.has_data()) or
                                (self.ipv4 is not None and self.ipv4.has_data()) or
                                (self.ipv6 is not None and self.ipv6.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.association_type.yfilter != YFilter.not_set or
                                (self.extended_ipv4 is not None and self.extended_ipv4.has_operation()) or
                                (self.extended_ipv6 is not None and self.extended_ipv6.has_operation()) or
                                (self.ipv4 is not None and self.ipv4.has_operation()) or
                                (self.ipv6 is not None and self.ipv6.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "association" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/psb-rsb-info/psb-info/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.association_type.is_set or self.association_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.association_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "extended-ipv4"):
                                if (self.extended_ipv4 is None):
                                    self.extended_ipv4 = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association.ExtendedIpv4()
                                    self.extended_ipv4.parent = self
                                    self._children_name_map["extended_ipv4"] = "extended-ipv4"
                                return self.extended_ipv4

                            if (child_yang_name == "extended-ipv6"):
                                if (self.extended_ipv6 is None):
                                    self.extended_ipv6 = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association.ExtendedIpv6()
                                    self.extended_ipv6.parent = self
                                    self._children_name_map["extended_ipv6"] = "extended-ipv6"
                                return self.extended_ipv6

                            if (child_yang_name == "ipv4"):
                                if (self.ipv4 is None):
                                    self.ipv4 = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association.Ipv4()
                                    self.ipv4.parent = self
                                    self._children_name_map["ipv4"] = "ipv4"
                                return self.ipv4

                            if (child_yang_name == "ipv6"):
                                if (self.ipv6 is None):
                                    self.ipv6 = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association.Ipv6()
                                    self.ipv6.parent = self
                                    self._children_name_map["ipv6"] = "ipv6"
                                return self.ipv6

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "extended-ipv4" or name == "extended-ipv6" or name == "ipv4" or name == "ipv6" or name == "association-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "association-type"):
                                self.association_type = value
                                self.association_type.value_namespace = name_space
                                self.association_type.value_namespace_prefix = name_space_prefix


                    class Protection(Entity):
                        """
                        Protection object
                        
                        .. attribute:: link_flags
                        
                        	PROTECTION Object Link Flags
                        	**type**\:   :py:class:`LinkFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Protection.LinkFlags>`
                        
                        .. attribute:: lsp_flags
                        
                        	PROTECTION Object LSP Flags
                        	**type**\:   :py:class:`LspFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Protection.LspFlags>`
                        
                        .. attribute:: n
                        
                        	Notification Bit
                        	**type**\:  bool
                        
                        .. attribute:: o
                        
                        	Operational Bit
                        	**type**\:  bool
                        
                        .. attribute:: p
                        
                        	Protecting Bit
                        	**type**\:  bool
                        
                        .. attribute:: s
                        
                        	Secondary Bit
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Protection, self).__init__()

                            self.yang_name = "protection"
                            self.yang_parent_name = "psb-info"

                            self.n = YLeaf(YType.boolean, "n")

                            self.o = YLeaf(YType.boolean, "o")

                            self.p = YLeaf(YType.boolean, "p")

                            self.s = YLeaf(YType.boolean, "s")

                            self.link_flags = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Protection.LinkFlags()
                            self.link_flags.parent = self
                            self._children_name_map["link_flags"] = "link-flags"
                            self._children_yang_names.add("link-flags")

                            self.lsp_flags = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Protection.LspFlags()
                            self.lsp_flags.parent = self
                            self._children_name_map["lsp_flags"] = "lsp-flags"
                            self._children_yang_names.add("lsp-flags")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("n",
                                            "o",
                                            "p",
                                            "s") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Protection, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Protection, self).__setattr__(name, value)


                        class LspFlags(Entity):
                            """
                            PROTECTION Object LSP Flags
                            
                            .. attribute:: one_plus_one_bi
                            
                            	1+1 Bidirectional Protection
                            	**type**\:  bool
                            
                            .. attribute:: one_plus_one_uni
                            
                            	1+1 Unidirectional Protection
                            	**type**\:  bool
                            
                            .. attribute:: one_to_n_protection_et
                            
                            	1\:N Protection with Extra\-Traffic
                            	**type**\:  bool
                            
                            .. attribute:: rerouting
                            
                            	Full Rerouting
                            	**type**\:  bool
                            
                            .. attribute:: rerouting_no_et
                            
                            	Rerouting Without Extra\-Traffic
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Protection.LspFlags, self).__init__()

                                self.yang_name = "lsp-flags"
                                self.yang_parent_name = "protection"

                                self.one_plus_one_bi = YLeaf(YType.boolean, "one-plus-one-bi")

                                self.one_plus_one_uni = YLeaf(YType.boolean, "one-plus-one-uni")

                                self.one_to_n_protection_et = YLeaf(YType.boolean, "one-to-n-protection-et")

                                self.rerouting = YLeaf(YType.boolean, "rerouting")

                                self.rerouting_no_et = YLeaf(YType.boolean, "rerouting-no-et")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("one_plus_one_bi",
                                                "one_plus_one_uni",
                                                "one_to_n_protection_et",
                                                "rerouting",
                                                "rerouting_no_et") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Protection.LspFlags, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Protection.LspFlags, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.one_plus_one_bi.is_set or
                                    self.one_plus_one_uni.is_set or
                                    self.one_to_n_protection_et.is_set or
                                    self.rerouting.is_set or
                                    self.rerouting_no_et.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.one_plus_one_bi.yfilter != YFilter.not_set or
                                    self.one_plus_one_uni.yfilter != YFilter.not_set or
                                    self.one_to_n_protection_et.yfilter != YFilter.not_set or
                                    self.rerouting.yfilter != YFilter.not_set or
                                    self.rerouting_no_et.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "lsp-flags" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/psb-rsb-info/psb-info/protection/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.one_plus_one_bi.is_set or self.one_plus_one_bi.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.one_plus_one_bi.get_name_leafdata())
                                if (self.one_plus_one_uni.is_set or self.one_plus_one_uni.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.one_plus_one_uni.get_name_leafdata())
                                if (self.one_to_n_protection_et.is_set or self.one_to_n_protection_et.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.one_to_n_protection_et.get_name_leafdata())
                                if (self.rerouting.is_set or self.rerouting.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rerouting.get_name_leafdata())
                                if (self.rerouting_no_et.is_set or self.rerouting_no_et.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rerouting_no_et.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "one-plus-one-bi" or name == "one-plus-one-uni" or name == "one-to-n-protection-et" or name == "rerouting" or name == "rerouting-no-et"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "one-plus-one-bi"):
                                    self.one_plus_one_bi = value
                                    self.one_plus_one_bi.value_namespace = name_space
                                    self.one_plus_one_bi.value_namespace_prefix = name_space_prefix
                                if(value_path == "one-plus-one-uni"):
                                    self.one_plus_one_uni = value
                                    self.one_plus_one_uni.value_namespace = name_space
                                    self.one_plus_one_uni.value_namespace_prefix = name_space_prefix
                                if(value_path == "one-to-n-protection-et"):
                                    self.one_to_n_protection_et = value
                                    self.one_to_n_protection_et.value_namespace = name_space
                                    self.one_to_n_protection_et.value_namespace_prefix = name_space_prefix
                                if(value_path == "rerouting"):
                                    self.rerouting = value
                                    self.rerouting.value_namespace = name_space
                                    self.rerouting.value_namespace_prefix = name_space_prefix
                                if(value_path == "rerouting-no-et"):
                                    self.rerouting_no_et = value
                                    self.rerouting_no_et.value_namespace = name_space
                                    self.rerouting_no_et.value_namespace_prefix = name_space_prefix


                        class LinkFlags(Entity):
                            """
                            PROTECTION Object Link Flags
                            
                            .. attribute:: ded1_plus1
                            
                            	Dedicated 1+1 Protection
                            	**type**\:  bool
                            
                            .. attribute:: ded1_to1
                            
                            	Dedicated 1\:1 Protection
                            	**type**\:  bool
                            
                            .. attribute:: enhanced
                            
                            	Indicates Enhanced Protection Scheme
                            	**type**\:  bool
                            
                            .. attribute:: extra_traffic
                            
                            	LSP should use Links that are protecting other (primary) traffic
                            	**type**\:  bool
                            
                            .. attribute:: reserved_bit1
                            
                            	Reserved Bit 1
                            	**type**\:  bool
                            
                            .. attribute:: reserved_bit2
                            
                            	Reserved Bit 2
                            	**type**\:  bool
                            
                            .. attribute:: shared
                            
                            	Shared Link Layer Protection
                            	**type**\:  bool
                            
                            .. attribute:: unprotected
                            
                            	LSP should not use any Link Layer Protection
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Protection.LinkFlags, self).__init__()

                                self.yang_name = "link-flags"
                                self.yang_parent_name = "protection"

                                self.ded1_plus1 = YLeaf(YType.boolean, "ded1-plus1")

                                self.ded1_to1 = YLeaf(YType.boolean, "ded1-to1")

                                self.enhanced = YLeaf(YType.boolean, "enhanced")

                                self.extra_traffic = YLeaf(YType.boolean, "extra-traffic")

                                self.reserved_bit1 = YLeaf(YType.boolean, "reserved-bit1")

                                self.reserved_bit2 = YLeaf(YType.boolean, "reserved-bit2")

                                self.shared = YLeaf(YType.boolean, "shared")

                                self.unprotected = YLeaf(YType.boolean, "unprotected")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ded1_plus1",
                                                "ded1_to1",
                                                "enhanced",
                                                "extra_traffic",
                                                "reserved_bit1",
                                                "reserved_bit2",
                                                "shared",
                                                "unprotected") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Protection.LinkFlags, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Protection.LinkFlags, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.ded1_plus1.is_set or
                                    self.ded1_to1.is_set or
                                    self.enhanced.is_set or
                                    self.extra_traffic.is_set or
                                    self.reserved_bit1.is_set or
                                    self.reserved_bit2.is_set or
                                    self.shared.is_set or
                                    self.unprotected.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ded1_plus1.yfilter != YFilter.not_set or
                                    self.ded1_to1.yfilter != YFilter.not_set or
                                    self.enhanced.yfilter != YFilter.not_set or
                                    self.extra_traffic.yfilter != YFilter.not_set or
                                    self.reserved_bit1.yfilter != YFilter.not_set or
                                    self.reserved_bit2.yfilter != YFilter.not_set or
                                    self.shared.yfilter != YFilter.not_set or
                                    self.unprotected.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "link-flags" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/psb-rsb-info/psb-info/protection/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ded1_plus1.is_set or self.ded1_plus1.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ded1_plus1.get_name_leafdata())
                                if (self.ded1_to1.is_set or self.ded1_to1.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ded1_to1.get_name_leafdata())
                                if (self.enhanced.is_set or self.enhanced.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.enhanced.get_name_leafdata())
                                if (self.extra_traffic.is_set or self.extra_traffic.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.extra_traffic.get_name_leafdata())
                                if (self.reserved_bit1.is_set or self.reserved_bit1.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.reserved_bit1.get_name_leafdata())
                                if (self.reserved_bit2.is_set or self.reserved_bit2.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.reserved_bit2.get_name_leafdata())
                                if (self.shared.is_set or self.shared.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.shared.get_name_leafdata())
                                if (self.unprotected.is_set or self.unprotected.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.unprotected.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ded1-plus1" or name == "ded1-to1" or name == "enhanced" or name == "extra-traffic" or name == "reserved-bit1" or name == "reserved-bit2" or name == "shared" or name == "unprotected"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ded1-plus1"):
                                    self.ded1_plus1 = value
                                    self.ded1_plus1.value_namespace = name_space
                                    self.ded1_plus1.value_namespace_prefix = name_space_prefix
                                if(value_path == "ded1-to1"):
                                    self.ded1_to1 = value
                                    self.ded1_to1.value_namespace = name_space
                                    self.ded1_to1.value_namespace_prefix = name_space_prefix
                                if(value_path == "enhanced"):
                                    self.enhanced = value
                                    self.enhanced.value_namespace = name_space
                                    self.enhanced.value_namespace_prefix = name_space_prefix
                                if(value_path == "extra-traffic"):
                                    self.extra_traffic = value
                                    self.extra_traffic.value_namespace = name_space
                                    self.extra_traffic.value_namespace_prefix = name_space_prefix
                                if(value_path == "reserved-bit1"):
                                    self.reserved_bit1 = value
                                    self.reserved_bit1.value_namespace = name_space
                                    self.reserved_bit1.value_namespace_prefix = name_space_prefix
                                if(value_path == "reserved-bit2"):
                                    self.reserved_bit2 = value
                                    self.reserved_bit2.value_namespace = name_space
                                    self.reserved_bit2.value_namespace_prefix = name_space_prefix
                                if(value_path == "shared"):
                                    self.shared = value
                                    self.shared.value_namespace = name_space
                                    self.shared.value_namespace_prefix = name_space_prefix
                                if(value_path == "unprotected"):
                                    self.unprotected = value
                                    self.unprotected.value_namespace = name_space
                                    self.unprotected.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.n.is_set or
                                self.o.is_set or
                                self.p.is_set or
                                self.s.is_set or
                                (self.link_flags is not None and self.link_flags.has_data()) or
                                (self.lsp_flags is not None and self.lsp_flags.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.n.yfilter != YFilter.not_set or
                                self.o.yfilter != YFilter.not_set or
                                self.p.yfilter != YFilter.not_set or
                                self.s.yfilter != YFilter.not_set or
                                (self.link_flags is not None and self.link_flags.has_operation()) or
                                (self.lsp_flags is not None and self.lsp_flags.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "protection" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/psb-rsb-info/psb-info/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.n.is_set or self.n.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.n.get_name_leafdata())
                            if (self.o.is_set or self.o.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.o.get_name_leafdata())
                            if (self.p.is_set or self.p.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.p.get_name_leafdata())
                            if (self.s.is_set or self.s.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.s.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "link-flags"):
                                if (self.link_flags is None):
                                    self.link_flags = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Protection.LinkFlags()
                                    self.link_flags.parent = self
                                    self._children_name_map["link_flags"] = "link-flags"
                                return self.link_flags

                            if (child_yang_name == "lsp-flags"):
                                if (self.lsp_flags is None):
                                    self.lsp_flags = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Protection.LspFlags()
                                    self.lsp_flags.parent = self
                                    self._children_name_map["lsp_flags"] = "lsp-flags"
                                return self.lsp_flags

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "link-flags" or name == "lsp-flags" or name == "n" or name == "o" or name == "p" or name == "s"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "n"):
                                self.n = value
                                self.n.value_namespace = name_space
                                self.n.value_namespace_prefix = name_space_prefix
                            if(value_path == "o"):
                                self.o = value
                                self.o.value_namespace = name_space
                                self.o.value_namespace_prefix = name_space_prefix
                            if(value_path == "p"):
                                self.p = value
                                self.p.value_namespace = name_space
                                self.p.value_namespace_prefix = name_space_prefix
                            if(value_path == "s"):
                                self.s = value
                                self.s.value_namespace = name_space
                                self.s.value_namespace_prefix = name_space_prefix


                    class ReverseLsp(Entity):
                        """
                        Reverse LSP object
                        
                        .. attribute:: ero
                        
                        	Explicit Route Sub Objects
                        	**type**\: list of    :py:class:`Ero <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.Ero>`
                        
                        .. attribute:: generic_traffic_spec
                        
                        	Generic Traffic Spec object
                        	**type**\:   :py:class:`GenericTrafficSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.GenericTrafficSpec>`
                        
                        .. attribute:: unsup_sub_object
                        
                        	Unsupported REVERSE\_LSP Sub Objects
                        	**type**\: list of    :py:class:`UnsupSubObject <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.UnsupSubObject>`
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp, self).__init__()

                            self.yang_name = "reverse-lsp"
                            self.yang_parent_name = "psb-info"

                            self.generic_traffic_spec = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.GenericTrafficSpec()
                            self.generic_traffic_spec.parent = self
                            self._children_name_map["generic_traffic_spec"] = "generic-traffic-spec"
                            self._children_yang_names.add("generic-traffic-spec")

                            self.ero = YList(self)
                            self.unsup_sub_object = YList(self)

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in () and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp, self).__setattr__(name, value)


                        class GenericTrafficSpec(Entity):
                            """
                            Generic Traffic Spec object
                            
                            .. attribute:: g709otn_tspec
                            
                            	G709 OTN Sender Tspec
                            	**type**\:   :py:class:`G709OtnTspec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.GenericTrafficSpec.G709OtnTspec>`
                            
                            .. attribute:: intsrv_tspec
                            
                            	Integrated Services Sender Tspec
                            	**type**\:   :py:class:`IntsrvTspec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.GenericTrafficSpec.IntsrvTspec>`
                            
                            .. attribute:: tspec_type
                            
                            	TspecType
                            	**type**\:   :py:class:`RsvpMgmtTspec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtTspec>`
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.GenericTrafficSpec, self).__init__()

                                self.yang_name = "generic-traffic-spec"
                                self.yang_parent_name = "reverse-lsp"

                                self.tspec_type = YLeaf(YType.enumeration, "tspec-type")

                                self.g709otn_tspec = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.GenericTrafficSpec.G709OtnTspec()
                                self.g709otn_tspec.parent = self
                                self._children_name_map["g709otn_tspec"] = "g709otn-tspec"
                                self._children_yang_names.add("g709otn-tspec")

                                self.intsrv_tspec = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.GenericTrafficSpec.IntsrvTspec()
                                self.intsrv_tspec.parent = self
                                self._children_name_map["intsrv_tspec"] = "intsrv-tspec"
                                self._children_yang_names.add("intsrv-tspec")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("tspec_type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.GenericTrafficSpec, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.GenericTrafficSpec, self).__setattr__(name, value)


                            class G709OtnTspec(Entity):
                                """
                                G709 OTN Sender Tspec
                                
                                .. attribute:: traffic_bit_rate
                                
                                	G709 OTN Traffic Bit Rate
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: traffic_multiplier
                                
                                	G709 OTN Traffic Multiplier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: traffic_nvc
                                
                                	G709 OTN Traffic NVC
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: traffic_signal_type
                                
                                	G709 OTN Traffic Signal Type (Refer G709 v3)
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ip-rsvp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.GenericTrafficSpec.G709OtnTspec, self).__init__()

                                    self.yang_name = "g709otn-tspec"
                                    self.yang_parent_name = "generic-traffic-spec"

                                    self.traffic_bit_rate = YLeaf(YType.uint64, "traffic-bit-rate")

                                    self.traffic_multiplier = YLeaf(YType.uint16, "traffic-multiplier")

                                    self.traffic_nvc = YLeaf(YType.uint16, "traffic-nvc")

                                    self.traffic_signal_type = YLeaf(YType.uint8, "traffic-signal-type")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("traffic_bit_rate",
                                                    "traffic_multiplier",
                                                    "traffic_nvc",
                                                    "traffic_signal_type") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.GenericTrafficSpec.G709OtnTspec, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.GenericTrafficSpec.G709OtnTspec, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.traffic_bit_rate.is_set or
                                        self.traffic_multiplier.is_set or
                                        self.traffic_nvc.is_set or
                                        self.traffic_signal_type.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.traffic_bit_rate.yfilter != YFilter.not_set or
                                        self.traffic_multiplier.yfilter != YFilter.not_set or
                                        self.traffic_nvc.yfilter != YFilter.not_set or
                                        self.traffic_signal_type.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "g709otn-tspec" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/psb-rsb-info/psb-info/reverse-lsp/generic-traffic-spec/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.traffic_bit_rate.is_set or self.traffic_bit_rate.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.traffic_bit_rate.get_name_leafdata())
                                    if (self.traffic_multiplier.is_set or self.traffic_multiplier.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.traffic_multiplier.get_name_leafdata())
                                    if (self.traffic_nvc.is_set or self.traffic_nvc.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.traffic_nvc.get_name_leafdata())
                                    if (self.traffic_signal_type.is_set or self.traffic_signal_type.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.traffic_signal_type.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "traffic-bit-rate" or name == "traffic-multiplier" or name == "traffic-nvc" or name == "traffic-signal-type"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "traffic-bit-rate"):
                                        self.traffic_bit_rate = value
                                        self.traffic_bit_rate.value_namespace = name_space
                                        self.traffic_bit_rate.value_namespace_prefix = name_space_prefix
                                    if(value_path == "traffic-multiplier"):
                                        self.traffic_multiplier = value
                                        self.traffic_multiplier.value_namespace = name_space
                                        self.traffic_multiplier.value_namespace_prefix = name_space_prefix
                                    if(value_path == "traffic-nvc"):
                                        self.traffic_nvc = value
                                        self.traffic_nvc.value_namespace = name_space
                                        self.traffic_nvc.value_namespace_prefix = name_space_prefix
                                    if(value_path == "traffic-signal-type"):
                                        self.traffic_signal_type = value
                                        self.traffic_signal_type.value_namespace = name_space
                                        self.traffic_signal_type.value_namespace_prefix = name_space_prefix


                            class IntsrvTspec(Entity):
                                """
                                Integrated Services Sender Tspec
                                
                                .. attribute:: traffic_average_rate
                                
                                	Traffic Average Rate in bytes per second
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte/s
                                
                                .. attribute:: traffic_max_burst
                                
                                	Traffic Maximum Burst
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: traffic_max_unit
                                
                                	Traffic Maximum Unit
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: traffic_min_unit
                                
                                	Traffic Minimum Unit
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: traffic_peak_rate
                                
                                	Traffic Peak Rate in bytes per second
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte/s
                                
                                

                                """

                                _prefix = 'ip-rsvp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.GenericTrafficSpec.IntsrvTspec, self).__init__()

                                    self.yang_name = "intsrv-tspec"
                                    self.yang_parent_name = "generic-traffic-spec"

                                    self.traffic_average_rate = YLeaf(YType.uint64, "traffic-average-rate")

                                    self.traffic_max_burst = YLeaf(YType.uint64, "traffic-max-burst")

                                    self.traffic_max_unit = YLeaf(YType.uint32, "traffic-max-unit")

                                    self.traffic_min_unit = YLeaf(YType.uint32, "traffic-min-unit")

                                    self.traffic_peak_rate = YLeaf(YType.uint64, "traffic-peak-rate")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("traffic_average_rate",
                                                    "traffic_max_burst",
                                                    "traffic_max_unit",
                                                    "traffic_min_unit",
                                                    "traffic_peak_rate") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.GenericTrafficSpec.IntsrvTspec, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.GenericTrafficSpec.IntsrvTspec, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.traffic_average_rate.is_set or
                                        self.traffic_max_burst.is_set or
                                        self.traffic_max_unit.is_set or
                                        self.traffic_min_unit.is_set or
                                        self.traffic_peak_rate.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.traffic_average_rate.yfilter != YFilter.not_set or
                                        self.traffic_max_burst.yfilter != YFilter.not_set or
                                        self.traffic_max_unit.yfilter != YFilter.not_set or
                                        self.traffic_min_unit.yfilter != YFilter.not_set or
                                        self.traffic_peak_rate.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "intsrv-tspec" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/psb-rsb-info/psb-info/reverse-lsp/generic-traffic-spec/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.traffic_average_rate.is_set or self.traffic_average_rate.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.traffic_average_rate.get_name_leafdata())
                                    if (self.traffic_max_burst.is_set or self.traffic_max_burst.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.traffic_max_burst.get_name_leafdata())
                                    if (self.traffic_max_unit.is_set or self.traffic_max_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.traffic_max_unit.get_name_leafdata())
                                    if (self.traffic_min_unit.is_set or self.traffic_min_unit.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.traffic_min_unit.get_name_leafdata())
                                    if (self.traffic_peak_rate.is_set or self.traffic_peak_rate.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.traffic_peak_rate.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "traffic-average-rate" or name == "traffic-max-burst" or name == "traffic-max-unit" or name == "traffic-min-unit" or name == "traffic-peak-rate"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "traffic-average-rate"):
                                        self.traffic_average_rate = value
                                        self.traffic_average_rate.value_namespace = name_space
                                        self.traffic_average_rate.value_namespace_prefix = name_space_prefix
                                    if(value_path == "traffic-max-burst"):
                                        self.traffic_max_burst = value
                                        self.traffic_max_burst.value_namespace = name_space
                                        self.traffic_max_burst.value_namespace_prefix = name_space_prefix
                                    if(value_path == "traffic-max-unit"):
                                        self.traffic_max_unit = value
                                        self.traffic_max_unit.value_namespace = name_space
                                        self.traffic_max_unit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "traffic-min-unit"):
                                        self.traffic_min_unit = value
                                        self.traffic_min_unit.value_namespace = name_space
                                        self.traffic_min_unit.value_namespace_prefix = name_space_prefix
                                    if(value_path == "traffic-peak-rate"):
                                        self.traffic_peak_rate = value
                                        self.traffic_peak_rate.value_namespace = name_space
                                        self.traffic_peak_rate.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.tspec_type.is_set or
                                    (self.g709otn_tspec is not None and self.g709otn_tspec.has_data()) or
                                    (self.intsrv_tspec is not None and self.intsrv_tspec.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.tspec_type.yfilter != YFilter.not_set or
                                    (self.g709otn_tspec is not None and self.g709otn_tspec.has_operation()) or
                                    (self.intsrv_tspec is not None and self.intsrv_tspec.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "generic-traffic-spec" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/psb-rsb-info/psb-info/reverse-lsp/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.tspec_type.is_set or self.tspec_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.tspec_type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "g709otn-tspec"):
                                    if (self.g709otn_tspec is None):
                                        self.g709otn_tspec = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.GenericTrafficSpec.G709OtnTspec()
                                        self.g709otn_tspec.parent = self
                                        self._children_name_map["g709otn_tspec"] = "g709otn-tspec"
                                    return self.g709otn_tspec

                                if (child_yang_name == "intsrv-tspec"):
                                    if (self.intsrv_tspec is None):
                                        self.intsrv_tspec = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.GenericTrafficSpec.IntsrvTspec()
                                        self.intsrv_tspec.parent = self
                                        self._children_name_map["intsrv_tspec"] = "intsrv-tspec"
                                    return self.intsrv_tspec

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "g709otn-tspec" or name == "intsrv-tspec" or name == "tspec-type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "tspec-type"):
                                    self.tspec_type = value
                                    self.tspec_type.value_namespace = name_space
                                    self.tspec_type.value_namespace_prefix = name_space_prefix


                        class Ero(Entity):
                            """
                            Explicit Route Sub Objects
                            
                            .. attribute:: ero_type
                            
                            	EROType
                            	**type**\:   :py:class:`RsvpMgmtEroSubobj <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtEroSubobj>`
                            
                            .. attribute:: ipv4ero_sub_object
                            
                            	IPV4 ERO Sub Object
                            	**type**\:   :py:class:`Ipv4EroSubObject <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.Ero.Ipv4EroSubObject>`
                            
                            .. attribute:: unnumbered_ero_sub_object
                            
                            	Unnumbered ERO Sub Object
                            	**type**\:   :py:class:`UnnumberedEroSubObject <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.Ero.UnnumberedEroSubObject>`
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.Ero, self).__init__()

                                self.yang_name = "ero"
                                self.yang_parent_name = "reverse-lsp"

                                self.ero_type = YLeaf(YType.enumeration, "ero-type")

                                self.ipv4ero_sub_object = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.Ero.Ipv4EroSubObject()
                                self.ipv4ero_sub_object.parent = self
                                self._children_name_map["ipv4ero_sub_object"] = "ipv4ero-sub-object"
                                self._children_yang_names.add("ipv4ero-sub-object")

                                self.unnumbered_ero_sub_object = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.Ero.UnnumberedEroSubObject()
                                self.unnumbered_ero_sub_object.parent = self
                                self._children_name_map["unnumbered_ero_sub_object"] = "unnumbered-ero-sub-object"
                                self._children_yang_names.add("unnumbered-ero-sub-object")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ero_type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.Ero, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.Ero, self).__setattr__(name, value)


                            class Ipv4EroSubObject(Entity):
                                """
                                IPV4 ERO Sub Object
                                
                                .. attribute:: ero_address
                                
                                	The ERO IPV4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: is_strict_route
                                
                                	ERO Entry Is Strict
                                	**type**\:  bool
                                
                                .. attribute:: prefix_length
                                
                                	ERO Prefix Length
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ip-rsvp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.Ero.Ipv4EroSubObject, self).__init__()

                                    self.yang_name = "ipv4ero-sub-object"
                                    self.yang_parent_name = "ero"

                                    self.ero_address = YLeaf(YType.str, "ero-address")

                                    self.is_strict_route = YLeaf(YType.boolean, "is-strict-route")

                                    self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("ero_address",
                                                    "is_strict_route",
                                                    "prefix_length") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.Ero.Ipv4EroSubObject, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.Ero.Ipv4EroSubObject, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.ero_address.is_set or
                                        self.is_strict_route.is_set or
                                        self.prefix_length.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.ero_address.yfilter != YFilter.not_set or
                                        self.is_strict_route.yfilter != YFilter.not_set or
                                        self.prefix_length.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "ipv4ero-sub-object" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/psb-rsb-info/psb-info/reverse-lsp/ero/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.ero_address.is_set or self.ero_address.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ero_address.get_name_leafdata())
                                    if (self.is_strict_route.is_set or self.is_strict_route.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_strict_route.get_name_leafdata())
                                    if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.prefix_length.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "ero-address" or name == "is-strict-route" or name == "prefix-length"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "ero-address"):
                                        self.ero_address = value
                                        self.ero_address.value_namespace = name_space
                                        self.ero_address.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-strict-route"):
                                        self.is_strict_route = value
                                        self.is_strict_route.value_namespace = name_space
                                        self.is_strict_route.value_namespace_prefix = name_space_prefix
                                    if(value_path == "prefix-length"):
                                        self.prefix_length = value
                                        self.prefix_length.value_namespace = name_space
                                        self.prefix_length.value_namespace_prefix = name_space_prefix


                            class UnnumberedEroSubObject(Entity):
                                """
                                Unnumbered ERO Sub Object
                                
                                .. attribute:: ero_interface_id
                                
                                	The Interface ID in ERO
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ero_router_id
                                
                                	The Router ID in ERO
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: is_strict_route
                                
                                	ERO Entry Is Strict
                                	**type**\:  bool
                                
                                .. attribute:: status
                                
                                	Status of ERO
                                	**type**\:   :py:class:`RsvpMgmtEroSubobjStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtEroSubobjStatus>`
                                
                                

                                """

                                _prefix = 'ip-rsvp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.Ero.UnnumberedEroSubObject, self).__init__()

                                    self.yang_name = "unnumbered-ero-sub-object"
                                    self.yang_parent_name = "ero"

                                    self.ero_interface_id = YLeaf(YType.uint32, "ero-interface-id")

                                    self.ero_router_id = YLeaf(YType.str, "ero-router-id")

                                    self.is_strict_route = YLeaf(YType.boolean, "is-strict-route")

                                    self.status = YLeaf(YType.enumeration, "status")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("ero_interface_id",
                                                    "ero_router_id",
                                                    "is_strict_route",
                                                    "status") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.Ero.UnnumberedEroSubObject, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.Ero.UnnumberedEroSubObject, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.ero_interface_id.is_set or
                                        self.ero_router_id.is_set or
                                        self.is_strict_route.is_set or
                                        self.status.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.ero_interface_id.yfilter != YFilter.not_set or
                                        self.ero_router_id.yfilter != YFilter.not_set or
                                        self.is_strict_route.yfilter != YFilter.not_set or
                                        self.status.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "unnumbered-ero-sub-object" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/psb-rsb-info/psb-info/reverse-lsp/ero/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.ero_interface_id.is_set or self.ero_interface_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ero_interface_id.get_name_leafdata())
                                    if (self.ero_router_id.is_set or self.ero_router_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.ero_router_id.get_name_leafdata())
                                    if (self.is_strict_route.is_set or self.is_strict_route.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_strict_route.get_name_leafdata())
                                    if (self.status.is_set or self.status.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.status.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "ero-interface-id" or name == "ero-router-id" or name == "is-strict-route" or name == "status"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "ero-interface-id"):
                                        self.ero_interface_id = value
                                        self.ero_interface_id.value_namespace = name_space
                                        self.ero_interface_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "ero-router-id"):
                                        self.ero_router_id = value
                                        self.ero_router_id.value_namespace = name_space
                                        self.ero_router_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-strict-route"):
                                        self.is_strict_route = value
                                        self.is_strict_route.value_namespace = name_space
                                        self.is_strict_route.value_namespace_prefix = name_space_prefix
                                    if(value_path == "status"):
                                        self.status = value
                                        self.status.value_namespace = name_space
                                        self.status.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.ero_type.is_set or
                                    (self.ipv4ero_sub_object is not None and self.ipv4ero_sub_object.has_data()) or
                                    (self.unnumbered_ero_sub_object is not None and self.unnumbered_ero_sub_object.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ero_type.yfilter != YFilter.not_set or
                                    (self.ipv4ero_sub_object is not None and self.ipv4ero_sub_object.has_operation()) or
                                    (self.unnumbered_ero_sub_object is not None and self.unnumbered_ero_sub_object.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ero" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/psb-rsb-info/psb-info/reverse-lsp/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ero_type.is_set or self.ero_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ero_type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "ipv4ero-sub-object"):
                                    if (self.ipv4ero_sub_object is None):
                                        self.ipv4ero_sub_object = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.Ero.Ipv4EroSubObject()
                                        self.ipv4ero_sub_object.parent = self
                                        self._children_name_map["ipv4ero_sub_object"] = "ipv4ero-sub-object"
                                    return self.ipv4ero_sub_object

                                if (child_yang_name == "unnumbered-ero-sub-object"):
                                    if (self.unnumbered_ero_sub_object is None):
                                        self.unnumbered_ero_sub_object = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.Ero.UnnumberedEroSubObject()
                                        self.unnumbered_ero_sub_object.parent = self
                                        self._children_name_map["unnumbered_ero_sub_object"] = "unnumbered-ero-sub-object"
                                    return self.unnumbered_ero_sub_object

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ipv4ero-sub-object" or name == "unnumbered-ero-sub-object" or name == "ero-type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ero-type"):
                                    self.ero_type = value
                                    self.ero_type.value_namespace = name_space
                                    self.ero_type.value_namespace_prefix = name_space_prefix


                        class UnsupSubObject(Entity):
                            """
                            Unsupported REVERSE\_LSP Sub Objects
                            
                            .. attribute:: rsvp_mgmt_rev_lsp_unsupported_subobj
                            
                            	rsvp mgmt rev lsp unsupported subobj
                            	**type**\:  list of int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.UnsupSubObject, self).__init__()

                                self.yang_name = "unsup-sub-object"
                                self.yang_parent_name = "reverse-lsp"

                                self.rsvp_mgmt_rev_lsp_unsupported_subobj = YLeafList(YType.uint8, "rsvp-mgmt-rev-lsp-unsupported-subobj")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("rsvp_mgmt_rev_lsp_unsupported_subobj") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.UnsupSubObject, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.UnsupSubObject, self).__setattr__(name, value)

                            def has_data(self):
                                for leaf in self.rsvp_mgmt_rev_lsp_unsupported_subobj.getYLeafs():
                                    if (leaf.yfilter != YFilter.not_set):
                                        return True
                                return False

                            def has_operation(self):
                                for leaf in self.rsvp_mgmt_rev_lsp_unsupported_subobj.getYLeafs():
                                    if (leaf.is_set):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.rsvp_mgmt_rev_lsp_unsupported_subobj.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "unsup-sub-object" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/psb-rsb-info/psb-info/reverse-lsp/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                leaf_name_data.extend(self.rsvp_mgmt_rev_lsp_unsupported_subobj.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "rsvp-mgmt-rev-lsp-unsupported-subobj"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "rsvp-mgmt-rev-lsp-unsupported-subobj"):
                                    self.rsvp_mgmt_rev_lsp_unsupported_subobj.append(value)

                        def has_data(self):
                            for c in self.ero:
                                if (c.has_data()):
                                    return True
                            for c in self.unsup_sub_object:
                                if (c.has_data()):
                                    return True
                            return (self.generic_traffic_spec is not None and self.generic_traffic_spec.has_data())

                        def has_operation(self):
                            for c in self.ero:
                                if (c.has_operation()):
                                    return True
                            for c in self.unsup_sub_object:
                                if (c.has_operation()):
                                    return True
                            return (
                                self.yfilter != YFilter.not_set or
                                (self.generic_traffic_spec is not None and self.generic_traffic_spec.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "reverse-lsp" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/psb-rsb-info/psb-info/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "ero"):
                                for c in self.ero:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.Ero()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.ero.append(c)
                                return c

                            if (child_yang_name == "generic-traffic-spec"):
                                if (self.generic_traffic_spec is None):
                                    self.generic_traffic_spec = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.GenericTrafficSpec()
                                    self.generic_traffic_spec.parent = self
                                    self._children_name_map["generic_traffic_spec"] = "generic-traffic-spec"
                                return self.generic_traffic_spec

                            if (child_yang_name == "unsup-sub-object"):
                                for c in self.unsup_sub_object:
                                    segment = c.get_segment_path()
                                    if (segment_path == segment):
                                        return c
                                c = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp.UnsupSubObject()
                                c.parent = self
                                local_reference_key = "ydk::seg::%s" % segment_path
                                self._local_refs[local_reference_key] = c
                                self.unsup_sub_object.append(c)
                                return c

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ero" or name == "generic-traffic-spec" or name == "unsup-sub-object"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            pass


                    class Ero(Entity):
                        """
                        Explicit Route Sub Objects
                        
                        .. attribute:: ero_type
                        
                        	EROType
                        	**type**\:   :py:class:`RsvpMgmtEroSubobj <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtEroSubobj>`
                        
                        .. attribute:: ipv4ero_sub_object
                        
                        	IPV4 ERO Sub Object
                        	**type**\:   :py:class:`Ipv4EroSubObject <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Ero.Ipv4EroSubObject>`
                        
                        .. attribute:: unnumbered_ero_sub_object
                        
                        	Unnumbered ERO Sub Object
                        	**type**\:   :py:class:`UnnumberedEroSubObject <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Ero.UnnumberedEroSubObject>`
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Ero, self).__init__()

                            self.yang_name = "ero"
                            self.yang_parent_name = "psb-info"

                            self.ero_type = YLeaf(YType.enumeration, "ero-type")

                            self.ipv4ero_sub_object = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Ero.Ipv4EroSubObject()
                            self.ipv4ero_sub_object.parent = self
                            self._children_name_map["ipv4ero_sub_object"] = "ipv4ero-sub-object"
                            self._children_yang_names.add("ipv4ero-sub-object")

                            self.unnumbered_ero_sub_object = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Ero.UnnumberedEroSubObject()
                            self.unnumbered_ero_sub_object.parent = self
                            self._children_name_map["unnumbered_ero_sub_object"] = "unnumbered-ero-sub-object"
                            self._children_yang_names.add("unnumbered-ero-sub-object")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("ero_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Ero, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Ero, self).__setattr__(name, value)


                        class Ipv4EroSubObject(Entity):
                            """
                            IPV4 ERO Sub Object
                            
                            .. attribute:: ero_address
                            
                            	The ERO IPV4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: is_strict_route
                            
                            	ERO Entry Is Strict
                            	**type**\:  bool
                            
                            .. attribute:: prefix_length
                            
                            	ERO Prefix Length
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Ero.Ipv4EroSubObject, self).__init__()

                                self.yang_name = "ipv4ero-sub-object"
                                self.yang_parent_name = "ero"

                                self.ero_address = YLeaf(YType.str, "ero-address")

                                self.is_strict_route = YLeaf(YType.boolean, "is-strict-route")

                                self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ero_address",
                                                "is_strict_route",
                                                "prefix_length") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Ero.Ipv4EroSubObject, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Ero.Ipv4EroSubObject, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.ero_address.is_set or
                                    self.is_strict_route.is_set or
                                    self.prefix_length.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ero_address.yfilter != YFilter.not_set or
                                    self.is_strict_route.yfilter != YFilter.not_set or
                                    self.prefix_length.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ipv4ero-sub-object" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/psb-rsb-info/psb-info/ero/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ero_address.is_set or self.ero_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ero_address.get_name_leafdata())
                                if (self.is_strict_route.is_set or self.is_strict_route.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_strict_route.get_name_leafdata())
                                if (self.prefix_length.is_set or self.prefix_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.prefix_length.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ero-address" or name == "is-strict-route" or name == "prefix-length"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ero-address"):
                                    self.ero_address = value
                                    self.ero_address.value_namespace = name_space
                                    self.ero_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-strict-route"):
                                    self.is_strict_route = value
                                    self.is_strict_route.value_namespace = name_space
                                    self.is_strict_route.value_namespace_prefix = name_space_prefix
                                if(value_path == "prefix-length"):
                                    self.prefix_length = value
                                    self.prefix_length.value_namespace = name_space
                                    self.prefix_length.value_namespace_prefix = name_space_prefix


                        class UnnumberedEroSubObject(Entity):
                            """
                            Unnumbered ERO Sub Object
                            
                            .. attribute:: ero_interface_id
                            
                            	The Interface ID in ERO
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ero_router_id
                            
                            	The Router ID in ERO
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: is_strict_route
                            
                            	ERO Entry Is Strict
                            	**type**\:  bool
                            
                            .. attribute:: status
                            
                            	Status of ERO
                            	**type**\:   :py:class:`RsvpMgmtEroSubobjStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtEroSubobjStatus>`
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Ero.UnnumberedEroSubObject, self).__init__()

                                self.yang_name = "unnumbered-ero-sub-object"
                                self.yang_parent_name = "ero"

                                self.ero_interface_id = YLeaf(YType.uint32, "ero-interface-id")

                                self.ero_router_id = YLeaf(YType.str, "ero-router-id")

                                self.is_strict_route = YLeaf(YType.boolean, "is-strict-route")

                                self.status = YLeaf(YType.enumeration, "status")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("ero_interface_id",
                                                "ero_router_id",
                                                "is_strict_route",
                                                "status") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Ero.UnnumberedEroSubObject, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Ero.UnnumberedEroSubObject, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.ero_interface_id.is_set or
                                    self.ero_router_id.is_set or
                                    self.is_strict_route.is_set or
                                    self.status.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.ero_interface_id.yfilter != YFilter.not_set or
                                    self.ero_router_id.yfilter != YFilter.not_set or
                                    self.is_strict_route.yfilter != YFilter.not_set or
                                    self.status.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "unnumbered-ero-sub-object" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/psb-rsb-info/psb-info/ero/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.ero_interface_id.is_set or self.ero_interface_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ero_interface_id.get_name_leafdata())
                                if (self.ero_router_id.is_set or self.ero_router_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.ero_router_id.get_name_leafdata())
                                if (self.is_strict_route.is_set or self.is_strict_route.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_strict_route.get_name_leafdata())
                                if (self.status.is_set or self.status.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.status.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "ero-interface-id" or name == "ero-router-id" or name == "is-strict-route" or name == "status"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "ero-interface-id"):
                                    self.ero_interface_id = value
                                    self.ero_interface_id.value_namespace = name_space
                                    self.ero_interface_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "ero-router-id"):
                                    self.ero_router_id = value
                                    self.ero_router_id.value_namespace = name_space
                                    self.ero_router_id.value_namespace_prefix = name_space_prefix
                                if(value_path == "is-strict-route"):
                                    self.is_strict_route = value
                                    self.is_strict_route.value_namespace = name_space
                                    self.is_strict_route.value_namespace_prefix = name_space_prefix
                                if(value_path == "status"):
                                    self.status = value
                                    self.status.value_namespace = name_space
                                    self.status.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.ero_type.is_set or
                                (self.ipv4ero_sub_object is not None and self.ipv4ero_sub_object.has_data()) or
                                (self.unnumbered_ero_sub_object is not None and self.unnumbered_ero_sub_object.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.ero_type.yfilter != YFilter.not_set or
                                (self.ipv4ero_sub_object is not None and self.ipv4ero_sub_object.has_operation()) or
                                (self.unnumbered_ero_sub_object is not None and self.unnumbered_ero_sub_object.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ero" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/psb-rsb-info/psb-info/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.ero_type.is_set or self.ero_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.ero_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "ipv4ero-sub-object"):
                                if (self.ipv4ero_sub_object is None):
                                    self.ipv4ero_sub_object = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Ero.Ipv4EroSubObject()
                                    self.ipv4ero_sub_object.parent = self
                                    self._children_name_map["ipv4ero_sub_object"] = "ipv4ero-sub-object"
                                return self.ipv4ero_sub_object

                            if (child_yang_name == "unnumbered-ero-sub-object"):
                                if (self.unnumbered_ero_sub_object is None):
                                    self.unnumbered_ero_sub_object = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Ero.UnnumberedEroSubObject()
                                    self.unnumbered_ero_sub_object.parent = self
                                    self._children_name_map["unnumbered_ero_sub_object"] = "unnumbered-ero-sub-object"
                                return self.unnumbered_ero_sub_object

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ipv4ero-sub-object" or name == "unnumbered-ero-sub-object" or name == "ero-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "ero-type"):
                                self.ero_type = value
                                self.ero_type.value_namespace = name_space
                                self.ero_type.value_namespace_prefix = name_space_prefix


                    class Rro(Entity):
                        """
                        Record Route Sub Objects
                        
                        .. attribute:: ipv4rro_sub_object
                        
                        	IPV4 RRO Sub Object
                        	**type**\:   :py:class:`Ipv4RroSubObject <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.Ipv4RroSubObject>`
                        
                        .. attribute:: label_rro_sub_object
                        
                        	Label RRO Sub Object
                        	**type**\:   :py:class:`LabelRroSubObject <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.LabelRroSubObject>`
                        
                        .. attribute:: rro_type
                        
                        	RROType
                        	**type**\:   :py:class:`RsvpMgmtRroSubobj <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtRroSubobj>`
                        
                        .. attribute:: srlg_rro_sub_object
                        
                        	SRLG RRO Sub Object
                        	**type**\:   :py:class:`SrlgRroSubObject <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.SrlgRroSubObject>`
                        
                        .. attribute:: unnumbered_rro_sub_object
                        
                        	Unnumbered RRO Sub Object
                        	**type**\:   :py:class:`UnnumberedRroSubObject <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.UnnumberedRroSubObject>`
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro, self).__init__()

                            self.yang_name = "rro"
                            self.yang_parent_name = "psb-info"

                            self.rro_type = YLeaf(YType.enumeration, "rro-type")

                            self.ipv4rro_sub_object = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.Ipv4RroSubObject()
                            self.ipv4rro_sub_object.parent = self
                            self._children_name_map["ipv4rro_sub_object"] = "ipv4rro-sub-object"
                            self._children_yang_names.add("ipv4rro-sub-object")

                            self.label_rro_sub_object = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.LabelRroSubObject()
                            self.label_rro_sub_object.parent = self
                            self._children_name_map["label_rro_sub_object"] = "label-rro-sub-object"
                            self._children_yang_names.add("label-rro-sub-object")

                            self.srlg_rro_sub_object = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.SrlgRroSubObject()
                            self.srlg_rro_sub_object.parent = self
                            self._children_name_map["srlg_rro_sub_object"] = "srlg-rro-sub-object"
                            self._children_yang_names.add("srlg-rro-sub-object")

                            self.unnumbered_rro_sub_object = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.UnnumberedRroSubObject()
                            self.unnumbered_rro_sub_object.parent = self
                            self._children_name_map["unnumbered_rro_sub_object"] = "unnumbered-rro-sub-object"
                            self._children_yang_names.add("unnumbered-rro-sub-object")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("rro_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro, self).__setattr__(name, value)


                        class Ipv4RroSubObject(Entity):
                            """
                            IPV4 RRO Sub Object
                            
                            .. attribute:: flags
                            
                            	The RRO IPV4 Subobject Flags
                            	**type**\:   :py:class:`Flags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.Ipv4RroSubObject.Flags>`
                            
                            .. attribute:: rro_address
                            
                            	The RRO IPV4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.Ipv4RroSubObject, self).__init__()

                                self.yang_name = "ipv4rro-sub-object"
                                self.yang_parent_name = "rro"

                                self.rro_address = YLeaf(YType.str, "rro-address")

                                self.flags = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.Ipv4RroSubObject.Flags()
                                self.flags.parent = self
                                self._children_name_map["flags"] = "flags"
                                self._children_yang_names.add("flags")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("rro_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.Ipv4RroSubObject, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.Ipv4RroSubObject, self).__setattr__(name, value)


                            class Flags(Entity):
                                """
                                The RRO IPV4 Subobject Flags
                                
                                .. attribute:: is_bandwidth_protected
                                
                                	Bandwidth Protection Available
                                	**type**\:  bool
                                
                                .. attribute:: is_node_id
                                
                                	Node ID In Use
                                	**type**\:  bool
                                
                                .. attribute:: is_node_protection_available
                                
                                	Node Protection Available
                                	**type**\:  bool
                                
                                .. attribute:: is_protection_available
                                
                                	Local Protection Available
                                	**type**\:  bool
                                
                                .. attribute:: is_protection_in_use
                                
                                	Local Protection In Use
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ip-rsvp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.Ipv4RroSubObject.Flags, self).__init__()

                                    self.yang_name = "flags"
                                    self.yang_parent_name = "ipv4rro-sub-object"

                                    self.is_bandwidth_protected = YLeaf(YType.boolean, "is-bandwidth-protected")

                                    self.is_node_id = YLeaf(YType.boolean, "is-node-id")

                                    self.is_node_protection_available = YLeaf(YType.boolean, "is-node-protection-available")

                                    self.is_protection_available = YLeaf(YType.boolean, "is-protection-available")

                                    self.is_protection_in_use = YLeaf(YType.boolean, "is-protection-in-use")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("is_bandwidth_protected",
                                                    "is_node_id",
                                                    "is_node_protection_available",
                                                    "is_protection_available",
                                                    "is_protection_in_use") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.Ipv4RroSubObject.Flags, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.Ipv4RroSubObject.Flags, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.is_bandwidth_protected.is_set or
                                        self.is_node_id.is_set or
                                        self.is_node_protection_available.is_set or
                                        self.is_protection_available.is_set or
                                        self.is_protection_in_use.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.is_bandwidth_protected.yfilter != YFilter.not_set or
                                        self.is_node_id.yfilter != YFilter.not_set or
                                        self.is_node_protection_available.yfilter != YFilter.not_set or
                                        self.is_protection_available.yfilter != YFilter.not_set or
                                        self.is_protection_in_use.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "flags" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/psb-rsb-info/psb-info/rro/ipv4rro-sub-object/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.is_bandwidth_protected.is_set or self.is_bandwidth_protected.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_bandwidth_protected.get_name_leafdata())
                                    if (self.is_node_id.is_set or self.is_node_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_node_id.get_name_leafdata())
                                    if (self.is_node_protection_available.is_set or self.is_node_protection_available.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_node_protection_available.get_name_leafdata())
                                    if (self.is_protection_available.is_set or self.is_protection_available.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_protection_available.get_name_leafdata())
                                    if (self.is_protection_in_use.is_set or self.is_protection_in_use.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_protection_in_use.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "is-bandwidth-protected" or name == "is-node-id" or name == "is-node-protection-available" or name == "is-protection-available" or name == "is-protection-in-use"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "is-bandwidth-protected"):
                                        self.is_bandwidth_protected = value
                                        self.is_bandwidth_protected.value_namespace = name_space
                                        self.is_bandwidth_protected.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-node-id"):
                                        self.is_node_id = value
                                        self.is_node_id.value_namespace = name_space
                                        self.is_node_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-node-protection-available"):
                                        self.is_node_protection_available = value
                                        self.is_node_protection_available.value_namespace = name_space
                                        self.is_node_protection_available.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-protection-available"):
                                        self.is_protection_available = value
                                        self.is_protection_available.value_namespace = name_space
                                        self.is_protection_available.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-protection-in-use"):
                                        self.is_protection_in_use = value
                                        self.is_protection_in_use.value_namespace = name_space
                                        self.is_protection_in_use.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.rro_address.is_set or
                                    (self.flags is not None and self.flags.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.rro_address.yfilter != YFilter.not_set or
                                    (self.flags is not None and self.flags.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ipv4rro-sub-object" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/psb-rsb-info/psb-info/rro/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.rro_address.is_set or self.rro_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rro_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "flags"):
                                    if (self.flags is None):
                                        self.flags = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.Ipv4RroSubObject.Flags()
                                        self.flags.parent = self
                                        self._children_name_map["flags"] = "flags"
                                    return self.flags

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "flags" or name == "rro-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "rro-address"):
                                    self.rro_address = value
                                    self.rro_address.value_namespace = name_space
                                    self.rro_address.value_namespace_prefix = name_space_prefix


                        class LabelRroSubObject(Entity):
                            """
                            Label RRO Sub Object
                            
                            .. attribute:: flags
                            
                            	The RRO Subobject Label Flags
                            	**type**\:   :py:class:`Flags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.LabelRroSubObject.Flags>`
                            
                            .. attribute:: is_label_variable_length
                            
                            	Is the RRO Subobject Label Variable Length
                            	**type**\:  bool
                            
                            .. attribute:: label
                            
                            	The RRO Subobject Label Value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: variable_length_label
                            
                            	The RRO Subobject Variable Length Label
                            	**type**\:  list of int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.LabelRroSubObject, self).__init__()

                                self.yang_name = "label-rro-sub-object"
                                self.yang_parent_name = "rro"

                                self.is_label_variable_length = YLeaf(YType.boolean, "is-label-variable-length")

                                self.label = YLeaf(YType.uint32, "label")

                                self.variable_length_label = YLeafList(YType.uint32, "variable-length-label")

                                self.flags = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.LabelRroSubObject.Flags()
                                self.flags.parent = self
                                self._children_name_map["flags"] = "flags"
                                self._children_yang_names.add("flags")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("is_label_variable_length",
                                                "label",
                                                "variable_length_label") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.LabelRroSubObject, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.LabelRroSubObject, self).__setattr__(name, value)


                            class Flags(Entity):
                                """
                                The RRO Subobject Label Flags
                                
                                .. attribute:: is_global_label
                                
                                	Label is Global across all interfaces
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ip-rsvp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.LabelRroSubObject.Flags, self).__init__()

                                    self.yang_name = "flags"
                                    self.yang_parent_name = "label-rro-sub-object"

                                    self.is_global_label = YLeaf(YType.boolean, "is-global-label")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("is_global_label") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.LabelRroSubObject.Flags, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.LabelRroSubObject.Flags, self).__setattr__(name, value)

                                def has_data(self):
                                    return self.is_global_label.is_set

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.is_global_label.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "flags" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/psb-rsb-info/psb-info/rro/label-rro-sub-object/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.is_global_label.is_set or self.is_global_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_global_label.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "is-global-label"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "is-global-label"):
                                        self.is_global_label = value
                                        self.is_global_label.value_namespace = name_space
                                        self.is_global_label.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for leaf in self.variable_length_label.getYLeafs():
                                    if (leaf.yfilter != YFilter.not_set):
                                        return True
                                return (
                                    self.is_label_variable_length.is_set or
                                    self.label.is_set or
                                    (self.flags is not None and self.flags.has_data()))

                            def has_operation(self):
                                for leaf in self.variable_length_label.getYLeafs():
                                    if (leaf.is_set):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.is_label_variable_length.yfilter != YFilter.not_set or
                                    self.label.yfilter != YFilter.not_set or
                                    self.variable_length_label.yfilter != YFilter.not_set or
                                    (self.flags is not None and self.flags.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "label-rro-sub-object" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/psb-rsb-info/psb-info/rro/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.is_label_variable_length.is_set or self.is_label_variable_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_label_variable_length.get_name_leafdata())
                                if (self.label.is_set or self.label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.label.get_name_leafdata())

                                leaf_name_data.extend(self.variable_length_label.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "flags"):
                                    if (self.flags is None):
                                        self.flags = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.LabelRroSubObject.Flags()
                                        self.flags.parent = self
                                        self._children_name_map["flags"] = "flags"
                                    return self.flags

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "flags" or name == "is-label-variable-length" or name == "label" or name == "variable-length-label"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "is-label-variable-length"):
                                    self.is_label_variable_length = value
                                    self.is_label_variable_length.value_namespace = name_space
                                    self.is_label_variable_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "label"):
                                    self.label = value
                                    self.label.value_namespace = name_space
                                    self.label.value_namespace_prefix = name_space_prefix
                                if(value_path == "variable-length-label"):
                                    self.variable_length_label.append(value)


                        class UnnumberedRroSubObject(Entity):
                            """
                            Unnumbered RRO Sub Object
                            
                            .. attribute:: flags
                            
                            	The RRO Subobject Unnumbered Flags
                            	**type**\:   :py:class:`Flags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.UnnumberedRroSubObject.Flags>`
                            
                            .. attribute:: interface_address
                            
                            	The RRO Interface Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: interface_id
                            
                            	The RRO Interface ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.UnnumberedRroSubObject, self).__init__()

                                self.yang_name = "unnumbered-rro-sub-object"
                                self.yang_parent_name = "rro"

                                self.interface_address = YLeaf(YType.str, "interface-address")

                                self.interface_id = YLeaf(YType.uint32, "interface-id")

                                self.flags = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.UnnumberedRroSubObject.Flags()
                                self.flags.parent = self
                                self._children_name_map["flags"] = "flags"
                                self._children_yang_names.add("flags")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("interface_address",
                                                "interface_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.UnnumberedRroSubObject, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.UnnumberedRroSubObject, self).__setattr__(name, value)


                            class Flags(Entity):
                                """
                                The RRO Subobject Unnumbered Flags
                                
                                .. attribute:: is_bandwidth_protected
                                
                                	Bandwidth Protection Available
                                	**type**\:  bool
                                
                                .. attribute:: is_node_id
                                
                                	Node ID In Use
                                	**type**\:  bool
                                
                                .. attribute:: is_node_protection_available
                                
                                	Node Protection Available
                                	**type**\:  bool
                                
                                .. attribute:: is_protection_available
                                
                                	Local Protection Available
                                	**type**\:  bool
                                
                                .. attribute:: is_protection_in_use
                                
                                	Local Protection In Use
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ip-rsvp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.UnnumberedRroSubObject.Flags, self).__init__()

                                    self.yang_name = "flags"
                                    self.yang_parent_name = "unnumbered-rro-sub-object"

                                    self.is_bandwidth_protected = YLeaf(YType.boolean, "is-bandwidth-protected")

                                    self.is_node_id = YLeaf(YType.boolean, "is-node-id")

                                    self.is_node_protection_available = YLeaf(YType.boolean, "is-node-protection-available")

                                    self.is_protection_available = YLeaf(YType.boolean, "is-protection-available")

                                    self.is_protection_in_use = YLeaf(YType.boolean, "is-protection-in-use")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("is_bandwidth_protected",
                                                    "is_node_id",
                                                    "is_node_protection_available",
                                                    "is_protection_available",
                                                    "is_protection_in_use") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.UnnumberedRroSubObject.Flags, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.UnnumberedRroSubObject.Flags, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.is_bandwidth_protected.is_set or
                                        self.is_node_id.is_set or
                                        self.is_node_protection_available.is_set or
                                        self.is_protection_available.is_set or
                                        self.is_protection_in_use.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.is_bandwidth_protected.yfilter != YFilter.not_set or
                                        self.is_node_id.yfilter != YFilter.not_set or
                                        self.is_node_protection_available.yfilter != YFilter.not_set or
                                        self.is_protection_available.yfilter != YFilter.not_set or
                                        self.is_protection_in_use.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "flags" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/psb-rsb-info/psb-info/rro/unnumbered-rro-sub-object/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.is_bandwidth_protected.is_set or self.is_bandwidth_protected.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_bandwidth_protected.get_name_leafdata())
                                    if (self.is_node_id.is_set or self.is_node_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_node_id.get_name_leafdata())
                                    if (self.is_node_protection_available.is_set or self.is_node_protection_available.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_node_protection_available.get_name_leafdata())
                                    if (self.is_protection_available.is_set or self.is_protection_available.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_protection_available.get_name_leafdata())
                                    if (self.is_protection_in_use.is_set or self.is_protection_in_use.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_protection_in_use.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "is-bandwidth-protected" or name == "is-node-id" or name == "is-node-protection-available" or name == "is-protection-available" or name == "is-protection-in-use"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "is-bandwidth-protected"):
                                        self.is_bandwidth_protected = value
                                        self.is_bandwidth_protected.value_namespace = name_space
                                        self.is_bandwidth_protected.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-node-id"):
                                        self.is_node_id = value
                                        self.is_node_id.value_namespace = name_space
                                        self.is_node_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-node-protection-available"):
                                        self.is_node_protection_available = value
                                        self.is_node_protection_available.value_namespace = name_space
                                        self.is_node_protection_available.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-protection-available"):
                                        self.is_protection_available = value
                                        self.is_protection_available.value_namespace = name_space
                                        self.is_protection_available.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-protection-in-use"):
                                        self.is_protection_in_use = value
                                        self.is_protection_in_use.value_namespace = name_space
                                        self.is_protection_in_use.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.interface_address.is_set or
                                    self.interface_id.is_set or
                                    (self.flags is not None and self.flags.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.interface_address.yfilter != YFilter.not_set or
                                    self.interface_id.yfilter != YFilter.not_set or
                                    (self.flags is not None and self.flags.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "unnumbered-rro-sub-object" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/psb-rsb-info/psb-info/rro/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.interface_address.is_set or self.interface_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_address.get_name_leafdata())
                                if (self.interface_id.is_set or self.interface_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "flags"):
                                    if (self.flags is None):
                                        self.flags = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.UnnumberedRroSubObject.Flags()
                                        self.flags.parent = self
                                        self._children_name_map["flags"] = "flags"
                                    return self.flags

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "flags" or name == "interface-address" or name == "interface-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "interface-address"):
                                    self.interface_address = value
                                    self.interface_address.value_namespace = name_space
                                    self.interface_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-id"):
                                    self.interface_id = value
                                    self.interface_id.value_namespace = name_space
                                    self.interface_id.value_namespace_prefix = name_space_prefix


                        class SrlgRroSubObject(Entity):
                            """
                            SRLG RRO Sub Object
                            
                            .. attribute:: srl_gs
                            
                            	The RRO Subobject SRLGs
                            	**type**\:  list of int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.SrlgRroSubObject, self).__init__()

                                self.yang_name = "srlg-rro-sub-object"
                                self.yang_parent_name = "rro"

                                self.srl_gs = YLeafList(YType.uint32, "srl-gs")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("srl_gs") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.SrlgRroSubObject, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.SrlgRroSubObject, self).__setattr__(name, value)

                            def has_data(self):
                                for leaf in self.srl_gs.getYLeafs():
                                    if (leaf.yfilter != YFilter.not_set):
                                        return True
                                return False

                            def has_operation(self):
                                for leaf in self.srl_gs.getYLeafs():
                                    if (leaf.is_set):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.srl_gs.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "srlg-rro-sub-object" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/psb-rsb-info/psb-info/rro/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                leaf_name_data.extend(self.srl_gs.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "srl-gs"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "srl-gs"):
                                    self.srl_gs.append(value)

                        def has_data(self):
                            return (
                                self.rro_type.is_set or
                                (self.ipv4rro_sub_object is not None and self.ipv4rro_sub_object.has_data()) or
                                (self.label_rro_sub_object is not None and self.label_rro_sub_object.has_data()) or
                                (self.srlg_rro_sub_object is not None and self.srlg_rro_sub_object.has_data()) or
                                (self.unnumbered_rro_sub_object is not None and self.unnumbered_rro_sub_object.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.rro_type.yfilter != YFilter.not_set or
                                (self.ipv4rro_sub_object is not None and self.ipv4rro_sub_object.has_operation()) or
                                (self.label_rro_sub_object is not None and self.label_rro_sub_object.has_operation()) or
                                (self.srlg_rro_sub_object is not None and self.srlg_rro_sub_object.has_operation()) or
                                (self.unnumbered_rro_sub_object is not None and self.unnumbered_rro_sub_object.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rro" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/psb-rsb-info/psb-info/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.rro_type.is_set or self.rro_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rro_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "ipv4rro-sub-object"):
                                if (self.ipv4rro_sub_object is None):
                                    self.ipv4rro_sub_object = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.Ipv4RroSubObject()
                                    self.ipv4rro_sub_object.parent = self
                                    self._children_name_map["ipv4rro_sub_object"] = "ipv4rro-sub-object"
                                return self.ipv4rro_sub_object

                            if (child_yang_name == "label-rro-sub-object"):
                                if (self.label_rro_sub_object is None):
                                    self.label_rro_sub_object = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.LabelRroSubObject()
                                    self.label_rro_sub_object.parent = self
                                    self._children_name_map["label_rro_sub_object"] = "label-rro-sub-object"
                                return self.label_rro_sub_object

                            if (child_yang_name == "srlg-rro-sub-object"):
                                if (self.srlg_rro_sub_object is None):
                                    self.srlg_rro_sub_object = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.SrlgRroSubObject()
                                    self.srlg_rro_sub_object.parent = self
                                    self._children_name_map["srlg_rro_sub_object"] = "srlg-rro-sub-object"
                                return self.srlg_rro_sub_object

                            if (child_yang_name == "unnumbered-rro-sub-object"):
                                if (self.unnumbered_rro_sub_object is None):
                                    self.unnumbered_rro_sub_object = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro.UnnumberedRroSubObject()
                                    self.unnumbered_rro_sub_object.parent = self
                                    self._children_name_map["unnumbered_rro_sub_object"] = "unnumbered-rro-sub-object"
                                return self.unnumbered_rro_sub_object

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ipv4rro-sub-object" or name == "label-rro-sub-object" or name == "srlg-rro-sub-object" or name == "unnumbered-rro-sub-object" or name == "rro-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "rro-type"):
                                self.rro_type = value
                                self.rro_type.value_namespace = name_space
                                self.rro_type.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.ero:
                            if (c.has_data()):
                                return True
                        for c in self.rro:
                            if (c.has_data()):
                                return True
                        return (
                            self.destination_address.is_set or
                            self.in_interface.is_set or
                            self.in_label.is_set or
                            self.incoming_interface_address.is_set or
                            self.is_bad_address.is_set or
                            self.is_ero_valid.is_set or
                            self.is_rro_valid.is_set or
                            self.is_traffic_spec_valid.is_set or
                            self.is_valid.is_set or
                            self.lsp_id.is_set or
                            self.lsp_wrap_label.is_set or
                            self.p2mp_sub_group_origin.is_set or
                            self.sub_group_id.is_set or
                            self.tunnel_name.is_set or
                            (self.association is not None and self.association.has_data()) or
                            (self.generic_in_label is not None and self.generic_in_label.has_data()) or
                            (self.generic_traffic_spec is not None and self.generic_traffic_spec.has_data()) or
                            (self.protection is not None and self.protection.has_data()) or
                            (self.reverse_lsp is not None and self.reverse_lsp.has_data()) or
                            (self.traffic_spec is not None and self.traffic_spec.has_data()))

                    def has_operation(self):
                        for c in self.ero:
                            if (c.has_operation()):
                                return True
                        for c in self.rro:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.destination_address.yfilter != YFilter.not_set or
                            self.in_interface.yfilter != YFilter.not_set or
                            self.in_label.yfilter != YFilter.not_set or
                            self.incoming_interface_address.yfilter != YFilter.not_set or
                            self.is_bad_address.yfilter != YFilter.not_set or
                            self.is_ero_valid.yfilter != YFilter.not_set or
                            self.is_rro_valid.yfilter != YFilter.not_set or
                            self.is_traffic_spec_valid.yfilter != YFilter.not_set or
                            self.is_valid.yfilter != YFilter.not_set or
                            self.lsp_id.yfilter != YFilter.not_set or
                            self.lsp_wrap_label.yfilter != YFilter.not_set or
                            self.p2mp_sub_group_origin.yfilter != YFilter.not_set or
                            self.sub_group_id.yfilter != YFilter.not_set or
                            self.tunnel_name.yfilter != YFilter.not_set or
                            (self.association is not None and self.association.has_operation()) or
                            (self.generic_in_label is not None and self.generic_in_label.has_operation()) or
                            (self.generic_traffic_spec is not None and self.generic_traffic_spec.has_operation()) or
                            (self.protection is not None and self.protection.has_operation()) or
                            (self.reverse_lsp is not None and self.reverse_lsp.has_operation()) or
                            (self.traffic_spec is not None and self.traffic_spec.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "psb-info" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/psb-rsb-info/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.destination_address.get_name_leafdata())
                        if (self.in_interface.is_set or self.in_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.in_interface.get_name_leafdata())
                        if (self.in_label.is_set or self.in_label.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.in_label.get_name_leafdata())
                        if (self.incoming_interface_address.is_set or self.incoming_interface_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.incoming_interface_address.get_name_leafdata())
                        if (self.is_bad_address.is_set or self.is_bad_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_bad_address.get_name_leafdata())
                        if (self.is_ero_valid.is_set or self.is_ero_valid.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_ero_valid.get_name_leafdata())
                        if (self.is_rro_valid.is_set or self.is_rro_valid.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_rro_valid.get_name_leafdata())
                        if (self.is_traffic_spec_valid.is_set or self.is_traffic_spec_valid.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_traffic_spec_valid.get_name_leafdata())
                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_valid.get_name_leafdata())
                        if (self.lsp_id.is_set or self.lsp_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.lsp_id.get_name_leafdata())
                        if (self.lsp_wrap_label.is_set or self.lsp_wrap_label.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.lsp_wrap_label.get_name_leafdata())
                        if (self.p2mp_sub_group_origin.is_set or self.p2mp_sub_group_origin.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.p2mp_sub_group_origin.get_name_leafdata())
                        if (self.sub_group_id.is_set or self.sub_group_id.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.sub_group_id.get_name_leafdata())
                        if (self.tunnel_name.is_set or self.tunnel_name.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.tunnel_name.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "association"):
                            if (self.association is None):
                                self.association = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Association()
                                self.association.parent = self
                                self._children_name_map["association"] = "association"
                            return self.association

                        if (child_yang_name == "ero"):
                            for c in self.ero:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Ero()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.ero.append(c)
                            return c

                        if (child_yang_name == "generic-in-label"):
                            if (self.generic_in_label is None):
                                self.generic_in_label = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericInLabel()
                                self.generic_in_label.parent = self
                                self._children_name_map["generic_in_label"] = "generic-in-label"
                            return self.generic_in_label

                        if (child_yang_name == "generic-traffic-spec"):
                            if (self.generic_traffic_spec is None):
                                self.generic_traffic_spec = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.GenericTrafficSpec()
                                self.generic_traffic_spec.parent = self
                                self._children_name_map["generic_traffic_spec"] = "generic-traffic-spec"
                            return self.generic_traffic_spec

                        if (child_yang_name == "protection"):
                            if (self.protection is None):
                                self.protection = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Protection()
                                self.protection.parent = self
                                self._children_name_map["protection"] = "protection"
                            return self.protection

                        if (child_yang_name == "reverse-lsp"):
                            if (self.reverse_lsp is None):
                                self.reverse_lsp = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.ReverseLsp()
                                self.reverse_lsp.parent = self
                                self._children_name_map["reverse_lsp"] = "reverse-lsp"
                            return self.reverse_lsp

                        if (child_yang_name == "rro"):
                            for c in self.rro:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.Rro()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.rro.append(c)
                            return c

                        if (child_yang_name == "traffic-spec"):
                            if (self.traffic_spec is None):
                                self.traffic_spec = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo.TrafficSpec()
                                self.traffic_spec.parent = self
                                self._children_name_map["traffic_spec"] = "traffic-spec"
                            return self.traffic_spec

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "association" or name == "ero" or name == "generic-in-label" or name == "generic-traffic-spec" or name == "protection" or name == "reverse-lsp" or name == "rro" or name == "traffic-spec" or name == "destination-address" or name == "in-interface" or name == "in-label" or name == "incoming-interface-address" or name == "is-bad-address" or name == "is-ero-valid" or name == "is-rro-valid" or name == "is-traffic-spec-valid" or name == "is-valid" or name == "lsp-id" or name == "lsp-wrap-label" or name == "p2mp-sub-group-origin" or name == "sub-group-id" or name == "tunnel-name"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "destination-address"):
                            self.destination_address = value
                            self.destination_address.value_namespace = name_space
                            self.destination_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "in-interface"):
                            self.in_interface = value
                            self.in_interface.value_namespace = name_space
                            self.in_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "in-label"):
                            self.in_label = value
                            self.in_label.value_namespace = name_space
                            self.in_label.value_namespace_prefix = name_space_prefix
                        if(value_path == "incoming-interface-address"):
                            self.incoming_interface_address = value
                            self.incoming_interface_address.value_namespace = name_space
                            self.incoming_interface_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-bad-address"):
                            self.is_bad_address = value
                            self.is_bad_address.value_namespace = name_space
                            self.is_bad_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-ero-valid"):
                            self.is_ero_valid = value
                            self.is_ero_valid.value_namespace = name_space
                            self.is_ero_valid.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-rro-valid"):
                            self.is_rro_valid = value
                            self.is_rro_valid.value_namespace = name_space
                            self.is_rro_valid.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-traffic-spec-valid"):
                            self.is_traffic_spec_valid = value
                            self.is_traffic_spec_valid.value_namespace = name_space
                            self.is_traffic_spec_valid.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-valid"):
                            self.is_valid = value
                            self.is_valid.value_namespace = name_space
                            self.is_valid.value_namespace_prefix = name_space_prefix
                        if(value_path == "lsp-id"):
                            self.lsp_id = value
                            self.lsp_id.value_namespace = name_space
                            self.lsp_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "lsp-wrap-label"):
                            self.lsp_wrap_label = value
                            self.lsp_wrap_label.value_namespace = name_space
                            self.lsp_wrap_label.value_namespace_prefix = name_space_prefix
                        if(value_path == "p2mp-sub-group-origin"):
                            self.p2mp_sub_group_origin = value
                            self.p2mp_sub_group_origin.value_namespace = name_space
                            self.p2mp_sub_group_origin.value_namespace_prefix = name_space_prefix
                        if(value_path == "sub-group-id"):
                            self.sub_group_id = value
                            self.sub_group_id.value_namespace = name_space
                            self.sub_group_id.value_namespace_prefix = name_space_prefix
                        if(value_path == "tunnel-name"):
                            self.tunnel_name = value
                            self.tunnel_name.value_namespace = name_space
                            self.tunnel_name.value_namespace_prefix = name_space_prefix


                class RsbInfo(Entity):
                    """
                    Reservation Info
                    
                    .. attribute:: backup_interface
                    
                    	Backup tunnel interface
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: backup_label
                    
                    	Backup label
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: destination_address
                    
                    	Destination address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: flow_spec
                    
                    	Flow spec object
                    	**type**\:   :py:class:`FlowSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.FlowSpec>`
                    
                    .. attribute:: generic_flow_spec
                    
                    	Generic Flow Spec object
                    	**type**\:   :py:class:`GenericFlowSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.GenericFlowSpec>`
                    
                    .. attribute:: generic_out_label
                    
                    	Generic Label for outbound traffic
                    	**type**\:   :py:class:`GenericOutLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.GenericOutLabel>`
                    
                    .. attribute:: is_flow_spec_valid
                    
                    	FlowSpec validity
                    	**type**\:  bool
                    
                    .. attribute:: is_rro_valid
                    
                    	RRO validity
                    	**type**\:  bool
                    
                    .. attribute:: is_valid
                    
                    	Entry validity
                    	**type**\:  bool
                    
                    .. attribute:: out_interface
                    
                    	Interface on which outbound message was sent
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: out_label
                    
                    	Label for outbound traffic
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rro
                    
                    	Record route object
                    	**type**\: list of    :py:class:`Rro <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo, self).__init__()

                        self.yang_name = "rsb-info"
                        self.yang_parent_name = "psb-rsb-info"

                        self.backup_interface = YLeaf(YType.str, "backup-interface")

                        self.backup_label = YLeaf(YType.uint32, "backup-label")

                        self.destination_address = YLeaf(YType.str, "destination-address")

                        self.is_flow_spec_valid = YLeaf(YType.boolean, "is-flow-spec-valid")

                        self.is_rro_valid = YLeaf(YType.boolean, "is-rro-valid")

                        self.is_valid = YLeaf(YType.boolean, "is-valid")

                        self.out_interface = YLeaf(YType.str, "out-interface")

                        self.out_label = YLeaf(YType.uint32, "out-label")

                        self.flow_spec = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.FlowSpec()
                        self.flow_spec.parent = self
                        self._children_name_map["flow_spec"] = "flow-spec"
                        self._children_yang_names.add("flow-spec")

                        self.generic_flow_spec = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.GenericFlowSpec()
                        self.generic_flow_spec.parent = self
                        self._children_name_map["generic_flow_spec"] = "generic-flow-spec"
                        self._children_yang_names.add("generic-flow-spec")

                        self.generic_out_label = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.GenericOutLabel()
                        self.generic_out_label.parent = self
                        self._children_name_map["generic_out_label"] = "generic-out-label"
                        self._children_yang_names.add("generic-out-label")

                        self.rro = YList(self)

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("backup_interface",
                                        "backup_label",
                                        "destination_address",
                                        "is_flow_spec_valid",
                                        "is_rro_valid",
                                        "is_valid",
                                        "out_interface",
                                        "out_label") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo, self).__setattr__(name, value)


                    class GenericOutLabel(Entity):
                        """
                        Generic Label for outbound traffic
                        
                        .. attribute:: generalized_label
                        
                        	Generalized Label
                        	**type**\:   :py:class:`GeneralizedLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.GenericOutLabel.GeneralizedLabel>`
                        
                        .. attribute:: generic_label_type
                        
                        	GenericLabelType
                        	**type**\:   :py:class:`RsvpMgmtGenericLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtGenericLabel>`
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.GenericOutLabel, self).__init__()

                            self.yang_name = "generic-out-label"
                            self.yang_parent_name = "rsb-info"

                            self.generic_label_type = YLeaf(YType.enumeration, "generic-label-type")

                            self.generalized_label = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.GenericOutLabel.GeneralizedLabel()
                            self.generalized_label.parent = self
                            self._children_name_map["generalized_label"] = "generalized-label"
                            self._children_yang_names.add("generalized-label")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("generic_label_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.GenericOutLabel, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.GenericOutLabel, self).__setattr__(name, value)


                        class GeneralizedLabel(Entity):
                            """
                            Generalized Label
                            
                            .. attribute:: value
                            
                            	Generalized Label Value
                            	**type**\:  list of int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.GenericOutLabel.GeneralizedLabel, self).__init__()

                                self.yang_name = "generalized-label"
                                self.yang_parent_name = "generic-out-label"

                                self.value = YLeafList(YType.uint32, "value")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("value") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.GenericOutLabel.GeneralizedLabel, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.GenericOutLabel.GeneralizedLabel, self).__setattr__(name, value)

                            def has_data(self):
                                for leaf in self.value.getYLeafs():
                                    if (leaf.yfilter != YFilter.not_set):
                                        return True
                                return False

                            def has_operation(self):
                                for leaf in self.value.getYLeafs():
                                    if (leaf.is_set):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.value.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "generalized-label" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/psb-rsb-info/rsb-info/generic-out-label/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                leaf_name_data.extend(self.value.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "value"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "value"):
                                    self.value.append(value)

                        def has_data(self):
                            return (
                                self.generic_label_type.is_set or
                                (self.generalized_label is not None and self.generalized_label.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.generic_label_type.yfilter != YFilter.not_set or
                                (self.generalized_label is not None and self.generalized_label.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "generic-out-label" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/psb-rsb-info/rsb-info/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.generic_label_type.is_set or self.generic_label_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.generic_label_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "generalized-label"):
                                if (self.generalized_label is None):
                                    self.generalized_label = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.GenericOutLabel.GeneralizedLabel()
                                    self.generalized_label.parent = self
                                    self._children_name_map["generalized_label"] = "generalized-label"
                                return self.generalized_label

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "generalized-label" or name == "generic-label-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "generic-label-type"):
                                self.generic_label_type = value
                                self.generic_label_type.value_namespace = name_space
                                self.generic_label_type.value_namespace_prefix = name_space_prefix


                    class FlowSpec(Entity):
                        """
                        Flow spec object
                        
                        .. attribute:: flow_average_rate
                        
                        	The Flow Average Rate in bytes per second
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: byte/s
                        
                        .. attribute:: flow_max_burst
                        
                        	The Flow Maximum Burst
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: flow_max_unit
                        
                        	The Flow Maximum Unit
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: flow_min_unit
                        
                        	The Flow Minimum Unit
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: flow_peak_rate
                        
                        	The Flow Peak Rate in bytes per second
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: byte/s
                        
                        .. attribute:: flow_qos
                        
                        	The Flow Quality of Service
                        	**type**\:   :py:class:`RsvpMgmtQosServiceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtQosServiceEnum>`
                        
                        .. attribute:: flow_requested_rate
                        
                        	The Flow Requested Rate in bytes per second
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: byte/s
                        
                        .. attribute:: flow_slack
                        
                        	The Flow Slack
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.FlowSpec, self).__init__()

                            self.yang_name = "flow-spec"
                            self.yang_parent_name = "rsb-info"

                            self.flow_average_rate = YLeaf(YType.uint64, "flow-average-rate")

                            self.flow_max_burst = YLeaf(YType.uint64, "flow-max-burst")

                            self.flow_max_unit = YLeaf(YType.uint32, "flow-max-unit")

                            self.flow_min_unit = YLeaf(YType.uint32, "flow-min-unit")

                            self.flow_peak_rate = YLeaf(YType.uint64, "flow-peak-rate")

                            self.flow_qos = YLeaf(YType.enumeration, "flow-qos")

                            self.flow_requested_rate = YLeaf(YType.uint64, "flow-requested-rate")

                            self.flow_slack = YLeaf(YType.uint32, "flow-slack")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("flow_average_rate",
                                            "flow_max_burst",
                                            "flow_max_unit",
                                            "flow_min_unit",
                                            "flow_peak_rate",
                                            "flow_qos",
                                            "flow_requested_rate",
                                            "flow_slack") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.FlowSpec, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.FlowSpec, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.flow_average_rate.is_set or
                                self.flow_max_burst.is_set or
                                self.flow_max_unit.is_set or
                                self.flow_min_unit.is_set or
                                self.flow_peak_rate.is_set or
                                self.flow_qos.is_set or
                                self.flow_requested_rate.is_set or
                                self.flow_slack.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.flow_average_rate.yfilter != YFilter.not_set or
                                self.flow_max_burst.yfilter != YFilter.not_set or
                                self.flow_max_unit.yfilter != YFilter.not_set or
                                self.flow_min_unit.yfilter != YFilter.not_set or
                                self.flow_peak_rate.yfilter != YFilter.not_set or
                                self.flow_qos.yfilter != YFilter.not_set or
                                self.flow_requested_rate.yfilter != YFilter.not_set or
                                self.flow_slack.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "flow-spec" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/psb-rsb-info/rsb-info/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.flow_average_rate.is_set or self.flow_average_rate.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.flow_average_rate.get_name_leafdata())
                            if (self.flow_max_burst.is_set or self.flow_max_burst.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.flow_max_burst.get_name_leafdata())
                            if (self.flow_max_unit.is_set or self.flow_max_unit.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.flow_max_unit.get_name_leafdata())
                            if (self.flow_min_unit.is_set or self.flow_min_unit.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.flow_min_unit.get_name_leafdata())
                            if (self.flow_peak_rate.is_set or self.flow_peak_rate.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.flow_peak_rate.get_name_leafdata())
                            if (self.flow_qos.is_set or self.flow_qos.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.flow_qos.get_name_leafdata())
                            if (self.flow_requested_rate.is_set or self.flow_requested_rate.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.flow_requested_rate.get_name_leafdata())
                            if (self.flow_slack.is_set or self.flow_slack.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.flow_slack.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "flow-average-rate" or name == "flow-max-burst" or name == "flow-max-unit" or name == "flow-min-unit" or name == "flow-peak-rate" or name == "flow-qos" or name == "flow-requested-rate" or name == "flow-slack"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "flow-average-rate"):
                                self.flow_average_rate = value
                                self.flow_average_rate.value_namespace = name_space
                                self.flow_average_rate.value_namespace_prefix = name_space_prefix
                            if(value_path == "flow-max-burst"):
                                self.flow_max_burst = value
                                self.flow_max_burst.value_namespace = name_space
                                self.flow_max_burst.value_namespace_prefix = name_space_prefix
                            if(value_path == "flow-max-unit"):
                                self.flow_max_unit = value
                                self.flow_max_unit.value_namespace = name_space
                                self.flow_max_unit.value_namespace_prefix = name_space_prefix
                            if(value_path == "flow-min-unit"):
                                self.flow_min_unit = value
                                self.flow_min_unit.value_namespace = name_space
                                self.flow_min_unit.value_namespace_prefix = name_space_prefix
                            if(value_path == "flow-peak-rate"):
                                self.flow_peak_rate = value
                                self.flow_peak_rate.value_namespace = name_space
                                self.flow_peak_rate.value_namespace_prefix = name_space_prefix
                            if(value_path == "flow-qos"):
                                self.flow_qos = value
                                self.flow_qos.value_namespace = name_space
                                self.flow_qos.value_namespace_prefix = name_space_prefix
                            if(value_path == "flow-requested-rate"):
                                self.flow_requested_rate = value
                                self.flow_requested_rate.value_namespace = name_space
                                self.flow_requested_rate.value_namespace_prefix = name_space_prefix
                            if(value_path == "flow-slack"):
                                self.flow_slack = value
                                self.flow_slack.value_namespace = name_space
                                self.flow_slack.value_namespace_prefix = name_space_prefix


                    class GenericFlowSpec(Entity):
                        """
                        Generic Flow Spec object
                        
                        .. attribute:: flow_spec_type
                        
                        	FlowSpecType
                        	**type**\:   :py:class:`RsvpMgmtFlowSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtFlowSpec>`
                        
                        .. attribute:: g709otn_flow_spec
                        
                        	G709 OTN FlowSpec
                        	**type**\:   :py:class:`G709OtnFlowSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.GenericFlowSpec.G709OtnFlowSpec>`
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.GenericFlowSpec, self).__init__()

                            self.yang_name = "generic-flow-spec"
                            self.yang_parent_name = "rsb-info"

                            self.flow_spec_type = YLeaf(YType.enumeration, "flow-spec-type")

                            self.g709otn_flow_spec = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.GenericFlowSpec.G709OtnFlowSpec()
                            self.g709otn_flow_spec.parent = self
                            self._children_name_map["g709otn_flow_spec"] = "g709otn-flow-spec"
                            self._children_yang_names.add("g709otn-flow-spec")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("flow_spec_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.GenericFlowSpec, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.GenericFlowSpec, self).__setattr__(name, value)


                        class G709OtnFlowSpec(Entity):
                            """
                            G709 OTN FlowSpec
                            
                            .. attribute:: flow_bit_rate
                            
                            	G709 OTN Flow Bit Rate
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: flow_multiplier
                            
                            	G709 OTN Flow Multiplier
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: flow_nvc
                            
                            	G709 OTN Flow NVC
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: flow_signal_type
                            
                            	G709 OTN Flow Signal Type (Refer G709 v3)
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.GenericFlowSpec.G709OtnFlowSpec, self).__init__()

                                self.yang_name = "g709otn-flow-spec"
                                self.yang_parent_name = "generic-flow-spec"

                                self.flow_bit_rate = YLeaf(YType.uint64, "flow-bit-rate")

                                self.flow_multiplier = YLeaf(YType.uint16, "flow-multiplier")

                                self.flow_nvc = YLeaf(YType.uint16, "flow-nvc")

                                self.flow_signal_type = YLeaf(YType.uint8, "flow-signal-type")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("flow_bit_rate",
                                                "flow_multiplier",
                                                "flow_nvc",
                                                "flow_signal_type") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.GenericFlowSpec.G709OtnFlowSpec, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.GenericFlowSpec.G709OtnFlowSpec, self).__setattr__(name, value)

                            def has_data(self):
                                return (
                                    self.flow_bit_rate.is_set or
                                    self.flow_multiplier.is_set or
                                    self.flow_nvc.is_set or
                                    self.flow_signal_type.is_set)

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.flow_bit_rate.yfilter != YFilter.not_set or
                                    self.flow_multiplier.yfilter != YFilter.not_set or
                                    self.flow_nvc.yfilter != YFilter.not_set or
                                    self.flow_signal_type.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "g709otn-flow-spec" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/psb-rsb-info/rsb-info/generic-flow-spec/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.flow_bit_rate.is_set or self.flow_bit_rate.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.flow_bit_rate.get_name_leafdata())
                                if (self.flow_multiplier.is_set or self.flow_multiplier.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.flow_multiplier.get_name_leafdata())
                                if (self.flow_nvc.is_set or self.flow_nvc.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.flow_nvc.get_name_leafdata())
                                if (self.flow_signal_type.is_set or self.flow_signal_type.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.flow_signal_type.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "flow-bit-rate" or name == "flow-multiplier" or name == "flow-nvc" or name == "flow-signal-type"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "flow-bit-rate"):
                                    self.flow_bit_rate = value
                                    self.flow_bit_rate.value_namespace = name_space
                                    self.flow_bit_rate.value_namespace_prefix = name_space_prefix
                                if(value_path == "flow-multiplier"):
                                    self.flow_multiplier = value
                                    self.flow_multiplier.value_namespace = name_space
                                    self.flow_multiplier.value_namespace_prefix = name_space_prefix
                                if(value_path == "flow-nvc"):
                                    self.flow_nvc = value
                                    self.flow_nvc.value_namespace = name_space
                                    self.flow_nvc.value_namespace_prefix = name_space_prefix
                                if(value_path == "flow-signal-type"):
                                    self.flow_signal_type = value
                                    self.flow_signal_type.value_namespace = name_space
                                    self.flow_signal_type.value_namespace_prefix = name_space_prefix

                        def has_data(self):
                            return (
                                self.flow_spec_type.is_set or
                                (self.g709otn_flow_spec is not None and self.g709otn_flow_spec.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.flow_spec_type.yfilter != YFilter.not_set or
                                (self.g709otn_flow_spec is not None and self.g709otn_flow_spec.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "generic-flow-spec" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/psb-rsb-info/rsb-info/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.flow_spec_type.is_set or self.flow_spec_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.flow_spec_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "g709otn-flow-spec"):
                                if (self.g709otn_flow_spec is None):
                                    self.g709otn_flow_spec = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.GenericFlowSpec.G709OtnFlowSpec()
                                    self.g709otn_flow_spec.parent = self
                                    self._children_name_map["g709otn_flow_spec"] = "g709otn-flow-spec"
                                return self.g709otn_flow_spec

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "g709otn-flow-spec" or name == "flow-spec-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "flow-spec-type"):
                                self.flow_spec_type = value
                                self.flow_spec_type.value_namespace = name_space
                                self.flow_spec_type.value_namespace_prefix = name_space_prefix


                    class Rro(Entity):
                        """
                        Record route object
                        
                        .. attribute:: ipv4rro_sub_object
                        
                        	IPV4 RRO Sub Object
                        	**type**\:   :py:class:`Ipv4RroSubObject <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.Ipv4RroSubObject>`
                        
                        .. attribute:: label_rro_sub_object
                        
                        	Label RRO Sub Object
                        	**type**\:   :py:class:`LabelRroSubObject <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.LabelRroSubObject>`
                        
                        .. attribute:: rro_type
                        
                        	RROType
                        	**type**\:   :py:class:`RsvpMgmtRroSubobj <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtRroSubobj>`
                        
                        .. attribute:: srlg_rro_sub_object
                        
                        	SRLG RRO Sub Object
                        	**type**\:   :py:class:`SrlgRroSubObject <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.SrlgRroSubObject>`
                        
                        .. attribute:: unnumbered_rro_sub_object
                        
                        	Unnumbered RRO Sub Object
                        	**type**\:   :py:class:`UnnumberedRroSubObject <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.UnnumberedRroSubObject>`
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro, self).__init__()

                            self.yang_name = "rro"
                            self.yang_parent_name = "rsb-info"

                            self.rro_type = YLeaf(YType.enumeration, "rro-type")

                            self.ipv4rro_sub_object = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.Ipv4RroSubObject()
                            self.ipv4rro_sub_object.parent = self
                            self._children_name_map["ipv4rro_sub_object"] = "ipv4rro-sub-object"
                            self._children_yang_names.add("ipv4rro-sub-object")

                            self.label_rro_sub_object = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.LabelRroSubObject()
                            self.label_rro_sub_object.parent = self
                            self._children_name_map["label_rro_sub_object"] = "label-rro-sub-object"
                            self._children_yang_names.add("label-rro-sub-object")

                            self.srlg_rro_sub_object = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.SrlgRroSubObject()
                            self.srlg_rro_sub_object.parent = self
                            self._children_name_map["srlg_rro_sub_object"] = "srlg-rro-sub-object"
                            self._children_yang_names.add("srlg-rro-sub-object")

                            self.unnumbered_rro_sub_object = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.UnnumberedRroSubObject()
                            self.unnumbered_rro_sub_object.parent = self
                            self._children_name_map["unnumbered_rro_sub_object"] = "unnumbered-rro-sub-object"
                            self._children_yang_names.add("unnumbered-rro-sub-object")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("rro_type") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro, self).__setattr__(name, value)


                        class Ipv4RroSubObject(Entity):
                            """
                            IPV4 RRO Sub Object
                            
                            .. attribute:: flags
                            
                            	The RRO IPV4 Subobject Flags
                            	**type**\:   :py:class:`Flags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.Ipv4RroSubObject.Flags>`
                            
                            .. attribute:: rro_address
                            
                            	The RRO IPV4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.Ipv4RroSubObject, self).__init__()

                                self.yang_name = "ipv4rro-sub-object"
                                self.yang_parent_name = "rro"

                                self.rro_address = YLeaf(YType.str, "rro-address")

                                self.flags = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.Ipv4RroSubObject.Flags()
                                self.flags.parent = self
                                self._children_name_map["flags"] = "flags"
                                self._children_yang_names.add("flags")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("rro_address") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.Ipv4RroSubObject, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.Ipv4RroSubObject, self).__setattr__(name, value)


                            class Flags(Entity):
                                """
                                The RRO IPV4 Subobject Flags
                                
                                .. attribute:: is_bandwidth_protected
                                
                                	Bandwidth Protection Available
                                	**type**\:  bool
                                
                                .. attribute:: is_node_id
                                
                                	Node ID In Use
                                	**type**\:  bool
                                
                                .. attribute:: is_node_protection_available
                                
                                	Node Protection Available
                                	**type**\:  bool
                                
                                .. attribute:: is_protection_available
                                
                                	Local Protection Available
                                	**type**\:  bool
                                
                                .. attribute:: is_protection_in_use
                                
                                	Local Protection In Use
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ip-rsvp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.Ipv4RroSubObject.Flags, self).__init__()

                                    self.yang_name = "flags"
                                    self.yang_parent_name = "ipv4rro-sub-object"

                                    self.is_bandwidth_protected = YLeaf(YType.boolean, "is-bandwidth-protected")

                                    self.is_node_id = YLeaf(YType.boolean, "is-node-id")

                                    self.is_node_protection_available = YLeaf(YType.boolean, "is-node-protection-available")

                                    self.is_protection_available = YLeaf(YType.boolean, "is-protection-available")

                                    self.is_protection_in_use = YLeaf(YType.boolean, "is-protection-in-use")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("is_bandwidth_protected",
                                                    "is_node_id",
                                                    "is_node_protection_available",
                                                    "is_protection_available",
                                                    "is_protection_in_use") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.Ipv4RroSubObject.Flags, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.Ipv4RroSubObject.Flags, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.is_bandwidth_protected.is_set or
                                        self.is_node_id.is_set or
                                        self.is_node_protection_available.is_set or
                                        self.is_protection_available.is_set or
                                        self.is_protection_in_use.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.is_bandwidth_protected.yfilter != YFilter.not_set or
                                        self.is_node_id.yfilter != YFilter.not_set or
                                        self.is_node_protection_available.yfilter != YFilter.not_set or
                                        self.is_protection_available.yfilter != YFilter.not_set or
                                        self.is_protection_in_use.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "flags" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/psb-rsb-info/rsb-info/rro/ipv4rro-sub-object/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.is_bandwidth_protected.is_set or self.is_bandwidth_protected.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_bandwidth_protected.get_name_leafdata())
                                    if (self.is_node_id.is_set or self.is_node_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_node_id.get_name_leafdata())
                                    if (self.is_node_protection_available.is_set or self.is_node_protection_available.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_node_protection_available.get_name_leafdata())
                                    if (self.is_protection_available.is_set or self.is_protection_available.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_protection_available.get_name_leafdata())
                                    if (self.is_protection_in_use.is_set or self.is_protection_in_use.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_protection_in_use.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "is-bandwidth-protected" or name == "is-node-id" or name == "is-node-protection-available" or name == "is-protection-available" or name == "is-protection-in-use"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "is-bandwidth-protected"):
                                        self.is_bandwidth_protected = value
                                        self.is_bandwidth_protected.value_namespace = name_space
                                        self.is_bandwidth_protected.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-node-id"):
                                        self.is_node_id = value
                                        self.is_node_id.value_namespace = name_space
                                        self.is_node_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-node-protection-available"):
                                        self.is_node_protection_available = value
                                        self.is_node_protection_available.value_namespace = name_space
                                        self.is_node_protection_available.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-protection-available"):
                                        self.is_protection_available = value
                                        self.is_protection_available.value_namespace = name_space
                                        self.is_protection_available.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-protection-in-use"):
                                        self.is_protection_in_use = value
                                        self.is_protection_in_use.value_namespace = name_space
                                        self.is_protection_in_use.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.rro_address.is_set or
                                    (self.flags is not None and self.flags.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.rro_address.yfilter != YFilter.not_set or
                                    (self.flags is not None and self.flags.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "ipv4rro-sub-object" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/psb-rsb-info/rsb-info/rro/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.rro_address.is_set or self.rro_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.rro_address.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "flags"):
                                    if (self.flags is None):
                                        self.flags = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.Ipv4RroSubObject.Flags()
                                        self.flags.parent = self
                                        self._children_name_map["flags"] = "flags"
                                    return self.flags

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "flags" or name == "rro-address"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "rro-address"):
                                    self.rro_address = value
                                    self.rro_address.value_namespace = name_space
                                    self.rro_address.value_namespace_prefix = name_space_prefix


                        class LabelRroSubObject(Entity):
                            """
                            Label RRO Sub Object
                            
                            .. attribute:: flags
                            
                            	The RRO Subobject Label Flags
                            	**type**\:   :py:class:`Flags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.LabelRroSubObject.Flags>`
                            
                            .. attribute:: is_label_variable_length
                            
                            	Is the RRO Subobject Label Variable Length
                            	**type**\:  bool
                            
                            .. attribute:: label
                            
                            	The RRO Subobject Label Value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: variable_length_label
                            
                            	The RRO Subobject Variable Length Label
                            	**type**\:  list of int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.LabelRroSubObject, self).__init__()

                                self.yang_name = "label-rro-sub-object"
                                self.yang_parent_name = "rro"

                                self.is_label_variable_length = YLeaf(YType.boolean, "is-label-variable-length")

                                self.label = YLeaf(YType.uint32, "label")

                                self.variable_length_label = YLeafList(YType.uint32, "variable-length-label")

                                self.flags = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.LabelRroSubObject.Flags()
                                self.flags.parent = self
                                self._children_name_map["flags"] = "flags"
                                self._children_yang_names.add("flags")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("is_label_variable_length",
                                                "label",
                                                "variable_length_label") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.LabelRroSubObject, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.LabelRroSubObject, self).__setattr__(name, value)


                            class Flags(Entity):
                                """
                                The RRO Subobject Label Flags
                                
                                .. attribute:: is_global_label
                                
                                	Label is Global across all interfaces
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ip-rsvp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.LabelRroSubObject.Flags, self).__init__()

                                    self.yang_name = "flags"
                                    self.yang_parent_name = "label-rro-sub-object"

                                    self.is_global_label = YLeaf(YType.boolean, "is-global-label")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("is_global_label") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.LabelRroSubObject.Flags, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.LabelRroSubObject.Flags, self).__setattr__(name, value)

                                def has_data(self):
                                    return self.is_global_label.is_set

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.is_global_label.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "flags" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/psb-rsb-info/rsb-info/rro/label-rro-sub-object/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.is_global_label.is_set or self.is_global_label.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_global_label.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "is-global-label"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "is-global-label"):
                                        self.is_global_label = value
                                        self.is_global_label.value_namespace = name_space
                                        self.is_global_label.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                for leaf in self.variable_length_label.getYLeafs():
                                    if (leaf.yfilter != YFilter.not_set):
                                        return True
                                return (
                                    self.is_label_variable_length.is_set or
                                    self.label.is_set or
                                    (self.flags is not None and self.flags.has_data()))

                            def has_operation(self):
                                for leaf in self.variable_length_label.getYLeafs():
                                    if (leaf.is_set):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.is_label_variable_length.yfilter != YFilter.not_set or
                                    self.label.yfilter != YFilter.not_set or
                                    self.variable_length_label.yfilter != YFilter.not_set or
                                    (self.flags is not None and self.flags.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "label-rro-sub-object" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/psb-rsb-info/rsb-info/rro/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.is_label_variable_length.is_set or self.is_label_variable_length.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.is_label_variable_length.get_name_leafdata())
                                if (self.label.is_set or self.label.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.label.get_name_leafdata())

                                leaf_name_data.extend(self.variable_length_label.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "flags"):
                                    if (self.flags is None):
                                        self.flags = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.LabelRroSubObject.Flags()
                                        self.flags.parent = self
                                        self._children_name_map["flags"] = "flags"
                                    return self.flags

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "flags" or name == "is-label-variable-length" or name == "label" or name == "variable-length-label"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "is-label-variable-length"):
                                    self.is_label_variable_length = value
                                    self.is_label_variable_length.value_namespace = name_space
                                    self.is_label_variable_length.value_namespace_prefix = name_space_prefix
                                if(value_path == "label"):
                                    self.label = value
                                    self.label.value_namespace = name_space
                                    self.label.value_namespace_prefix = name_space_prefix
                                if(value_path == "variable-length-label"):
                                    self.variable_length_label.append(value)


                        class UnnumberedRroSubObject(Entity):
                            """
                            Unnumbered RRO Sub Object
                            
                            .. attribute:: flags
                            
                            	The RRO Subobject Unnumbered Flags
                            	**type**\:   :py:class:`Flags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.UnnumberedRroSubObject.Flags>`
                            
                            .. attribute:: interface_address
                            
                            	The RRO Interface Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: interface_id
                            
                            	The RRO Interface ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.UnnumberedRroSubObject, self).__init__()

                                self.yang_name = "unnumbered-rro-sub-object"
                                self.yang_parent_name = "rro"

                                self.interface_address = YLeaf(YType.str, "interface-address")

                                self.interface_id = YLeaf(YType.uint32, "interface-id")

                                self.flags = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.UnnumberedRroSubObject.Flags()
                                self.flags.parent = self
                                self._children_name_map["flags"] = "flags"
                                self._children_yang_names.add("flags")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("interface_address",
                                                "interface_id") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.UnnumberedRroSubObject, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.UnnumberedRroSubObject, self).__setattr__(name, value)


                            class Flags(Entity):
                                """
                                The RRO Subobject Unnumbered Flags
                                
                                .. attribute:: is_bandwidth_protected
                                
                                	Bandwidth Protection Available
                                	**type**\:  bool
                                
                                .. attribute:: is_node_id
                                
                                	Node ID In Use
                                	**type**\:  bool
                                
                                .. attribute:: is_node_protection_available
                                
                                	Node Protection Available
                                	**type**\:  bool
                                
                                .. attribute:: is_protection_available
                                
                                	Local Protection Available
                                	**type**\:  bool
                                
                                .. attribute:: is_protection_in_use
                                
                                	Local Protection In Use
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ip-rsvp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.UnnumberedRroSubObject.Flags, self).__init__()

                                    self.yang_name = "flags"
                                    self.yang_parent_name = "unnumbered-rro-sub-object"

                                    self.is_bandwidth_protected = YLeaf(YType.boolean, "is-bandwidth-protected")

                                    self.is_node_id = YLeaf(YType.boolean, "is-node-id")

                                    self.is_node_protection_available = YLeaf(YType.boolean, "is-node-protection-available")

                                    self.is_protection_available = YLeaf(YType.boolean, "is-protection-available")

                                    self.is_protection_in_use = YLeaf(YType.boolean, "is-protection-in-use")

                                def __setattr__(self, name, value):
                                    self._check_monkey_patching_error(name, value)
                                    with _handle_type_error():
                                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                                "Please use list append or extend method."
                                                                .format(value))
                                        if isinstance(value, Enum.YLeaf):
                                            value = value.name
                                        if name in ("is_bandwidth_protected",
                                                    "is_node_id",
                                                    "is_node_protection_available",
                                                    "is_protection_available",
                                                    "is_protection_in_use") and name in self.__dict__:
                                            if isinstance(value, YLeaf):
                                                self.__dict__[name].set(value.get())
                                            elif isinstance(value, YLeafList):
                                                super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.UnnumberedRroSubObject.Flags, self).__setattr__(name, value)
                                            else:
                                                self.__dict__[name].set(value)
                                        else:
                                            if hasattr(value, "parent") and name != "parent":
                                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                    value.parent = self
                                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                                    value.parent = self
                                            super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.UnnumberedRroSubObject.Flags, self).__setattr__(name, value)

                                def has_data(self):
                                    return (
                                        self.is_bandwidth_protected.is_set or
                                        self.is_node_id.is_set or
                                        self.is_node_protection_available.is_set or
                                        self.is_protection_available.is_set or
                                        self.is_protection_in_use.is_set)

                                def has_operation(self):
                                    return (
                                        self.yfilter != YFilter.not_set or
                                        self.is_bandwidth_protected.yfilter != YFilter.not_set or
                                        self.is_node_id.yfilter != YFilter.not_set or
                                        self.is_node_protection_available.yfilter != YFilter.not_set or
                                        self.is_protection_available.yfilter != YFilter.not_set or
                                        self.is_protection_in_use.yfilter != YFilter.not_set)

                                def get_segment_path(self):
                                    path_buffer = ""
                                    path_buffer = "flags" + path_buffer

                                    return path_buffer

                                def get_entity_path(self, ancestor):
                                    path_buffer = ""
                                    if (ancestor is None):
                                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/psb-rsb-info/rsb-info/rro/unnumbered-rro-sub-object/%s" % self.get_segment_path()
                                    else:
                                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                    leaf_name_data = LeafDataList()
                                    if (self.is_bandwidth_protected.is_set or self.is_bandwidth_protected.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_bandwidth_protected.get_name_leafdata())
                                    if (self.is_node_id.is_set or self.is_node_id.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_node_id.get_name_leafdata())
                                    if (self.is_node_protection_available.is_set or self.is_node_protection_available.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_node_protection_available.get_name_leafdata())
                                    if (self.is_protection_available.is_set or self.is_protection_available.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_protection_available.get_name_leafdata())
                                    if (self.is_protection_in_use.is_set or self.is_protection_in_use.yfilter != YFilter.not_set):
                                        leaf_name_data.append(self.is_protection_in_use.get_name_leafdata())

                                    entity_path = EntityPath(path_buffer, leaf_name_data)
                                    return entity_path

                                def get_child_by_name(self, child_yang_name, segment_path):
                                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                    if child is not None:
                                        return child

                                    return None

                                def has_leaf_or_child_of_name(self, name):
                                    if(name == "is-bandwidth-protected" or name == "is-node-id" or name == "is-node-protection-available" or name == "is-protection-available" or name == "is-protection-in-use"):
                                        return True
                                    return False

                                def set_value(self, value_path, value, name_space, name_space_prefix):
                                    if(value_path == "is-bandwidth-protected"):
                                        self.is_bandwidth_protected = value
                                        self.is_bandwidth_protected.value_namespace = name_space
                                        self.is_bandwidth_protected.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-node-id"):
                                        self.is_node_id = value
                                        self.is_node_id.value_namespace = name_space
                                        self.is_node_id.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-node-protection-available"):
                                        self.is_node_protection_available = value
                                        self.is_node_protection_available.value_namespace = name_space
                                        self.is_node_protection_available.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-protection-available"):
                                        self.is_protection_available = value
                                        self.is_protection_available.value_namespace = name_space
                                        self.is_protection_available.value_namespace_prefix = name_space_prefix
                                    if(value_path == "is-protection-in-use"):
                                        self.is_protection_in_use = value
                                        self.is_protection_in_use.value_namespace = name_space
                                        self.is_protection_in_use.value_namespace_prefix = name_space_prefix

                            def has_data(self):
                                return (
                                    self.interface_address.is_set or
                                    self.interface_id.is_set or
                                    (self.flags is not None and self.flags.has_data()))

                            def has_operation(self):
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.interface_address.yfilter != YFilter.not_set or
                                    self.interface_id.yfilter != YFilter.not_set or
                                    (self.flags is not None and self.flags.has_operation()))

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "unnumbered-rro-sub-object" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/psb-rsb-info/rsb-info/rro/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()
                                if (self.interface_address.is_set or self.interface_address.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_address.get_name_leafdata())
                                if (self.interface_id.is_set or self.interface_id.yfilter != YFilter.not_set):
                                    leaf_name_data.append(self.interface_id.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                if (child_yang_name == "flags"):
                                    if (self.flags is None):
                                        self.flags = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.UnnumberedRroSubObject.Flags()
                                        self.flags.parent = self
                                        self._children_name_map["flags"] = "flags"
                                    return self.flags

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "flags" or name == "interface-address" or name == "interface-id"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "interface-address"):
                                    self.interface_address = value
                                    self.interface_address.value_namespace = name_space
                                    self.interface_address.value_namespace_prefix = name_space_prefix
                                if(value_path == "interface-id"):
                                    self.interface_id = value
                                    self.interface_id.value_namespace = name_space
                                    self.interface_id.value_namespace_prefix = name_space_prefix


                        class SrlgRroSubObject(Entity):
                            """
                            SRLG RRO Sub Object
                            
                            .. attribute:: srl_gs
                            
                            	The RRO Subobject SRLGs
                            	**type**\:  list of int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ip-rsvp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.SrlgRroSubObject, self).__init__()

                                self.yang_name = "srlg-rro-sub-object"
                                self.yang_parent_name = "rro"

                                self.srl_gs = YLeafList(YType.uint32, "srl-gs")

                            def __setattr__(self, name, value):
                                self._check_monkey_patching_error(name, value)
                                with _handle_type_error():
                                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                            "Please use list append or extend method."
                                                            .format(value))
                                    if isinstance(value, Enum.YLeaf):
                                        value = value.name
                                    if name in ("srl_gs") and name in self.__dict__:
                                        if isinstance(value, YLeaf):
                                            self.__dict__[name].set(value.get())
                                        elif isinstance(value, YLeafList):
                                            super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.SrlgRroSubObject, self).__setattr__(name, value)
                                        else:
                                            self.__dict__[name].set(value)
                                    else:
                                        if hasattr(value, "parent") and name != "parent":
                                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                                value.parent = self
                                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                                value.parent = self
                                        super(Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.SrlgRroSubObject, self).__setattr__(name, value)

                            def has_data(self):
                                for leaf in self.srl_gs.getYLeafs():
                                    if (leaf.yfilter != YFilter.not_set):
                                        return True
                                return False

                            def has_operation(self):
                                for leaf in self.srl_gs.getYLeafs():
                                    if (leaf.is_set):
                                        return True
                                return (
                                    self.yfilter != YFilter.not_set or
                                    self.srl_gs.yfilter != YFilter.not_set)

                            def get_segment_path(self):
                                path_buffer = ""
                                path_buffer = "srlg-rro-sub-object" + path_buffer

                                return path_buffer

                            def get_entity_path(self, ancestor):
                                path_buffer = ""
                                if (ancestor is None):
                                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/psb-rsb-info/rsb-info/rro/%s" % self.get_segment_path()
                                else:
                                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                                leaf_name_data = LeafDataList()

                                leaf_name_data.extend(self.srl_gs.get_name_leafdata())

                                entity_path = EntityPath(path_buffer, leaf_name_data)
                                return entity_path

                            def get_child_by_name(self, child_yang_name, segment_path):
                                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                                if child is not None:
                                    return child

                                return None

                            def has_leaf_or_child_of_name(self, name):
                                if(name == "srl-gs"):
                                    return True
                                return False

                            def set_value(self, value_path, value, name_space, name_space_prefix):
                                if(value_path == "srl-gs"):
                                    self.srl_gs.append(value)

                        def has_data(self):
                            return (
                                self.rro_type.is_set or
                                (self.ipv4rro_sub_object is not None and self.ipv4rro_sub_object.has_data()) or
                                (self.label_rro_sub_object is not None and self.label_rro_sub_object.has_data()) or
                                (self.srlg_rro_sub_object is not None and self.srlg_rro_sub_object.has_data()) or
                                (self.unnumbered_rro_sub_object is not None and self.unnumbered_rro_sub_object.has_data()))

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.rro_type.yfilter != YFilter.not_set or
                                (self.ipv4rro_sub_object is not None and self.ipv4rro_sub_object.has_operation()) or
                                (self.label_rro_sub_object is not None and self.label_rro_sub_object.has_operation()) or
                                (self.srlg_rro_sub_object is not None and self.srlg_rro_sub_object.has_operation()) or
                                (self.unnumbered_rro_sub_object is not None and self.unnumbered_rro_sub_object.has_operation()))

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "rro" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/psb-rsb-info/rsb-info/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.rro_type.is_set or self.rro_type.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.rro_type.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            if (child_yang_name == "ipv4rro-sub-object"):
                                if (self.ipv4rro_sub_object is None):
                                    self.ipv4rro_sub_object = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.Ipv4RroSubObject()
                                    self.ipv4rro_sub_object.parent = self
                                    self._children_name_map["ipv4rro_sub_object"] = "ipv4rro-sub-object"
                                return self.ipv4rro_sub_object

                            if (child_yang_name == "label-rro-sub-object"):
                                if (self.label_rro_sub_object is None):
                                    self.label_rro_sub_object = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.LabelRroSubObject()
                                    self.label_rro_sub_object.parent = self
                                    self._children_name_map["label_rro_sub_object"] = "label-rro-sub-object"
                                return self.label_rro_sub_object

                            if (child_yang_name == "srlg-rro-sub-object"):
                                if (self.srlg_rro_sub_object is None):
                                    self.srlg_rro_sub_object = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.SrlgRroSubObject()
                                    self.srlg_rro_sub_object.parent = self
                                    self._children_name_map["srlg_rro_sub_object"] = "srlg-rro-sub-object"
                                return self.srlg_rro_sub_object

                            if (child_yang_name == "unnumbered-rro-sub-object"):
                                if (self.unnumbered_rro_sub_object is None):
                                    self.unnumbered_rro_sub_object = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro.UnnumberedRroSubObject()
                                    self.unnumbered_rro_sub_object.parent = self
                                    self._children_name_map["unnumbered_rro_sub_object"] = "unnumbered-rro-sub-object"
                                return self.unnumbered_rro_sub_object

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "ipv4rro-sub-object" or name == "label-rro-sub-object" or name == "srlg-rro-sub-object" or name == "unnumbered-rro-sub-object" or name == "rro-type"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "rro-type"):
                                self.rro_type = value
                                self.rro_type.value_namespace = name_space
                                self.rro_type.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        for c in self.rro:
                            if (c.has_data()):
                                return True
                        return (
                            self.backup_interface.is_set or
                            self.backup_label.is_set or
                            self.destination_address.is_set or
                            self.is_flow_spec_valid.is_set or
                            self.is_rro_valid.is_set or
                            self.is_valid.is_set or
                            self.out_interface.is_set or
                            self.out_label.is_set or
                            (self.flow_spec is not None and self.flow_spec.has_data()) or
                            (self.generic_flow_spec is not None and self.generic_flow_spec.has_data()) or
                            (self.generic_out_label is not None and self.generic_out_label.has_data()))

                    def has_operation(self):
                        for c in self.rro:
                            if (c.has_operation()):
                                return True
                        return (
                            self.yfilter != YFilter.not_set or
                            self.backup_interface.yfilter != YFilter.not_set or
                            self.backup_label.yfilter != YFilter.not_set or
                            self.destination_address.yfilter != YFilter.not_set or
                            self.is_flow_spec_valid.yfilter != YFilter.not_set or
                            self.is_rro_valid.yfilter != YFilter.not_set or
                            self.is_valid.yfilter != YFilter.not_set or
                            self.out_interface.yfilter != YFilter.not_set or
                            self.out_label.yfilter != YFilter.not_set or
                            (self.flow_spec is not None and self.flow_spec.has_operation()) or
                            (self.generic_flow_spec is not None and self.generic_flow_spec.has_operation()) or
                            (self.generic_out_label is not None and self.generic_out_label.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rsb-info" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/psb-rsb-info/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.backup_interface.is_set or self.backup_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.backup_interface.get_name_leafdata())
                        if (self.backup_label.is_set or self.backup_label.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.backup_label.get_name_leafdata())
                        if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.destination_address.get_name_leafdata())
                        if (self.is_flow_spec_valid.is_set or self.is_flow_spec_valid.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_flow_spec_valid.get_name_leafdata())
                        if (self.is_rro_valid.is_set or self.is_rro_valid.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_rro_valid.get_name_leafdata())
                        if (self.is_valid.is_set or self.is_valid.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_valid.get_name_leafdata())
                        if (self.out_interface.is_set or self.out_interface.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.out_interface.get_name_leafdata())
                        if (self.out_label.is_set or self.out_label.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.out_label.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "flow-spec"):
                            if (self.flow_spec is None):
                                self.flow_spec = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.FlowSpec()
                                self.flow_spec.parent = self
                                self._children_name_map["flow_spec"] = "flow-spec"
                            return self.flow_spec

                        if (child_yang_name == "generic-flow-spec"):
                            if (self.generic_flow_spec is None):
                                self.generic_flow_spec = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.GenericFlowSpec()
                                self.generic_flow_spec.parent = self
                                self._children_name_map["generic_flow_spec"] = "generic-flow-spec"
                            return self.generic_flow_spec

                        if (child_yang_name == "generic-out-label"):
                            if (self.generic_out_label is None):
                                self.generic_out_label = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.GenericOutLabel()
                                self.generic_out_label.parent = self
                                self._children_name_map["generic_out_label"] = "generic-out-label"
                            return self.generic_out_label

                        if (child_yang_name == "rro"):
                            for c in self.rro:
                                segment = c.get_segment_path()
                                if (segment_path == segment):
                                    return c
                            c = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo.Rro()
                            c.parent = self
                            local_reference_key = "ydk::seg::%s" % segment_path
                            self._local_refs[local_reference_key] = c
                            self.rro.append(c)
                            return c

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "flow-spec" or name == "generic-flow-spec" or name == "generic-out-label" or name == "rro" or name == "backup-interface" or name == "backup-label" or name == "destination-address" or name == "is-flow-spec-valid" or name == "is-rro-valid" or name == "is-valid" or name == "out-interface" or name == "out-label"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "backup-interface"):
                            self.backup_interface = value
                            self.backup_interface.value_namespace = name_space
                            self.backup_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "backup-label"):
                            self.backup_label = value
                            self.backup_label.value_namespace = name_space
                            self.backup_label.value_namespace_prefix = name_space_prefix
                        if(value_path == "destination-address"):
                            self.destination_address = value
                            self.destination_address.value_namespace = name_space
                            self.destination_address.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-flow-spec-valid"):
                            self.is_flow_spec_valid = value
                            self.is_flow_spec_valid.value_namespace = name_space
                            self.is_flow_spec_valid.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-rro-valid"):
                            self.is_rro_valid = value
                            self.is_rro_valid.value_namespace = name_space
                            self.is_rro_valid.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-valid"):
                            self.is_valid = value
                            self.is_valid.value_namespace = name_space
                            self.is_valid.value_namespace_prefix = name_space_prefix
                        if(value_path == "out-interface"):
                            self.out_interface = value
                            self.out_interface.value_namespace = name_space
                            self.out_interface.value_namespace_prefix = name_space_prefix
                        if(value_path == "out-label"):
                            self.out_label = value
                            self.out_label.value_namespace = name_space
                            self.out_label.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    for c in self.psb_info:
                        if (c.has_data()):
                            return True
                    for c in self.rsb_info:
                        if (c.has_data()):
                            return True
                    return False

                def has_operation(self):
                    for c in self.psb_info:
                        if (c.has_operation()):
                            return True
                    for c in self.rsb_info:
                        if (c.has_operation()):
                            return True
                    return self.yfilter != YFilter.not_set

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "psb-rsb-info" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/session-detailed/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "psb-info"):
                        for c in self.psb_info:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.PsbInfo()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.psb_info.append(c)
                        return c

                    if (child_yang_name == "rsb-info"):
                        for c in self.rsb_info:
                            segment = c.get_segment_path()
                            if (segment_path == segment):
                                return c
                        c = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo.RsbInfo()
                        c.parent = self
                        local_reference_key = "ydk::seg::%s" % segment_path
                        self._local_refs[local_reference_key] = c
                        self.rsb_info.append(c)
                        return c

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "psb-info" or name == "rsb-info"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass

            def has_data(self):
                for c in self.psb_rsb_info:
                    if (c.has_data()):
                        return True
                return (
                    self.destination_address.is_set or
                    self.destination_port.is_set or
                    self.extended_tunnel_id.is_set or
                    self.p2mp_id.is_set or
                    self.protocol.is_set or
                    self.session_type.is_set or
                    self.vrf_name.is_set or
                    (self.compact is not None and self.compact.has_data()) or
                    (self.s2l_sub_lsp is not None and self.s2l_sub_lsp.has_data()))

            def has_operation(self):
                for c in self.psb_rsb_info:
                    if (c.has_operation()):
                        return True
                return (
                    self.yfilter != YFilter.not_set or
                    self.destination_address.yfilter != YFilter.not_set or
                    self.destination_port.yfilter != YFilter.not_set or
                    self.extended_tunnel_id.yfilter != YFilter.not_set or
                    self.p2mp_id.yfilter != YFilter.not_set or
                    self.protocol.yfilter != YFilter.not_set or
                    self.session_type.yfilter != YFilter.not_set or
                    self.vrf_name.yfilter != YFilter.not_set or
                    (self.compact is not None and self.compact.has_operation()) or
                    (self.s2l_sub_lsp is not None and self.s2l_sub_lsp.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "session-detailed" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/session-detaileds/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_address.get_name_leafdata())
                if (self.destination_port.is_set or self.destination_port.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_port.get_name_leafdata())
                if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                if (self.p2mp_id.is_set or self.p2mp_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.p2mp_id.get_name_leafdata())
                if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.protocol.get_name_leafdata())
                if (self.session_type.is_set or self.session_type.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.session_type.get_name_leafdata())
                if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.vrf_name.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "compact"):
                    if (self.compact is None):
                        self.compact = Rsvp.SessionDetaileds.SessionDetailed.Compact()
                        self.compact.parent = self
                        self._children_name_map["compact"] = "compact"
                    return self.compact

                if (child_yang_name == "psb-rsb-info"):
                    for c in self.psb_rsb_info:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = Rsvp.SessionDetaileds.SessionDetailed.PsbRsbInfo()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.psb_rsb_info.append(c)
                    return c

                if (child_yang_name == "s2l-sub-lsp"):
                    if (self.s2l_sub_lsp is None):
                        self.s2l_sub_lsp = Rsvp.SessionDetaileds.SessionDetailed.S2LSubLsp()
                        self.s2l_sub_lsp.parent = self
                        self._children_name_map["s2l_sub_lsp"] = "s2l-sub-lsp"
                    return self.s2l_sub_lsp

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "compact" or name == "psb-rsb-info" or name == "s2l-sub-lsp" or name == "destination-address" or name == "destination-port" or name == "extended-tunnel-id" or name == "p2mp-id" or name == "protocol" or name == "session-type" or name == "vrf-name"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "destination-address"):
                    self.destination_address = value
                    self.destination_address.value_namespace = name_space
                    self.destination_address.value_namespace_prefix = name_space_prefix
                if(value_path == "destination-port"):
                    self.destination_port = value
                    self.destination_port.value_namespace = name_space
                    self.destination_port.value_namespace_prefix = name_space_prefix
                if(value_path == "extended-tunnel-id"):
                    self.extended_tunnel_id = value
                    self.extended_tunnel_id.value_namespace = name_space
                    self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                if(value_path == "p2mp-id"):
                    self.p2mp_id = value
                    self.p2mp_id.value_namespace = name_space
                    self.p2mp_id.value_namespace_prefix = name_space_prefix
                if(value_path == "protocol"):
                    self.protocol = value
                    self.protocol.value_namespace = name_space
                    self.protocol.value_namespace_prefix = name_space_prefix
                if(value_path == "session-type"):
                    self.session_type = value
                    self.session_type.value_namespace = name_space
                    self.session_type.value_namespace_prefix = name_space_prefix
                if(value_path == "vrf-name"):
                    self.vrf_name = value
                    self.vrf_name.value_namespace = name_space
                    self.vrf_name.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.session_detailed:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.session_detailed:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "session-detaileds" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "session-detailed"):
                for c in self.session_detailed:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = Rsvp.SessionDetaileds.SessionDetailed()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.session_detailed.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "session-detailed"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class HelloInstanceDetails(Entity):
        """
        Table of detailed info about hello instances
        
        .. attribute:: hello_instance_detail
        
        	Detailed info for a single hello instance
        	**type**\: list of    :py:class:`HelloInstanceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.HelloInstanceDetails.HelloInstanceDetail>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Rsvp.HelloInstanceDetails, self).__init__()

            self.yang_name = "hello-instance-details"
            self.yang_parent_name = "rsvp"

            self.hello_instance_detail = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(Rsvp.HelloInstanceDetails, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(Rsvp.HelloInstanceDetails, self).__setattr__(name, value)


        class HelloInstanceDetail(Entity):
            """
            Detailed info for a single hello instance
            
            .. attribute:: source_address  <key>
            
            	Source Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: destination_address  <key>
            
            	Destination Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: communication_lost_hello_missed
            
            	Lost Comm. Hello missed count
            	**type**\:  int
            
            	**range:** 0..65535
            
            .. attribute:: communication_lost_interface_down
            
            	Count of lost comm. due to interface down
            	**type**\:  int
            
            	**range:** 0..65535
            
            .. attribute:: communication_lost_neighbor_disabled_hello
            
            	Count of lost comm. due to nbor disabling Hellos
            	**type**\:  int
            
            	**range:** 0..65535
            
            .. attribute:: communication_lost_reason
            
            	Reason why communication was lost
            	**type**\:   :py:class:`RsvpMgmtHelloDownReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtHelloDownReason>`
            
            .. attribute:: communication_lost_time
            
            	Time when communication was lost
            	**type**\:   :py:class:`CommunicationLostTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.HelloInstanceDetails.HelloInstanceDetail.CommunicationLostTime>`
            
            .. attribute:: communication_lost_wrong_destination_inst
            
            	Count of lost comm. due to wrong Destination Inst
            	**type**\:  int
            
            	**range:** 0..65535
            
            .. attribute:: communication_lost_wrong_source_inst
            
            	Count of lost comm. due to wrong Source Inst
            	**type**\:  int
            
            	**range:** 0..65535
            
            .. attribute:: destination_address_xr
            
            	Destination address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: destination_instance
            
            	Destination Instance
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: hello_instance_owner
            
            	Hello instance owner
            	**type**\:   :py:class:`RsvpMgmtHelloInstanceOwner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtHelloInstanceOwner>`
            
            .. attribute:: hello_interface
            
            	Interface to use
            	**type**\:  str
            
            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
            
            .. attribute:: hello_interval
            
            	Hello Interval
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: hello_messages_received
            
            	Number of hello messages received
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: hello_messages_sent
            
            	Number of hello messages sent
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: hello_request_suppressed
            
            	Count of Hello Requests suppessed
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: instance_type
            
            	Hello instance type
            	**type**\:   :py:class:`RsvpMgmtHelloInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtHelloInstance>`
            
            .. attribute:: missed_acks_allowed
            
            	Number of missed Hello allowed
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: neighbor_hello_state
            
            	Neighbor Hello state
            	**type**\:   :py:class:`RsvpMgmtHelloState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtHelloState>`
            
            .. attribute:: source_address_xr
            
            	Source address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: source_instance
            
            	Source Instance
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: total_communication_lost
            
            	Total number of times communication got lost
            	**type**\:  int
            
            	**range:** 0..65535
            
            .. attribute:: up_time
            
            	Hello up time
            	**type**\:   :py:class:`UpTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.HelloInstanceDetails.HelloInstanceDetail.UpTime>`
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Rsvp.HelloInstanceDetails.HelloInstanceDetail, self).__init__()

                self.yang_name = "hello-instance-detail"
                self.yang_parent_name = "hello-instance-details"

                self.source_address = YLeaf(YType.str, "source-address")

                self.destination_address = YLeaf(YType.str, "destination-address")

                self.communication_lost_hello_missed = YLeaf(YType.uint16, "communication-lost-hello-missed")

                self.communication_lost_interface_down = YLeaf(YType.uint16, "communication-lost-interface-down")

                self.communication_lost_neighbor_disabled_hello = YLeaf(YType.uint16, "communication-lost-neighbor-disabled-hello")

                self.communication_lost_reason = YLeaf(YType.enumeration, "communication-lost-reason")

                self.communication_lost_wrong_destination_inst = YLeaf(YType.uint16, "communication-lost-wrong-destination-inst")

                self.communication_lost_wrong_source_inst = YLeaf(YType.uint16, "communication-lost-wrong-source-inst")

                self.destination_address_xr = YLeaf(YType.str, "destination-address-xr")

                self.destination_instance = YLeaf(YType.uint32, "destination-instance")

                self.hello_instance_owner = YLeaf(YType.enumeration, "hello-instance-owner")

                self.hello_interface = YLeaf(YType.str, "hello-interface")

                self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                self.hello_messages_received = YLeaf(YType.uint64, "hello-messages-received")

                self.hello_messages_sent = YLeaf(YType.uint64, "hello-messages-sent")

                self.hello_request_suppressed = YLeaf(YType.uint64, "hello-request-suppressed")

                self.instance_type = YLeaf(YType.enumeration, "instance-type")

                self.missed_acks_allowed = YLeaf(YType.uint32, "missed-acks-allowed")

                self.neighbor_hello_state = YLeaf(YType.enumeration, "neighbor-hello-state")

                self.source_address_xr = YLeaf(YType.str, "source-address-xr")

                self.source_instance = YLeaf(YType.uint32, "source-instance")

                self.total_communication_lost = YLeaf(YType.uint16, "total-communication-lost")

                self.communication_lost_time = Rsvp.HelloInstanceDetails.HelloInstanceDetail.CommunicationLostTime()
                self.communication_lost_time.parent = self
                self._children_name_map["communication_lost_time"] = "communication-lost-time"
                self._children_yang_names.add("communication-lost-time")

                self.up_time = Rsvp.HelloInstanceDetails.HelloInstanceDetail.UpTime()
                self.up_time.parent = self
                self._children_name_map["up_time"] = "up-time"
                self._children_yang_names.add("up-time")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("source_address",
                                "destination_address",
                                "communication_lost_hello_missed",
                                "communication_lost_interface_down",
                                "communication_lost_neighbor_disabled_hello",
                                "communication_lost_reason",
                                "communication_lost_wrong_destination_inst",
                                "communication_lost_wrong_source_inst",
                                "destination_address_xr",
                                "destination_instance",
                                "hello_instance_owner",
                                "hello_interface",
                                "hello_interval",
                                "hello_messages_received",
                                "hello_messages_sent",
                                "hello_request_suppressed",
                                "instance_type",
                                "missed_acks_allowed",
                                "neighbor_hello_state",
                                "source_address_xr",
                                "source_instance",
                                "total_communication_lost") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Rsvp.HelloInstanceDetails.HelloInstanceDetail, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Rsvp.HelloInstanceDetails.HelloInstanceDetail, self).__setattr__(name, value)


            class UpTime(Entity):
                """
                Hello up time
                
                .. attribute:: nanoseconds
                
                	Time Value in Nano\-seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: nanosecond
                
                .. attribute:: seconds
                
                	Time Value in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.HelloInstanceDetails.HelloInstanceDetail.UpTime, self).__init__()

                    self.yang_name = "up-time"
                    self.yang_parent_name = "hello-instance-detail"

                    self.nanoseconds = YLeaf(YType.int32, "nanoseconds")

                    self.seconds = YLeaf(YType.int32, "seconds")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("nanoseconds",
                                    "seconds") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.HelloInstanceDetails.HelloInstanceDetail.UpTime, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.HelloInstanceDetails.HelloInstanceDetail.UpTime, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.nanoseconds.is_set or
                        self.seconds.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.nanoseconds.yfilter != YFilter.not_set or
                        self.seconds.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "up-time" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.nanoseconds.is_set or self.nanoseconds.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.nanoseconds.get_name_leafdata())
                    if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.seconds.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "nanoseconds" or name == "seconds"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "nanoseconds"):
                        self.nanoseconds = value
                        self.nanoseconds.value_namespace = name_space
                        self.nanoseconds.value_namespace_prefix = name_space_prefix
                    if(value_path == "seconds"):
                        self.seconds = value
                        self.seconds.value_namespace = name_space
                        self.seconds.value_namespace_prefix = name_space_prefix


            class CommunicationLostTime(Entity):
                """
                Time when communication was lost
                
                .. attribute:: nanoseconds
                
                	Time Value in Nano\-seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: nanosecond
                
                .. attribute:: seconds
                
                	Time Value in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.HelloInstanceDetails.HelloInstanceDetail.CommunicationLostTime, self).__init__()

                    self.yang_name = "communication-lost-time"
                    self.yang_parent_name = "hello-instance-detail"

                    self.nanoseconds = YLeaf(YType.int32, "nanoseconds")

                    self.seconds = YLeaf(YType.int32, "seconds")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("nanoseconds",
                                    "seconds") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.HelloInstanceDetails.HelloInstanceDetail.CommunicationLostTime, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.HelloInstanceDetails.HelloInstanceDetail.CommunicationLostTime, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.nanoseconds.is_set or
                        self.seconds.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.nanoseconds.yfilter != YFilter.not_set or
                        self.seconds.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "communication-lost-time" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.nanoseconds.is_set or self.nanoseconds.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.nanoseconds.get_name_leafdata())
                    if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.seconds.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "nanoseconds" or name == "seconds"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "nanoseconds"):
                        self.nanoseconds = value
                        self.nanoseconds.value_namespace = name_space
                        self.nanoseconds.value_namespace_prefix = name_space_prefix
                    if(value_path == "seconds"):
                        self.seconds = value
                        self.seconds.value_namespace = name_space
                        self.seconds.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.source_address.is_set or
                    self.destination_address.is_set or
                    self.communication_lost_hello_missed.is_set or
                    self.communication_lost_interface_down.is_set or
                    self.communication_lost_neighbor_disabled_hello.is_set or
                    self.communication_lost_reason.is_set or
                    self.communication_lost_wrong_destination_inst.is_set or
                    self.communication_lost_wrong_source_inst.is_set or
                    self.destination_address_xr.is_set or
                    self.destination_instance.is_set or
                    self.hello_instance_owner.is_set or
                    self.hello_interface.is_set or
                    self.hello_interval.is_set or
                    self.hello_messages_received.is_set or
                    self.hello_messages_sent.is_set or
                    self.hello_request_suppressed.is_set or
                    self.instance_type.is_set or
                    self.missed_acks_allowed.is_set or
                    self.neighbor_hello_state.is_set or
                    self.source_address_xr.is_set or
                    self.source_instance.is_set or
                    self.total_communication_lost.is_set or
                    (self.communication_lost_time is not None and self.communication_lost_time.has_data()) or
                    (self.up_time is not None and self.up_time.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.source_address.yfilter != YFilter.not_set or
                    self.destination_address.yfilter != YFilter.not_set or
                    self.communication_lost_hello_missed.yfilter != YFilter.not_set or
                    self.communication_lost_interface_down.yfilter != YFilter.not_set or
                    self.communication_lost_neighbor_disabled_hello.yfilter != YFilter.not_set or
                    self.communication_lost_reason.yfilter != YFilter.not_set or
                    self.communication_lost_wrong_destination_inst.yfilter != YFilter.not_set or
                    self.communication_lost_wrong_source_inst.yfilter != YFilter.not_set or
                    self.destination_address_xr.yfilter != YFilter.not_set or
                    self.destination_instance.yfilter != YFilter.not_set or
                    self.hello_instance_owner.yfilter != YFilter.not_set or
                    self.hello_interface.yfilter != YFilter.not_set or
                    self.hello_interval.yfilter != YFilter.not_set or
                    self.hello_messages_received.yfilter != YFilter.not_set or
                    self.hello_messages_sent.yfilter != YFilter.not_set or
                    self.hello_request_suppressed.yfilter != YFilter.not_set or
                    self.instance_type.yfilter != YFilter.not_set or
                    self.missed_acks_allowed.yfilter != YFilter.not_set or
                    self.neighbor_hello_state.yfilter != YFilter.not_set or
                    self.source_address_xr.yfilter != YFilter.not_set or
                    self.source_instance.yfilter != YFilter.not_set or
                    self.total_communication_lost.yfilter != YFilter.not_set or
                    (self.communication_lost_time is not None and self.communication_lost_time.has_operation()) or
                    (self.up_time is not None and self.up_time.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "hello-instance-detail" + "[source-address='" + self.source_address.get() + "']" + "[destination-address='" + self.destination_address.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/hello-instance-details/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_address.get_name_leafdata())
                if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_address.get_name_leafdata())
                if (self.communication_lost_hello_missed.is_set or self.communication_lost_hello_missed.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.communication_lost_hello_missed.get_name_leafdata())
                if (self.communication_lost_interface_down.is_set or self.communication_lost_interface_down.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.communication_lost_interface_down.get_name_leafdata())
                if (self.communication_lost_neighbor_disabled_hello.is_set or self.communication_lost_neighbor_disabled_hello.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.communication_lost_neighbor_disabled_hello.get_name_leafdata())
                if (self.communication_lost_reason.is_set or self.communication_lost_reason.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.communication_lost_reason.get_name_leafdata())
                if (self.communication_lost_wrong_destination_inst.is_set or self.communication_lost_wrong_destination_inst.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.communication_lost_wrong_destination_inst.get_name_leafdata())
                if (self.communication_lost_wrong_source_inst.is_set or self.communication_lost_wrong_source_inst.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.communication_lost_wrong_source_inst.get_name_leafdata())
                if (self.destination_address_xr.is_set or self.destination_address_xr.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_address_xr.get_name_leafdata())
                if (self.destination_instance.is_set or self.destination_instance.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_instance.get_name_leafdata())
                if (self.hello_instance_owner.is_set or self.hello_instance_owner.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.hello_instance_owner.get_name_leafdata())
                if (self.hello_interface.is_set or self.hello_interface.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.hello_interface.get_name_leafdata())
                if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.hello_interval.get_name_leafdata())
                if (self.hello_messages_received.is_set or self.hello_messages_received.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.hello_messages_received.get_name_leafdata())
                if (self.hello_messages_sent.is_set or self.hello_messages_sent.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.hello_messages_sent.get_name_leafdata())
                if (self.hello_request_suppressed.is_set or self.hello_request_suppressed.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.hello_request_suppressed.get_name_leafdata())
                if (self.instance_type.is_set or self.instance_type.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.instance_type.get_name_leafdata())
                if (self.missed_acks_allowed.is_set or self.missed_acks_allowed.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.missed_acks_allowed.get_name_leafdata())
                if (self.neighbor_hello_state.is_set or self.neighbor_hello_state.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.neighbor_hello_state.get_name_leafdata())
                if (self.source_address_xr.is_set or self.source_address_xr.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_address_xr.get_name_leafdata())
                if (self.source_instance.is_set or self.source_instance.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_instance.get_name_leafdata())
                if (self.total_communication_lost.is_set or self.total_communication_lost.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.total_communication_lost.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "communication-lost-time"):
                    if (self.communication_lost_time is None):
                        self.communication_lost_time = Rsvp.HelloInstanceDetails.HelloInstanceDetail.CommunicationLostTime()
                        self.communication_lost_time.parent = self
                        self._children_name_map["communication_lost_time"] = "communication-lost-time"
                    return self.communication_lost_time

                if (child_yang_name == "up-time"):
                    if (self.up_time is None):
                        self.up_time = Rsvp.HelloInstanceDetails.HelloInstanceDetail.UpTime()
                        self.up_time.parent = self
                        self._children_name_map["up_time"] = "up-time"
                    return self.up_time

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "communication-lost-time" or name == "up-time" or name == "source-address" or name == "destination-address" or name == "communication-lost-hello-missed" or name == "communication-lost-interface-down" or name == "communication-lost-neighbor-disabled-hello" or name == "communication-lost-reason" or name == "communication-lost-wrong-destination-inst" or name == "communication-lost-wrong-source-inst" or name == "destination-address-xr" or name == "destination-instance" or name == "hello-instance-owner" or name == "hello-interface" or name == "hello-interval" or name == "hello-messages-received" or name == "hello-messages-sent" or name == "hello-request-suppressed" or name == "instance-type" or name == "missed-acks-allowed" or name == "neighbor-hello-state" or name == "source-address-xr" or name == "source-instance" or name == "total-communication-lost"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "source-address"):
                    self.source_address = value
                    self.source_address.value_namespace = name_space
                    self.source_address.value_namespace_prefix = name_space_prefix
                if(value_path == "destination-address"):
                    self.destination_address = value
                    self.destination_address.value_namespace = name_space
                    self.destination_address.value_namespace_prefix = name_space_prefix
                if(value_path == "communication-lost-hello-missed"):
                    self.communication_lost_hello_missed = value
                    self.communication_lost_hello_missed.value_namespace = name_space
                    self.communication_lost_hello_missed.value_namespace_prefix = name_space_prefix
                if(value_path == "communication-lost-interface-down"):
                    self.communication_lost_interface_down = value
                    self.communication_lost_interface_down.value_namespace = name_space
                    self.communication_lost_interface_down.value_namespace_prefix = name_space_prefix
                if(value_path == "communication-lost-neighbor-disabled-hello"):
                    self.communication_lost_neighbor_disabled_hello = value
                    self.communication_lost_neighbor_disabled_hello.value_namespace = name_space
                    self.communication_lost_neighbor_disabled_hello.value_namespace_prefix = name_space_prefix
                if(value_path == "communication-lost-reason"):
                    self.communication_lost_reason = value
                    self.communication_lost_reason.value_namespace = name_space
                    self.communication_lost_reason.value_namespace_prefix = name_space_prefix
                if(value_path == "communication-lost-wrong-destination-inst"):
                    self.communication_lost_wrong_destination_inst = value
                    self.communication_lost_wrong_destination_inst.value_namespace = name_space
                    self.communication_lost_wrong_destination_inst.value_namespace_prefix = name_space_prefix
                if(value_path == "communication-lost-wrong-source-inst"):
                    self.communication_lost_wrong_source_inst = value
                    self.communication_lost_wrong_source_inst.value_namespace = name_space
                    self.communication_lost_wrong_source_inst.value_namespace_prefix = name_space_prefix
                if(value_path == "destination-address-xr"):
                    self.destination_address_xr = value
                    self.destination_address_xr.value_namespace = name_space
                    self.destination_address_xr.value_namespace_prefix = name_space_prefix
                if(value_path == "destination-instance"):
                    self.destination_instance = value
                    self.destination_instance.value_namespace = name_space
                    self.destination_instance.value_namespace_prefix = name_space_prefix
                if(value_path == "hello-instance-owner"):
                    self.hello_instance_owner = value
                    self.hello_instance_owner.value_namespace = name_space
                    self.hello_instance_owner.value_namespace_prefix = name_space_prefix
                if(value_path == "hello-interface"):
                    self.hello_interface = value
                    self.hello_interface.value_namespace = name_space
                    self.hello_interface.value_namespace_prefix = name_space_prefix
                if(value_path == "hello-interval"):
                    self.hello_interval = value
                    self.hello_interval.value_namespace = name_space
                    self.hello_interval.value_namespace_prefix = name_space_prefix
                if(value_path == "hello-messages-received"):
                    self.hello_messages_received = value
                    self.hello_messages_received.value_namespace = name_space
                    self.hello_messages_received.value_namespace_prefix = name_space_prefix
                if(value_path == "hello-messages-sent"):
                    self.hello_messages_sent = value
                    self.hello_messages_sent.value_namespace = name_space
                    self.hello_messages_sent.value_namespace_prefix = name_space_prefix
                if(value_path == "hello-request-suppressed"):
                    self.hello_request_suppressed = value
                    self.hello_request_suppressed.value_namespace = name_space
                    self.hello_request_suppressed.value_namespace_prefix = name_space_prefix
                if(value_path == "instance-type"):
                    self.instance_type = value
                    self.instance_type.value_namespace = name_space
                    self.instance_type.value_namespace_prefix = name_space_prefix
                if(value_path == "missed-acks-allowed"):
                    self.missed_acks_allowed = value
                    self.missed_acks_allowed.value_namespace = name_space
                    self.missed_acks_allowed.value_namespace_prefix = name_space_prefix
                if(value_path == "neighbor-hello-state"):
                    self.neighbor_hello_state = value
                    self.neighbor_hello_state.value_namespace = name_space
                    self.neighbor_hello_state.value_namespace_prefix = name_space_prefix
                if(value_path == "source-address-xr"):
                    self.source_address_xr = value
                    self.source_address_xr.value_namespace = name_space
                    self.source_address_xr.value_namespace_prefix = name_space_prefix
                if(value_path == "source-instance"):
                    self.source_instance = value
                    self.source_instance.value_namespace = name_space
                    self.source_instance.value_namespace_prefix = name_space_prefix
                if(value_path == "total-communication-lost"):
                    self.total_communication_lost = value
                    self.total_communication_lost.value_namespace = name_space
                    self.total_communication_lost.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.hello_instance_detail:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.hello_instance_detail:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "hello-instance-details" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "hello-instance-detail"):
                for c in self.hello_instance_detail:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = Rsvp.HelloInstanceDetails.HelloInstanceDetail()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.hello_instance_detail.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "hello-instance-detail"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class GlobalNeighborDetails(Entity):
        """
        Table of detailed info about global neighbors
        
        .. attribute:: global_neighbor_detail
        
        	Detail info for a single global neighbor
        	**type**\: list of    :py:class:`GlobalNeighborDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.GlobalNeighborDetails.GlobalNeighborDetail>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Rsvp.GlobalNeighborDetails, self).__init__()

            self.yang_name = "global-neighbor-details"
            self.yang_parent_name = "rsvp"

            self.global_neighbor_detail = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(Rsvp.GlobalNeighborDetails, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(Rsvp.GlobalNeighborDetails, self).__setattr__(name, value)


        class GlobalNeighborDetail(Entity):
            """
            Detail info for a single global neighbor
            
            .. attribute:: neighbor_address  <key>
            
            	Address of global neighbor
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: global_neighbor_flags
            
            	Global Neighbor Flags
            	**type**\:   :py:class:`GlobalNeighborFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.GlobalNeighborDetails.GlobalNeighborDetail.GlobalNeighborFlags>`
            
            .. attribute:: hello_interval
            
            	Hello Interval (milliseconds)
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            	**units**\: millisecond
            
            .. attribute:: interface_neighbor
            
            	Interface Neighbor List
            	**type**\:  list of str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: is_gr_enabled
            
            	Is GR enabled
            	**type**\:  bool
            
            .. attribute:: is_recovery_timer_running
            
            	Is RSVP recovery timer running
            	**type**\:  bool
            
            .. attribute:: is_restart_timer_running
            
            	Is GR restart timer running
            	**type**\:  bool
            
            .. attribute:: local_node_address
            
            	Local node address
            	**type**\:  list of str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: lost_communication_reason
            
            	Reason why communication was lost
            	**type**\:  list of   :py:class:`RsvpMgmtHelloDownReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtHelloDownReason>`
            
            .. attribute:: lost_communication_time
            
            	Time when communication was lost
            	**type**\: list of    :py:class:`LostCommunicationTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.GlobalNeighborDetails.GlobalNeighborDetail.LostCommunicationTime>`
            
            .. attribute:: lost_communication_total
            
            	Total number of times communication got lost
            	**type**\:  list of int
            
            	**range:** 0..65535
            
            .. attribute:: missed_hellos
            
            	Hello missed count
            	**type**\:  int
            
            	**range:** 0..255
            
            .. attribute:: neighbor_hello_state
            
            	Neighbor's hello state
            	**type**\:  list of   :py:class:`RsvpMgmtHelloState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtHelloState>`
            
            .. attribute:: node_address
            
            	Neighbor node address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: pending_states
            
            	Number of pending states for this neighbor
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: recovery_time
            
            	GR Recovery Time (milliseconds)
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            	**units**\: millisecond
            
            .. attribute:: recovery_time_left
            
            	How much recovery timer remains
            	**type**\:   :py:class:`RecoveryTimeLeft <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.GlobalNeighborDetails.GlobalNeighborDetail.RecoveryTimeLeft>`
            
            .. attribute:: recovery_timer_exp_time
            
            	Time at which recovery timer will expire
            	**type**\:   :py:class:`RecoveryTimerExpTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.GlobalNeighborDetails.GlobalNeighborDetail.RecoveryTimerExpTime>`
            
            .. attribute:: restart_state
            
            	Current restart state
            	**type**\:   :py:class:`RsvpMgmtRestartState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtRestartState>`
            
            .. attribute:: restart_time
            
            	GR Restart Time (milliseconds)
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            	**units**\: millisecond
            
            .. attribute:: restart_time_left
            
            	How much restart time remains
            	**type**\:   :py:class:`RestartTimeLeft <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.GlobalNeighborDetails.GlobalNeighborDetail.RestartTimeLeft>`
            
            .. attribute:: restart_timer_expiry_time
            
            	When will restart timer expire
            	**type**\:   :py:class:`RestartTimerExpiryTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.GlobalNeighborDetails.GlobalNeighborDetail.RestartTimerExpiryTime>`
            
            .. attribute:: up_time
            
            	Hello up time
            	**type**\: list of    :py:class:`UpTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.GlobalNeighborDetails.GlobalNeighborDetail.UpTime>`
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Rsvp.GlobalNeighborDetails.GlobalNeighborDetail, self).__init__()

                self.yang_name = "global-neighbor-detail"
                self.yang_parent_name = "global-neighbor-details"

                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                self.interface_neighbor = YLeafList(YType.str, "interface-neighbor")

                self.is_gr_enabled = YLeaf(YType.boolean, "is-gr-enabled")

                self.is_recovery_timer_running = YLeaf(YType.boolean, "is-recovery-timer-running")

                self.is_restart_timer_running = YLeaf(YType.boolean, "is-restart-timer-running")

                self.local_node_address = YLeafList(YType.str, "local-node-address")

                self.lost_communication_reason = YLeafList(YType.enumeration, "lost-communication-reason")

                self.lost_communication_total = YLeafList(YType.uint16, "lost-communication-total")

                self.missed_hellos = YLeaf(YType.uint8, "missed-hellos")

                self.neighbor_hello_state = YLeafList(YType.enumeration, "neighbor-hello-state")

                self.node_address = YLeaf(YType.str, "node-address")

                self.pending_states = YLeaf(YType.uint32, "pending-states")

                self.recovery_time = YLeaf(YType.uint32, "recovery-time")

                self.restart_state = YLeaf(YType.enumeration, "restart-state")

                self.restart_time = YLeaf(YType.uint32, "restart-time")

                self.global_neighbor_flags = Rsvp.GlobalNeighborDetails.GlobalNeighborDetail.GlobalNeighborFlags()
                self.global_neighbor_flags.parent = self
                self._children_name_map["global_neighbor_flags"] = "global-neighbor-flags"
                self._children_yang_names.add("global-neighbor-flags")

                self.recovery_time_left = Rsvp.GlobalNeighborDetails.GlobalNeighborDetail.RecoveryTimeLeft()
                self.recovery_time_left.parent = self
                self._children_name_map["recovery_time_left"] = "recovery-time-left"
                self._children_yang_names.add("recovery-time-left")

                self.recovery_timer_exp_time = Rsvp.GlobalNeighborDetails.GlobalNeighborDetail.RecoveryTimerExpTime()
                self.recovery_timer_exp_time.parent = self
                self._children_name_map["recovery_timer_exp_time"] = "recovery-timer-exp-time"
                self._children_yang_names.add("recovery-timer-exp-time")

                self.restart_time_left = Rsvp.GlobalNeighborDetails.GlobalNeighborDetail.RestartTimeLeft()
                self.restart_time_left.parent = self
                self._children_name_map["restart_time_left"] = "restart-time-left"
                self._children_yang_names.add("restart-time-left")

                self.restart_timer_expiry_time = Rsvp.GlobalNeighborDetails.GlobalNeighborDetail.RestartTimerExpiryTime()
                self.restart_timer_expiry_time.parent = self
                self._children_name_map["restart_timer_expiry_time"] = "restart-timer-expiry-time"
                self._children_yang_names.add("restart-timer-expiry-time")

                self.lost_communication_time = YList(self)
                self.up_time = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("neighbor_address",
                                "hello_interval",
                                "interface_neighbor",
                                "is_gr_enabled",
                                "is_recovery_timer_running",
                                "is_restart_timer_running",
                                "local_node_address",
                                "lost_communication_reason",
                                "lost_communication_total",
                                "missed_hellos",
                                "neighbor_hello_state",
                                "node_address",
                                "pending_states",
                                "recovery_time",
                                "restart_state",
                                "restart_time") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Rsvp.GlobalNeighborDetails.GlobalNeighborDetail, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Rsvp.GlobalNeighborDetails.GlobalNeighborDetail, self).__setattr__(name, value)


            class GlobalNeighborFlags(Entity):
                """
                Global Neighbor Flags
                
                .. attribute:: is_application_mpls
                
                	MPLS Application
                	**type**\:  bool
                
                .. attribute:: is_application_ouni
                
                	OUNI Application
                	**type**\:  bool
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.GlobalNeighborDetails.GlobalNeighborDetail.GlobalNeighborFlags, self).__init__()

                    self.yang_name = "global-neighbor-flags"
                    self.yang_parent_name = "global-neighbor-detail"

                    self.is_application_mpls = YLeaf(YType.boolean, "is-application-mpls")

                    self.is_application_ouni = YLeaf(YType.boolean, "is-application-ouni")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("is_application_mpls",
                                    "is_application_ouni") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.GlobalNeighborDetails.GlobalNeighborDetail.GlobalNeighborFlags, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.GlobalNeighborDetails.GlobalNeighborDetail.GlobalNeighborFlags, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.is_application_mpls.is_set or
                        self.is_application_ouni.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.is_application_mpls.yfilter != YFilter.not_set or
                        self.is_application_ouni.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "global-neighbor-flags" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.is_application_mpls.is_set or self.is_application_mpls.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_application_mpls.get_name_leafdata())
                    if (self.is_application_ouni.is_set or self.is_application_ouni.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_application_ouni.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "is-application-mpls" or name == "is-application-ouni"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "is-application-mpls"):
                        self.is_application_mpls = value
                        self.is_application_mpls.value_namespace = name_space
                        self.is_application_mpls.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-application-ouni"):
                        self.is_application_ouni = value
                        self.is_application_ouni.value_namespace = name_space
                        self.is_application_ouni.value_namespace_prefix = name_space_prefix


            class RestartTimeLeft(Entity):
                """
                How much restart time remains
                
                .. attribute:: nanoseconds
                
                	Time Value in Nano\-seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: nanosecond
                
                .. attribute:: seconds
                
                	Time Value in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.GlobalNeighborDetails.GlobalNeighborDetail.RestartTimeLeft, self).__init__()

                    self.yang_name = "restart-time-left"
                    self.yang_parent_name = "global-neighbor-detail"

                    self.nanoseconds = YLeaf(YType.int32, "nanoseconds")

                    self.seconds = YLeaf(YType.int32, "seconds")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("nanoseconds",
                                    "seconds") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.GlobalNeighborDetails.GlobalNeighborDetail.RestartTimeLeft, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.GlobalNeighborDetails.GlobalNeighborDetail.RestartTimeLeft, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.nanoseconds.is_set or
                        self.seconds.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.nanoseconds.yfilter != YFilter.not_set or
                        self.seconds.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "restart-time-left" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.nanoseconds.is_set or self.nanoseconds.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.nanoseconds.get_name_leafdata())
                    if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.seconds.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "nanoseconds" or name == "seconds"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "nanoseconds"):
                        self.nanoseconds = value
                        self.nanoseconds.value_namespace = name_space
                        self.nanoseconds.value_namespace_prefix = name_space_prefix
                    if(value_path == "seconds"):
                        self.seconds = value
                        self.seconds.value_namespace = name_space
                        self.seconds.value_namespace_prefix = name_space_prefix


            class RestartTimerExpiryTime(Entity):
                """
                When will restart timer expire
                
                .. attribute:: nanoseconds
                
                	Time Value in Nano\-seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: nanosecond
                
                .. attribute:: seconds
                
                	Time Value in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.GlobalNeighborDetails.GlobalNeighborDetail.RestartTimerExpiryTime, self).__init__()

                    self.yang_name = "restart-timer-expiry-time"
                    self.yang_parent_name = "global-neighbor-detail"

                    self.nanoseconds = YLeaf(YType.int32, "nanoseconds")

                    self.seconds = YLeaf(YType.int32, "seconds")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("nanoseconds",
                                    "seconds") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.GlobalNeighborDetails.GlobalNeighborDetail.RestartTimerExpiryTime, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.GlobalNeighborDetails.GlobalNeighborDetail.RestartTimerExpiryTime, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.nanoseconds.is_set or
                        self.seconds.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.nanoseconds.yfilter != YFilter.not_set or
                        self.seconds.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "restart-timer-expiry-time" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.nanoseconds.is_set or self.nanoseconds.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.nanoseconds.get_name_leafdata())
                    if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.seconds.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "nanoseconds" or name == "seconds"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "nanoseconds"):
                        self.nanoseconds = value
                        self.nanoseconds.value_namespace = name_space
                        self.nanoseconds.value_namespace_prefix = name_space_prefix
                    if(value_path == "seconds"):
                        self.seconds = value
                        self.seconds.value_namespace = name_space
                        self.seconds.value_namespace_prefix = name_space_prefix


            class RecoveryTimeLeft(Entity):
                """
                How much recovery timer remains
                
                .. attribute:: nanoseconds
                
                	Time Value in Nano\-seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: nanosecond
                
                .. attribute:: seconds
                
                	Time Value in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.GlobalNeighborDetails.GlobalNeighborDetail.RecoveryTimeLeft, self).__init__()

                    self.yang_name = "recovery-time-left"
                    self.yang_parent_name = "global-neighbor-detail"

                    self.nanoseconds = YLeaf(YType.int32, "nanoseconds")

                    self.seconds = YLeaf(YType.int32, "seconds")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("nanoseconds",
                                    "seconds") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.GlobalNeighborDetails.GlobalNeighborDetail.RecoveryTimeLeft, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.GlobalNeighborDetails.GlobalNeighborDetail.RecoveryTimeLeft, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.nanoseconds.is_set or
                        self.seconds.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.nanoseconds.yfilter != YFilter.not_set or
                        self.seconds.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "recovery-time-left" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.nanoseconds.is_set or self.nanoseconds.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.nanoseconds.get_name_leafdata())
                    if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.seconds.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "nanoseconds" or name == "seconds"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "nanoseconds"):
                        self.nanoseconds = value
                        self.nanoseconds.value_namespace = name_space
                        self.nanoseconds.value_namespace_prefix = name_space_prefix
                    if(value_path == "seconds"):
                        self.seconds = value
                        self.seconds.value_namespace = name_space
                        self.seconds.value_namespace_prefix = name_space_prefix


            class RecoveryTimerExpTime(Entity):
                """
                Time at which recovery timer will expire
                
                .. attribute:: nanoseconds
                
                	Time Value in Nano\-seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: nanosecond
                
                .. attribute:: seconds
                
                	Time Value in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.GlobalNeighborDetails.GlobalNeighborDetail.RecoveryTimerExpTime, self).__init__()

                    self.yang_name = "recovery-timer-exp-time"
                    self.yang_parent_name = "global-neighbor-detail"

                    self.nanoseconds = YLeaf(YType.int32, "nanoseconds")

                    self.seconds = YLeaf(YType.int32, "seconds")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("nanoseconds",
                                    "seconds") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.GlobalNeighborDetails.GlobalNeighborDetail.RecoveryTimerExpTime, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.GlobalNeighborDetails.GlobalNeighborDetail.RecoveryTimerExpTime, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.nanoseconds.is_set or
                        self.seconds.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.nanoseconds.yfilter != YFilter.not_set or
                        self.seconds.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "recovery-timer-exp-time" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.nanoseconds.is_set or self.nanoseconds.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.nanoseconds.get_name_leafdata())
                    if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.seconds.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "nanoseconds" or name == "seconds"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "nanoseconds"):
                        self.nanoseconds = value
                        self.nanoseconds.value_namespace = name_space
                        self.nanoseconds.value_namespace_prefix = name_space_prefix
                    if(value_path == "seconds"):
                        self.seconds = value
                        self.seconds.value_namespace = name_space
                        self.seconds.value_namespace_prefix = name_space_prefix


            class UpTime(Entity):
                """
                Hello up time
                
                .. attribute:: nanoseconds
                
                	Time Value in Nano\-seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: nanosecond
                
                .. attribute:: seconds
                
                	Time Value in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.GlobalNeighborDetails.GlobalNeighborDetail.UpTime, self).__init__()

                    self.yang_name = "up-time"
                    self.yang_parent_name = "global-neighbor-detail"

                    self.nanoseconds = YLeaf(YType.int32, "nanoseconds")

                    self.seconds = YLeaf(YType.int32, "seconds")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("nanoseconds",
                                    "seconds") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.GlobalNeighborDetails.GlobalNeighborDetail.UpTime, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.GlobalNeighborDetails.GlobalNeighborDetail.UpTime, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.nanoseconds.is_set or
                        self.seconds.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.nanoseconds.yfilter != YFilter.not_set or
                        self.seconds.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "up-time" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.nanoseconds.is_set or self.nanoseconds.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.nanoseconds.get_name_leafdata())
                    if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.seconds.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "nanoseconds" or name == "seconds"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "nanoseconds"):
                        self.nanoseconds = value
                        self.nanoseconds.value_namespace = name_space
                        self.nanoseconds.value_namespace_prefix = name_space_prefix
                    if(value_path == "seconds"):
                        self.seconds = value
                        self.seconds.value_namespace = name_space
                        self.seconds.value_namespace_prefix = name_space_prefix


            class LostCommunicationTime(Entity):
                """
                Time when communication was lost
                
                .. attribute:: nanoseconds
                
                	Time Value in Nano\-seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: nanosecond
                
                .. attribute:: seconds
                
                	Time Value in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.GlobalNeighborDetails.GlobalNeighborDetail.LostCommunicationTime, self).__init__()

                    self.yang_name = "lost-communication-time"
                    self.yang_parent_name = "global-neighbor-detail"

                    self.nanoseconds = YLeaf(YType.int32, "nanoseconds")

                    self.seconds = YLeaf(YType.int32, "seconds")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("nanoseconds",
                                    "seconds") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.GlobalNeighborDetails.GlobalNeighborDetail.LostCommunicationTime, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.GlobalNeighborDetails.GlobalNeighborDetail.LostCommunicationTime, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.nanoseconds.is_set or
                        self.seconds.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.nanoseconds.yfilter != YFilter.not_set or
                        self.seconds.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "lost-communication-time" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.nanoseconds.is_set or self.nanoseconds.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.nanoseconds.get_name_leafdata())
                    if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.seconds.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "nanoseconds" or name == "seconds"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "nanoseconds"):
                        self.nanoseconds = value
                        self.nanoseconds.value_namespace = name_space
                        self.nanoseconds.value_namespace_prefix = name_space_prefix
                    if(value_path == "seconds"):
                        self.seconds = value
                        self.seconds.value_namespace = name_space
                        self.seconds.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.lost_communication_time:
                    if (c.has_data()):
                        return True
                for c in self.up_time:
                    if (c.has_data()):
                        return True
                for leaf in self.interface_neighbor.getYLeafs():
                    if (leaf.yfilter != YFilter.not_set):
                        return True
                for leaf in self.local_node_address.getYLeafs():
                    if (leaf.yfilter != YFilter.not_set):
                        return True
                for leaf in self.lost_communication_reason.getYLeafs():
                    if (leaf.yfilter != YFilter.not_set):
                        return True
                for leaf in self.lost_communication_total.getYLeafs():
                    if (leaf.yfilter != YFilter.not_set):
                        return True
                for leaf in self.neighbor_hello_state.getYLeafs():
                    if (leaf.yfilter != YFilter.not_set):
                        return True
                return (
                    self.neighbor_address.is_set or
                    self.hello_interval.is_set or
                    self.is_gr_enabled.is_set or
                    self.is_recovery_timer_running.is_set or
                    self.is_restart_timer_running.is_set or
                    self.missed_hellos.is_set or
                    self.node_address.is_set or
                    self.pending_states.is_set or
                    self.recovery_time.is_set or
                    self.restart_state.is_set or
                    self.restart_time.is_set or
                    (self.global_neighbor_flags is not None and self.global_neighbor_flags.has_data()) or
                    (self.recovery_time_left is not None and self.recovery_time_left.has_data()) or
                    (self.recovery_timer_exp_time is not None and self.recovery_timer_exp_time.has_data()) or
                    (self.restart_time_left is not None and self.restart_time_left.has_data()) or
                    (self.restart_timer_expiry_time is not None and self.restart_timer_expiry_time.has_data()))

            def has_operation(self):
                for c in self.lost_communication_time:
                    if (c.has_operation()):
                        return True
                for c in self.up_time:
                    if (c.has_operation()):
                        return True
                for leaf in self.interface_neighbor.getYLeafs():
                    if (leaf.is_set):
                        return True
                for leaf in self.local_node_address.getYLeafs():
                    if (leaf.is_set):
                        return True
                for leaf in self.lost_communication_reason.getYLeafs():
                    if (leaf.is_set):
                        return True
                for leaf in self.lost_communication_total.getYLeafs():
                    if (leaf.is_set):
                        return True
                for leaf in self.neighbor_hello_state.getYLeafs():
                    if (leaf.is_set):
                        return True
                return (
                    self.yfilter != YFilter.not_set or
                    self.neighbor_address.yfilter != YFilter.not_set or
                    self.hello_interval.yfilter != YFilter.not_set or
                    self.interface_neighbor.yfilter != YFilter.not_set or
                    self.is_gr_enabled.yfilter != YFilter.not_set or
                    self.is_recovery_timer_running.yfilter != YFilter.not_set or
                    self.is_restart_timer_running.yfilter != YFilter.not_set or
                    self.local_node_address.yfilter != YFilter.not_set or
                    self.lost_communication_reason.yfilter != YFilter.not_set or
                    self.lost_communication_total.yfilter != YFilter.not_set or
                    self.missed_hellos.yfilter != YFilter.not_set or
                    self.neighbor_hello_state.yfilter != YFilter.not_set or
                    self.node_address.yfilter != YFilter.not_set or
                    self.pending_states.yfilter != YFilter.not_set or
                    self.recovery_time.yfilter != YFilter.not_set or
                    self.restart_state.yfilter != YFilter.not_set or
                    self.restart_time.yfilter != YFilter.not_set or
                    (self.global_neighbor_flags is not None and self.global_neighbor_flags.has_operation()) or
                    (self.recovery_time_left is not None and self.recovery_time_left.has_operation()) or
                    (self.recovery_timer_exp_time is not None and self.recovery_timer_exp_time.has_operation()) or
                    (self.restart_time_left is not None and self.restart_time_left.has_operation()) or
                    (self.restart_timer_expiry_time is not None and self.restart_timer_expiry_time.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "global-neighbor-detail" + "[neighbor-address='" + self.neighbor_address.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/global-neighbor-details/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                if (self.hello_interval.is_set or self.hello_interval.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.hello_interval.get_name_leafdata())
                if (self.is_gr_enabled.is_set or self.is_gr_enabled.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.is_gr_enabled.get_name_leafdata())
                if (self.is_recovery_timer_running.is_set or self.is_recovery_timer_running.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.is_recovery_timer_running.get_name_leafdata())
                if (self.is_restart_timer_running.is_set or self.is_restart_timer_running.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.is_restart_timer_running.get_name_leafdata())
                if (self.missed_hellos.is_set or self.missed_hellos.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.missed_hellos.get_name_leafdata())
                if (self.node_address.is_set or self.node_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.node_address.get_name_leafdata())
                if (self.pending_states.is_set or self.pending_states.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.pending_states.get_name_leafdata())
                if (self.recovery_time.is_set or self.recovery_time.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.recovery_time.get_name_leafdata())
                if (self.restart_state.is_set or self.restart_state.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.restart_state.get_name_leafdata())
                if (self.restart_time.is_set or self.restart_time.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.restart_time.get_name_leafdata())

                leaf_name_data.extend(self.interface_neighbor.get_name_leafdata())

                leaf_name_data.extend(self.local_node_address.get_name_leafdata())

                leaf_name_data.extend(self.lost_communication_reason.get_name_leafdata())

                leaf_name_data.extend(self.lost_communication_total.get_name_leafdata())

                leaf_name_data.extend(self.neighbor_hello_state.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "global-neighbor-flags"):
                    if (self.global_neighbor_flags is None):
                        self.global_neighbor_flags = Rsvp.GlobalNeighborDetails.GlobalNeighborDetail.GlobalNeighborFlags()
                        self.global_neighbor_flags.parent = self
                        self._children_name_map["global_neighbor_flags"] = "global-neighbor-flags"
                    return self.global_neighbor_flags

                if (child_yang_name == "lost-communication-time"):
                    for c in self.lost_communication_time:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = Rsvp.GlobalNeighborDetails.GlobalNeighborDetail.LostCommunicationTime()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.lost_communication_time.append(c)
                    return c

                if (child_yang_name == "recovery-time-left"):
                    if (self.recovery_time_left is None):
                        self.recovery_time_left = Rsvp.GlobalNeighborDetails.GlobalNeighborDetail.RecoveryTimeLeft()
                        self.recovery_time_left.parent = self
                        self._children_name_map["recovery_time_left"] = "recovery-time-left"
                    return self.recovery_time_left

                if (child_yang_name == "recovery-timer-exp-time"):
                    if (self.recovery_timer_exp_time is None):
                        self.recovery_timer_exp_time = Rsvp.GlobalNeighborDetails.GlobalNeighborDetail.RecoveryTimerExpTime()
                        self.recovery_timer_exp_time.parent = self
                        self._children_name_map["recovery_timer_exp_time"] = "recovery-timer-exp-time"
                    return self.recovery_timer_exp_time

                if (child_yang_name == "restart-time-left"):
                    if (self.restart_time_left is None):
                        self.restart_time_left = Rsvp.GlobalNeighborDetails.GlobalNeighborDetail.RestartTimeLeft()
                        self.restart_time_left.parent = self
                        self._children_name_map["restart_time_left"] = "restart-time-left"
                    return self.restart_time_left

                if (child_yang_name == "restart-timer-expiry-time"):
                    if (self.restart_timer_expiry_time is None):
                        self.restart_timer_expiry_time = Rsvp.GlobalNeighborDetails.GlobalNeighborDetail.RestartTimerExpiryTime()
                        self.restart_timer_expiry_time.parent = self
                        self._children_name_map["restart_timer_expiry_time"] = "restart-timer-expiry-time"
                    return self.restart_timer_expiry_time

                if (child_yang_name == "up-time"):
                    for c in self.up_time:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = Rsvp.GlobalNeighborDetails.GlobalNeighborDetail.UpTime()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.up_time.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "global-neighbor-flags" or name == "lost-communication-time" or name == "recovery-time-left" or name == "recovery-timer-exp-time" or name == "restart-time-left" or name == "restart-timer-expiry-time" or name == "up-time" or name == "neighbor-address" or name == "hello-interval" or name == "interface-neighbor" or name == "is-gr-enabled" or name == "is-recovery-timer-running" or name == "is-restart-timer-running" or name == "local-node-address" or name == "lost-communication-reason" or name == "lost-communication-total" or name == "missed-hellos" or name == "neighbor-hello-state" or name == "node-address" or name == "pending-states" or name == "recovery-time" or name == "restart-state" or name == "restart-time"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "neighbor-address"):
                    self.neighbor_address = value
                    self.neighbor_address.value_namespace = name_space
                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                if(value_path == "hello-interval"):
                    self.hello_interval = value
                    self.hello_interval.value_namespace = name_space
                    self.hello_interval.value_namespace_prefix = name_space_prefix
                if(value_path == "interface-neighbor"):
                    self.interface_neighbor.append(value)
                if(value_path == "is-gr-enabled"):
                    self.is_gr_enabled = value
                    self.is_gr_enabled.value_namespace = name_space
                    self.is_gr_enabled.value_namespace_prefix = name_space_prefix
                if(value_path == "is-recovery-timer-running"):
                    self.is_recovery_timer_running = value
                    self.is_recovery_timer_running.value_namespace = name_space
                    self.is_recovery_timer_running.value_namespace_prefix = name_space_prefix
                if(value_path == "is-restart-timer-running"):
                    self.is_restart_timer_running = value
                    self.is_restart_timer_running.value_namespace = name_space
                    self.is_restart_timer_running.value_namespace_prefix = name_space_prefix
                if(value_path == "local-node-address"):
                    self.local_node_address.append(value)
                if(value_path == "lost-communication-reason"):
                    self.lost_communication_reason.append(value)
                if(value_path == "lost-communication-total"):
                    self.lost_communication_total.append(value)
                if(value_path == "missed-hellos"):
                    self.missed_hellos = value
                    self.missed_hellos.value_namespace = name_space
                    self.missed_hellos.value_namespace_prefix = name_space_prefix
                if(value_path == "neighbor-hello-state"):
                    self.neighbor_hello_state.append(value)
                if(value_path == "node-address"):
                    self.node_address = value
                    self.node_address.value_namespace = name_space
                    self.node_address.value_namespace_prefix = name_space_prefix
                if(value_path == "pending-states"):
                    self.pending_states = value
                    self.pending_states.value_namespace = name_space
                    self.pending_states.value_namespace_prefix = name_space_prefix
                if(value_path == "recovery-time"):
                    self.recovery_time = value
                    self.recovery_time.value_namespace = name_space
                    self.recovery_time.value_namespace_prefix = name_space_prefix
                if(value_path == "restart-state"):
                    self.restart_state = value
                    self.restart_state.value_namespace = name_space
                    self.restart_state.value_namespace_prefix = name_space_prefix
                if(value_path == "restart-time"):
                    self.restart_time = value
                    self.restart_time.value_namespace = name_space
                    self.restart_time.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.global_neighbor_detail:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.global_neighbor_detail:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "global-neighbor-details" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "global-neighbor-detail"):
                for c in self.global_neighbor_detail:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = Rsvp.GlobalNeighborDetails.GlobalNeighborDetail()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.global_neighbor_detail.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "global-neighbor-detail"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class PsbBriefs(Entity):
        """
        Table of brief info about path state blocks
        
        .. attribute:: psb_brief
        
        	Brief info for a single path state block
        	**type**\: list of    :py:class:`PsbBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbBriefs.PsbBrief>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Rsvp.PsbBriefs, self).__init__()

            self.yang_name = "psb-briefs"
            self.yang_parent_name = "rsvp"

            self.psb_brief = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(Rsvp.PsbBriefs, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(Rsvp.PsbBriefs, self).__setattr__(name, value)


        class PsbBrief(Entity):
            """
            Brief info for a single path state block
            
            .. attribute:: destination_address
            
            	Destination Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: destination_port
            
            	Destination Port
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: extended_tunnel_id
            
            	Extended Tunnel ID
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: generic_traffic_spec
            
            	RSVP Generic Traffic Spec Info
            	**type**\:   :py:class:`GenericTrafficSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbBriefs.PsbBrief.GenericTrafficSpec>`
            
            .. attribute:: input_interface
            
            	Path Input Interface
            	**type**\:  str
            
            .. attribute:: p2mp_id
            
            	P2MP ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: protocol
            
            	Protocol
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: s2l_sub_lsp
            
            	RSVP S2L Sub\-LSP information
            	**type**\:   :py:class:`S2LSubLsp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbBriefs.PsbBrief.S2LSubLsp>`
            
            .. attribute:: session
            
            	RSVP Session Information
            	**type**\:   :py:class:`Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbBriefs.PsbBrief.Session>`
            
            .. attribute:: session_attribute
            
            	RSVP Session Attribute
            	**type**\:   :py:class:`SessionAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbBriefs.PsbBrief.SessionAttribute>`
            
            .. attribute:: session_type
            
            	Session Type
            	**type**\:   :py:class:`RsvpSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpSession>`
            
            .. attribute:: source_address
            
            	Source Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: source_port
            
            	Source Port 
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: sub_group_id
            
            	Subgroup ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: sub_group_origin
            
            	Subgroup Origin
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: template
            
            	RSVP Template
            	**type**\:   :py:class:`Template <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbBriefs.PsbBrief.Template>`
            
            .. attribute:: traffic_spec
            
            	RSVP Traffic Spec Info
            	**type**\:   :py:class:`TrafficSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbBriefs.PsbBrief.TrafficSpec>`
            
            .. attribute:: vrf_name
            
            	VRF Name
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Rsvp.PsbBriefs.PsbBrief, self).__init__()

                self.yang_name = "psb-brief"
                self.yang_parent_name = "psb-briefs"

                self.destination_address = YLeaf(YType.str, "destination-address")

                self.destination_port = YLeaf(YType.int32, "destination-port")

                self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                self.input_interface = YLeaf(YType.str, "input-interface")

                self.p2mp_id = YLeaf(YType.int32, "p2mp-id")

                self.protocol = YLeaf(YType.int32, "protocol")

                self.session_type = YLeaf(YType.enumeration, "session-type")

                self.source_address = YLeaf(YType.str, "source-address")

                self.source_port = YLeaf(YType.int32, "source-port")

                self.sub_group_id = YLeaf(YType.int32, "sub-group-id")

                self.sub_group_origin = YLeaf(YType.str, "sub-group-origin")

                self.vrf_name = YLeaf(YType.str, "vrf-name")

                self.generic_traffic_spec = Rsvp.PsbBriefs.PsbBrief.GenericTrafficSpec()
                self.generic_traffic_spec.parent = self
                self._children_name_map["generic_traffic_spec"] = "generic-traffic-spec"
                self._children_yang_names.add("generic-traffic-spec")

                self.s2l_sub_lsp = Rsvp.PsbBriefs.PsbBrief.S2LSubLsp()
                self.s2l_sub_lsp.parent = self
                self._children_name_map["s2l_sub_lsp"] = "s2l-sub-lsp"
                self._children_yang_names.add("s2l-sub-lsp")

                self.session = Rsvp.PsbBriefs.PsbBrief.Session()
                self.session.parent = self
                self._children_name_map["session"] = "session"
                self._children_yang_names.add("session")

                self.session_attribute = Rsvp.PsbBriefs.PsbBrief.SessionAttribute()
                self.session_attribute.parent = self
                self._children_name_map["session_attribute"] = "session-attribute"
                self._children_yang_names.add("session-attribute")

                self.template = Rsvp.PsbBriefs.PsbBrief.Template()
                self.template.parent = self
                self._children_name_map["template"] = "template"
                self._children_yang_names.add("template")

                self.traffic_spec = Rsvp.PsbBriefs.PsbBrief.TrafficSpec()
                self.traffic_spec.parent = self
                self._children_name_map["traffic_spec"] = "traffic-spec"
                self._children_yang_names.add("traffic-spec")

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("destination_address",
                                "destination_port",
                                "extended_tunnel_id",
                                "input_interface",
                                "p2mp_id",
                                "protocol",
                                "session_type",
                                "source_address",
                                "source_port",
                                "sub_group_id",
                                "sub_group_origin",
                                "vrf_name") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Rsvp.PsbBriefs.PsbBrief, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Rsvp.PsbBriefs.PsbBrief, self).__setattr__(name, value)


            class Session(Entity):
                """
                RSVP Session Information
                
                .. attribute:: rsvp_session
                
                	RSVP Session
                	**type**\:   :py:class:`RsvpSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbBriefs.PsbBrief.Session.RsvpSession>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.PsbBriefs.PsbBrief.Session, self).__init__()

                    self.yang_name = "session"
                    self.yang_parent_name = "psb-brief"

                    self.rsvp_session = Rsvp.PsbBriefs.PsbBrief.Session.RsvpSession()
                    self.rsvp_session.parent = self
                    self._children_name_map["rsvp_session"] = "rsvp-session"
                    self._children_yang_names.add("rsvp-session")


                class RsvpSession(Entity):
                    """
                    RSVP Session
                    
                    .. attribute:: ipv4
                    
                    	UDP IPv4 session
                    	**type**\:   :py:class:`Ipv4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbBriefs.PsbBrief.Session.RsvpSession.Ipv4>`
                    
                    .. attribute:: ipv4_lsp_session
                    
                    	IPv4 LSP session
                    	**type**\:   :py:class:`Ipv4LspSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbBriefs.PsbBrief.Session.RsvpSession.Ipv4LspSession>`
                    
                    .. attribute:: ipv4_p2mp_lsp_session
                    
                    	IPv4 P2MP LSP session
                    	**type**\:   :py:class:`Ipv4P2MpLspSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbBriefs.PsbBrief.Session.RsvpSession.Ipv4P2MpLspSession>`
                    
                    .. attribute:: ipv4_uni_session
                    
                    	IPv4 UNI session
                    	**type**\:   :py:class:`Ipv4UniSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbBriefs.PsbBrief.Session.RsvpSession.Ipv4UniSession>`
                    
                    .. attribute:: session_type
                    
                    	SessionType
                    	**type**\:   :py:class:`RsvpMgmtSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtSession>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.PsbBriefs.PsbBrief.Session.RsvpSession, self).__init__()

                        self.yang_name = "rsvp-session"
                        self.yang_parent_name = "session"

                        self.session_type = YLeaf(YType.enumeration, "session-type")

                        self.ipv4 = Rsvp.PsbBriefs.PsbBrief.Session.RsvpSession.Ipv4()
                        self.ipv4.parent = self
                        self._children_name_map["ipv4"] = "ipv4"
                        self._children_yang_names.add("ipv4")

                        self.ipv4_lsp_session = Rsvp.PsbBriefs.PsbBrief.Session.RsvpSession.Ipv4LspSession()
                        self.ipv4_lsp_session.parent = self
                        self._children_name_map["ipv4_lsp_session"] = "ipv4-lsp-session"
                        self._children_yang_names.add("ipv4-lsp-session")

                        self.ipv4_p2mp_lsp_session = Rsvp.PsbBriefs.PsbBrief.Session.RsvpSession.Ipv4P2MpLspSession()
                        self.ipv4_p2mp_lsp_session.parent = self
                        self._children_name_map["ipv4_p2mp_lsp_session"] = "ipv4-p2mp-lsp-session"
                        self._children_yang_names.add("ipv4-p2mp-lsp-session")

                        self.ipv4_uni_session = Rsvp.PsbBriefs.PsbBrief.Session.RsvpSession.Ipv4UniSession()
                        self.ipv4_uni_session.parent = self
                        self._children_name_map["ipv4_uni_session"] = "ipv4-uni-session"
                        self._children_yang_names.add("ipv4-uni-session")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("session_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.PsbBriefs.PsbBrief.Session.RsvpSession, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.PsbBriefs.PsbBrief.Session.RsvpSession, self).__setattr__(name, value)


                    class Ipv4(Entity):
                        """
                        UDP IPv4 session
                        
                        .. attribute:: destination_address
                        
                        	Destination address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: destination_port
                        
                        	The Session Destination Port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: protocol
                        
                        	Protocol type (originally defined in RFC 790, further values in subsequent RFCs)
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.PsbBriefs.PsbBrief.Session.RsvpSession.Ipv4, self).__init__()

                            self.yang_name = "ipv4"
                            self.yang_parent_name = "rsvp-session"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.destination_port = YLeaf(YType.uint16, "destination-port")

                            self.protocol = YLeaf(YType.uint8, "protocol")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "destination_port",
                                            "protocol") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.PsbBriefs.PsbBrief.Session.RsvpSession.Ipv4, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.PsbBriefs.PsbBrief.Session.RsvpSession.Ipv4, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination_address.is_set or
                                self.destination_port.is_set or
                                self.protocol.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.destination_port.yfilter != YFilter.not_set or
                                self.protocol.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-briefs/psb-brief/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.destination_port.is_set or self.destination_port.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_port.get_name_leafdata())
                            if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.protocol.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "destination-port" or name == "protocol"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "destination-port"):
                                self.destination_port = value
                                self.destination_port.value_namespace = name_space
                                self.destination_port.value_namespace_prefix = name_space_prefix
                            if(value_path == "protocol"):
                                self.protocol = value
                                self.protocol.value_namespace = name_space
                                self.protocol.value_namespace_prefix = name_space_prefix


                    class Ipv4LspSession(Entity):
                        """
                        IPv4 LSP session
                        
                        .. attribute:: destination_address
                        
                        	Destination address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: extended_tunnel_id
                        
                        	The Session Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: tunnel_id
                        
                        	The Session Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.PsbBriefs.PsbBrief.Session.RsvpSession.Ipv4LspSession, self).__init__()

                            self.yang_name = "ipv4-lsp-session"
                            self.yang_parent_name = "rsvp-session"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                            self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "extended_tunnel_id",
                                            "tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.PsbBriefs.PsbBrief.Session.RsvpSession.Ipv4LspSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.PsbBriefs.PsbBrief.Session.RsvpSession.Ipv4LspSession, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination_address.is_set or
                                self.extended_tunnel_id.is_set or
                                self.tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.extended_tunnel_id.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-lsp-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-briefs/psb-brief/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "extended-tunnel-id" or name == "tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "extended-tunnel-id"):
                                self.extended_tunnel_id = value
                                self.extended_tunnel_id.value_namespace = name_space
                                self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix


                    class Ipv4UniSession(Entity):
                        """
                        IPv4 UNI session
                        
                        .. attribute:: destination_address
                        
                        	Destination address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: extended_address
                        
                        	The Session Extended Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: tunnel_id
                        
                        	The Session Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.PsbBriefs.PsbBrief.Session.RsvpSession.Ipv4UniSession, self).__init__()

                            self.yang_name = "ipv4-uni-session"
                            self.yang_parent_name = "rsvp-session"

                            self.destination_address = YLeaf(YType.str, "destination-address")

                            self.extended_address = YLeaf(YType.str, "extended-address")

                            self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("destination_address",
                                            "extended_address",
                                            "tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.PsbBriefs.PsbBrief.Session.RsvpSession.Ipv4UniSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.PsbBriefs.PsbBrief.Session.RsvpSession.Ipv4UniSession, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.destination_address.is_set or
                                self.extended_address.is_set or
                                self.tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.destination_address.yfilter != YFilter.not_set or
                                self.extended_address.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-uni-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-briefs/psb-brief/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.destination_address.get_name_leafdata())
                            if (self.extended_address.is_set or self.extended_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_address.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "destination-address" or name == "extended-address" or name == "tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "destination-address"):
                                self.destination_address = value
                                self.destination_address.value_namespace = name_space
                                self.destination_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "extended-address"):
                                self.extended_address = value
                                self.extended_address.value_namespace = name_space
                                self.extended_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix


                    class Ipv4P2MpLspSession(Entity):
                        """
                        IPv4 P2MP LSP session
                        
                        .. attribute:: extended_tunnel_id
                        
                        	The Session Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: p2mp_id
                        
                        	The Point to Multipoint ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tunnel_id
                        
                        	The Session Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.PsbBriefs.PsbBrief.Session.RsvpSession.Ipv4P2MpLspSession, self).__init__()

                            self.yang_name = "ipv4-p2mp-lsp-session"
                            self.yang_parent_name = "rsvp-session"

                            self.extended_tunnel_id = YLeaf(YType.str, "extended-tunnel-id")

                            self.p2mp_id = YLeaf(YType.uint32, "p2mp-id")

                            self.tunnel_id = YLeaf(YType.uint16, "tunnel-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("extended_tunnel_id",
                                            "p2mp_id",
                                            "tunnel_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.PsbBriefs.PsbBrief.Session.RsvpSession.Ipv4P2MpLspSession, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.PsbBriefs.PsbBrief.Session.RsvpSession.Ipv4P2MpLspSession, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.extended_tunnel_id.is_set or
                                self.p2mp_id.is_set or
                                self.tunnel_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.extended_tunnel_id.yfilter != YFilter.not_set or
                                self.p2mp_id.yfilter != YFilter.not_set or
                                self.tunnel_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "ipv4-p2mp-lsp-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-briefs/psb-brief/session/rsvp-session/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                            if (self.p2mp_id.is_set or self.p2mp_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.p2mp_id.get_name_leafdata())
                            if (self.tunnel_id.is_set or self.tunnel_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.tunnel_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "extended-tunnel-id" or name == "p2mp-id" or name == "tunnel-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "extended-tunnel-id"):
                                self.extended_tunnel_id = value
                                self.extended_tunnel_id.value_namespace = name_space
                                self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "p2mp-id"):
                                self.p2mp_id = value
                                self.p2mp_id.value_namespace = name_space
                                self.p2mp_id.value_namespace_prefix = name_space_prefix
                            if(value_path == "tunnel-id"):
                                self.tunnel_id = value
                                self.tunnel_id.value_namespace = name_space
                                self.tunnel_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.session_type.is_set or
                            (self.ipv4 is not None and self.ipv4.has_data()) or
                            (self.ipv4_lsp_session is not None and self.ipv4_lsp_session.has_data()) or
                            (self.ipv4_p2mp_lsp_session is not None and self.ipv4_p2mp_lsp_session.has_data()) or
                            (self.ipv4_uni_session is not None and self.ipv4_uni_session.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.session_type.yfilter != YFilter.not_set or
                            (self.ipv4 is not None and self.ipv4.has_operation()) or
                            (self.ipv4_lsp_session is not None and self.ipv4_lsp_session.has_operation()) or
                            (self.ipv4_p2mp_lsp_session is not None and self.ipv4_p2mp_lsp_session.has_operation()) or
                            (self.ipv4_uni_session is not None and self.ipv4_uni_session.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rsvp-session" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-briefs/psb-brief/session/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.session_type.is_set or self.session_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.session_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "ipv4"):
                            if (self.ipv4 is None):
                                self.ipv4 = Rsvp.PsbBriefs.PsbBrief.Session.RsvpSession.Ipv4()
                                self.ipv4.parent = self
                                self._children_name_map["ipv4"] = "ipv4"
                            return self.ipv4

                        if (child_yang_name == "ipv4-lsp-session"):
                            if (self.ipv4_lsp_session is None):
                                self.ipv4_lsp_session = Rsvp.PsbBriefs.PsbBrief.Session.RsvpSession.Ipv4LspSession()
                                self.ipv4_lsp_session.parent = self
                                self._children_name_map["ipv4_lsp_session"] = "ipv4-lsp-session"
                            return self.ipv4_lsp_session

                        if (child_yang_name == "ipv4-p2mp-lsp-session"):
                            if (self.ipv4_p2mp_lsp_session is None):
                                self.ipv4_p2mp_lsp_session = Rsvp.PsbBriefs.PsbBrief.Session.RsvpSession.Ipv4P2MpLspSession()
                                self.ipv4_p2mp_lsp_session.parent = self
                                self._children_name_map["ipv4_p2mp_lsp_session"] = "ipv4-p2mp-lsp-session"
                            return self.ipv4_p2mp_lsp_session

                        if (child_yang_name == "ipv4-uni-session"):
                            if (self.ipv4_uni_session is None):
                                self.ipv4_uni_session = Rsvp.PsbBriefs.PsbBrief.Session.RsvpSession.Ipv4UniSession()
                                self.ipv4_uni_session.parent = self
                                self._children_name_map["ipv4_uni_session"] = "ipv4-uni-session"
                            return self.ipv4_uni_session

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "ipv4" or name == "ipv4-lsp-session" or name == "ipv4-p2mp-lsp-session" or name == "ipv4-uni-session" or name == "session-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "session-type"):
                            self.session_type = value
                            self.session_type.value_namespace = name_space
                            self.session_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (self.rsvp_session is not None and self.rsvp_session.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.rsvp_session is not None and self.rsvp_session.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "session" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-briefs/psb-brief/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "rsvp-session"):
                        if (self.rsvp_session is None):
                            self.rsvp_session = Rsvp.PsbBriefs.PsbBrief.Session.RsvpSession()
                            self.rsvp_session.parent = self
                            self._children_name_map["rsvp_session"] = "rsvp-session"
                        return self.rsvp_session

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "rsvp-session"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class S2LSubLsp(Entity):
                """
                RSVP S2L Sub\-LSP information
                
                .. attribute:: s2l_destination_address
                
                	S2L Sub\-LSP Destination Address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.PsbBriefs.PsbBrief.S2LSubLsp, self).__init__()

                    self.yang_name = "s2l-sub-lsp"
                    self.yang_parent_name = "psb-brief"

                    self.s2l_destination_address = YLeaf(YType.str, "s2l-destination-address")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("s2l_destination_address") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.PsbBriefs.PsbBrief.S2LSubLsp, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.PsbBriefs.PsbBrief.S2LSubLsp, self).__setattr__(name, value)

                def has_data(self):
                    return self.s2l_destination_address.is_set

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.s2l_destination_address.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "s2l-sub-lsp" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-briefs/psb-brief/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.s2l_destination_address.is_set or self.s2l_destination_address.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.s2l_destination_address.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "s2l-destination-address"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "s2l-destination-address"):
                        self.s2l_destination_address = value
                        self.s2l_destination_address.value_namespace = name_space
                        self.s2l_destination_address.value_namespace_prefix = name_space_prefix


            class Template(Entity):
                """
                RSVP Template
                
                .. attribute:: rsvp_filter
                
                	RSVP Filter
                	**type**\:   :py:class:`RsvpFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbBriefs.PsbBrief.Template.RsvpFilter>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.PsbBriefs.PsbBrief.Template, self).__init__()

                    self.yang_name = "template"
                    self.yang_parent_name = "psb-brief"

                    self.rsvp_filter = Rsvp.PsbBriefs.PsbBrief.Template.RsvpFilter()
                    self.rsvp_filter.parent = self
                    self._children_name_map["rsvp_filter"] = "rsvp-filter"
                    self._children_yang_names.add("rsvp-filter")


                class RsvpFilter(Entity):
                    """
                    RSVP Filter
                    
                    .. attribute:: filter_type
                    
                    	FilterType
                    	**type**\:   :py:class:`RsvpMgmtFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtFilter>`
                    
                    .. attribute:: p2mp_ipv4_session
                    
                    	IPv4 P2MP LSP FilterSpec
                    	**type**\:   :py:class:`P2MpIpv4Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbBriefs.PsbBrief.Template.RsvpFilter.P2MpIpv4Session>`
                    
                    .. attribute:: udp_ipv4_session
                    
                    	UDP IPV4 FilterSpec
                    	**type**\:   :py:class:`UdpIpv4Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbBriefs.PsbBrief.Template.RsvpFilter.UdpIpv4Session>`
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.PsbBriefs.PsbBrief.Template.RsvpFilter, self).__init__()

                        self.yang_name = "rsvp-filter"
                        self.yang_parent_name = "template"

                        self.filter_type = YLeaf(YType.enumeration, "filter-type")

                        self.p2mp_ipv4_session = Rsvp.PsbBriefs.PsbBrief.Template.RsvpFilter.P2MpIpv4Session()
                        self.p2mp_ipv4_session.parent = self
                        self._children_name_map["p2mp_ipv4_session"] = "p2mp-ipv4-session"
                        self._children_yang_names.add("p2mp-ipv4-session")

                        self.udp_ipv4_session = Rsvp.PsbBriefs.PsbBrief.Template.RsvpFilter.UdpIpv4Session()
                        self.udp_ipv4_session.parent = self
                        self._children_name_map["udp_ipv4_session"] = "udp-ipv4-session"
                        self._children_yang_names.add("udp-ipv4-session")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("filter_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.PsbBriefs.PsbBrief.Template.RsvpFilter, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.PsbBriefs.PsbBrief.Template.RsvpFilter, self).__setattr__(name, value)


                    class UdpIpv4Session(Entity):
                        """
                        UDP IPV4 FilterSpec
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source_port
                        
                        	Source Port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.PsbBriefs.PsbBrief.Template.RsvpFilter.UdpIpv4Session, self).__init__()

                            self.yang_name = "udp-ipv4-session"
                            self.yang_parent_name = "rsvp-filter"

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.source_port = YLeaf(YType.uint16, "source-port")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("source_address",
                                            "source_port") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.PsbBriefs.PsbBrief.Template.RsvpFilter.UdpIpv4Session, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.PsbBriefs.PsbBrief.Template.RsvpFilter.UdpIpv4Session, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.source_address.is_set or
                                self.source_port.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                self.source_port.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "udp-ipv4-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-briefs/psb-brief/template/rsvp-filter/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())
                            if (self.source_port.is_set or self.source_port.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_port.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "source-address" or name == "source-port"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-port"):
                                self.source_port = value
                                self.source_port.value_namespace = name_space
                                self.source_port.value_namespace_prefix = name_space_prefix


                    class P2MpIpv4Session(Entity):
                        """
                        IPv4 P2MP LSP FilterSpec
                        
                        .. attribute:: p2mp_sub_group_origin
                        
                        	Point to Multipoint SubGroup Origin
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source_port
                        
                        	Source Port
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: sub_group_id
                        
                        	Point to Multipoint Subgroup ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'ip-rsvp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rsvp.PsbBriefs.PsbBrief.Template.RsvpFilter.P2MpIpv4Session, self).__init__()

                            self.yang_name = "p2mp-ipv4-session"
                            self.yang_parent_name = "rsvp-filter"

                            self.p2mp_sub_group_origin = YLeaf(YType.str, "p2mp-sub-group-origin")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.source_port = YLeaf(YType.uint16, "source-port")

                            self.sub_group_id = YLeaf(YType.uint16, "sub-group-id")

                        def __setattr__(self, name, value):
                            self._check_monkey_patching_error(name, value)
                            with _handle_type_error():
                                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                        "Please use list append or extend method."
                                                        .format(value))
                                if isinstance(value, Enum.YLeaf):
                                    value = value.name
                                if name in ("p2mp_sub_group_origin",
                                            "source_address",
                                            "source_port",
                                            "sub_group_id") and name in self.__dict__:
                                    if isinstance(value, YLeaf):
                                        self.__dict__[name].set(value.get())
                                    elif isinstance(value, YLeafList):
                                        super(Rsvp.PsbBriefs.PsbBrief.Template.RsvpFilter.P2MpIpv4Session, self).__setattr__(name, value)
                                    else:
                                        self.__dict__[name].set(value)
                                else:
                                    if hasattr(value, "parent") and name != "parent":
                                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                                            value.parent = self
                                        elif value.parent is None and value.yang_name in self._children_yang_names:
                                            value.parent = self
                                    super(Rsvp.PsbBriefs.PsbBrief.Template.RsvpFilter.P2MpIpv4Session, self).__setattr__(name, value)

                        def has_data(self):
                            return (
                                self.p2mp_sub_group_origin.is_set or
                                self.source_address.is_set or
                                self.source_port.is_set or
                                self.sub_group_id.is_set)

                        def has_operation(self):
                            return (
                                self.yfilter != YFilter.not_set or
                                self.p2mp_sub_group_origin.yfilter != YFilter.not_set or
                                self.source_address.yfilter != YFilter.not_set or
                                self.source_port.yfilter != YFilter.not_set or
                                self.sub_group_id.yfilter != YFilter.not_set)

                        def get_segment_path(self):
                            path_buffer = ""
                            path_buffer = "p2mp-ipv4-session" + path_buffer

                            return path_buffer

                        def get_entity_path(self, ancestor):
                            path_buffer = ""
                            if (ancestor is None):
                                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-briefs/psb-brief/template/rsvp-filter/%s" % self.get_segment_path()
                            else:
                                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                            leaf_name_data = LeafDataList()
                            if (self.p2mp_sub_group_origin.is_set or self.p2mp_sub_group_origin.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.p2mp_sub_group_origin.get_name_leafdata())
                            if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_address.get_name_leafdata())
                            if (self.source_port.is_set or self.source_port.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.source_port.get_name_leafdata())
                            if (self.sub_group_id.is_set or self.sub_group_id.yfilter != YFilter.not_set):
                                leaf_name_data.append(self.sub_group_id.get_name_leafdata())

                            entity_path = EntityPath(path_buffer, leaf_name_data)
                            return entity_path

                        def get_child_by_name(self, child_yang_name, segment_path):
                            child = self._get_child_by_seg_name([child_yang_name, segment_path])
                            if child is not None:
                                return child

                            return None

                        def has_leaf_or_child_of_name(self, name):
                            if(name == "p2mp-sub-group-origin" or name == "source-address" or name == "source-port" or name == "sub-group-id"):
                                return True
                            return False

                        def set_value(self, value_path, value, name_space, name_space_prefix):
                            if(value_path == "p2mp-sub-group-origin"):
                                self.p2mp_sub_group_origin = value
                                self.p2mp_sub_group_origin.value_namespace = name_space
                                self.p2mp_sub_group_origin.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-address"):
                                self.source_address = value
                                self.source_address.value_namespace = name_space
                                self.source_address.value_namespace_prefix = name_space_prefix
                            if(value_path == "source-port"):
                                self.source_port = value
                                self.source_port.value_namespace = name_space
                                self.source_port.value_namespace_prefix = name_space_prefix
                            if(value_path == "sub-group-id"):
                                self.sub_group_id = value
                                self.sub_group_id.value_namespace = name_space
                                self.sub_group_id.value_namespace_prefix = name_space_prefix

                    def has_data(self):
                        return (
                            self.filter_type.is_set or
                            (self.p2mp_ipv4_session is not None and self.p2mp_ipv4_session.has_data()) or
                            (self.udp_ipv4_session is not None and self.udp_ipv4_session.has_data()))

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.filter_type.yfilter != YFilter.not_set or
                            (self.p2mp_ipv4_session is not None and self.p2mp_ipv4_session.has_operation()) or
                            (self.udp_ipv4_session is not None and self.udp_ipv4_session.has_operation()))

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "rsvp-filter" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-briefs/psb-brief/template/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.filter_type.is_set or self.filter_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.filter_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        if (child_yang_name == "p2mp-ipv4-session"):
                            if (self.p2mp_ipv4_session is None):
                                self.p2mp_ipv4_session = Rsvp.PsbBriefs.PsbBrief.Template.RsvpFilter.P2MpIpv4Session()
                                self.p2mp_ipv4_session.parent = self
                                self._children_name_map["p2mp_ipv4_session"] = "p2mp-ipv4-session"
                            return self.p2mp_ipv4_session

                        if (child_yang_name == "udp-ipv4-session"):
                            if (self.udp_ipv4_session is None):
                                self.udp_ipv4_session = Rsvp.PsbBriefs.PsbBrief.Template.RsvpFilter.UdpIpv4Session()
                                self.udp_ipv4_session.parent = self
                                self._children_name_map["udp_ipv4_session"] = "udp-ipv4-session"
                            return self.udp_ipv4_session

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "p2mp-ipv4-session" or name == "udp-ipv4-session" or name == "filter-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "filter-type"):
                            self.filter_type = value
                            self.filter_type.value_namespace = name_space
                            self.filter_type.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (self.rsvp_filter is not None and self.rsvp_filter.has_data())

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        (self.rsvp_filter is not None and self.rsvp_filter.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "template" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-briefs/psb-brief/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "rsvp-filter"):
                        if (self.rsvp_filter is None):
                            self.rsvp_filter = Rsvp.PsbBriefs.PsbBrief.Template.RsvpFilter()
                            self.rsvp_filter.parent = self
                            self._children_name_map["rsvp_filter"] = "rsvp-filter"
                        return self.rsvp_filter

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "rsvp-filter"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    pass


            class SessionAttribute(Entity):
                """
                RSVP Session Attribute
                
                .. attribute:: reservation_priority
                
                	Reservation Priority
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: sess_attribute_flags
                
                	Session Attributes
                	**type**\:   :py:class:`SessAttributeFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbBriefs.PsbBrief.SessionAttribute.SessAttributeFlags>`
                
                .. attribute:: setup_priority
                
                	Setup Priority
                	**type**\:  int
                
                	**range:** 0..255
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.PsbBriefs.PsbBrief.SessionAttribute, self).__init__()

                    self.yang_name = "session-attribute"
                    self.yang_parent_name = "psb-brief"

                    self.reservation_priority = YLeaf(YType.uint8, "reservation-priority")

                    self.setup_priority = YLeaf(YType.uint8, "setup-priority")

                    self.sess_attribute_flags = Rsvp.PsbBriefs.PsbBrief.SessionAttribute.SessAttributeFlags()
                    self.sess_attribute_flags.parent = self
                    self._children_name_map["sess_attribute_flags"] = "sess-attribute-flags"
                    self._children_yang_names.add("sess-attribute-flags")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("reservation_priority",
                                    "setup_priority") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.PsbBriefs.PsbBrief.SessionAttribute, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.PsbBriefs.PsbBrief.SessionAttribute, self).__setattr__(name, value)


                class SessAttributeFlags(Entity):
                    """
                    Session Attributes
                    
                    .. attribute:: is_bandwidth_protect
                    
                    	Bandwidth Protection
                    	**type**\:  bool
                    
                    .. attribute:: is_local_protect
                    
                    	Local Protection
                    	**type**\:  bool
                    
                    .. attribute:: is_node_protect
                    
                    	Node Protection
                    	**type**\:  bool
                    
                    .. attribute:: is_record_labels
                    
                    	Records Labels
                    	**type**\:  bool
                    
                    .. attribute:: is_shared_explicit_requested
                    
                    	Shared Explicit Requested
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.PsbBriefs.PsbBrief.SessionAttribute.SessAttributeFlags, self).__init__()

                        self.yang_name = "sess-attribute-flags"
                        self.yang_parent_name = "session-attribute"

                        self.is_bandwidth_protect = YLeaf(YType.boolean, "is-bandwidth-protect")

                        self.is_local_protect = YLeaf(YType.boolean, "is-local-protect")

                        self.is_node_protect = YLeaf(YType.boolean, "is-node-protect")

                        self.is_record_labels = YLeaf(YType.boolean, "is-record-labels")

                        self.is_shared_explicit_requested = YLeaf(YType.boolean, "is-shared-explicit-requested")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("is_bandwidth_protect",
                                        "is_local_protect",
                                        "is_node_protect",
                                        "is_record_labels",
                                        "is_shared_explicit_requested") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.PsbBriefs.PsbBrief.SessionAttribute.SessAttributeFlags, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.PsbBriefs.PsbBrief.SessionAttribute.SessAttributeFlags, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.is_bandwidth_protect.is_set or
                            self.is_local_protect.is_set or
                            self.is_node_protect.is_set or
                            self.is_record_labels.is_set or
                            self.is_shared_explicit_requested.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.is_bandwidth_protect.yfilter != YFilter.not_set or
                            self.is_local_protect.yfilter != YFilter.not_set or
                            self.is_node_protect.yfilter != YFilter.not_set or
                            self.is_record_labels.yfilter != YFilter.not_set or
                            self.is_shared_explicit_requested.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "sess-attribute-flags" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-briefs/psb-brief/session-attribute/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.is_bandwidth_protect.is_set or self.is_bandwidth_protect.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_bandwidth_protect.get_name_leafdata())
                        if (self.is_local_protect.is_set or self.is_local_protect.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_local_protect.get_name_leafdata())
                        if (self.is_node_protect.is_set or self.is_node_protect.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_node_protect.get_name_leafdata())
                        if (self.is_record_labels.is_set or self.is_record_labels.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_record_labels.get_name_leafdata())
                        if (self.is_shared_explicit_requested.is_set or self.is_shared_explicit_requested.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.is_shared_explicit_requested.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "is-bandwidth-protect" or name == "is-local-protect" or name == "is-node-protect" or name == "is-record-labels" or name == "is-shared-explicit-requested"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "is-bandwidth-protect"):
                            self.is_bandwidth_protect = value
                            self.is_bandwidth_protect.value_namespace = name_space
                            self.is_bandwidth_protect.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-local-protect"):
                            self.is_local_protect = value
                            self.is_local_protect.value_namespace = name_space
                            self.is_local_protect.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-node-protect"):
                            self.is_node_protect = value
                            self.is_node_protect.value_namespace = name_space
                            self.is_node_protect.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-record-labels"):
                            self.is_record_labels = value
                            self.is_record_labels.value_namespace = name_space
                            self.is_record_labels.value_namespace_prefix = name_space_prefix
                        if(value_path == "is-shared-explicit-requested"):
                            self.is_shared_explicit_requested = value
                            self.is_shared_explicit_requested.value_namespace = name_space
                            self.is_shared_explicit_requested.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.reservation_priority.is_set or
                        self.setup_priority.is_set or
                        (self.sess_attribute_flags is not None and self.sess_attribute_flags.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.reservation_priority.yfilter != YFilter.not_set or
                        self.setup_priority.yfilter != YFilter.not_set or
                        (self.sess_attribute_flags is not None and self.sess_attribute_flags.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "session-attribute" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-briefs/psb-brief/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.reservation_priority.is_set or self.reservation_priority.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.reservation_priority.get_name_leafdata())
                    if (self.setup_priority.is_set or self.setup_priority.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.setup_priority.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "sess-attribute-flags"):
                        if (self.sess_attribute_flags is None):
                            self.sess_attribute_flags = Rsvp.PsbBriefs.PsbBrief.SessionAttribute.SessAttributeFlags()
                            self.sess_attribute_flags.parent = self
                            self._children_name_map["sess_attribute_flags"] = "sess-attribute-flags"
                        return self.sess_attribute_flags

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "sess-attribute-flags" or name == "reservation-priority" or name == "setup-priority"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "reservation-priority"):
                        self.reservation_priority = value
                        self.reservation_priority.value_namespace = name_space
                        self.reservation_priority.value_namespace_prefix = name_space_prefix
                    if(value_path == "setup-priority"):
                        self.setup_priority = value
                        self.setup_priority.value_namespace = name_space
                        self.setup_priority.value_namespace_prefix = name_space_prefix


            class TrafficSpec(Entity):
                """
                RSVP Traffic Spec Info
                
                .. attribute:: traffic_average_rate
                
                	Traffic Average Rate in bytes per second
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: byte/s
                
                .. attribute:: traffic_max_burst
                
                	Traffic Maximum Burst
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: traffic_max_unit
                
                	Traffic Maximum Unit
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: traffic_min_unit
                
                	Traffic Minimum Unit
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: traffic_peak_rate
                
                	Traffic Peak Rate in bytes per second
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: byte/s
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.PsbBriefs.PsbBrief.TrafficSpec, self).__init__()

                    self.yang_name = "traffic-spec"
                    self.yang_parent_name = "psb-brief"

                    self.traffic_average_rate = YLeaf(YType.uint64, "traffic-average-rate")

                    self.traffic_max_burst = YLeaf(YType.uint64, "traffic-max-burst")

                    self.traffic_max_unit = YLeaf(YType.uint32, "traffic-max-unit")

                    self.traffic_min_unit = YLeaf(YType.uint32, "traffic-min-unit")

                    self.traffic_peak_rate = YLeaf(YType.uint64, "traffic-peak-rate")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("traffic_average_rate",
                                    "traffic_max_burst",
                                    "traffic_max_unit",
                                    "traffic_min_unit",
                                    "traffic_peak_rate") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.PsbBriefs.PsbBrief.TrafficSpec, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.PsbBriefs.PsbBrief.TrafficSpec, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.traffic_average_rate.is_set or
                        self.traffic_max_burst.is_set or
                        self.traffic_max_unit.is_set or
                        self.traffic_min_unit.is_set or
                        self.traffic_peak_rate.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.traffic_average_rate.yfilter != YFilter.not_set or
                        self.traffic_max_burst.yfilter != YFilter.not_set or
                        self.traffic_max_unit.yfilter != YFilter.not_set or
                        self.traffic_min_unit.yfilter != YFilter.not_set or
                        self.traffic_peak_rate.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "traffic-spec" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-briefs/psb-brief/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.traffic_average_rate.is_set or self.traffic_average_rate.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.traffic_average_rate.get_name_leafdata())
                    if (self.traffic_max_burst.is_set or self.traffic_max_burst.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.traffic_max_burst.get_name_leafdata())
                    if (self.traffic_max_unit.is_set or self.traffic_max_unit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.traffic_max_unit.get_name_leafdata())
                    if (self.traffic_min_unit.is_set or self.traffic_min_unit.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.traffic_min_unit.get_name_leafdata())
                    if (self.traffic_peak_rate.is_set or self.traffic_peak_rate.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.traffic_peak_rate.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "traffic-average-rate" or name == "traffic-max-burst" or name == "traffic-max-unit" or name == "traffic-min-unit" or name == "traffic-peak-rate"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "traffic-average-rate"):
                        self.traffic_average_rate = value
                        self.traffic_average_rate.value_namespace = name_space
                        self.traffic_average_rate.value_namespace_prefix = name_space_prefix
                    if(value_path == "traffic-max-burst"):
                        self.traffic_max_burst = value
                        self.traffic_max_burst.value_namespace = name_space
                        self.traffic_max_burst.value_namespace_prefix = name_space_prefix
                    if(value_path == "traffic-max-unit"):
                        self.traffic_max_unit = value
                        self.traffic_max_unit.value_namespace = name_space
                        self.traffic_max_unit.value_namespace_prefix = name_space_prefix
                    if(value_path == "traffic-min-unit"):
                        self.traffic_min_unit = value
                        self.traffic_min_unit.value_namespace = name_space
                        self.traffic_min_unit.value_namespace_prefix = name_space_prefix
                    if(value_path == "traffic-peak-rate"):
                        self.traffic_peak_rate = value
                        self.traffic_peak_rate.value_namespace = name_space
                        self.traffic_peak_rate.value_namespace_prefix = name_space_prefix


            class GenericTrafficSpec(Entity):
                """
                RSVP Generic Traffic Spec Info
                
                .. attribute:: g709otn_tspec
                
                	G709 OTN Sender Tspec
                	**type**\:   :py:class:`G709OtnTspec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbBriefs.PsbBrief.GenericTrafficSpec.G709OtnTspec>`
                
                .. attribute:: intsrv_tspec
                
                	Integrated Services Sender Tspec
                	**type**\:   :py:class:`IntsrvTspec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.PsbBriefs.PsbBrief.GenericTrafficSpec.IntsrvTspec>`
                
                .. attribute:: tspec_type
                
                	TspecType
                	**type**\:   :py:class:`RsvpMgmtTspec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtTspec>`
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.PsbBriefs.PsbBrief.GenericTrafficSpec, self).__init__()

                    self.yang_name = "generic-traffic-spec"
                    self.yang_parent_name = "psb-brief"

                    self.tspec_type = YLeaf(YType.enumeration, "tspec-type")

                    self.g709otn_tspec = Rsvp.PsbBriefs.PsbBrief.GenericTrafficSpec.G709OtnTspec()
                    self.g709otn_tspec.parent = self
                    self._children_name_map["g709otn_tspec"] = "g709otn-tspec"
                    self._children_yang_names.add("g709otn-tspec")

                    self.intsrv_tspec = Rsvp.PsbBriefs.PsbBrief.GenericTrafficSpec.IntsrvTspec()
                    self.intsrv_tspec.parent = self
                    self._children_name_map["intsrv_tspec"] = "intsrv-tspec"
                    self._children_yang_names.add("intsrv-tspec")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("tspec_type") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.PsbBriefs.PsbBrief.GenericTrafficSpec, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.PsbBriefs.PsbBrief.GenericTrafficSpec, self).__setattr__(name, value)


                class G709OtnTspec(Entity):
                    """
                    G709 OTN Sender Tspec
                    
                    .. attribute:: traffic_bit_rate
                    
                    	G709 OTN Traffic Bit Rate
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: traffic_multiplier
                    
                    	G709 OTN Traffic Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: traffic_nvc
                    
                    	G709 OTN Traffic NVC
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: traffic_signal_type
                    
                    	G709 OTN Traffic Signal Type (Refer G709 v3)
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.PsbBriefs.PsbBrief.GenericTrafficSpec.G709OtnTspec, self).__init__()

                        self.yang_name = "g709otn-tspec"
                        self.yang_parent_name = "generic-traffic-spec"

                        self.traffic_bit_rate = YLeaf(YType.uint64, "traffic-bit-rate")

                        self.traffic_multiplier = YLeaf(YType.uint16, "traffic-multiplier")

                        self.traffic_nvc = YLeaf(YType.uint16, "traffic-nvc")

                        self.traffic_signal_type = YLeaf(YType.uint8, "traffic-signal-type")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("traffic_bit_rate",
                                        "traffic_multiplier",
                                        "traffic_nvc",
                                        "traffic_signal_type") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.PsbBriefs.PsbBrief.GenericTrafficSpec.G709OtnTspec, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.PsbBriefs.PsbBrief.GenericTrafficSpec.G709OtnTspec, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.traffic_bit_rate.is_set or
                            self.traffic_multiplier.is_set or
                            self.traffic_nvc.is_set or
                            self.traffic_signal_type.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.traffic_bit_rate.yfilter != YFilter.not_set or
                            self.traffic_multiplier.yfilter != YFilter.not_set or
                            self.traffic_nvc.yfilter != YFilter.not_set or
                            self.traffic_signal_type.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "g709otn-tspec" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-briefs/psb-brief/generic-traffic-spec/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.traffic_bit_rate.is_set or self.traffic_bit_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.traffic_bit_rate.get_name_leafdata())
                        if (self.traffic_multiplier.is_set or self.traffic_multiplier.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.traffic_multiplier.get_name_leafdata())
                        if (self.traffic_nvc.is_set or self.traffic_nvc.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.traffic_nvc.get_name_leafdata())
                        if (self.traffic_signal_type.is_set or self.traffic_signal_type.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.traffic_signal_type.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "traffic-bit-rate" or name == "traffic-multiplier" or name == "traffic-nvc" or name == "traffic-signal-type"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "traffic-bit-rate"):
                            self.traffic_bit_rate = value
                            self.traffic_bit_rate.value_namespace = name_space
                            self.traffic_bit_rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "traffic-multiplier"):
                            self.traffic_multiplier = value
                            self.traffic_multiplier.value_namespace = name_space
                            self.traffic_multiplier.value_namespace_prefix = name_space_prefix
                        if(value_path == "traffic-nvc"):
                            self.traffic_nvc = value
                            self.traffic_nvc.value_namespace = name_space
                            self.traffic_nvc.value_namespace_prefix = name_space_prefix
                        if(value_path == "traffic-signal-type"):
                            self.traffic_signal_type = value
                            self.traffic_signal_type.value_namespace = name_space
                            self.traffic_signal_type.value_namespace_prefix = name_space_prefix


                class IntsrvTspec(Entity):
                    """
                    Integrated Services Sender Tspec
                    
                    .. attribute:: traffic_average_rate
                    
                    	Traffic Average Rate in bytes per second
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: byte/s
                    
                    .. attribute:: traffic_max_burst
                    
                    	Traffic Maximum Burst
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: traffic_max_unit
                    
                    	Traffic Maximum Unit
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: traffic_min_unit
                    
                    	Traffic Minimum Unit
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: traffic_peak_rate
                    
                    	Traffic Peak Rate in bytes per second
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: byte/s
                    
                    

                    """

                    _prefix = 'ip-rsvp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rsvp.PsbBriefs.PsbBrief.GenericTrafficSpec.IntsrvTspec, self).__init__()

                        self.yang_name = "intsrv-tspec"
                        self.yang_parent_name = "generic-traffic-spec"

                        self.traffic_average_rate = YLeaf(YType.uint64, "traffic-average-rate")

                        self.traffic_max_burst = YLeaf(YType.uint64, "traffic-max-burst")

                        self.traffic_max_unit = YLeaf(YType.uint32, "traffic-max-unit")

                        self.traffic_min_unit = YLeaf(YType.uint32, "traffic-min-unit")

                        self.traffic_peak_rate = YLeaf(YType.uint64, "traffic-peak-rate")

                    def __setattr__(self, name, value):
                        self._check_monkey_patching_error(name, value)
                        with _handle_type_error():
                            if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                                raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                    "Please use list append or extend method."
                                                    .format(value))
                            if isinstance(value, Enum.YLeaf):
                                value = value.name
                            if name in ("traffic_average_rate",
                                        "traffic_max_burst",
                                        "traffic_max_unit",
                                        "traffic_min_unit",
                                        "traffic_peak_rate") and name in self.__dict__:
                                if isinstance(value, YLeaf):
                                    self.__dict__[name].set(value.get())
                                elif isinstance(value, YLeafList):
                                    super(Rsvp.PsbBriefs.PsbBrief.GenericTrafficSpec.IntsrvTspec, self).__setattr__(name, value)
                                else:
                                    self.__dict__[name].set(value)
                            else:
                                if hasattr(value, "parent") and name != "parent":
                                    if hasattr(value, "is_presence_container") and value.is_presence_container:
                                        value.parent = self
                                    elif value.parent is None and value.yang_name in self._children_yang_names:
                                        value.parent = self
                                super(Rsvp.PsbBriefs.PsbBrief.GenericTrafficSpec.IntsrvTspec, self).__setattr__(name, value)

                    def has_data(self):
                        return (
                            self.traffic_average_rate.is_set or
                            self.traffic_max_burst.is_set or
                            self.traffic_max_unit.is_set or
                            self.traffic_min_unit.is_set or
                            self.traffic_peak_rate.is_set)

                    def has_operation(self):
                        return (
                            self.yfilter != YFilter.not_set or
                            self.traffic_average_rate.yfilter != YFilter.not_set or
                            self.traffic_max_burst.yfilter != YFilter.not_set or
                            self.traffic_max_unit.yfilter != YFilter.not_set or
                            self.traffic_min_unit.yfilter != YFilter.not_set or
                            self.traffic_peak_rate.yfilter != YFilter.not_set)

                    def get_segment_path(self):
                        path_buffer = ""
                        path_buffer = "intsrv-tspec" + path_buffer

                        return path_buffer

                    def get_entity_path(self, ancestor):
                        path_buffer = ""
                        if (ancestor is None):
                            path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-briefs/psb-brief/generic-traffic-spec/%s" % self.get_segment_path()
                        else:
                            path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                        leaf_name_data = LeafDataList()
                        if (self.traffic_average_rate.is_set or self.traffic_average_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.traffic_average_rate.get_name_leafdata())
                        if (self.traffic_max_burst.is_set or self.traffic_max_burst.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.traffic_max_burst.get_name_leafdata())
                        if (self.traffic_max_unit.is_set or self.traffic_max_unit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.traffic_max_unit.get_name_leafdata())
                        if (self.traffic_min_unit.is_set or self.traffic_min_unit.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.traffic_min_unit.get_name_leafdata())
                        if (self.traffic_peak_rate.is_set or self.traffic_peak_rate.yfilter != YFilter.not_set):
                            leaf_name_data.append(self.traffic_peak_rate.get_name_leafdata())

                        entity_path = EntityPath(path_buffer, leaf_name_data)
                        return entity_path

                    def get_child_by_name(self, child_yang_name, segment_path):
                        child = self._get_child_by_seg_name([child_yang_name, segment_path])
                        if child is not None:
                            return child

                        return None

                    def has_leaf_or_child_of_name(self, name):
                        if(name == "traffic-average-rate" or name == "traffic-max-burst" or name == "traffic-max-unit" or name == "traffic-min-unit" or name == "traffic-peak-rate"):
                            return True
                        return False

                    def set_value(self, value_path, value, name_space, name_space_prefix):
                        if(value_path == "traffic-average-rate"):
                            self.traffic_average_rate = value
                            self.traffic_average_rate.value_namespace = name_space
                            self.traffic_average_rate.value_namespace_prefix = name_space_prefix
                        if(value_path == "traffic-max-burst"):
                            self.traffic_max_burst = value
                            self.traffic_max_burst.value_namespace = name_space
                            self.traffic_max_burst.value_namespace_prefix = name_space_prefix
                        if(value_path == "traffic-max-unit"):
                            self.traffic_max_unit = value
                            self.traffic_max_unit.value_namespace = name_space
                            self.traffic_max_unit.value_namespace_prefix = name_space_prefix
                        if(value_path == "traffic-min-unit"):
                            self.traffic_min_unit = value
                            self.traffic_min_unit.value_namespace = name_space
                            self.traffic_min_unit.value_namespace_prefix = name_space_prefix
                        if(value_path == "traffic-peak-rate"):
                            self.traffic_peak_rate = value
                            self.traffic_peak_rate.value_namespace = name_space
                            self.traffic_peak_rate.value_namespace_prefix = name_space_prefix

                def has_data(self):
                    return (
                        self.tspec_type.is_set or
                        (self.g709otn_tspec is not None and self.g709otn_tspec.has_data()) or
                        (self.intsrv_tspec is not None and self.intsrv_tspec.has_data()))

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.tspec_type.yfilter != YFilter.not_set or
                        (self.g709otn_tspec is not None and self.g709otn_tspec.has_operation()) or
                        (self.intsrv_tspec is not None and self.intsrv_tspec.has_operation()))

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "generic-traffic-spec" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-briefs/psb-brief/%s" % self.get_segment_path()
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.tspec_type.is_set or self.tspec_type.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.tspec_type.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    if (child_yang_name == "g709otn-tspec"):
                        if (self.g709otn_tspec is None):
                            self.g709otn_tspec = Rsvp.PsbBriefs.PsbBrief.GenericTrafficSpec.G709OtnTspec()
                            self.g709otn_tspec.parent = self
                            self._children_name_map["g709otn_tspec"] = "g709otn-tspec"
                        return self.g709otn_tspec

                    if (child_yang_name == "intsrv-tspec"):
                        if (self.intsrv_tspec is None):
                            self.intsrv_tspec = Rsvp.PsbBriefs.PsbBrief.GenericTrafficSpec.IntsrvTspec()
                            self.intsrv_tspec.parent = self
                            self._children_name_map["intsrv_tspec"] = "intsrv-tspec"
                        return self.intsrv_tspec

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "g709otn-tspec" or name == "intsrv-tspec" or name == "tspec-type"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "tspec-type"):
                        self.tspec_type = value
                        self.tspec_type.value_namespace = name_space
                        self.tspec_type.value_namespace_prefix = name_space_prefix

            def has_data(self):
                return (
                    self.destination_address.is_set or
                    self.destination_port.is_set or
                    self.extended_tunnel_id.is_set or
                    self.input_interface.is_set or
                    self.p2mp_id.is_set or
                    self.protocol.is_set or
                    self.session_type.is_set or
                    self.source_address.is_set or
                    self.source_port.is_set or
                    self.sub_group_id.is_set or
                    self.sub_group_origin.is_set or
                    self.vrf_name.is_set or
                    (self.generic_traffic_spec is not None and self.generic_traffic_spec.has_data()) or
                    (self.s2l_sub_lsp is not None and self.s2l_sub_lsp.has_data()) or
                    (self.session is not None and self.session.has_data()) or
                    (self.session_attribute is not None and self.session_attribute.has_data()) or
                    (self.template is not None and self.template.has_data()) or
                    (self.traffic_spec is not None and self.traffic_spec.has_data()))

            def has_operation(self):
                return (
                    self.yfilter != YFilter.not_set or
                    self.destination_address.yfilter != YFilter.not_set or
                    self.destination_port.yfilter != YFilter.not_set or
                    self.extended_tunnel_id.yfilter != YFilter.not_set or
                    self.input_interface.yfilter != YFilter.not_set or
                    self.p2mp_id.yfilter != YFilter.not_set or
                    self.protocol.yfilter != YFilter.not_set or
                    self.session_type.yfilter != YFilter.not_set or
                    self.source_address.yfilter != YFilter.not_set or
                    self.source_port.yfilter != YFilter.not_set or
                    self.sub_group_id.yfilter != YFilter.not_set or
                    self.sub_group_origin.yfilter != YFilter.not_set or
                    self.vrf_name.yfilter != YFilter.not_set or
                    (self.generic_traffic_spec is not None and self.generic_traffic_spec.has_operation()) or
                    (self.s2l_sub_lsp is not None and self.s2l_sub_lsp.has_operation()) or
                    (self.session is not None and self.session.has_operation()) or
                    (self.session_attribute is not None and self.session_attribute.has_operation()) or
                    (self.template is not None and self.template.has_operation()) or
                    (self.traffic_spec is not None and self.traffic_spec.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "psb-brief" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/psb-briefs/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.destination_address.is_set or self.destination_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_address.get_name_leafdata())
                if (self.destination_port.is_set or self.destination_port.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.destination_port.get_name_leafdata())
                if (self.extended_tunnel_id.is_set or self.extended_tunnel_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.extended_tunnel_id.get_name_leafdata())
                if (self.input_interface.is_set or self.input_interface.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.input_interface.get_name_leafdata())
                if (self.p2mp_id.is_set or self.p2mp_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.p2mp_id.get_name_leafdata())
                if (self.protocol.is_set or self.protocol.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.protocol.get_name_leafdata())
                if (self.session_type.is_set or self.session_type.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.session_type.get_name_leafdata())
                if (self.source_address.is_set or self.source_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_address.get_name_leafdata())
                if (self.source_port.is_set or self.source_port.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.source_port.get_name_leafdata())
                if (self.sub_group_id.is_set or self.sub_group_id.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.sub_group_id.get_name_leafdata())
                if (self.sub_group_origin.is_set or self.sub_group_origin.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.sub_group_origin.get_name_leafdata())
                if (self.vrf_name.is_set or self.vrf_name.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.vrf_name.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "generic-traffic-spec"):
                    if (self.generic_traffic_spec is None):
                        self.generic_traffic_spec = Rsvp.PsbBriefs.PsbBrief.GenericTrafficSpec()
                        self.generic_traffic_spec.parent = self
                        self._children_name_map["generic_traffic_spec"] = "generic-traffic-spec"
                    return self.generic_traffic_spec

                if (child_yang_name == "s2l-sub-lsp"):
                    if (self.s2l_sub_lsp is None):
                        self.s2l_sub_lsp = Rsvp.PsbBriefs.PsbBrief.S2LSubLsp()
                        self.s2l_sub_lsp.parent = self
                        self._children_name_map["s2l_sub_lsp"] = "s2l-sub-lsp"
                    return self.s2l_sub_lsp

                if (child_yang_name == "session"):
                    if (self.session is None):
                        self.session = Rsvp.PsbBriefs.PsbBrief.Session()
                        self.session.parent = self
                        self._children_name_map["session"] = "session"
                    return self.session

                if (child_yang_name == "session-attribute"):
                    if (self.session_attribute is None):
                        self.session_attribute = Rsvp.PsbBriefs.PsbBrief.SessionAttribute()
                        self.session_attribute.parent = self
                        self._children_name_map["session_attribute"] = "session-attribute"
                    return self.session_attribute

                if (child_yang_name == "template"):
                    if (self.template is None):
                        self.template = Rsvp.PsbBriefs.PsbBrief.Template()
                        self.template.parent = self
                        self._children_name_map["template"] = "template"
                    return self.template

                if (child_yang_name == "traffic-spec"):
                    if (self.traffic_spec is None):
                        self.traffic_spec = Rsvp.PsbBriefs.PsbBrief.TrafficSpec()
                        self.traffic_spec.parent = self
                        self._children_name_map["traffic_spec"] = "traffic-spec"
                    return self.traffic_spec

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "generic-traffic-spec" or name == "s2l-sub-lsp" or name == "session" or name == "session-attribute" or name == "template" or name == "traffic-spec" or name == "destination-address" or name == "destination-port" or name == "extended-tunnel-id" or name == "input-interface" or name == "p2mp-id" or name == "protocol" or name == "session-type" or name == "source-address" or name == "source-port" or name == "sub-group-id" or name == "sub-group-origin" or name == "vrf-name"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "destination-address"):
                    self.destination_address = value
                    self.destination_address.value_namespace = name_space
                    self.destination_address.value_namespace_prefix = name_space_prefix
                if(value_path == "destination-port"):
                    self.destination_port = value
                    self.destination_port.value_namespace = name_space
                    self.destination_port.value_namespace_prefix = name_space_prefix
                if(value_path == "extended-tunnel-id"):
                    self.extended_tunnel_id = value
                    self.extended_tunnel_id.value_namespace = name_space
                    self.extended_tunnel_id.value_namespace_prefix = name_space_prefix
                if(value_path == "input-interface"):
                    self.input_interface = value
                    self.input_interface.value_namespace = name_space
                    self.input_interface.value_namespace_prefix = name_space_prefix
                if(value_path == "p2mp-id"):
                    self.p2mp_id = value
                    self.p2mp_id.value_namespace = name_space
                    self.p2mp_id.value_namespace_prefix = name_space_prefix
                if(value_path == "protocol"):
                    self.protocol = value
                    self.protocol.value_namespace = name_space
                    self.protocol.value_namespace_prefix = name_space_prefix
                if(value_path == "session-type"):
                    self.session_type = value
                    self.session_type.value_namespace = name_space
                    self.session_type.value_namespace_prefix = name_space_prefix
                if(value_path == "source-address"):
                    self.source_address = value
                    self.source_address.value_namespace = name_space
                    self.source_address.value_namespace_prefix = name_space_prefix
                if(value_path == "source-port"):
                    self.source_port = value
                    self.source_port.value_namespace = name_space
                    self.source_port.value_namespace_prefix = name_space_prefix
                if(value_path == "sub-group-id"):
                    self.sub_group_id = value
                    self.sub_group_id.value_namespace = name_space
                    self.sub_group_id.value_namespace_prefix = name_space_prefix
                if(value_path == "sub-group-origin"):
                    self.sub_group_origin = value
                    self.sub_group_origin.value_namespace = name_space
                    self.sub_group_origin.value_namespace_prefix = name_space_prefix
                if(value_path == "vrf-name"):
                    self.vrf_name = value
                    self.vrf_name.value_namespace = name_space
                    self.vrf_name.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.psb_brief:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.psb_brief:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "psb-briefs" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "psb-brief"):
                for c in self.psb_brief:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = Rsvp.PsbBriefs.PsbBrief()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.psb_brief.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "psb-brief"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass


    class GlobalNeighborBriefs(Entity):
        """
        Table of brief info about global neighbors
        
        .. attribute:: global_neighbor_brief
        
        	Brief info for a single global neighbor
        	**type**\: list of    :py:class:`GlobalNeighborBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.GlobalNeighborBriefs.GlobalNeighborBrief>`
        
        

        """

        _prefix = 'ip-rsvp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Rsvp.GlobalNeighborBriefs, self).__init__()

            self.yang_name = "global-neighbor-briefs"
            self.yang_parent_name = "rsvp"

            self.global_neighbor_brief = YList(self)

        def __setattr__(self, name, value):
            self._check_monkey_patching_error(name, value)
            with _handle_type_error():
                if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                    raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                        "Please use list append or extend method."
                                        .format(value))
                if isinstance(value, Enum.YLeaf):
                    value = value.name
                if name in () and name in self.__dict__:
                    if isinstance(value, YLeaf):
                        self.__dict__[name].set(value.get())
                    elif isinstance(value, YLeafList):
                        super(Rsvp.GlobalNeighborBriefs, self).__setattr__(name, value)
                    else:
                        self.__dict__[name].set(value)
                else:
                    if hasattr(value, "parent") and name != "parent":
                        if hasattr(value, "is_presence_container") and value.is_presence_container:
                            value.parent = self
                        elif value.parent is None and value.yang_name in self._children_yang_names:
                            value.parent = self
                    super(Rsvp.GlobalNeighborBriefs, self).__setattr__(name, value)


        class GlobalNeighborBrief(Entity):
            """
            Brief info for a single global neighbor
            
            .. attribute:: neighbor_address  <key>
            
            	Address of global neighbor
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: global_neighbor_flags
            
            	Global Neighbor Flags
            	**type**\:   :py:class:`GlobalNeighborFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.GlobalNeighborBriefs.GlobalNeighborBrief.GlobalNeighborFlags>`
            
            .. attribute:: is_gr_enabled
            
            	Is GR enabled
            	**type**\:  bool
            
            .. attribute:: local_node_address
            
            	Local node address
            	**type**\:  list of str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: lost_communication_reason
            
            	Reason why communication was lost
            	**type**\:  list of   :py:class:`RsvpMgmtHelloDownReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtHelloDownReason>`
            
            .. attribute:: lost_communication_time
            
            	Time when communication was lost
            	**type**\: list of    :py:class:`LostCommunicationTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.GlobalNeighborBriefs.GlobalNeighborBrief.LostCommunicationTime>`
            
            .. attribute:: lost_communication_total
            
            	Total number of times communication got lost
            	**type**\:  list of int
            
            	**range:** 0..65535
            
            .. attribute:: neighbor_hello_state
            
            	Neighbor Hello state
            	**type**\:  list of   :py:class:`RsvpMgmtHelloState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtHelloState>`
            
            .. attribute:: node_address
            
            	Neighbor node address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: restart_state
            
            	Restart state
            	**type**\:   :py:class:`RsvpMgmtRestartState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.RsvpMgmtRestartState>`
            
            .. attribute:: up_time
            
            	Time hellos have been up
            	**type**\: list of    :py:class:`UpTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rsvp_oper.Rsvp.GlobalNeighborBriefs.GlobalNeighborBrief.UpTime>`
            
            

            """

            _prefix = 'ip-rsvp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Rsvp.GlobalNeighborBriefs.GlobalNeighborBrief, self).__init__()

                self.yang_name = "global-neighbor-brief"
                self.yang_parent_name = "global-neighbor-briefs"

                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                self.is_gr_enabled = YLeaf(YType.boolean, "is-gr-enabled")

                self.local_node_address = YLeafList(YType.str, "local-node-address")

                self.lost_communication_reason = YLeafList(YType.enumeration, "lost-communication-reason")

                self.lost_communication_total = YLeafList(YType.uint16, "lost-communication-total")

                self.neighbor_hello_state = YLeafList(YType.enumeration, "neighbor-hello-state")

                self.node_address = YLeaf(YType.str, "node-address")

                self.restart_state = YLeaf(YType.enumeration, "restart-state")

                self.global_neighbor_flags = Rsvp.GlobalNeighborBriefs.GlobalNeighborBrief.GlobalNeighborFlags()
                self.global_neighbor_flags.parent = self
                self._children_name_map["global_neighbor_flags"] = "global-neighbor-flags"
                self._children_yang_names.add("global-neighbor-flags")

                self.lost_communication_time = YList(self)
                self.up_time = YList(self)

            def __setattr__(self, name, value):
                self._check_monkey_patching_error(name, value)
                with _handle_type_error():
                    if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                        raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                            "Please use list append or extend method."
                                            .format(value))
                    if isinstance(value, Enum.YLeaf):
                        value = value.name
                    if name in ("neighbor_address",
                                "is_gr_enabled",
                                "local_node_address",
                                "lost_communication_reason",
                                "lost_communication_total",
                                "neighbor_hello_state",
                                "node_address",
                                "restart_state") and name in self.__dict__:
                        if isinstance(value, YLeaf):
                            self.__dict__[name].set(value.get())
                        elif isinstance(value, YLeafList):
                            super(Rsvp.GlobalNeighborBriefs.GlobalNeighborBrief, self).__setattr__(name, value)
                        else:
                            self.__dict__[name].set(value)
                    else:
                        if hasattr(value, "parent") and name != "parent":
                            if hasattr(value, "is_presence_container") and value.is_presence_container:
                                value.parent = self
                            elif value.parent is None and value.yang_name in self._children_yang_names:
                                value.parent = self
                        super(Rsvp.GlobalNeighborBriefs.GlobalNeighborBrief, self).__setattr__(name, value)


            class GlobalNeighborFlags(Entity):
                """
                Global Neighbor Flags
                
                .. attribute:: is_application_mpls
                
                	MPLS Application
                	**type**\:  bool
                
                .. attribute:: is_application_ouni
                
                	OUNI Application
                	**type**\:  bool
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.GlobalNeighborBriefs.GlobalNeighborBrief.GlobalNeighborFlags, self).__init__()

                    self.yang_name = "global-neighbor-flags"
                    self.yang_parent_name = "global-neighbor-brief"

                    self.is_application_mpls = YLeaf(YType.boolean, "is-application-mpls")

                    self.is_application_ouni = YLeaf(YType.boolean, "is-application-ouni")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("is_application_mpls",
                                    "is_application_ouni") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.GlobalNeighborBriefs.GlobalNeighborBrief.GlobalNeighborFlags, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.GlobalNeighborBriefs.GlobalNeighborBrief.GlobalNeighborFlags, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.is_application_mpls.is_set or
                        self.is_application_ouni.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.is_application_mpls.yfilter != YFilter.not_set or
                        self.is_application_ouni.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "global-neighbor-flags" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.is_application_mpls.is_set or self.is_application_mpls.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_application_mpls.get_name_leafdata())
                    if (self.is_application_ouni.is_set or self.is_application_ouni.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.is_application_ouni.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "is-application-mpls" or name == "is-application-ouni"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "is-application-mpls"):
                        self.is_application_mpls = value
                        self.is_application_mpls.value_namespace = name_space
                        self.is_application_mpls.value_namespace_prefix = name_space_prefix
                    if(value_path == "is-application-ouni"):
                        self.is_application_ouni = value
                        self.is_application_ouni.value_namespace = name_space
                        self.is_application_ouni.value_namespace_prefix = name_space_prefix


            class UpTime(Entity):
                """
                Time hellos have been up
                
                .. attribute:: nanoseconds
                
                	Time Value in Nano\-seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: nanosecond
                
                .. attribute:: seconds
                
                	Time Value in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.GlobalNeighborBriefs.GlobalNeighborBrief.UpTime, self).__init__()

                    self.yang_name = "up-time"
                    self.yang_parent_name = "global-neighbor-brief"

                    self.nanoseconds = YLeaf(YType.int32, "nanoseconds")

                    self.seconds = YLeaf(YType.int32, "seconds")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("nanoseconds",
                                    "seconds") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.GlobalNeighborBriefs.GlobalNeighborBrief.UpTime, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.GlobalNeighborBriefs.GlobalNeighborBrief.UpTime, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.nanoseconds.is_set or
                        self.seconds.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.nanoseconds.yfilter != YFilter.not_set or
                        self.seconds.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "up-time" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.nanoseconds.is_set or self.nanoseconds.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.nanoseconds.get_name_leafdata())
                    if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.seconds.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "nanoseconds" or name == "seconds"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "nanoseconds"):
                        self.nanoseconds = value
                        self.nanoseconds.value_namespace = name_space
                        self.nanoseconds.value_namespace_prefix = name_space_prefix
                    if(value_path == "seconds"):
                        self.seconds = value
                        self.seconds.value_namespace = name_space
                        self.seconds.value_namespace_prefix = name_space_prefix


            class LostCommunicationTime(Entity):
                """
                Time when communication was lost
                
                .. attribute:: nanoseconds
                
                	Time Value in Nano\-seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: nanosecond
                
                .. attribute:: seconds
                
                	Time Value in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                

                """

                _prefix = 'ip-rsvp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rsvp.GlobalNeighborBriefs.GlobalNeighborBrief.LostCommunicationTime, self).__init__()

                    self.yang_name = "lost-communication-time"
                    self.yang_parent_name = "global-neighbor-brief"

                    self.nanoseconds = YLeaf(YType.int32, "nanoseconds")

                    self.seconds = YLeaf(YType.int32, "seconds")

                def __setattr__(self, name, value):
                    self._check_monkey_patching_error(name, value)
                    with _handle_type_error():
                        if name in self.__dict__ and isinstance(self.__dict__[name], YList):
                            raise YPYModelError("Attempt to assign value of '{}' to YList ldata. "
                                                "Please use list append or extend method."
                                                .format(value))
                        if isinstance(value, Enum.YLeaf):
                            value = value.name
                        if name in ("nanoseconds",
                                    "seconds") and name in self.__dict__:
                            if isinstance(value, YLeaf):
                                self.__dict__[name].set(value.get())
                            elif isinstance(value, YLeafList):
                                super(Rsvp.GlobalNeighborBriefs.GlobalNeighborBrief.LostCommunicationTime, self).__setattr__(name, value)
                            else:
                                self.__dict__[name].set(value)
                        else:
                            if hasattr(value, "parent") and name != "parent":
                                if hasattr(value, "is_presence_container") and value.is_presence_container:
                                    value.parent = self
                                elif value.parent is None and value.yang_name in self._children_yang_names:
                                    value.parent = self
                            super(Rsvp.GlobalNeighborBriefs.GlobalNeighborBrief.LostCommunicationTime, self).__setattr__(name, value)

                def has_data(self):
                    return (
                        self.nanoseconds.is_set or
                        self.seconds.is_set)

                def has_operation(self):
                    return (
                        self.yfilter != YFilter.not_set or
                        self.nanoseconds.yfilter != YFilter.not_set or
                        self.seconds.yfilter != YFilter.not_set)

                def get_segment_path(self):
                    path_buffer = ""
                    path_buffer = "lost-communication-time" + path_buffer

                    return path_buffer

                def get_entity_path(self, ancestor):
                    path_buffer = ""
                    if (ancestor is None):
                        raise YPYModelError("ancestor cannot be None as one of the ancestors is a list")
                    else:
                        path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                    leaf_name_data = LeafDataList()
                    if (self.nanoseconds.is_set or self.nanoseconds.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.nanoseconds.get_name_leafdata())
                    if (self.seconds.is_set or self.seconds.yfilter != YFilter.not_set):
                        leaf_name_data.append(self.seconds.get_name_leafdata())

                    entity_path = EntityPath(path_buffer, leaf_name_data)
                    return entity_path

                def get_child_by_name(self, child_yang_name, segment_path):
                    child = self._get_child_by_seg_name([child_yang_name, segment_path])
                    if child is not None:
                        return child

                    return None

                def has_leaf_or_child_of_name(self, name):
                    if(name == "nanoseconds" or name == "seconds"):
                        return True
                    return False

                def set_value(self, value_path, value, name_space, name_space_prefix):
                    if(value_path == "nanoseconds"):
                        self.nanoseconds = value
                        self.nanoseconds.value_namespace = name_space
                        self.nanoseconds.value_namespace_prefix = name_space_prefix
                    if(value_path == "seconds"):
                        self.seconds = value
                        self.seconds.value_namespace = name_space
                        self.seconds.value_namespace_prefix = name_space_prefix

            def has_data(self):
                for c in self.lost_communication_time:
                    if (c.has_data()):
                        return True
                for c in self.up_time:
                    if (c.has_data()):
                        return True
                for leaf in self.local_node_address.getYLeafs():
                    if (leaf.yfilter != YFilter.not_set):
                        return True
                for leaf in self.lost_communication_reason.getYLeafs():
                    if (leaf.yfilter != YFilter.not_set):
                        return True
                for leaf in self.lost_communication_total.getYLeafs():
                    if (leaf.yfilter != YFilter.not_set):
                        return True
                for leaf in self.neighbor_hello_state.getYLeafs():
                    if (leaf.yfilter != YFilter.not_set):
                        return True
                return (
                    self.neighbor_address.is_set or
                    self.is_gr_enabled.is_set or
                    self.node_address.is_set or
                    self.restart_state.is_set or
                    (self.global_neighbor_flags is not None and self.global_neighbor_flags.has_data()))

            def has_operation(self):
                for c in self.lost_communication_time:
                    if (c.has_operation()):
                        return True
                for c in self.up_time:
                    if (c.has_operation()):
                        return True
                for leaf in self.local_node_address.getYLeafs():
                    if (leaf.is_set):
                        return True
                for leaf in self.lost_communication_reason.getYLeafs():
                    if (leaf.is_set):
                        return True
                for leaf in self.lost_communication_total.getYLeafs():
                    if (leaf.is_set):
                        return True
                for leaf in self.neighbor_hello_state.getYLeafs():
                    if (leaf.is_set):
                        return True
                return (
                    self.yfilter != YFilter.not_set or
                    self.neighbor_address.yfilter != YFilter.not_set or
                    self.is_gr_enabled.yfilter != YFilter.not_set or
                    self.local_node_address.yfilter != YFilter.not_set or
                    self.lost_communication_reason.yfilter != YFilter.not_set or
                    self.lost_communication_total.yfilter != YFilter.not_set or
                    self.neighbor_hello_state.yfilter != YFilter.not_set or
                    self.node_address.yfilter != YFilter.not_set or
                    self.restart_state.yfilter != YFilter.not_set or
                    (self.global_neighbor_flags is not None and self.global_neighbor_flags.has_operation()))

            def get_segment_path(self):
                path_buffer = ""
                path_buffer = "global-neighbor-brief" + "[neighbor-address='" + self.neighbor_address.get() + "']" + path_buffer

                return path_buffer

            def get_entity_path(self, ancestor):
                path_buffer = ""
                if (ancestor is None):
                    path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/global-neighbor-briefs/%s" % self.get_segment_path()
                else:
                    path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

                leaf_name_data = LeafDataList()
                if (self.neighbor_address.is_set or self.neighbor_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.neighbor_address.get_name_leafdata())
                if (self.is_gr_enabled.is_set or self.is_gr_enabled.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.is_gr_enabled.get_name_leafdata())
                if (self.node_address.is_set or self.node_address.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.node_address.get_name_leafdata())
                if (self.restart_state.is_set or self.restart_state.yfilter != YFilter.not_set):
                    leaf_name_data.append(self.restart_state.get_name_leafdata())

                leaf_name_data.extend(self.local_node_address.get_name_leafdata())

                leaf_name_data.extend(self.lost_communication_reason.get_name_leafdata())

                leaf_name_data.extend(self.lost_communication_total.get_name_leafdata())

                leaf_name_data.extend(self.neighbor_hello_state.get_name_leafdata())

                entity_path = EntityPath(path_buffer, leaf_name_data)
                return entity_path

            def get_child_by_name(self, child_yang_name, segment_path):
                child = self._get_child_by_seg_name([child_yang_name, segment_path])
                if child is not None:
                    return child

                if (child_yang_name == "global-neighbor-flags"):
                    if (self.global_neighbor_flags is None):
                        self.global_neighbor_flags = Rsvp.GlobalNeighborBriefs.GlobalNeighborBrief.GlobalNeighborFlags()
                        self.global_neighbor_flags.parent = self
                        self._children_name_map["global_neighbor_flags"] = "global-neighbor-flags"
                    return self.global_neighbor_flags

                if (child_yang_name == "lost-communication-time"):
                    for c in self.lost_communication_time:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = Rsvp.GlobalNeighborBriefs.GlobalNeighborBrief.LostCommunicationTime()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.lost_communication_time.append(c)
                    return c

                if (child_yang_name == "up-time"):
                    for c in self.up_time:
                        segment = c.get_segment_path()
                        if (segment_path == segment):
                            return c
                    c = Rsvp.GlobalNeighborBriefs.GlobalNeighborBrief.UpTime()
                    c.parent = self
                    local_reference_key = "ydk::seg::%s" % segment_path
                    self._local_refs[local_reference_key] = c
                    self.up_time.append(c)
                    return c

                return None

            def has_leaf_or_child_of_name(self, name):
                if(name == "global-neighbor-flags" or name == "lost-communication-time" or name == "up-time" or name == "neighbor-address" or name == "is-gr-enabled" or name == "local-node-address" or name == "lost-communication-reason" or name == "lost-communication-total" or name == "neighbor-hello-state" or name == "node-address" or name == "restart-state"):
                    return True
                return False

            def set_value(self, value_path, value, name_space, name_space_prefix):
                if(value_path == "neighbor-address"):
                    self.neighbor_address = value
                    self.neighbor_address.value_namespace = name_space
                    self.neighbor_address.value_namespace_prefix = name_space_prefix
                if(value_path == "is-gr-enabled"):
                    self.is_gr_enabled = value
                    self.is_gr_enabled.value_namespace = name_space
                    self.is_gr_enabled.value_namespace_prefix = name_space_prefix
                if(value_path == "local-node-address"):
                    self.local_node_address.append(value)
                if(value_path == "lost-communication-reason"):
                    self.lost_communication_reason.append(value)
                if(value_path == "lost-communication-total"):
                    self.lost_communication_total.append(value)
                if(value_path == "neighbor-hello-state"):
                    self.neighbor_hello_state.append(value)
                if(value_path == "node-address"):
                    self.node_address = value
                    self.node_address.value_namespace = name_space
                    self.node_address.value_namespace_prefix = name_space_prefix
                if(value_path == "restart-state"):
                    self.restart_state = value
                    self.restart_state.value_namespace = name_space
                    self.restart_state.value_namespace_prefix = name_space_prefix

        def has_data(self):
            for c in self.global_neighbor_brief:
                if (c.has_data()):
                    return True
            return False

        def has_operation(self):
            for c in self.global_neighbor_brief:
                if (c.has_operation()):
                    return True
            return self.yfilter != YFilter.not_set

        def get_segment_path(self):
            path_buffer = ""
            path_buffer = "global-neighbor-briefs" + path_buffer

            return path_buffer

        def get_entity_path(self, ancestor):
            path_buffer = ""
            if (ancestor is None):
                path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp/%s" % self.get_segment_path()
            else:
                path_buffer = _get_relative_entity_path(self, ancestor, path_buffer)

            leaf_name_data = LeafDataList()

            entity_path = EntityPath(path_buffer, leaf_name_data)
            return entity_path

        def get_child_by_name(self, child_yang_name, segment_path):
            child = self._get_child_by_seg_name([child_yang_name, segment_path])
            if child is not None:
                return child

            if (child_yang_name == "global-neighbor-brief"):
                for c in self.global_neighbor_brief:
                    segment = c.get_segment_path()
                    if (segment_path == segment):
                        return c
                c = Rsvp.GlobalNeighborBriefs.GlobalNeighborBrief()
                c.parent = self
                local_reference_key = "ydk::seg::%s" % segment_path
                self._local_refs[local_reference_key] = c
                self.global_neighbor_brief.append(c)
                return c

            return None

        def has_leaf_or_child_of_name(self, name):
            if(name == "global-neighbor-brief"):
                return True
            return False

        def set_value(self, value_path, value, name_space, name_space_prefix):
            pass

    def has_data(self):
        return (
            (self.authentication_briefs is not None and self.authentication_briefs.has_data()) or
            (self.authentication_details is not None and self.authentication_details.has_data()) or
            (self.bw_pool_info is not None and self.bw_pool_info.has_data()) or
            (self.controller_briefs is not None and self.controller_briefs.has_data()) or
            (self.controller_detaileds is not None and self.controller_detaileds.has_data()) or
            (self.controller_summaries is not None and self.controller_summaries.has_data()) or
            (self.counters is not None and self.counters.has_data()) or
            (self.frr_summary is not None and self.frr_summary.has_data()) or
            (self.frrs is not None and self.frrs.has_data()) or
            (self.global_neighbor_briefs is not None and self.global_neighbor_briefs.has_data()) or
            (self.global_neighbor_details is not None and self.global_neighbor_details.has_data()) or
            (self.graceful_restart is not None and self.graceful_restart.has_data()) or
            (self.hello_instance_briefs is not None and self.hello_instance_briefs.has_data()) or
            (self.hello_instance_details is not None and self.hello_instance_details.has_data()) or
            (self.hello_interface_instance_briefs is not None and self.hello_interface_instance_briefs.has_data()) or
            (self.hello_interface_instance_details is not None and self.hello_interface_instance_details.has_data()) or
            (self.interface_briefs is not None and self.interface_briefs.has_data()) or
            (self.interface_detaileds is not None and self.interface_detaileds.has_data()) or
            (self.interface_neighbor_briefs is not None and self.interface_neighbor_briefs.has_data()) or
            (self.interface_neighbor_details is not None and self.interface_neighbor_details.has_data()) or
            (self.interface_summaries is not None and self.interface_summaries.has_data()) or
            (self.issu is not None and self.issu.has_data()) or
            (self.nsr is not None and self.nsr.has_data()) or
            (self.open_config is not None and self.open_config.has_data()) or
            (self.psb_briefs is not None and self.psb_briefs.has_data()) or
            (self.psb_detaileds is not None and self.psb_detaileds.has_data()) or
            (self.pxsb_details is not None and self.pxsb_details.has_data()) or
            (self.request_briefs is not None and self.request_briefs.has_data()) or
            (self.request_details is not None and self.request_details.has_data()) or
            (self.rsb_briefs is not None and self.rsb_briefs.has_data()) or
            (self.rsb_detaileds is not None and self.rsb_detaileds.has_data()) or
            (self.rxsb_details is not None and self.rxsb_details.has_data()) or
            (self.session_briefs is not None and self.session_briefs.has_data()) or
            (self.session_detaileds is not None and self.session_detaileds.has_data()) or
            (self.summary is not None and self.summary.has_data()))

    def has_operation(self):
        return (
            self.yfilter != YFilter.not_set or
            (self.authentication_briefs is not None and self.authentication_briefs.has_operation()) or
            (self.authentication_details is not None and self.authentication_details.has_operation()) or
            (self.bw_pool_info is not None and self.bw_pool_info.has_operation()) or
            (self.controller_briefs is not None and self.controller_briefs.has_operation()) or
            (self.controller_detaileds is not None and self.controller_detaileds.has_operation()) or
            (self.controller_summaries is not None and self.controller_summaries.has_operation()) or
            (self.counters is not None and self.counters.has_operation()) or
            (self.frr_summary is not None and self.frr_summary.has_operation()) or
            (self.frrs is not None and self.frrs.has_operation()) or
            (self.global_neighbor_briefs is not None and self.global_neighbor_briefs.has_operation()) or
            (self.global_neighbor_details is not None and self.global_neighbor_details.has_operation()) or
            (self.graceful_restart is not None and self.graceful_restart.has_operation()) or
            (self.hello_instance_briefs is not None and self.hello_instance_briefs.has_operation()) or
            (self.hello_instance_details is not None and self.hello_instance_details.has_operation()) or
            (self.hello_interface_instance_briefs is not None and self.hello_interface_instance_briefs.has_operation()) or
            (self.hello_interface_instance_details is not None and self.hello_interface_instance_details.has_operation()) or
            (self.interface_briefs is not None and self.interface_briefs.has_operation()) or
            (self.interface_detaileds is not None and self.interface_detaileds.has_operation()) or
            (self.interface_neighbor_briefs is not None and self.interface_neighbor_briefs.has_operation()) or
            (self.interface_neighbor_details is not None and self.interface_neighbor_details.has_operation()) or
            (self.interface_summaries is not None and self.interface_summaries.has_operation()) or
            (self.issu is not None and self.issu.has_operation()) or
            (self.nsr is not None and self.nsr.has_operation()) or
            (self.open_config is not None and self.open_config.has_operation()) or
            (self.psb_briefs is not None and self.psb_briefs.has_operation()) or
            (self.psb_detaileds is not None and self.psb_detaileds.has_operation()) or
            (self.pxsb_details is not None and self.pxsb_details.has_operation()) or
            (self.request_briefs is not None and self.request_briefs.has_operation()) or
            (self.request_details is not None and self.request_details.has_operation()) or
            (self.rsb_briefs is not None and self.rsb_briefs.has_operation()) or
            (self.rsb_detaileds is not None and self.rsb_detaileds.has_operation()) or
            (self.rxsb_details is not None and self.rxsb_details.has_operation()) or
            (self.session_briefs is not None and self.session_briefs.has_operation()) or
            (self.session_detaileds is not None and self.session_detaileds.has_operation()) or
            (self.summary is not None and self.summary.has_operation()))

    def get_segment_path(self):
        path_buffer = ""
        path_buffer = "Cisco-IOS-XR-ip-rsvp-oper:rsvp" + path_buffer

        return path_buffer

    def get_entity_path(self, ancestor):
        path_buffer = ""
        if (not ancestor is None):
            raise YPYModelError("ancestor has to be None for top-level node")

        path_buffer = self.get_segment_path()
        leaf_name_data = LeafDataList()

        entity_path = EntityPath(path_buffer, leaf_name_data)
        return entity_path

    def get_child_by_name(self, child_yang_name, segment_path):
        child = self._get_child_by_seg_name([child_yang_name, segment_path])
        if child is not None:
            return child

        if (child_yang_name == "authentication-briefs"):
            if (self.authentication_briefs is None):
                self.authentication_briefs = Rsvp.AuthenticationBriefs()
                self.authentication_briefs.parent = self
                self._children_name_map["authentication_briefs"] = "authentication-briefs"
            return self.authentication_briefs

        if (child_yang_name == "authentication-details"):
            if (self.authentication_details is None):
                self.authentication_details = Rsvp.AuthenticationDetails()
                self.authentication_details.parent = self
                self._children_name_map["authentication_details"] = "authentication-details"
            return self.authentication_details

        if (child_yang_name == "bw-pool-info"):
            if (self.bw_pool_info is None):
                self.bw_pool_info = Rsvp.BwPoolInfo()
                self.bw_pool_info.parent = self
                self._children_name_map["bw_pool_info"] = "bw-pool-info"
            return self.bw_pool_info

        if (child_yang_name == "controller-briefs"):
            if (self.controller_briefs is None):
                self.controller_briefs = Rsvp.ControllerBriefs()
                self.controller_briefs.parent = self
                self._children_name_map["controller_briefs"] = "controller-briefs"
            return self.controller_briefs

        if (child_yang_name == "controller-detaileds"):
            if (self.controller_detaileds is None):
                self.controller_detaileds = Rsvp.ControllerDetaileds()
                self.controller_detaileds.parent = self
                self._children_name_map["controller_detaileds"] = "controller-detaileds"
            return self.controller_detaileds

        if (child_yang_name == "controller-summaries"):
            if (self.controller_summaries is None):
                self.controller_summaries = Rsvp.ControllerSummaries()
                self.controller_summaries.parent = self
                self._children_name_map["controller_summaries"] = "controller-summaries"
            return self.controller_summaries

        if (child_yang_name == "counters"):
            if (self.counters is None):
                self.counters = Rsvp.Counters()
                self.counters.parent = self
                self._children_name_map["counters"] = "counters"
            return self.counters

        if (child_yang_name == "frr-summary"):
            if (self.frr_summary is None):
                self.frr_summary = Rsvp.FrrSummary()
                self.frr_summary.parent = self
                self._children_name_map["frr_summary"] = "frr-summary"
            return self.frr_summary

        if (child_yang_name == "frrs"):
            if (self.frrs is None):
                self.frrs = Rsvp.Frrs()
                self.frrs.parent = self
                self._children_name_map["frrs"] = "frrs"
            return self.frrs

        if (child_yang_name == "global-neighbor-briefs"):
            if (self.global_neighbor_briefs is None):
                self.global_neighbor_briefs = Rsvp.GlobalNeighborBriefs()
                self.global_neighbor_briefs.parent = self
                self._children_name_map["global_neighbor_briefs"] = "global-neighbor-briefs"
            return self.global_neighbor_briefs

        if (child_yang_name == "global-neighbor-details"):
            if (self.global_neighbor_details is None):
                self.global_neighbor_details = Rsvp.GlobalNeighborDetails()
                self.global_neighbor_details.parent = self
                self._children_name_map["global_neighbor_details"] = "global-neighbor-details"
            return self.global_neighbor_details

        if (child_yang_name == "graceful-restart"):
            if (self.graceful_restart is None):
                self.graceful_restart = Rsvp.GracefulRestart()
                self.graceful_restart.parent = self
                self._children_name_map["graceful_restart"] = "graceful-restart"
            return self.graceful_restart

        if (child_yang_name == "hello-instance-briefs"):
            if (self.hello_instance_briefs is None):
                self.hello_instance_briefs = Rsvp.HelloInstanceBriefs()
                self.hello_instance_briefs.parent = self
                self._children_name_map["hello_instance_briefs"] = "hello-instance-briefs"
            return self.hello_instance_briefs

        if (child_yang_name == "hello-instance-details"):
            if (self.hello_instance_details is None):
                self.hello_instance_details = Rsvp.HelloInstanceDetails()
                self.hello_instance_details.parent = self
                self._children_name_map["hello_instance_details"] = "hello-instance-details"
            return self.hello_instance_details

        if (child_yang_name == "hello-interface-instance-briefs"):
            if (self.hello_interface_instance_briefs is None):
                self.hello_interface_instance_briefs = Rsvp.HelloInterfaceInstanceBriefs()
                self.hello_interface_instance_briefs.parent = self
                self._children_name_map["hello_interface_instance_briefs"] = "hello-interface-instance-briefs"
            return self.hello_interface_instance_briefs

        if (child_yang_name == "hello-interface-instance-details"):
            if (self.hello_interface_instance_details is None):
                self.hello_interface_instance_details = Rsvp.HelloInterfaceInstanceDetails()
                self.hello_interface_instance_details.parent = self
                self._children_name_map["hello_interface_instance_details"] = "hello-interface-instance-details"
            return self.hello_interface_instance_details

        if (child_yang_name == "interface-briefs"):
            if (self.interface_briefs is None):
                self.interface_briefs = Rsvp.InterfaceBriefs()
                self.interface_briefs.parent = self
                self._children_name_map["interface_briefs"] = "interface-briefs"
            return self.interface_briefs

        if (child_yang_name == "interface-detaileds"):
            if (self.interface_detaileds is None):
                self.interface_detaileds = Rsvp.InterfaceDetaileds()
                self.interface_detaileds.parent = self
                self._children_name_map["interface_detaileds"] = "interface-detaileds"
            return self.interface_detaileds

        if (child_yang_name == "interface-neighbor-briefs"):
            if (self.interface_neighbor_briefs is None):
                self.interface_neighbor_briefs = Rsvp.InterfaceNeighborBriefs()
                self.interface_neighbor_briefs.parent = self
                self._children_name_map["interface_neighbor_briefs"] = "interface-neighbor-briefs"
            return self.interface_neighbor_briefs

        if (child_yang_name == "interface-neighbor-details"):
            if (self.interface_neighbor_details is None):
                self.interface_neighbor_details = Rsvp.InterfaceNeighborDetails()
                self.interface_neighbor_details.parent = self
                self._children_name_map["interface_neighbor_details"] = "interface-neighbor-details"
            return self.interface_neighbor_details

        if (child_yang_name == "interface-summaries"):
            if (self.interface_summaries is None):
                self.interface_summaries = Rsvp.InterfaceSummaries()
                self.interface_summaries.parent = self
                self._children_name_map["interface_summaries"] = "interface-summaries"
            return self.interface_summaries

        if (child_yang_name == "issu"):
            if (self.issu is None):
                self.issu = Rsvp.Issu()
                self.issu.parent = self
                self._children_name_map["issu"] = "issu"
            return self.issu

        if (child_yang_name == "nsr"):
            if (self.nsr is None):
                self.nsr = Rsvp.Nsr()
                self.nsr.parent = self
                self._children_name_map["nsr"] = "nsr"
            return self.nsr

        if (child_yang_name == "open-config"):
            if (self.open_config is None):
                self.open_config = Rsvp.OpenConfig()
                self.open_config.parent = self
                self._children_name_map["open_config"] = "open-config"
            return self.open_config

        if (child_yang_name == "psb-briefs"):
            if (self.psb_briefs is None):
                self.psb_briefs = Rsvp.PsbBriefs()
                self.psb_briefs.parent = self
                self._children_name_map["psb_briefs"] = "psb-briefs"
            return self.psb_briefs

        if (child_yang_name == "psb-detaileds"):
            if (self.psb_detaileds is None):
                self.psb_detaileds = Rsvp.PsbDetaileds()
                self.psb_detaileds.parent = self
                self._children_name_map["psb_detaileds"] = "psb-detaileds"
            return self.psb_detaileds

        if (child_yang_name == "pxsb-details"):
            if (self.pxsb_details is None):
                self.pxsb_details = Rsvp.PxsbDetails()
                self.pxsb_details.parent = self
                self._children_name_map["pxsb_details"] = "pxsb-details"
            return self.pxsb_details

        if (child_yang_name == "request-briefs"):
            if (self.request_briefs is None):
                self.request_briefs = Rsvp.RequestBriefs()
                self.request_briefs.parent = self
                self._children_name_map["request_briefs"] = "request-briefs"
            return self.request_briefs

        if (child_yang_name == "request-details"):
            if (self.request_details is None):
                self.request_details = Rsvp.RequestDetails()
                self.request_details.parent = self
                self._children_name_map["request_details"] = "request-details"
            return self.request_details

        if (child_yang_name == "rsb-briefs"):
            if (self.rsb_briefs is None):
                self.rsb_briefs = Rsvp.RsbBriefs()
                self.rsb_briefs.parent = self
                self._children_name_map["rsb_briefs"] = "rsb-briefs"
            return self.rsb_briefs

        if (child_yang_name == "rsb-detaileds"):
            if (self.rsb_detaileds is None):
                self.rsb_detaileds = Rsvp.RsbDetaileds()
                self.rsb_detaileds.parent = self
                self._children_name_map["rsb_detaileds"] = "rsb-detaileds"
            return self.rsb_detaileds

        if (child_yang_name == "rxsb-details"):
            if (self.rxsb_details is None):
                self.rxsb_details = Rsvp.RxsbDetails()
                self.rxsb_details.parent = self
                self._children_name_map["rxsb_details"] = "rxsb-details"
            return self.rxsb_details

        if (child_yang_name == "session-briefs"):
            if (self.session_briefs is None):
                self.session_briefs = Rsvp.SessionBriefs()
                self.session_briefs.parent = self
                self._children_name_map["session_briefs"] = "session-briefs"
            return self.session_briefs

        if (child_yang_name == "session-detaileds"):
            if (self.session_detaileds is None):
                self.session_detaileds = Rsvp.SessionDetaileds()
                self.session_detaileds.parent = self
                self._children_name_map["session_detaileds"] = "session-detaileds"
            return self.session_detaileds

        if (child_yang_name == "summary"):
            if (self.summary is None):
                self.summary = Rsvp.Summary()
                self.summary.parent = self
                self._children_name_map["summary"] = "summary"
            return self.summary

        return None

    def has_leaf_or_child_of_name(self, name):
        if(name == "authentication-briefs" or name == "authentication-details" or name == "bw-pool-info" or name == "controller-briefs" or name == "controller-detaileds" or name == "controller-summaries" or name == "counters" or name == "frr-summary" or name == "frrs" or name == "global-neighbor-briefs" or name == "global-neighbor-details" or name == "graceful-restart" or name == "hello-instance-briefs" or name == "hello-instance-details" or name == "hello-interface-instance-briefs" or name == "hello-interface-instance-details" or name == "interface-briefs" or name == "interface-detaileds" or name == "interface-neighbor-briefs" or name == "interface-neighbor-details" or name == "interface-summaries" or name == "issu" or name == "nsr" or name == "open-config" or name == "psb-briefs" or name == "psb-detaileds" or name == "pxsb-details" or name == "request-briefs" or name == "request-details" or name == "rsb-briefs" or name == "rsb-detaileds" or name == "rxsb-details" or name == "session-briefs" or name == "session-detaileds" or name == "summary"):
            return True
        return False

    def set_value(self, value_path, value, name_space, name_space_prefix):
        pass

    def clone_ptr(self):
        self._top_entity = Rsvp()
        return self._top_entity

